Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
amns_data (alpha) |  |  |  | Atomic, molecular, nuclear and surface physics data. Each occurrence contains the data for a given element (nuclear charge), describing various physical processes. For each process, data tables are organized by charge states. The coordinate system used by the data tables is described under the coordinate_system node.
amns_data.a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
amns_data.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
amns_data.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
amns_data.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
amns_data.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
amns_data.code.library[:].name (alpha) |  | STR_0D |  | Name of software
amns_data.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
amns_data.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
amns_data.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
amns_data.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
amns_data.code.output_flag (alpha) | [amns_data.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
amns_data.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
amns_data.code.repository (alpha) |  | STR_0D |  | URL of software repository
amns_data.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
amns_data.coordinate_system (alpha) | [1...N] | STRUCT_ARRAY |  | Array of possible coordinate systems for process tables
amns_data.coordinate_system[:].coordinate (alpha) | [1...N] | STRUCT_ARRAY |  | Set of coordinates for that coordinate system. A coordinate an be either a range of real values or a set of discrete values (if interpolation_type=0)
amns_data.coordinate_system[:].coordinate[:].extrapolation_type (alpha) | [1...2] | INT_1D |  | Extrapolation strategy when leaving the domain. The first value of the vector describes the behaviour at lower bound, the second describes the at upper bound. Possible values: 0=none, report error; 1=boundary value; 2=linear extrapolation
amns_data.coordinate_system[:].coordinate[:].interpolation_type (alpha) |  | INT_0D |  | Interpolation strategy in this coordinate direction. Integer flag: 0=discrete (no interpolation); 1=linear; ...
amns_data.coordinate_system[:].coordinate[:].label (alpha) |  | STR_0D |  | Description of coordinate (e.g. "Electron temperature")
amns_data.coordinate_system[:].coordinate[:].spacing (alpha) |  | INT_0D |  | Flag for specific coordinate spacing (for optimization purposes). Integer flag: 0=undefined; 1=uniform; ...
amns_data.coordinate_system[:].coordinate[:].transformation (alpha) |  | INT_0D |  | Coordinate transformation applied to coordinate values stored in coord. Integer flag: 0=none; 1=log10; 2=ln
amns_data.coordinate_system[:].coordinate[:].units (alpha) |  | STR_0D |  | Units of coordinate (e.g. eV)
amns_data.coordinate_system[:].coordinate[:].value_labels (alpha) | [amns_data.coordinate_system[:].coordinate[:].values] | STR_1D |  | String description of discrete coordinate values (if interpolation_type=0). E.g., for spectroscopic lines, the spectroscopic description of the transition.
amns_data.coordinate_system[:].coordinate[:].values (alpha) | [1...N] | FLT_1D (uncertain) | units given by coordinate_system(:)/coordinate(:)/units | Coordinate values
amns_data.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
amns_data.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
amns_data.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
amns_data.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
amns_data.ids_properties.occurrence |  | INT_0D |  |
amns_data.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
amns_data.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
amns_data.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
amns_data.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
amns_data.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
amns_data.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
amns_data.process (alpha) | [1...N] | STRUCT_ARRAY |  | Description and data for a set of physical processes.
amns_data.process[:].charge_state (alpha) | [1...N] | STRUCT_ARRAY |  | Process tables for a set of charge states. Only one table is used for that process, defined by process(:)/table_dimension
amns_data.process[:].charge_state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
amns_data.process[:].charge_state[:].table_0d (alpha) |  | FLT_0D (uncertain) | units given by process(:)/results_units | 0D table describing the process data
amns_data.process[:].charge_state[:].table_1d (alpha) | [amns_data.coordinate_system[:].coordinate] | FLT_1D (uncertain) | units given by process(i1)/results_units | 1D table describing the process data
amns_data.process[:].charge_state[:].table_2d (alpha) | [amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate] | FLT_2D (uncertain) | units given by process(i1)/results_units | 2D table describing the process data
amns_data.process[:].charge_state[:].table_3d (alpha) | [amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate] | FLT_3D (uncertain) | units given by process(:)/results_units | 3D table describing the process data
amns_data.process[:].charge_state[:].table_4d (alpha) | [amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate] | FLT_4D (uncertain) | units given by process(i1)/results_units | 4D table describing the process data
amns_data.process[:].charge_state[:].table_5d (alpha) | [amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate] | FLT_5D (uncertain) | units given by process(i1)/results_units | 5D table describing the process data
amns_data.process[:].charge_state[:].table_6d (alpha) | [amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate, amns_data.coordinate_system[:].coordinate] | FLT_6D (uncertain) | units given by process(i1)/results_units | 6D table describing the process data
amns_data.process[:].charge_state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
amns_data.process[:].charge_state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
amns_data.process[:].citation (alpha) |  | STR_0D |  | Reference to publication(s)
amns_data.process[:].coordinate_index (alpha) |  | INT_0D |  | Index in tables_coord, specifying what coordinate systems to use for this process (valid for all tables)
amns_data.process[:].label (alpha) |  | STR_0D |  | String identifying the process (e.g. EI, RC, ...)
amns_data.process[:].products (alpha) | [1...N] | STRUCT_ARRAY |  | Set of products resulting of this process
amns_data.process[:].products[:].charge (alpha) |  | FLT_0D (uncertain) | - | Charge number of the participant
amns_data.process[:].products[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom (in such case, this array should be of size 1) or molecule. Mass of atom and nuclear charge should be set to 0 for photons and electrons. The mass of atom shouldn't be set for an atomic process that is not isotope dependent.
amns_data.process[:].products[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
amns_data.process[:].products[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
amns_data.process[:].products[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
amns_data.process[:].products[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
amns_data.process[:].products[:].label (alpha) |  | STR_0D |  | String identifying reaction participant (e.g. "D", "e", "W", "CD4", "photon", "n")
amns_data.process[:].products[:].mass (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of the participant
amns_data.process[:].products[:].metastable (alpha) | [1...N] | INT_1D |  | An array identifying the metastable; if zero-length, then not a metastable; if of length 1, then the value indicates the electronic level for the metastable (mostly used for atoms/ions); if of length 2, then the 1st would indicate the electronic level and the second the vibrational level for the metastable (mostly used for molecules and molecular ions); if of length 3, then the 1st would indicate the electronic level, the second the vibrational level and the third the rotational level for the metastable (mostly used for molecules and molecular ions)
amns_data.process[:].products[:].metastable_label (alpha) |  | STR_0D |  | Label identifying in text form the metastable
amns_data.process[:].products[:].multiplicity (alpha) |  | FLT_0D (uncertain) | - | Multiplicity in the reaction
amns_data.process[:].products[:].relative_charge (alpha) |  | INT_0D |  | This is a flag indicating that charges are absolute (if set to 0), relative (if 1) or irrelevant (-1); relative would be used to categorize the ionization reactions from i to i+1 for all charge states; in the case of bundles, the +1 relative indicates the next bundle
amns_data.process[:].products[:].role (alpha) |  | STRUCTURE |  | Identifier for the role of this paricipant in the reaction. For surface reactions distinguish between projectile and wall.
amns_data.process[:].products[:].role.description (alpha) |  | STR_0D |  | Verbose description
amns_data.process[:].products[:].role.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
amns_data.process[:].products[:].role.name (alpha) |  | STR_0D |  | Short string identifier
amns_data.process[:].provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
amns_data.process[:].reactants (alpha) | [1...N] | STRUCT_ARRAY |  | Set of reactants involved in this process
amns_data.process[:].reactants[:].charge (alpha) |  | FLT_0D (uncertain) | - | Charge number of the participant
amns_data.process[:].reactants[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom (in such case, this array should be of size 1) or molecule. Mass of atom and nuclear charge should be set to 0 for photons and electrons. The mass of atom shouldn't be set for an atomic process that is not isotope dependent.
amns_data.process[:].reactants[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
amns_data.process[:].reactants[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
amns_data.process[:].reactants[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
amns_data.process[:].reactants[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
amns_data.process[:].reactants[:].label (alpha) |  | STR_0D |  | String identifying reaction participant (e.g. "D", "e", "W", "CD4", "photon", "n")
amns_data.process[:].reactants[:].mass (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of the participant
amns_data.process[:].reactants[:].metastable (alpha) | [1...N] | INT_1D |  | An array identifying the metastable; if zero-length, then not a metastable; if of length 1, then the value indicates the electronic level for the metastable (mostly used for atoms/ions); if of length 2, then the 1st would indicate the electronic level and the second the vibrational level for the metastable (mostly used for molecules and molecular ions); if of length 3, then the 1st would indicate the electronic level, the second the vibrational level and the third the rotational level for the metastable (mostly used for molecules and molecular ions)
amns_data.process[:].reactants[:].metastable_label (alpha) |  | STR_0D |  | Label identifying in text form the metastable
amns_data.process[:].reactants[:].multiplicity (alpha) |  | FLT_0D (uncertain) | - | Multiplicity in the reaction
amns_data.process[:].reactants[:].relative_charge (alpha) |  | INT_0D |  | This is a flag indicating that charges are absolute (if set to 0), relative (if 1) or irrelevant (-1); relative would be used to categorize the ionization reactions from i to i+1 for all charge states; in the case of bundles, the +1 relative indicates the next bundle
amns_data.process[:].reactants[:].role (alpha) |  | STRUCTURE |  | Identifier for the role of this paricipant in the reaction. For surface reactions distinguish between projectile and wall.
amns_data.process[:].reactants[:].role.description (alpha) |  | STR_0D |  | Verbose description
amns_data.process[:].reactants[:].role.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
amns_data.process[:].reactants[:].role.name (alpha) |  | STR_0D |  | Short string identifier
amns_data.process[:].result_label (alpha) |  | STR_0D |  | Description of the process result (rate, cross section, sputtering yield, ...)
amns_data.process[:].result_transformation (alpha) |  | INT_0D |  | Transformation of the process result. Integer flag: 0=no transformation; 1=10^; 2=exp()
amns_data.process[:].result_units (alpha) |  | STR_0D |  | Units of the process result
amns_data.process[:].source (alpha) |  | STR_0D |  | Filename or subroutine name used to provide this data
amns_data.process[:].table_dimension (alpha) |  | INT_0D |  | Table dimensionality of the process (1 to 6), valid for all charge states. Indicates which of the tables is filled (below the charge_state node)
amns_data.release (alpha) | [1...N] | STRUCT_ARRAY |  | List of available releases of the AMNS data; each element contains information about the AMNS data that is included in the release. This part of the IDS is filled and stored only into shot/run=0/1, playing the role of a catalogue.
amns_data.release[:].data_entry (alpha) | [1...N] | STRUCT_ARRAY |  | For this release, list of each data item (i.e. shot/run pair containing the actual data) included in this release
amns_data.release[:].data_entry[:].description (alpha) |  | STR_0D |  | Description of this data entry
amns_data.release[:].data_entry[:].run (alpha) |  | INT_0D |  | Which run number is the active run number for this version
amns_data.release[:].data_entry[:].shot (alpha) |  | INT_0D |  | Shot number = Mass*1000+Nuclear_charge
amns_data.release[:].date (alpha) |  | STR_0D |  | Date of this release
amns_data.release[:].description (alpha) |  | STR_0D |  | Description of this release
amns_data.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
amns_data.z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
barometry (alpha) |  |  |  | Pressure measurements in the vacuum vessel. NB will need to change the type of the pressure node to signal_1d when moving to the new LL.
barometry.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
barometry.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
barometry.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
barometry.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
barometry.code.library[:].name (alpha) |  | STR_0D |  | Name of software
barometry.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
barometry.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
barometry.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
barometry.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
barometry.code.output_flag (alpha) | [barometry.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
barometry.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
barometry.code.repository (alpha) |  | STR_0D |  | URL of software repository
barometry.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
barometry.gauge (alpha) | [1...N] | STRUCT_ARRAY |  | Set of gauges
barometry.gauge[:].calibration_coefficient (alpha) |  | FLT_0D (uncertain) | Pa | Coefficient used for converting raw signal into absolute pressure
barometry.gauge[:].name (alpha) |  | STR_0D |  | Name of the gauge
barometry.gauge[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
barometry.gauge[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
barometry.gauge[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
barometry.gauge[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
barometry.gauge[:].pressure (alpha) |  | STRUCTURE | Pa | Pressure
barometry.gauge[:].pressure.data (alpha) | [barometry.gauge[:].pressure.time] | FLT_1D (uncertain) | Pa | Data
barometry.gauge[:].pressure.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
barometry.gauge[:].type (alpha) |  | STRUCTURE |  | Type of the gauge (index = 1: Penning; index = 2: Baratron)
barometry.gauge[:].type.description (alpha) |  | STR_0D |  | Verbose description
barometry.gauge[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
barometry.gauge[:].type.name (alpha) |  | STR_0D |  | Short string identifier
barometry.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
barometry.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
barometry.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
barometry.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
barometry.ids_properties.occurrence |  | INT_0D |  |
barometry.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
barometry.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
barometry.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
barometry.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
barometry.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
barometry.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
barometry.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
bolometer (alpha) |  |  |  | Bolometer diagnostic
bolometer.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
bolometer.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
bolometer.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
bolometer.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bolometer.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
bolometer.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
bolometer.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
bolometer.channel[:].aperture[:].outline.x2 (alpha) | [bolometer.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
bolometer.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
bolometer.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
bolometer.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
bolometer.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
bolometer.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
bolometer.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
bolometer.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
bolometer.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
bolometer.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
bolometer.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bolometer.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
bolometer.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
bolometer.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
bolometer.channel[:].detector.outline.x2 (alpha) | [bolometer.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
bolometer.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
bolometer.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
bolometer.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
bolometer.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
bolometer.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
bolometer.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
bolometer.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
bolometer.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].etendue (alpha) |  | FLT_0D (uncertain) | m^2.sr | Etendue (geometric extent) of the channel's optical system
bolometer.channel[:].etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
bolometer.channel[:].etendue_method.description (alpha) |  | STR_0D |  | Verbose description
bolometer.channel[:].etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
bolometer.channel[:].etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
bolometer.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
bolometer.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the reference line of sight of the channel, defined by two points when the beam is not reflected, a third point is added to define the reflected beam path
bolometer.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
bolometer.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bolometer.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
bolometer.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bolometer.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].line_of_sight.third_point (alpha) |  | STRUCTURE |  | Position of the third point
bolometer.channel[:].line_of_sight.third_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bolometer.channel[:].line_of_sight.third_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.third_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
bolometer.channel[:].power (alpha) |  | STRUCTURE | W | Power received on the detector
bolometer.channel[:].power.data (alpha) | [bolometer.channel[:].power.time] | FLT_1D (uncertain) | W | Data
bolometer.channel[:].power.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
bolometer.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
bolometer.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
bolometer.channel[:].validity_timed.data (alpha) | [bolometer.channel[:].validity_timed.time] | INT_1D |  | Data
bolometer.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
bolometer.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
bolometer.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
bolometer.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
bolometer.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
bolometer.code.library[:].name (alpha) |  | STR_0D |  | Name of software
bolometer.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
bolometer.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
bolometer.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
bolometer.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
bolometer.code.output_flag (alpha) | [bolometer.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
bolometer.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
bolometer.code.repository (alpha) |  | STR_0D |  | URL of software repository
bolometer.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
bolometer.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
bolometer.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
bolometer.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
bolometer.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
bolometer.ids_properties.occurrence |  | INT_0D |  |
bolometer.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
bolometer.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
bolometer.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
bolometer.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
bolometer.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
bolometer.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
bolometer.power_radiated_inside_lcfs (alpha) | [bolometer.time] | FLT_1D (uncertain) | W | Radiated power from the plasma inside the Last Closed Flux Surface, reconstructed from bolometry data
bolometer.power_radiated_total (alpha) | [bolometer.time] | FLT_1D (uncertain) | W | Total radiated power reconstructed from bolometry data
bolometer.power_radiated_validity (alpha) | [bolometer.time] | INT_1D |  | Validity flag related to the radiated power reconstructions
bolometer.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
bremsstrahlung_visible (alpha) |  |  |  | Diagnostic for measuring the bremsstrahlung from thermal particules in the visible light range, in view of determining the effective charge of the plasma.
bremsstrahlung_visible.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
bremsstrahlung_visible.channel[:].filter (alpha) |  | STRUCTURE |  | Filter wavelength range and detection efficiency
bremsstrahlung_visible.channel[:].filter.detection_efficiency (alpha) | [bremsstrahlung_visible.channel[:].filter.wavelengths] | FLT_1D (uncertain) | - | Probability of detection of a photon impacting the detector as a function of its wavelength
bremsstrahlung_visible.channel[:].filter.wavelength_lower (alpha) |  | FLT_0D (uncertain) | m | Lower bound of the filter wavelength range
bremsstrahlung_visible.channel[:].filter.wavelength_upper (alpha) |  | FLT_0D (uncertain) | m | Upper bound of the filter wavelength range
bremsstrahlung_visible.channel[:].filter.wavelengths (alpha) | [1...N] | FLT_1D (uncertain) | m | Array of wavelength values
bremsstrahlung_visible.channel[:].intensity (alpha) |  | STRUCTURE | (counts) s^-1 | Intensity, i.e. number of photoelectrons detected by unit time, taking into account electronic gain compensation and channels relative calibration
bremsstrahlung_visible.channel[:].intensity.data (alpha) | [bremsstrahlung_visible.channel[:].intensity.time] | FLT_1D (uncertain) | (counts) s^-1 | Data
bremsstrahlung_visible.channel[:].intensity.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
bremsstrahlung_visible.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
bremsstrahlung_visible.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
bremsstrahlung_visible.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bremsstrahlung_visible.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bremsstrahlung_visible.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bremsstrahlung_visible.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
bremsstrahlung_visible.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
bremsstrahlung_visible.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bremsstrahlung_visible.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bremsstrahlung_visible.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
bremsstrahlung_visible.channel[:].radiance_spectral (alpha) |  | STRUCTURE | (photons).m^-2.s^-1.sr^-1.m^-1 | Calibrated spectral radiance (radiance per unit wavelength)
bremsstrahlung_visible.channel[:].radiance_spectral.data (alpha) | [bremsstrahlung_visible.channel[:].radiance_spectral.time] | FLT_1D (uncertain) | (photons).m^-2.s^-1.sr^-1.m^-1 | Data
bremsstrahlung_visible.channel[:].radiance_spectral.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
bremsstrahlung_visible.channel[:].zeff_line_average (alpha) |  | STRUCTURE | - | Average effective charge along the line of sight
bremsstrahlung_visible.channel[:].zeff_line_average.data (alpha) | [bremsstrahlung_visible.channel[:].zeff_line_average.time] | FLT_1D (uncertain) | - | Data
bremsstrahlung_visible.channel[:].zeff_line_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
bremsstrahlung_visible.channel[:].zeff_line_average.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
bremsstrahlung_visible.channel[:].zeff_line_average.validity_timed (alpha) | [bremsstrahlung_visible.channel[:].zeff_line_average.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
bremsstrahlung_visible.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
bremsstrahlung_visible.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
bremsstrahlung_visible.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
bremsstrahlung_visible.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
bremsstrahlung_visible.code.library[:].name (alpha) |  | STR_0D |  | Name of software
bremsstrahlung_visible.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
bremsstrahlung_visible.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
bremsstrahlung_visible.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
bremsstrahlung_visible.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
bremsstrahlung_visible.code.output_flag (alpha) | [bremsstrahlung_visible.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
bremsstrahlung_visible.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
bremsstrahlung_visible.code.repository (alpha) |  | STR_0D |  | URL of software repository
bremsstrahlung_visible.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
bremsstrahlung_visible.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
bremsstrahlung_visible.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
bremsstrahlung_visible.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
bremsstrahlung_visible.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
bremsstrahlung_visible.ids_properties.occurrence |  | INT_0D |  |
bremsstrahlung_visible.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
bremsstrahlung_visible.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
bremsstrahlung_visible.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
bremsstrahlung_visible.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
bremsstrahlung_visible.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
bremsstrahlung_visible.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
bremsstrahlung_visible.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
calorimetry (alpha) |  |  |  | Calometry measurements on various tokamak subsystems
calorimetry.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
calorimetry.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
calorimetry.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
calorimetry.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
calorimetry.code.library[:].name (alpha) |  | STR_0D |  | Name of software
calorimetry.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
calorimetry.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
calorimetry.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
calorimetry.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
calorimetry.code.output_flag (alpha) | [calorimetry.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
calorimetry.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
calorimetry.code.repository (alpha) |  | STR_0D |  | URL of software repository
calorimetry.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
calorimetry.cooling_loop (alpha) | [1...N] | STRUCT_ARRAY |  | Set of cooling loops
calorimetry.cooling_loop[:].identifier (alpha) |  | STR_0D |  | ID of the loop
calorimetry.cooling_loop[:].mass_flow (alpha) |  | STRUCTURE | kg.s^-1 | Mass flow of the coolant going through the loop
calorimetry.cooling_loop[:].mass_flow.data (alpha) | [calorimetry.cooling_loop[:].mass_flow.time] | FLT_1D (uncertain) | kg.s^-1 | Data
calorimetry.cooling_loop[:].mass_flow.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.cooling_loop[:].mass_flow.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.cooling_loop[:].mass_flow.validity_timed (alpha) | [calorimetry.cooling_loop[:].mass_flow.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.cooling_loop[:].name (alpha) |  | STR_0D |  | Name of the loop
calorimetry.cooling_loop[:].temperature_in (alpha) |  | STRUCTURE | K | Temperature of the coolant when entering the loop
calorimetry.cooling_loop[:].temperature_in.data (alpha) | [calorimetry.cooling_loop[:].temperature_in.time] | FLT_1D (uncertain) | K | Data
calorimetry.cooling_loop[:].temperature_in.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.cooling_loop[:].temperature_in.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.cooling_loop[:].temperature_in.validity_timed (alpha) | [calorimetry.cooling_loop[:].temperature_in.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.cooling_loop[:].temperature_out (alpha) |  | STRUCTURE | K | Temperature of the coolant when exiting the loop
calorimetry.cooling_loop[:].temperature_out.data (alpha) | [calorimetry.cooling_loop[:].temperature_out.time] | FLT_1D (uncertain) | K | Data
calorimetry.cooling_loop[:].temperature_out.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.cooling_loop[:].temperature_out.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.cooling_loop[:].temperature_out.validity_timed (alpha) | [calorimetry.cooling_loop[:].temperature_out.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group (alpha) | [1...N] | STRUCT_ARRAY |  | Set of groups of components on which calorimetry measurements are carried out (grouped by tokamak subsystems or localisation on the machine)
calorimetry.group[:].component (alpha) | [1...N] | STRUCT_ARRAY |  | Set of components on which calorimetry measurements are carried out
calorimetry.group[:].component[:].energy_cumulated (alpha) |  | STRUCTURE | J | Energy extracted from the component since the start of the pulse
calorimetry.group[:].component[:].energy_cumulated.data (alpha) | [calorimetry.group[:].component[:].energy_cumulated.time] | FLT_1D (uncertain) | J | Data
calorimetry.group[:].component[:].energy_cumulated.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].energy_cumulated.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].energy_cumulated.validity_timed (alpha) | [calorimetry.group[:].component[:].energy_cumulated.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].energy_total (alpha) |  | FLT_0D (uncertain) | J | Energy extracted from the component on the whole plasma discharge, including the return to thermal equilibrium of the component in the post-pulse phase
calorimetry.group[:].component[:].identifier (alpha) |  | STR_0D |  | ID of the component
calorimetry.group[:].component[:].mass_flow (alpha) |  | STRUCTURE | kg.s^-1 | Mass flow of the coolant going through the component
calorimetry.group[:].component[:].mass_flow.data (alpha) | [calorimetry.group[:].component[:].mass_flow.time] | FLT_1D (uncertain) | kg.s^-1 | Data
calorimetry.group[:].component[:].mass_flow.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].mass_flow.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].mass_flow.validity_timed (alpha) | [calorimetry.group[:].component[:].mass_flow.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].name (alpha) |  | STR_0D |  | Name of the component
calorimetry.group[:].component[:].power (alpha) |  | STRUCTURE | W | Power extracted from the component
calorimetry.group[:].component[:].power.data (alpha) | [calorimetry.group[:].component[:].power.time] | FLT_1D (uncertain) | W | Data
calorimetry.group[:].component[:].power.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].power.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].power.validity_timed (alpha) | [calorimetry.group[:].component[:].power.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].temperature_in (alpha) |  | STRUCTURE | K | Temperature of the coolant when entering the component
calorimetry.group[:].component[:].temperature_in.data (alpha) | [calorimetry.group[:].component[:].temperature_in.time] | FLT_1D (uncertain) | K | Data
calorimetry.group[:].component[:].temperature_in.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].temperature_in.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].temperature_in.validity_timed (alpha) | [calorimetry.group[:].component[:].temperature_in.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].temperature_out (alpha) |  | STRUCTURE | K | Temperature of the coolant when exiting the component
calorimetry.group[:].component[:].temperature_out.data (alpha) | [calorimetry.group[:].component[:].temperature_out.time] | FLT_1D (uncertain) | K | Data
calorimetry.group[:].component[:].temperature_out.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].temperature_out.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].temperature_out.validity_timed (alpha) | [calorimetry.group[:].component[:].temperature_out.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].transit_time (alpha) |  | STRUCTURE | s | Transit time for the coolant to go from the input to the output of the component
calorimetry.group[:].component[:].transit_time.data (alpha) | [calorimetry.group[:].component[:].transit_time.time] | FLT_1D (uncertain) | s | Data
calorimetry.group[:].component[:].transit_time.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
calorimetry.group[:].component[:].transit_time.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].component[:].transit_time.validity_timed (alpha) | [calorimetry.group[:].component[:].transit_time.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
calorimetry.group[:].identifier (alpha) |  | STR_0D |  | ID of the group
calorimetry.group[:].name (alpha) |  | STR_0D |  | Name of the group
calorimetry.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
calorimetry.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
calorimetry.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
calorimetry.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
calorimetry.ids_properties.occurrence |  | INT_0D |  |
calorimetry.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
calorimetry.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
calorimetry.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
calorimetry.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
calorimetry.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
calorimetry.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
calorimetry.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
camera_ir (alpha) |  |  |  | Infrared camera for monitoring of Plasma Facing Components
camera_ir.calibration (alpha) |  | STRUCTURE |  | Calibration data
camera_ir.calibration.luminance_to_temperature (alpha) | [1...N, 1...2] | INT_2D |  | Luminance to temperature conversion table
camera_ir.calibration.optical_temperature (alpha) | [1...N, 1...N] | INT_2D |  | Temperature of the optical components (digital levels)
camera_ir.calibration.transmission_barrel (alpha) | [1...N, 1...N] | INT_2D |  | Transmission of the optical barrel
camera_ir.calibration.transmission_mirror (alpha) | [1...N, 1...N] | INT_2D |  | Transmission of the mirror
camera_ir.calibration.transmission_window (alpha) | [1...N, 1...N] | INT_2D |  | Transmission of the window
camera_ir.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
camera_ir.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
camera_ir.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
camera_ir.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
camera_ir.code.library[:].name (alpha) |  | STR_0D |  | Name of software
camera_ir.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
camera_ir.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
camera_ir.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
camera_ir.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
camera_ir.code.output_flag (alpha) | [camera_ir.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
camera_ir.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
camera_ir.code.repository (alpha) |  | STR_0D |  | URL of software repository
camera_ir.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
camera_ir.frame (alpha) | [camera_ir.frame[:].time] | STRUCT_ARRAY |  | Set of frames
camera_ir.frame[:].image_raw (alpha) | [1...N, 1...N] | INT_2D |  | Raw image (unprocessed) (digital levels). First dimension : line index (horizontal axis). Second dimension: column index (vertical axis).
camera_ir.frame[:].time (alpha) |  | FLT_0D | s | Time
camera_ir.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
camera_ir.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
camera_ir.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
camera_ir.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
camera_ir.ids_properties.occurrence |  | INT_0D |  |
camera_ir.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
camera_ir.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
camera_ir.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
camera_ir.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
camera_ir.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
camera_ir.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
camera_ir.name (alpha) |  | STR_0D |  | Name of the camera
camera_ir.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
camera_visible (alpha) |  |  |  | Camera in the visible light range
camera_visible.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (a front aperture, possibly followed by others, viewing the plasma recorded by one or more detectors e.g. for different wavelength ranges)
camera_visible.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of apertures between plasma and the detectors (position, outline shape and orientation)
camera_visible.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
camera_visible.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
camera_visible.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
camera_visible.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
camera_visible.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
camera_visible.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
camera_visible.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
camera_visible.channel[:].aperture[:].outline.x2 (alpha) | [camera_visible.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
camera_visible.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
camera_visible.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
camera_visible.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
camera_visible.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
camera_visible.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
camera_visible.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
camera_visible.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
camera_visible.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
camera_visible.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
camera_visible.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
camera_visible.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
camera_visible.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
camera_visible.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
camera_visible.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
camera_visible.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
camera_visible.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
camera_visible.channel[:].detector (alpha) | [1...N] | STRUCT_ARRAY |  | Set of detectors
camera_visible.channel[:].detector[:].counts_to_radiance (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | photons.m^-2.s^-1.sr^-1.counts^-1 | Counts to radiance factor, for each pixel of the detector. Includes both the transmission losses in the relay optics and the quantum efficiency of the camera itself, integrated over the wavelength range
camera_visible.channel[:].detector[:].exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
camera_visible.channel[:].detector[:].frame (alpha) | [camera_visible.channel[:].detector[:].frame[:].time] | STRUCT_ARRAY |  | Set of frames
camera_visible.channel[:].detector[:].frame[:].image_raw (alpha) | [1...N, 1...N] | INT_2D |  | Raw image (unprocessed) (digital levels). First dimension : line index (horizontal axis). Second dimension: column index (vertical axis).
camera_visible.channel[:].detector[:].frame[:].radiance (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | photons.m^-2.s^-1.sr^-1 | Radiance image. First dimension : line index (horizontal axis). Second dimension: column index (vertical axis).
camera_visible.channel[:].detector[:].frame[:].time (alpha) |  | FLT_0D | s | Time
camera_visible.channel[:].detector[:].geometry_matrix (alpha) |  | STRUCTURE |  | Description of geometry matrix (ray transfer matrix)
camera_visible.channel[:].detector[:].geometry_matrix.data (alpha) | [1...N, 1...N, camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.r, camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.z, camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.phi] | FLT_5D (uncertain) | m | The Ray Transfer Matrix (RTM, or geometry matrix) here provides transformation of the signal from each individual unit light source (voxel) to each pixel of the receiver (detector). The emission profile has [photons.m^-3.s^-1.sr^-1] units and radiance signal has [photons.m^-2.s^-1.sr^-1] units. So the RTM has [m] units. The first two dimension correspond to the detector pixels : first dimension : line index (horizontal axis); second dimension: column index (vertical axis). The last three dimensions correspond to the light emission grid : Third dimension: Major radius. Fourth dimension: Height. Fifth dimension: Toroidal angle.
camera_visible.channel[:].detector[:].geometry_matrix.emission_grid (alpha) |  | STRUCTURE |  | Grid defining the light emission cells
camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.phi (alpha) | [camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.z (alpha) | [camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.r] | FLT_1D (uncertain) | m | Height
camera_visible.channel[:].detector[:].geometry_matrix.voxel_map (alpha) | [camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.r, camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.z, camera_visible.channel[:].detector[:].geometry_matrix.emission_grid.phi] | INT_3D |  | Voxel map for geometry matrix. The cells with same number are merged in the computation into a single emission source meta-cell. Cells with number -1 are excluded. Count starts from 0.
camera_visible.channel[:].detector[:].noise (alpha) |  | FLT_0D (uncertain) | - | Detector noise (e.g. read-out noise) (rms counts per second exposure time)
camera_visible.channel[:].detector[:].pixel_to_alpha (alpha) | [1...N] | FLT_1D (uncertain) | rad | Alpha angle of each pixel in the horizontal axis
camera_visible.channel[:].detector[:].pixel_to_beta (alpha) | [1...N] | FLT_1D (uncertain) | rad | Beta angle of each pixel in the vertical axis
camera_visible.channel[:].detector[:].wavelength_lower (alpha) |  | FLT_0D (uncertain) | m | Lower bound of the detector wavelength range
camera_visible.channel[:].detector[:].wavelength_upper (alpha) |  | FLT_0D (uncertain) | m | Upper bound of the detector wavelength range
camera_visible.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
camera_visible.channel[:].viewing_angle_alpha_bounds (alpha) | [1...2] | FLT_1D (uncertain) | rad | Minimum and maximum values of alpha angle of the field of view, where alpha is the agle between the axis X3 and projection of the chord of view on the plane X1X3 counted clockwise from the top view of X2 axis. X1, X2, X3 are the ones of the first aperture (i.e. the closest to the plasma).
camera_visible.channel[:].viewing_angle_beta_bounds (alpha) | [1...2] | FLT_1D (uncertain) | rad | Minimum and maximum values of beta angle of the field of view, where beta is the angle between the axis X3 and projection of the chord of view on the plane X2X3 counted clockwise from the top view of X1 axis. X1, X2, X3 are the ones of the first aperture (i.e. the closest to the plasma).
camera_visible.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
camera_visible.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
camera_visible.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
camera_visible.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
camera_visible.code.library[:].name (alpha) |  | STR_0D |  | Name of software
camera_visible.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
camera_visible.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
camera_visible.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
camera_visible.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
camera_visible.code.output_flag (alpha) | [camera_visible.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
camera_visible.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
camera_visible.code.repository (alpha) |  | STR_0D |  | URL of software repository
camera_visible.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
camera_visible.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
camera_visible.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
camera_visible.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
camera_visible.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
camera_visible.ids_properties.occurrence |  | INT_0D |  |
camera_visible.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
camera_visible.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
camera_visible.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
camera_visible.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
camera_visible.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
camera_visible.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
camera_visible.name (alpha) |  | STR_0D |  | Name of the camera
camera_visible.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
charge_exchange (alpha) |  |  |  | Charge exchange spectroscopy diagnostic
charge_exchange.aperture (alpha) |  | STRUCTURE |  | Description of the collimating aperture of the diagnostic, relevant to all lines-of-sight (channels)
charge_exchange.aperture.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
charge_exchange.aperture.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
charge_exchange.aperture.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
charge_exchange.aperture.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
charge_exchange.aperture.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
charge_exchange.aperture.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
charge_exchange.aperture.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
charge_exchange.aperture.outline.x2 (alpha) | [charge_exchange.aperture.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
charge_exchange.aperture.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
charge_exchange.aperture.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
charge_exchange.aperture.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
charge_exchange.aperture.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
charge_exchange.aperture.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
charge_exchange.aperture.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
charge_exchange.aperture.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
charge_exchange.aperture.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
charge_exchange.aperture.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
charge_exchange.aperture.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
charge_exchange.aperture.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
charge_exchange.aperture.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
charge_exchange.aperture.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
charge_exchange.aperture.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
charge_exchange.aperture.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
charge_exchange.aperture.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
charge_exchange.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight). The line-of-sight is defined by the centre of the collimating aperture and the position of the measurements.
charge_exchange.channel[:].bes (alpha) |  | STRUCTURE |  | Derived Beam Emission Spectroscopy (BES) parameters
charge_exchange.channel[:].bes.a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom of the diagnostic neutral beam particle
charge_exchange.channel[:].bes.doppler_shift (alpha) |  | STRUCTURE | m | Doppler shift due to the diagnostic neutral beam particle velocity
charge_exchange.channel[:].bes.doppler_shift.data (alpha) | [charge_exchange.channel[:].bes.doppler_shift.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].bes.doppler_shift.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].bes.label (alpha) |  | STR_0D |  | String identifying the diagnostic neutral beam particle
charge_exchange.channel[:].bes.lorentz_shift (alpha) |  | STRUCTURE | m | Lorentz shift due to the Lorentz electric field (vxB) in the frame of the diagnostic neutral beam particles moving with a velocity v across the magnetic field B
charge_exchange.channel[:].bes.lorentz_shift.data (alpha) | [charge_exchange.channel[:].bes.lorentz_shift.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].bes.lorentz_shift.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].bes.radiances (alpha) | [1...9, charge_exchange.channel[:].bes.radiances.time] | STRUCTURE | (photons) m^-2.s^-1.sr^-1 | Calibrated intensities of the 9 splitted lines (Stark effect due to Lorentz electric field). Note: radiances are integrated over the sightline crossing the neutral beam
charge_exchange.channel[:].bes.radiances.data (alpha) | [1...N, charge_exchange.channel[:].bes.radiances.time] | FLT_2D (uncertain) | (photons) m^-2.s^-1.sr^-1 | Data
charge_exchange.channel[:].bes.radiances.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].bes.transition_wavelength (alpha) |  | FLT_0D (uncertain) | m | Unshifted wavelength of the BES transition
charge_exchange.channel[:].bes.z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge of the diagnostic neutral beam particle
charge_exchange.channel[:].bes.z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge of the diagnostic neutral beam particle
charge_exchange.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
charge_exchange.channel[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Physical quantities related to ion species and charge stage (H+, D+, T+, He+2, Li+3, Be+4, C+6, N+7, O+8, Ne+10, Si+14, Ar+16 or Ar+18) derived from the measured charge exchange emission of each species, at the position of the measurement
charge_exchange.channel[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom of the ion
charge_exchange.channel[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the ion (e.g. H+, D+, T+, He+2, C+6, ...)
charge_exchange.channel[:].ion[:].n_i_over_n_e (alpha) |  | STRUCTURE | - | Ion concentration (ratio of the ion density over the electron density) at the channel measurement point
charge_exchange.channel[:].ion[:].n_i_over_n_e.data (alpha) | [charge_exchange.channel[:].ion[:].n_i_over_n_e.time] | FLT_1D (uncertain) | - | Data
charge_exchange.channel[:].ion[:].n_i_over_n_e.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].ion[:].n_i_over_n_e_method (alpha) |  | STRUCTURE |  | Description of the method used to derive the ion concentration
charge_exchange.channel[:].ion[:].n_i_over_n_e_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].ion[:].n_i_over_n_e_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].ion[:].n_i_over_n_e_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].ion[:].t_i (alpha) |  | STRUCTURE | eV | Ion temperature at the channel measurement point
charge_exchange.channel[:].ion[:].t_i.data (alpha) | [charge_exchange.channel[:].ion[:].t_i.time] | FLT_1D (uncertain) | eV | Data
charge_exchange.channel[:].ion[:].t_i.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].ion[:].t_i_method (alpha) |  | STRUCTURE |  | Description of the method used to derive the ion temperature
charge_exchange.channel[:].ion[:].t_i_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].ion[:].t_i_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].ion[:].t_i_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].ion[:].velocity_pol (alpha) |  | STRUCTURE | m.s^-1 | Poloidal velocity of the ion (oriented clockwise when seen from front on the right side of the tokamak axi-symmetry axis) at the channel measurement point
charge_exchange.channel[:].ion[:].velocity_pol.data (alpha) | [charge_exchange.channel[:].ion[:].velocity_pol.time] | FLT_1D (uncertain) | m.s^-1 | Data
charge_exchange.channel[:].ion[:].velocity_pol.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].ion[:].velocity_pol_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the ion poloidal velocity
charge_exchange.channel[:].ion[:].velocity_pol_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].ion[:].velocity_pol_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].ion[:].velocity_pol_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].ion[:].velocity_tor (alpha) |  | STRUCTURE | m.s^-1 | Toroidal velocity of the ion (oriented counter-clockwise when seen from above) at the channel measurement point
charge_exchange.channel[:].ion[:].velocity_tor.data (alpha) | [charge_exchange.channel[:].ion[:].velocity_tor.time] | FLT_1D (uncertain) | m.s^-1 | Data
charge_exchange.channel[:].ion[:].velocity_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].ion[:].velocity_tor_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the ion toroidal velocity
charge_exchange.channel[:].ion[:].velocity_tor_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].ion[:].velocity_tor_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].ion[:].velocity_tor_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge
charge_exchange.channel[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
charge_exchange.channel[:].ion_fast (alpha) | [1...N] | STRUCT_ARRAY |  | Derived Fast Ion Charge eXchange (FICX) parameters
charge_exchange.channel[:].ion_fast[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom of the fast ion
charge_exchange.channel[:].ion_fast[:].label (alpha) |  | STR_0D |  | String identifying the fast ion (e.g. H+, D+, T+, He+2, C+6, ...)
charge_exchange.channel[:].ion_fast[:].radiance (alpha) |  | STRUCTURE | (photons) m^-2.s^-1.sr^-1 | Calibrated radiance of the fast ion charge exchange spectrum assuming the shape is pre-defined (e.g. by the Fokker-Planck slowing-down function). Note: radiance is integrated over the sightline crossing the neutral beam
charge_exchange.channel[:].ion_fast[:].radiance.data (alpha) | [charge_exchange.channel[:].ion_fast[:].radiance.time] | FLT_1D (uncertain) | (photons) m^-2.s^-1.sr^-1 | Data
charge_exchange.channel[:].ion_fast[:].radiance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].ion_fast[:].radiance_spectral_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the fast ion charge exchange spectrum (e.g. what pre-defined slowing-down and source functions used)
charge_exchange.channel[:].ion_fast[:].radiance_spectral_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].ion_fast[:].radiance_spectral_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].ion_fast[:].radiance_spectral_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].ion_fast[:].transition_wavelength (alpha) |  | FLT_0D (uncertain) | m | Unshifted wavelength of the fast ion charge exchange transition
charge_exchange.channel[:].ion_fast[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Fast ion charge
charge_exchange.channel[:].ion_fast[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge of the fast ion
charge_exchange.channel[:].momentum_tor (alpha) |  | STRUCTURE | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi), at the channel measurement point
charge_exchange.channel[:].momentum_tor.data (alpha) | [charge_exchange.channel[:].momentum_tor.time] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Data
charge_exchange.channel[:].momentum_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].momentum_tor_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the total plasma toroidal momentum
charge_exchange.channel[:].momentum_tor_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].momentum_tor_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].momentum_tor_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
charge_exchange.channel[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
charge_exchange.channel[:].position.phi (alpha) |  | STRUCTURE | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
charge_exchange.channel[:].position.phi.data (alpha) | [charge_exchange.channel[:].position.phi.time] | FLT_1D (uncertain) | rad | Data
charge_exchange.channel[:].position.phi.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].position.r (alpha) |  | STRUCTURE | m | Major radius
charge_exchange.channel[:].position.r.data (alpha) | [charge_exchange.channel[:].position.r.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].position.r.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].position.z (alpha) |  | STRUCTURE | m | Height
charge_exchange.channel[:].position.z.data (alpha) | [charge_exchange.channel[:].position.z.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].position.z.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum (alpha) | [1...N] | STRUCT_ARRAY |  | Set of spectra obtained by various gratings
charge_exchange.channel[:].spectrum[:].exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
charge_exchange.channel[:].spectrum[:].grating (alpha) |  | FLT_0D (uncertain) | m^-1 | Number of grating lines per unit length
charge_exchange.channel[:].spectrum[:].instrument_function (alpha) | [1...2, 1...N] | FLT_2D (uncertain) | m | Array of Gaussian widths and amplitudes which as a sum make up the instrument fuction. IF(lambda) = sum( instrument_function(1,i)/sqrt(2 * pi * instrument_function(2,i)^2 ) * exp( -lambda^2/(2 * instrument_function(2,i)^2) ) ),whereby sum( instrument_function(1,i) ) = 1
charge_exchange.channel[:].spectrum[:].intensity_spectrum (alpha) | [charge_exchange.channel[:].spectrum[:].wavelengths, charge_exchange.channel[:].spectrum[:].intensity_spectrum.time] | STRUCTURE | (photoelectrons).s^-1 | Intensity spectrum (not calibrated), i.e. number of photoelectrons detected by unit time by a wavelength pixel of the channel, taking into account electronic gain compensation and channels relative calibration
charge_exchange.channel[:].spectrum[:].intensity_spectrum.data (alpha) | [1...N, charge_exchange.channel[:].spectrum[:].intensity_spectrum.time] | FLT_2D (uncertain) | (photoelectrons).s^-1 | Data
charge_exchange.channel[:].spectrum[:].intensity_spectrum.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].processed_line (alpha) | [1...N] | STRUCT_ARRAY |  | Set of processed spectral lines
charge_exchange.channel[:].spectrum[:].processed_line[:].intensity (alpha) |  | STRUCTURE | (photonelectrons).s^-1 | Non-calibrated intensity (integrated over the spectrum for this line), i.e. number of photoelectrons detected by unit time, taking into account electronic gain compensation and channels relative calibration
charge_exchange.channel[:].spectrum[:].processed_line[:].intensity.data (alpha) | [charge_exchange.channel[:].spectrum[:].processed_line[:].intensity.time] | FLT_1D (uncertain) | (photonelectrons).s^-1 | Data
charge_exchange.channel[:].spectrum[:].processed_line[:].intensity.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].processed_line[:].label (alpha) |  | STR_0D |  | String identifying the processed spectral line: Spectroscopy notation emitting element (e.g. D I, Be IV, W I, C VI), transition - if known - between round brackets (e.g. (3-2) ) and indication type of charge exchange - if applicable - between square brackets (e.g. [ACX] or [PCX]). Example for beryllium active charge exchange line at 468.5 nm: 'Be IV (8-6) [ACX]'. Example for impact excitation tungsten line coming from the plasma edge: 'W I'
charge_exchange.channel[:].spectrum[:].processed_line[:].radiance (alpha) |  | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated, background subtracted radiance (integrated over the spectrum for this line)
charge_exchange.channel[:].spectrum[:].processed_line[:].radiance.data (alpha) | [charge_exchange.channel[:].spectrum[:].processed_line[:].radiance.time] | FLT_1D (uncertain) | m^-2.s^-1.sr^-1 | Data
charge_exchange.channel[:].spectrum[:].processed_line[:].radiance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].processed_line[:].shift (alpha) |  | STRUCTURE | m | Shift of the emission line wavelength with respected to the unshifted cental wavelength (e.g. Doppler shift)
charge_exchange.channel[:].spectrum[:].processed_line[:].shift.data (alpha) | [charge_exchange.channel[:].spectrum[:].processed_line[:].shift.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].spectrum[:].processed_line[:].shift.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].processed_line[:].wavelength_central (alpha) |  | FLT_0D (uncertain) | m | Unshifted central wavelength of the processed spectral line
charge_exchange.channel[:].spectrum[:].processed_line[:].width (alpha) |  | STRUCTURE | m | Full width at Half Maximum (FWHM) of the emission line
charge_exchange.channel[:].spectrum[:].processed_line[:].width.data (alpha) | [charge_exchange.channel[:].spectrum[:].processed_line[:].width.time] | FLT_1D (uncertain) | m | Data
charge_exchange.channel[:].spectrum[:].processed_line[:].width.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].radiance_calibration (alpha) | [charge_exchange.channel[:].spectrum[:].wavelengths] | FLT_1D (uncertain) | m^-3.sr^-1 | Radiance calibration
charge_exchange.channel[:].spectrum[:].radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
charge_exchange.channel[:].spectrum[:].radiance_continuum (alpha) | [charge_exchange.channel[:].spectrum[:].wavelengths, charge_exchange.channel[:].spectrum[:].radiance_continuum.time] | STRUCTURE | m^-2.s^-1.sr^-1.m^-1 | Calibrated continuum intensity in the middle of the spectrum per unit wavelength
charge_exchange.channel[:].spectrum[:].radiance_continuum.data (alpha) | [1...N, charge_exchange.channel[:].spectrum[:].radiance_continuum.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1.m^-1 | Data
charge_exchange.channel[:].spectrum[:].radiance_continuum.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].radiance_spectral (alpha) | [charge_exchange.channel[:].spectrum[:].wavelengths, charge_exchange.channel[:].spectrum[:].radiance_spectral.time] | STRUCTURE | (photons) m^-2.s^-1.sr^-1.m^-1 | Calibrated spectral radiance (radiance per unit wavelength)
charge_exchange.channel[:].spectrum[:].radiance_spectral.data (alpha) | [1...N, charge_exchange.channel[:].spectrum[:].radiance_spectral.time] | FLT_2D (uncertain) | (photons) m^-2.s^-1.sr^-1.m^-1 | Data
charge_exchange.channel[:].spectrum[:].radiance_spectral.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].spectrum[:].slit_width (alpha) |  | FLT_0D (uncertain) | m | Width of the slit (placed in the object focal plane)
charge_exchange.channel[:].spectrum[:].wavelength_calibration_date (alpha) |  | STR_0D |  | Date of the wavelength calibration (yyyy_mm_dd)
charge_exchange.channel[:].spectrum[:].wavelengths (alpha) | [1...N] | FLT_1D (uncertain) | m | Measured wavelengths
charge_exchange.channel[:].t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (averaged on charge states and ion species) at the channel measurement point
charge_exchange.channel[:].t_i_average.data (alpha) | [charge_exchange.channel[:].t_i_average.time] | FLT_1D (uncertain) | eV | Data
charge_exchange.channel[:].t_i_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].t_i_average_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the average ion temperature
charge_exchange.channel[:].t_i_average_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].t_i_average_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].t_i_average_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].zeff (alpha) |  | STRUCTURE | - | Local ionic effective charge at the channel measurement point
charge_exchange.channel[:].zeff.data (alpha) | [charge_exchange.channel[:].zeff.time] | FLT_1D (uncertain) | - | Data
charge_exchange.channel[:].zeff.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].zeff_line_average (alpha) |  | STRUCTURE | - | Ionic effective charge, line average along the channel line-of-sight
charge_exchange.channel[:].zeff_line_average.data (alpha) | [charge_exchange.channel[:].zeff_line_average.time] | FLT_1D (uncertain) | - | Data
charge_exchange.channel[:].zeff_line_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
charge_exchange.channel[:].zeff_line_average_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the line average effective charge
charge_exchange.channel[:].zeff_line_average_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].zeff_line_average_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].zeff_line_average_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.channel[:].zeff_method (alpha) |  | STRUCTURE |  | Description of the method used to reconstruct the local effective charge
charge_exchange.channel[:].zeff_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.channel[:].zeff_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.channel[:].zeff_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
charge_exchange.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
charge_exchange.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
charge_exchange.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
charge_exchange.code.library[:].name (alpha) |  | STR_0D |  | Name of software
charge_exchange.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
charge_exchange.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
charge_exchange.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
charge_exchange.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
charge_exchange.code.output_flag (alpha) | [charge_exchange.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
charge_exchange.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
charge_exchange.code.repository (alpha) |  | STR_0D |  | URL of software repository
charge_exchange.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
charge_exchange.etendue (alpha) |  | FLT_0D (uncertain) | m^2.str | Etendue (geometric extent) of the optical system
charge_exchange.etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
charge_exchange.etendue_method.description (alpha) |  | STR_0D |  | Verbose description
charge_exchange.etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
charge_exchange.etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
charge_exchange.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
charge_exchange.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
charge_exchange.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
charge_exchange.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
charge_exchange.ids_properties.occurrence |  | INT_0D |  |
charge_exchange.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
charge_exchange.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
charge_exchange.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
charge_exchange.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
charge_exchange.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
charge_exchange.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
charge_exchange.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
coils_non_axisymmetric (alpha) |  |  |  | Non axisymmetric active coils system (e.g. ELM control coils, error field correction coils, ...)
coils_non_axisymmetric.coil (alpha) | [1...N] | STRUCT_ARRAY |  | Set of coils
coils_non_axisymmetric.coil[:].conductor (alpha) | [1...N] | STRUCT_ARRAY |  | Set of conductors inside the coil. The structure can be used with size 1 for a simplified description as a single conductor. A conductor is composed of several elements, serially connected, i.e. transporting the same current.
coils_non_axisymmetric.coil[:].conductor[:].cross_section (alpha) |  | STRUCTURE |  | The cross-section perpendicular to the conductor contour is described by a series of contour points, given by their relative position with respect to the start point of the first element. This cross-section is assumed constant for all elements.
coils_non_axisymmetric.coil[:].conductor[:].cross_section.delta_phi (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | rad | Toroidal angles (relative to a reference point)
coils_non_axisymmetric.coil[:].conductor[:].cross_section.delta_r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii (relative to a reference point)
coils_non_axisymmetric.coil[:].conductor[:].cross_section.delta_z (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | m | Heights (relative to a reference point)
coils_non_axisymmetric.coil[:].conductor[:].current (alpha) |  | STRUCTURE | A | Current in the conductor (positive when it flows from the first to the last element)
coils_non_axisymmetric.coil[:].conductor[:].current.data (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].current.time] | FLT_1D (uncertain) | A | Data
coils_non_axisymmetric.coil[:].conductor[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
coils_non_axisymmetric.coil[:].conductor[:].elements (alpha) |  | STRUCTURE |  | Set of geometrical elements (line segments and/or arcs of a circle) describing the contour of the conductor centre
coils_non_axisymmetric.coil[:].conductor[:].elements.centres (alpha) |  | STRUCTURE |  | Position of the centre of the arc of a circle of every element (meaningful only if type/index = 2 or 3, fill with default/empty value otherwise)
coils_non_axisymmetric.coil[:].conductor[:].elements.centres.phi (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
coils_non_axisymmetric.coil[:].conductor[:].elements.centres.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
coils_non_axisymmetric.coil[:].conductor[:].elements.centres.z (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | m | Height
coils_non_axisymmetric.coil[:].conductor[:].elements.end_points (alpha) |  | STRUCTURE |  | Position of the end point of every element. Meaningful only if type/index = 1 or 2, fill with default/empty value otherwise
coils_non_axisymmetric.coil[:].conductor[:].elements.end_points.phi (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
coils_non_axisymmetric.coil[:].conductor[:].elements.end_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
coils_non_axisymmetric.coil[:].conductor[:].elements.end_points.z (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | m | Height
coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points (alpha) |  | STRUCTURE |  | Position of an intermediate point along the arc of circle, for every element, providing the orientation of the element (must define with the corresponding start point an aperture angle strictly inferior to PI). Meaningful only if type/index = 2, fill with default/empty value otherwise
coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points.phi (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points.z (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | m | Height
coils_non_axisymmetric.coil[:].conductor[:].elements.names (alpha) | [1...N] | STR_1D |  | Name or description of every element
coils_non_axisymmetric.coil[:].conductor[:].elements.start_points (alpha) |  | STRUCTURE |  | Position of the start point of every element
coils_non_axisymmetric.coil[:].conductor[:].elements.start_points.phi (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
coils_non_axisymmetric.coil[:].conductor[:].elements.start_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
coils_non_axisymmetric.coil[:].conductor[:].elements.start_points.z (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | m | Height
coils_non_axisymmetric.coil[:].conductor[:].elements.types (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].elements.names] | INT_1D |  | Type of every element: 1: line segment, its ends are given by the start and end points; index = 2: arc of a circle; index = 3: full circle
coils_non_axisymmetric.coil[:].conductor[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | conductor resistance
coils_non_axisymmetric.coil[:].conductor[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the conductor terminals
coils_non_axisymmetric.coil[:].conductor[:].voltage.data (alpha) | [coils_non_axisymmetric.coil[:].conductor[:].voltage.time] | FLT_1D (uncertain) | V | Data
coils_non_axisymmetric.coil[:].conductor[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
coils_non_axisymmetric.coil[:].current (alpha) |  | STRUCTURE | A | Current in the coil
coils_non_axisymmetric.coil[:].current.data (alpha) | [coils_non_axisymmetric.coil[:].current.time] | FLT_1D (uncertain) | A | Data
coils_non_axisymmetric.coil[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
coils_non_axisymmetric.coil[:].identifier (alpha) |  | STR_0D |  | Alphanumeric identifier of coil
coils_non_axisymmetric.coil[:].name (alpha) |  | STR_0D |  | Name of the coil
coils_non_axisymmetric.coil[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Coil resistance
coils_non_axisymmetric.coil[:].turns (alpha) |  | FLT_0D (uncertain) | - | Number of total turns in the coil. May be a fraction when describing the coil connections.
coils_non_axisymmetric.coil[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the coil terminals
coils_non_axisymmetric.coil[:].voltage.data (alpha) | [coils_non_axisymmetric.coil[:].voltage.time] | FLT_1D (uncertain) | V | Data
coils_non_axisymmetric.coil[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
coils_non_axisymmetric.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
coils_non_axisymmetric.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
coils_non_axisymmetric.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
coils_non_axisymmetric.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
coils_non_axisymmetric.ids_properties.occurrence |  | INT_0D |  |
coils_non_axisymmetric.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
coils_non_axisymmetric.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
coils_non_axisymmetric.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
coils_non_axisymmetric.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
coils_non_axisymmetric.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
coils_non_axisymmetric.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
coils_non_axisymmetric.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
controllers (alpha) |  |  |  | Feedback and feedforward controllers
controllers.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
controllers.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
controllers.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
controllers.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
controllers.code.library[:].name (alpha) |  | STR_0D |  | Name of software
controllers.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
controllers.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
controllers.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
controllers.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
controllers.code.output_flag (alpha) | [controllers.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
controllers.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
controllers.code.repository (alpha) |  | STR_0D |  | URL of software repository
controllers.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
controllers.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
controllers.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
controllers.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
controllers.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
controllers.ids_properties.occurrence |  | INT_0D |  |
controllers.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
controllers.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
controllers.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
controllers.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
controllers.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
controllers.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
controllers.linear_controller (alpha) | [1...N] | STRUCT_ARRAY |  | A linear controller, this is rather conventional
controllers.linear_controller[:].controller_class (alpha) |  | STR_0D |  | One of a known class of controllers
controllers.linear_controller[:].description (alpha) |  | STR_0D |  | Description of this controller
controllers.linear_controller[:].input_names (alpha) | [1...N] | STR_1D |  | Names of the input signals, following the SDN convention
controllers.linear_controller[:].inputs (alpha) | [controllers.linear_controller[:].input_names, controllers.linear_controller[:].inputs.time] | STRUCTURE | mixed | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].inputs.data (alpha) | [1...N, controllers.linear_controller[:].inputs.time] | FLT_2D (uncertain) | mixed | Data
controllers.linear_controller[:].inputs.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].name (alpha) |  | STR_0D |  | Name of this controller
controllers.linear_controller[:].output_names (alpha) | [1...N] | STR_1D |  | Names of the output signals following the SDN convention
controllers.linear_controller[:].outputs (alpha) | [controllers.linear_controller[:].output_names, controllers.linear_controller[:].outputs.time] | STRUCTURE | mixed | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].outputs.data (alpha) | [1...N, controllers.linear_controller[:].outputs.time] | FLT_2D (uncertain) | mixed | Data
controllers.linear_controller[:].outputs.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].pid (alpha) |  | STRUCTURE |  | Filtered PID controller
controllers.linear_controller[:].pid.d (alpha) | [controllers.linear_controller[:].output_names, controllers.linear_controller[:].input_names, controllers.linear_controller[:].pid.d.time] | STRUCTURE | mixed | Derivative term
controllers.linear_controller[:].pid.d.data (alpha) | [controllers.linear_controller[:].pid.d.data.as_parent, controllers.linear_controller[:].pid.d.data.as_parent, controllers.linear_controller[:].pid.d.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].pid.d.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].pid.i (alpha) | [controllers.linear_controller[:].output_names, controllers.linear_controller[:].input_names, controllers.linear_controller[:].pid.i.time] | STRUCTURE | mixed | Integral term
controllers.linear_controller[:].pid.i.data (alpha) | [controllers.linear_controller[:].pid.i.data.as_parent, controllers.linear_controller[:].pid.i.data.as_parent, controllers.linear_controller[:].pid.i.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].pid.i.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].pid.p (alpha) | [controllers.linear_controller[:].output_names, controllers.linear_controller[:].input_names, controllers.linear_controller[:].pid.p.time] | STRUCTURE | mixed | Proportional term
controllers.linear_controller[:].pid.p.data (alpha) | [controllers.linear_controller[:].pid.p.data.as_parent, controllers.linear_controller[:].pid.p.data.as_parent, controllers.linear_controller[:].pid.p.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].pid.p.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].pid.tau (alpha) |  | STRUCTURE | s | Filter time-constant for the D-term
controllers.linear_controller[:].pid.tau.data (alpha) | [controllers.linear_controller[:].pid.tau.time] | FLT_1D (uncertain) | s | Data
controllers.linear_controller[:].pid.tau.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace (alpha) |  | STRUCTURE |  | Statespace controller in discrete or continuous time
controllers.linear_controller[:].statespace.a (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].statespace.a.time] | STRUCTURE | mixed | A matrix
controllers.linear_controller[:].statespace.a.data (alpha) | [controllers.linear_controller[:].statespace.a.data.as_parent, controllers.linear_controller[:].statespace.a.data.as_parent, controllers.linear_controller[:].statespace.a.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].statespace.a.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace.b (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].input_names, controllers.linear_controller[:].statespace.b.time] | STRUCTURE | mixed | B matrix
controllers.linear_controller[:].statespace.b.data (alpha) | [controllers.linear_controller[:].statespace.b.data.as_parent, controllers.linear_controller[:].statespace.b.data.as_parent, controllers.linear_controller[:].statespace.b.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].statespace.b.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace.c (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].output_names, controllers.linear_controller[:].statespace.c.time] | STRUCTURE | mixed | C matrix
controllers.linear_controller[:].statespace.c.data (alpha) | [controllers.linear_controller[:].statespace.c.data.as_parent, controllers.linear_controller[:].statespace.c.data.as_parent, controllers.linear_controller[:].statespace.c.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].statespace.c.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace.d (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].output_names, controllers.linear_controller[:].statespace.d.time] | STRUCTURE | mixed | D matrix, normally proper and D=0
controllers.linear_controller[:].statespace.d.data (alpha) | [controllers.linear_controller[:].statespace.d.data.as_parent, controllers.linear_controller[:].statespace.d.data.as_parent, controllers.linear_controller[:].statespace.d.time] | FLT_3D (uncertain) | mixed | Data
controllers.linear_controller[:].statespace.d.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace.deltat (alpha) |  | STRUCTURE | s | Discrete time sampling interval ; if less than 1e-10, the controller is considered to be expressed in continuous time
controllers.linear_controller[:].statespace.deltat.data (alpha) | [controllers.linear_controller[:].statespace.deltat.time] | FLT_1D (uncertain) | s | Data
controllers.linear_controller[:].statespace.deltat.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.linear_controller[:].statespace.state_names (alpha) | [1...N] | STR_1D |  | Names of the states
controllers.nonlinear_controller (alpha) | [1...N] | STRUCT_ARRAY |  | A non-linear controller, this is less conventional and will have to be developed
controllers.nonlinear_controller[:].controller_class (alpha) |  | STR_0D |  | One of a known class of controllers
controllers.nonlinear_controller[:].description (alpha) |  | STR_0D |  | Description of this controller
controllers.nonlinear_controller[:].function (alpha) |  | STR_0D |  | Method to be defined
controllers.nonlinear_controller[:].input_names (alpha) | [1...N] | STR_1D |  | Names of the input signals, following the SDN convention
controllers.nonlinear_controller[:].inputs (alpha) | [controllers.nonlinear_controller[:].input_names, controllers.nonlinear_controller[:].inputs.time] | STRUCTURE | mixed | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].inputs.data (alpha) | [1...N, controllers.nonlinear_controller[:].inputs.time] | FLT_2D (uncertain) | mixed | Data
controllers.nonlinear_controller[:].inputs.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.nonlinear_controller[:].name (alpha) |  | STR_0D |  | Name of this controller
controllers.nonlinear_controller[:].output_names (alpha) | [1...N] | STR_1D |  | Output signal names following the SDN convention
controllers.nonlinear_controller[:].outputs (alpha) | [controllers.nonlinear_controller[:].output_names, controllers.nonlinear_controller[:].outputs.time] | STRUCTURE | mixed | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].outputs.data (alpha) | [1...N, controllers.nonlinear_controller[:].outputs.time] | FLT_2D (uncertain) | mixed | Data
controllers.nonlinear_controller[:].outputs.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
controllers.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_instant_changes |  |  |  | Instant changes of the radial core plasma profiles due to pellet, MHD, ...
core_instant_changes.change | [1...N] | STRUCT_ARRAY |  | Set of instant change terms (each being due to a different phenomenon)
core_instant_changes.change[:].identifier |  | STRUCTURE |  | Instant change term identifier 0) unspecified : Unspecified instant changes 1) total : Total instant changes; combines all types of events 2) pellet : Instant changes from a pellet 3) sawtooth : Instant changes from a sawtooth 4) elm : Instant changes from an edge localised mode
core_instant_changes.change[:].identifier.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].identifier.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d | [core_instant_changes.change[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Changes in 1D core profiles for various time slices. This structure mirrors core_profiles/profiles_1d and describes instant changes to each of these physical quantities (i.e. a signed difference quantity after change - quantity before change)
core_instant_changes.change[:].profiles_1d[:].conductivity_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_instant_changes.change[:].profiles_1d[:].current_parallel_inside | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Parallel current driven inside the flux surface. Cumulative surface integral of j_total
core_instant_changes.change[:].profiles_1d[:].e_field |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parallel component, average(E.B) / B0, using core_profiles/vacuum_toroidal_field/b0
core_instant_changes.change[:].profiles_1d[:].e_field.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].e_field.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].e_field.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].e_field.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].e_field.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].e_field_parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
core_instant_changes.change[:].profiles_1d[:].electrons.collisionality_norm | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Collisionality normalised to the bounce frequency
core_instant_changes.change[:].profiles_1d[:].electrons.density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].electrons.density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.local | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.source | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.weight | [core_instant_changes.change[:].profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].electrons.density_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_instant_changes.change[:].profiles_1d[:].electrons.density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_instant_changes.change[:].profiles_1d[:].electrons.pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].electrons.pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].electrons.pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].electrons.pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_instant_changes.change[:].profiles_1d[:].electrons.temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.local | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.source | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.weight | [core_instant_changes.change[:].profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].electrons.temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_instant_changes.change[:].profiles_1d[:].electrons.velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.diamagnetic (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.poloidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.radial (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.toroidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity_pol (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
core_instant_changes.change[:].profiles_1d[:].electrons.velocity_tor (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
core_instant_changes.change[:].profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_instant_changes.change[:].profiles_1d[:].grid.area | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_instant_changes.change[:].profiles_1d[:].grid.psi | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_instant_changes.change[:].profiles_1d[:].grid.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_instant_changes.change[:].profiles_1d[:].grid.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_instant_changes.change[:].profiles_1d[:].grid.rho_pol_norm | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_instant_changes.change[:].profiles_1d[:].grid.rho_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_instant_changes.change[:].profiles_1d[:].grid.surface | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_instant_changes.change[:].profiles_1d[:].grid.volume | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_instant_changes.change[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
core_instant_changes.change[:].profiles_1d[:].ion[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.local | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.source | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.weight | [core_instant_changes.change[:].profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].ion[:].density_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_instant_changes.change[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_instant_changes.change[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_instant_changes.change[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].rotation_frequency_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken) (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.local | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.source | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.weight | [core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].ionisation_potential |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz’+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].rotation_frequency_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.diamagnetic (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.poloidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.radial (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.toroidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle, volume averaged over the plasma radius (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_average_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge profile of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_average_square_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average square charge profile of the charge state bundle (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_square_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle, volume averaged over the plasma radius (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.local | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.source | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.weight | [core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered) at the position of maximum major radius on every flux surface
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity_pol (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity_tor (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion_square_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average square charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
core_instant_changes.change[:].profiles_1d[:].j_bootstrap | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_non_inductive | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_ohmic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
core_instant_changes.change[:].profiles_1d[:].j_total | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].magnetic_shear | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
core_instant_changes.change[:].profiles_1d[:].momentum_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
core_instant_changes.change[:].profiles_1d[:].n_i_thermal_total | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Total ion thermal density (sum over species and charge states)
core_instant_changes.change[:].profiles_1d[:].n_i_total_over_n_e | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
core_instant_changes.change[:].profiles_1d[:].neutral[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].density_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_instant_changes.change[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_instant_changes.change[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying the species (e.g. H, D, T, He, C, D2, DT, CD4, ...)
core_instant_changes.change[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].density_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.diamagnetic (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.poloidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.radial (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.toroidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_instant_changes.change[:].profiles_1d[:].neutral[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.diamagnetic (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.poloidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.radial (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.toroidal (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].phi_potential | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Electrostatic potential, averaged on the magnetic flux surface
core_instant_changes.change[:].profiles_1d[:].pressure_ion_total | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
core_instant_changes.change[:].profiles_1d[:].pressure_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].pressure_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
core_instant_changes.change[:].profiles_1d[:].q | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
core_instant_changes.change[:].profiles_1d[:].rotation_frequency_tor_sonic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Derivative of the flux surface averaged electrostatic potential with respect to the poloidal flux, multiplied by -1. This quantity is the toroidal angular rotation frequency due to the ExB drift, introduced in formula (43) of Hinton and Wong, Physics of Fluids 3082 (1985), also referred to as sonic flow in regimes in which the toroidal velocity is dominant over the poloidal velocity
core_instant_changes.change[:].profiles_1d[:].t_i_average | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit |  | STRUCTURE | eV | Information on the fit used to obtain the t_i_average profile
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.local | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.source | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.weight | [core_instant_changes.change[:].profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.change[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_instant_changes.change[:].profiles_1d[:].zeff | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
core_instant_changes.change[:].profiles_1d[:].zeff_fit |  | STRUCTURE | - | Information on the fit used to obtain the zeff profile
core_instant_changes.change[:].profiles_1d[:].zeff_fit.chi_squared | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_instant_changes.change[:].profiles_1d[:].zeff_fit.local | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_instant_changes.change[:].profiles_1d[:].zeff_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_instant_changes.change[:].profiles_1d[:].zeff_fit.reconstructed | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_instant_changes.change[:].profiles_1d[:].zeff_fit.rho_tor_norm | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_instant_changes.change[:].profiles_1d[:].zeff_fit.source | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].zeff_fit.time_measurement_width | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_instant_changes.change[:].profiles_1d[:].zeff_fit.weight | [core_instant_changes.change[:].profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_instant_changes.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_instant_changes.code.commit |  | STR_0D |  | Unique commit reference of software
core_instant_changes.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
core_instant_changes.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
core_instant_changes.code.library[:].name |  | STR_0D |  | Name of software
core_instant_changes.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_instant_changes.code.library[:].repository |  | STR_0D |  | URL of software repository
core_instant_changes.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
core_instant_changes.code.name |  | STR_0D |  | Name of software generating IDS
core_instant_changes.code.output_flag | [core_instant_changes.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_instant_changes.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_instant_changes.code.repository |  | STR_0D |  | URL of software repository
core_instant_changes.code.version |  | STR_0D |  | Unique version (tag) of software
core_instant_changes.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_instant_changes.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_instant_changes.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
core_instant_changes.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
core_instant_changes.ids_properties.occurrence |  | INT_0D |  |
core_instant_changes.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
core_instant_changes.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
core_instant_changes.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
core_instant_changes.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
core_instant_changes.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
core_instant_changes.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
core_instant_changes.time | [1...N] | FLT_1D_TYPE | s | Generic time
core_instant_changes.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_instant_changes.vacuum_toroidal_field.b0 | [core_instant_changes.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_instant_changes.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_profiles |  |  |  | Core plasma radial profiles
core_profiles.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_profiles.code.commit |  | STR_0D |  | Unique commit reference of software
core_profiles.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
core_profiles.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
core_profiles.code.library[:].name |  | STR_0D |  | Name of software
core_profiles.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_profiles.code.library[:].repository |  | STR_0D |  | URL of software repository
core_profiles.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
core_profiles.code.name |  | STR_0D |  | Name of software generating IDS
core_profiles.code.output_flag | [core_profiles.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_profiles.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_profiles.code.repository |  | STR_0D |  | URL of software repository
core_profiles.code.version |  | STR_0D |  | Unique version (tag) of software
core_profiles.global_quantities |  | STRUCTURE |  | Various global quantities derived from the profiles
core_profiles.global_quantities.beta_pol | [core_profiles.time] | FLT_1D (uncertain) | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
core_profiles.global_quantities.beta_tor | [core_profiles.time] | FLT_1D (uncertain) | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
core_profiles.global_quantities.beta_tor_norm | [core_profiles.time] | FLT_1D (uncertain) | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
core_profiles.global_quantities.current_bootstrap | [core_profiles.time] | FLT_1D (uncertain) | A | Bootstrap current (toroidal component). Positive sign means anti-clockwise when viewed from above.
core_profiles.global_quantities.current_non_inductive | [core_profiles.time] | FLT_1D (uncertain) | A | Total non-inductive current (toroidal component). Positive sign means anti-clockwise when viewed from above.
core_profiles.global_quantities.energy_diamagnetic | [core_profiles.time] | FLT_1D (uncertain) | J | Plasma energy content = 3/2 * integral over the plasma volume of the total perpendicular pressure
core_profiles.global_quantities.ip | [core_profiles.time] | FLT_1D (uncertain) | A | Total plasma current (toroidal component). Positive sign means anti-clockwise when viewed from above.
core_profiles.global_quantities.li (obsolescent) | [core_profiles.time] | FLT_1D (uncertain) | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
core_profiles.global_quantities.li_3 | [core_profiles.time] | FLT_1D (uncertain) | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
core_profiles.global_quantities.v_loop | [core_profiles.time] | FLT_1D (uncertain) | V | LCFS loop voltage (positive value drives positive ohmic current that flows anti-clockwise when viewed from above)
core_profiles.global_quantities.z_eff_resistive | [core_profiles.time] | FLT_1D (uncertain) | - | Volume average plasma effective charge, estimated from the flux consumption in the ohmic phase
core_profiles.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_profiles.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_profiles.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
core_profiles.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
core_profiles.ids_properties.occurrence |  | INT_0D |  |
core_profiles.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
core_profiles.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
core_profiles.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
core_profiles.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
core_profiles.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
core_profiles.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
core_profiles.profiles_1d | [core_profiles.profiles_1d[:].time] | STRUCT_ARRAY |  | Core plasma radial profiles for various time slices
core_profiles.profiles_1d[:].conductivity_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_profiles.profiles_1d[:].current_parallel_inside | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Parallel current driven inside the flux surface. Cumulative surface integral of j_total
core_profiles.profiles_1d[:].e_field |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parallel component, average(E.B) / B0, using core_profiles/vacuum_toroidal_field/b0
core_profiles.profiles_1d[:].e_field.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
core_profiles.profiles_1d[:].e_field.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
core_profiles.profiles_1d[:].e_field.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
core_profiles.profiles_1d[:].e_field.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
core_profiles.profiles_1d[:].e_field.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
core_profiles.profiles_1d[:].e_field_parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
core_profiles.profiles_1d[:].electrons.collisionality_norm | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Collisionality normalised to the bounce frequency
core_profiles.profiles_1d[:].electrons.density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].electrons.density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].electrons.density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_profiles.profiles_1d[:].electrons.density_fit.chi_squared | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].electrons.density_fit.local | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].electrons.density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].electrons.density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].electrons.density_fit.reconstructed | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].electrons.density_fit.rho_tor_norm | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].electrons.density_fit.source | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].electrons.density_fit.time_measurement_width | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].electrons.density_fit.weight | [core_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].electrons.density_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_profiles.profiles_1d[:].electrons.density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_profiles.profiles_1d[:].electrons.pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].electrons.pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].electrons.pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].electrons.pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_profiles.profiles_1d[:].electrons.temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].electrons.temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
core_profiles.profiles_1d[:].electrons.temperature_fit.chi_squared | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].electrons.temperature_fit.local | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].electrons.temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].electrons.temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].electrons.temperature_fit.reconstructed | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].electrons.temperature_fit.rho_tor_norm | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].electrons.temperature_fit.source | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_width | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].electrons.temperature_fit.weight | [core_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].electrons.temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_profiles.profiles_1d[:].electrons.velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].electrons.velocity.diamagnetic (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].electrons.velocity.parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].electrons.velocity.poloidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].electrons.velocity.radial (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].electrons.velocity.toroidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].electrons.velocity_pol (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
core_profiles.profiles_1d[:].electrons.velocity_tor (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
core_profiles.profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_profiles.profiles_1d[:].grid.area | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_profiles.profiles_1d[:].grid.psi | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_profiles.profiles_1d[:].grid.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_profiles.profiles_1d[:].grid.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_profiles.profiles_1d[:].grid.rho_pol_norm | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_profiles.profiles_1d[:].grid.rho_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_profiles.profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_profiles.profiles_1d[:].grid.surface | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_profiles.profiles_1d[:].grid.volume | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_profiles.profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
core_profiles.profiles_1d[:].ion[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_profiles.profiles_1d[:].ion[:].density_fit.chi_squared | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].ion[:].density_fit.local | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].ion[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].ion[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].ion[:].density_fit.reconstructed | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].ion[:].density_fit.rho_tor_norm | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].ion[:].density_fit.source | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_width | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].ion[:].density_fit.weight | [core_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].ion[:].density_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_profiles.profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_profiles.profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_profiles.profiles_1d[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_profiles.profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_profiles.profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_profiles.profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_profiles.profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_profiles.profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_profiles.profiles_1d[:].ion[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].rotation_frequency_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken) (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
core_profiles.profiles_1d[:].ion[:].state[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].ion[:].state[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].ion[:].state[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.chi_squared | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.local | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.reconstructed | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.rho_tor_norm | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.source | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_width | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].ion[:].state[:].density_fit.weight | [core_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].ion[:].state[:].density_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_profiles.profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_profiles.profiles_1d[:].ion[:].state[:].ionisation_potential |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz’+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_profiles.profiles_1d[:].ion[:].state[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].ion[:].state[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_profiles.profiles_1d[:].ion[:].state[:].rotation_frequency_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken)
core_profiles.profiles_1d[:].ion[:].state[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].ion[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].ion[:].state[:].velocity.diamagnetic (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.poloidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.radial (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.toroidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_profiles.profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_profiles.profiles_1d[:].ion[:].state[:].z_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle, volume averaged over the plasma radius (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].z_average_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge profile of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].z_average_square_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average square charge profile of the charge state bundle (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
core_profiles.profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_profiles.profiles_1d[:].ion[:].state[:].z_square_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle, volume averaged over the plasma radius (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
core_profiles.profiles_1d[:].ion[:].temperature_fit.chi_squared | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].ion[:].temperature_fit.local | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].ion[:].temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].ion[:].temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].ion[:].temperature_fit.reconstructed | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].ion[:].temperature_fit.rho_tor_norm | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].ion[:].temperature_fit.source | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_width | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].ion[:].temperature_fit.weight | [core_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].ion[:].temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
core_profiles.profiles_1d[:].ion[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered) at the position of maximum major radius on every flux surface
core_profiles.profiles_1d[:].ion[:].velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].ion[:].velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].ion[:].velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].ion[:].velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].ion[:].velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].ion[:].velocity_pol (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].velocity_tor (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
core_profiles.profiles_1d[:].ion[:].z_ion_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
core_profiles.profiles_1d[:].ion[:].z_ion_square_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average square charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
core_profiles.profiles_1d[:].j_bootstrap | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_non_inductive | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_ohmic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
core_profiles.profiles_1d[:].j_total | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].magnetic_shear | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
core_profiles.profiles_1d[:].momentum_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
core_profiles.profiles_1d[:].n_i_thermal_total | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Total ion thermal density (sum over species and charge states)
core_profiles.profiles_1d[:].n_i_total_over_n_e | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
core_profiles.profiles_1d[:].neutral[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].density_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_profiles.profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_profiles.profiles_1d[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_profiles.profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_profiles.profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_profiles.profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_profiles.profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying the species (e.g. H, D, T, He, C, D2, DT, CD4, ...)
core_profiles.profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_profiles.profiles_1d[:].neutral[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
core_profiles.profiles_1d[:].neutral[:].state[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral[:].state[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].neutral[:].state[:].density_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
core_profiles.profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_profiles.profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].neutral[:].state[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].neutral[:].state[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
core_profiles.profiles_1d[:].neutral[:].state[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].neutral[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.diamagnetic (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.poloidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.radial (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.toroidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_profiles.profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_profiles.profiles_1d[:].neutral[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].velocity.diamagnetic (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].neutral[:].velocity.parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].neutral[:].velocity.poloidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].neutral[:].velocity.radial (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].neutral[:].velocity.toroidal (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].phi_potential | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Electrostatic potential, averaged on the magnetic flux surface
core_profiles.profiles_1d[:].pressure_ion_total | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
core_profiles.profiles_1d[:].pressure_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
core_profiles.profiles_1d[:].pressure_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
core_profiles.profiles_1d[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
core_profiles.profiles_1d[:].q | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
core_profiles.profiles_1d[:].rotation_frequency_tor_sonic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Derivative of the flux surface averaged electrostatic potential with respect to the poloidal flux, multiplied by -1. This quantity is the toroidal angular rotation frequency due to the ExB drift, introduced in formula (43) of Hinton and Wong, Physics of Fluids 3082 (1985), also referred to as sonic flow in regimes in which the toroidal velocity is dominant over the poloidal velocity
core_profiles.profiles_1d[:].t_i_average | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
core_profiles.profiles_1d[:].t_i_average_fit |  | STRUCTURE | eV | Information on the fit used to obtain the t_i_average profile
core_profiles.profiles_1d[:].t_i_average_fit.chi_squared | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].t_i_average_fit.local | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].t_i_average_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].t_i_average_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].t_i_average_fit.reconstructed | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].t_i_average_fit.rho_tor_norm | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].t_i_average_fit.source | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].t_i_average_fit.time_measurement_width | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].t_i_average_fit.weight | [core_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.profiles_1d[:].time |  | FLT_0D | s | Time
core_profiles.profiles_1d[:].zeff | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
core_profiles.profiles_1d[:].zeff_fit |  | STRUCTURE | - | Information on the fit used to obtain the zeff profile
core_profiles.profiles_1d[:].zeff_fit.chi_squared | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
core_profiles.profiles_1d[:].zeff_fit.local | [core_profiles.profiles_1d[:].zeff_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
core_profiles.profiles_1d[:].zeff_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
core_profiles.profiles_1d[:].zeff_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
core_profiles.profiles_1d[:].zeff_fit.reconstructed | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
core_profiles.profiles_1d[:].zeff_fit.rho_tor_norm | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
core_profiles.profiles_1d[:].zeff_fit.source | [core_profiles.profiles_1d[:].zeff_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
core_profiles.profiles_1d[:].zeff_fit.time_measurement | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
core_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
core_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].zeff_fit.time_measurement_width | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
core_profiles.profiles_1d[:].zeff_fit.weight | [core_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
core_profiles.time | [1...N] | FLT_1D_TYPE | s | Generic time
core_profiles.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
core_profiles.vacuum_toroidal_field.b0 | [core_profiles.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_profiles.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_sources |  |  |  | Core plasma thermal source terms (for the transport equations of the thermal species). Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
core_sources.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_sources.code.commit |  | STR_0D |  | Unique commit reference of software
core_sources.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
core_sources.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
core_sources.code.library[:].name |  | STR_0D |  | Name of software
core_sources.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_sources.code.library[:].repository |  | STR_0D |  | URL of software repository
core_sources.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
core_sources.code.name |  | STR_0D |  | Name of software generating IDS
core_sources.code.output_flag | [core_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_sources.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_sources.code.repository |  | STR_0D |  | URL of software repository
core_sources.code.version |  | STR_0D |  | Unique version (tag) of software
core_sources.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_sources.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_sources.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
core_sources.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
core_sources.ids_properties.occurrence |  | INT_0D |  |
core_sources.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
core_sources.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
core_sources.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
core_sources.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
core_sources.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
core_sources.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
core_sources.source | [1...N] | STRUCT_ARRAY |  | Set of source terms
core_sources.source[:].global_quantities | [core_sources.source[:].global_quantities[:].time] | STRUCT_ARRAY |  | Total source quantities integrated over the plasma volume or surface
core_sources.source[:].global_quantities[:].current_parallel |  | FLT_0D (uncertain) | A | Parallel current driven
core_sources.source[:].global_quantities[:].electrons |  | STRUCTURE |  | Sources for electrons
core_sources.source[:].global_quantities[:].electrons.particles |  | FLT_0D (uncertain) | s^-1 | Electron particle source
core_sources.source[:].global_quantities[:].electrons.power |  | FLT_0D (uncertain) | W | Power coupled to electrons
core_sources.source[:].global_quantities[:].power |  | FLT_0D (uncertain) | W | Total power coupled to the plasma
core_sources.source[:].global_quantities[:].time |  | FLT_0D | s | Time
core_sources.source[:].global_quantities[:].torque_tor |  | FLT_0D (uncertain) | kg.m^2.s^-2 | Toroidal torque
core_sources.source[:].global_quantities[:].total_ion_particles |  | FLT_0D (uncertain) | (ions).s^-1 | Total ion particle source (summed over ion species)
core_sources.source[:].global_quantities[:].total_ion_power |  | FLT_0D (uncertain) | W | Total power coupled to ion species (summed over ion species)
core_sources.source[:].identifier |  | STRUCTURE |  | Source term identifier (process causing this source term) 0) unspecified : Unspecified source type 1) total : Total source; combines all sources 2) nbi : Source from Neutral Beam Injection 3) ec : Sources from electron cyclotron heating and current drive 4) lh : Sources from lower hybrid heating and current drive 5) ic : Sources from heating at the ion cyclotron range of frequencies 6) fusion : Sources from fusion reactions, e.g. alpha particle heating 7) ohmic : Source from ohmic heating 8) bremsstrahlung : Source from bremsstrahlung; radiation losses are negative sources 9) synchrotron_radiation : Source from synchrotron radiation; radiation losses are negative sources 10) line_radiation : Source from line radiation; radiation losses are negative sources 11) collisional_equipartition : Collisional equipartition 12) cold_neutrals : Source of cold neutrals 13) bootstrap_current : Bootstrap current 14) pellet : Sources from injection 100) auxiliary : Source from auxiliary systems, e.g. heating and current drive systems 101) ic_nbi : A combination of the ic and nbi sources 102) ic_fusion : A combination of the ic and fusion sources 103) ic_nbi_fusion : A combination of the ic and fusion sources 104) ec_lh : A combination of the ec and lh sources 105) ec_ic : A combination of the ec and ic sources 106) lh_ic : A combination of the lh and ic sources 107) ec_lh_ic : A combination of the ec, lh and ic sources 108) gas_puff : Gas puff 109) killer_gas_puff : Killer gas puff 200) radiation : Total radiation source; radiation losses are negative sources 201) cyclotron_radiation : Source from cyclotron radiation; radiation losses are negative sources 202) cyclotron_synchrotron_radiation : Source from combined cyclotron and synchrotron radiation; radiation losses are negative sources 203) impurity_radiation : Line radiation and Bremsstrahlung source; radiation losses are negative sources. 303) particles_to_wall : Particle pumping by the wall; negative source for plasma and positive source for the wall 304) particles_to_pump : Particle pumping by external pump; negative source for plasma and positive source for the pump 305) charge_exchange : Source from charge exchange. Charge exchange losses are negative sources 400) transport : Source term related to transport processes 401) neoclassical : Source term related to neoclassical processes 402) equipartition : Equipartition due to collisions and turbulence 403) turbulent_equipartition : Turbulent equipartition 501) runaways : Source from run-away processes; includes both electron and ion run-away 601) ionisation : Source from ionisation processes (not accounting for charge exchange) 602) recombination : Source from recombination processes (not accounting for charge exchange) 603) excitation : Source from excitation processes 801) database : Source from database entry 802) gaussian : Artificial source with a gaussian profile 901) custom_1 : Custom source terms 1; content to be decided by data provided 902) custom_2 : Custom source terms 2; content to be decided by data provided 903) custom_3 : Custom source terms 3; content to be decided by data provided 904) custom_4 : Custom source terms 4; content to be decided by data provided 905) custom_5 : Custom source terms 5; content to be decided by data provided 906) custom_6 : Custom source terms 6; content to be decided by data provided 907) custom_7 : Custom source terms 7; content to be decided by data provided 908) custom_8 : Custom source terms 8; content to be decided by data provided 909) custom_9 : Custom source terms 9; content to be decided by data provided
core_sources.source[:].identifier.description |  | STR_0D |  | Verbose description
core_sources.source[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_sources.source[:].identifier.name |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d | [core_sources.source[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source profiles for various time slices. Source terms are positive (resp. negative) when there is a gain (resp. a loss) to the considered channel.
core_sources.source[:].profiles_1d[:].conductivity_parallel | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity due to this source
core_sources.source[:].profiles_1d[:].current_parallel_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Parallel current driven inside the flux surface. Cumulative surface integral of j_parallel
core_sources.source[:].profiles_1d[:].electrons |  | STRUCTURE |  | Sources for electrons
core_sources.source[:].profiles_1d[:].electrons.energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the electron energy equation
core_sources.source[:].profiles_1d[:].electrons.energy_decomposed |  | STRUCTURE |  | Decomposition of the source term for electron energy equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].electrons.energy_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].electrons.energy_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].electrons.particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3.s^-1 | Source term for electron density equation
core_sources.source[:].profiles_1d[:].electrons.particles_decomposed |  | STRUCTURE |  | Decomposition of the source term for electron density equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].electrons.particles_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3.s^-1 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].electrons.particles_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].electrons.particles_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Electron source inside the flux surface. Cumulative volume integral of the source term for the electron density equation.
core_sources.source[:].profiles_1d[:].electrons.power_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Power coupled to electrons inside the flux surface. Cumulative volume integral of the source term for the electron energy equation
core_sources.source[:].profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_sources.source[:].profiles_1d[:].grid.area | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_sources.source[:].profiles_1d[:].grid.psi | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_sources.source[:].profiles_1d[:].grid.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_sources.source[:].profiles_1d[:].grid.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_sources.source[:].profiles_1d[:].grid.rho_pol_norm | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_sources.source[:].profiles_1d[:].grid.rho_tor | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_sources.source[:].profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_sources.source[:].profiles_1d[:].grid.surface | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_sources.source[:].profiles_1d[:].grid.volume | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_sources.source[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Source terms related to the different ions species
core_sources.source[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].profiles_1d[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_sources.source[:].profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].profiles_1d[:].ion[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the ion energy transport equation.
core_sources.source[:].profiles_1d[:].ion[:].energy_decomposed |  | STRUCTURE |  | Decomposition of the source term for ion energy equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].ion[:].energy_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].ion[:].energy_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_sources.source[:].profiles_1d[:].ion[:].momentum |  | STRUCTURE |  | Source term for the ion momentum transport equations along various components (directions)
core_sources.source[:].profiles_1d[:].ion[:].momentum.diamagnetic | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component
core_sources.source[:].profiles_1d[:].ion[:].momentum.parallel | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component
core_sources.source[:].profiles_1d[:].ion[:].momentum.poloidal | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component
core_sources.source[:].profiles_1d[:].ion[:].momentum.radial | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component
core_sources.source[:].profiles_1d[:].ion[:].momentum.toroidal | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component
core_sources.source[:].profiles_1d[:].ion[:].momentum.toroidal_decomposed |  | STRUCTURE |  | Decomposition of the source term for ion toroidal momentum equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].ion[:].momentum.toroidal_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^2.s^-2 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].ion[:].momentum.toroidal_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_sources.source[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_sources.source[:].profiles_1d[:].ion[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for ion density equation
core_sources.source[:].profiles_1d[:].ion[:].particles_decomposed |  | STRUCTURE |  | Decomposition of the source term for ion density equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].ion[:].particles_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3.s^-1 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].ion[:].particles_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (ionisation, energy, excitation, ...)
core_sources.source[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].profiles_1d[:].ion[:].state[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source terms for the charge state energy transport equation
core_sources.source[:].profiles_1d[:].ion[:].state[:].energy_decomposed |  | STRUCTURE |  | Decomposition of the source term for state energy equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].ion[:].state[:].energy_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].ion[:].state[:].energy_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].ion[:].state[:].is_neutral (obsolescent) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
core_sources.source[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type (obsolescent) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.description (obsolescent) |  | STR_0D |  | Verbose description
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.name (obsolescent) |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d[:].ion[:].state[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the charge state density transport equation
core_sources.source[:].profiles_1d[:].ion[:].state[:].particles_decomposed |  | STRUCTURE |  | Decomposition of the source term for state density equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].ion[:].state[:].particles_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3.s^-1 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].ion[:].state[:].particles_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
core_sources.source[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_sources.source[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
core_sources.source[:].profiles_1d[:].j_parallel | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Parallel current density source, average(J.B) / B0, where B0 = core_sources/vacuum_toroidal_field/b0
core_sources.source[:].profiles_1d[:].momentum_tor | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Source term for total toroidal momentum equation
core_sources.source[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Source terms related to the different neutral species
core_sources.source[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].profiles_1d[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_sources.source[:].profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].profiles_1d[:].neutral[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the neutral energy transport equation.
core_sources.source[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_sources.source[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying the neutral species (e.g. H, D, T, He, C, ...)
core_sources.source[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_sources.source[:].profiles_1d[:].neutral[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for neutral density equation
core_sources.source[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (energy, excitation, ...)
core_sources.source[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].profiles_1d[:].neutral[:].state[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source terms for the state energy transport equation
core_sources.source[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d[:].neutral[:].state[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the state density transport equation
core_sources.source[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_sources.source[:].profiles_1d[:].torque_tor_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^2.s^-2 | Toroidal torque inside the flux surface. Cumulative volume integral of the source term for the total toroidal momentum equation
core_sources.source[:].profiles_1d[:].total_ion_energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the total (summed over ion species) energy equation
core_sources.source[:].profiles_1d[:].total_ion_energy_decomposed |  | STRUCTURE |  | Decomposition of the source term for total ion energy equation into implicit and explicit parts
core_sources.source[:].profiles_1d[:].total_ion_energy_decomposed.explicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Explicit part of the source term
core_sources.source[:].profiles_1d[:].total_ion_energy_decomposed.implicit_part | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Implicit part of the source term, i.e. to be multiplied by the equation's primary quantity
core_sources.source[:].profiles_1d[:].total_ion_power_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total power coupled to ion species (summed over ion species) inside the flux surface. Cumulative volume integral of the source term for the total ion energy equation
core_sources.source[:].species |  | STRUCTURE |  | Species causing this source term (if relevant, e.g. a particular ion or neutral state in case of line radiation)
core_sources.source[:].species.ion |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
core_sources.source[:].species.ion.element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].species.ion.element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].species.ion.element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_sources.source[:].species.ion.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].species.ion.element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].species.ion.label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_sources.source[:].species.ion.state |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
core_sources.source[:].species.ion.state.electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].species.ion.state.label |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_sources.source[:].species.ion.state.vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].species.ion.state.vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].species.ion.state.z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
core_sources.source[:].species.ion.state.z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
core_sources.source[:].species.ion.z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
core_sources.source[:].species.neutral |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
core_sources.source[:].species.neutral.element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].species.neutral.element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].species.neutral.element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_sources.source[:].species.neutral.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].species.neutral.element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].species.neutral.label |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
core_sources.source[:].species.neutral.state |  | STRUCTURE |  | State of the species (energy, excitation, ...)
core_sources.source[:].species.neutral.state.electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].species.neutral.state.label |  | STR_0D |  | String identifying neutral state
core_sources.source[:].species.neutral.state.neutral_type |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
core_sources.source[:].species.neutral.state.neutral_type.description |  | STR_0D |  | Verbose description
core_sources.source[:].species.neutral.state.neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_sources.source[:].species.neutral.state.neutral_type.name |  | STR_0D |  | Short string identifier
core_sources.source[:].species.neutral.state.vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].species.neutral.state.vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].species.type |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon 0) unspecified : unspecified 1) electron : Electron 2) ion : Ion species in a single/average state; refer to ion-structure 3) ion_state : Ion species in a particular state; refer to ion/state-structure 4) neutral : Neutral species in a single/average state; refer to neutral-structure 5) neutral_state : Neutral species in a particular state; refer to neutral/state-structure 6) neutron : Neutron 7) photon : Photon
core_sources.source[:].species.type.description |  | STR_0D |  | Verbose description
core_sources.source[:].species.type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_sources.source[:].species.type.name |  | STR_0D |  | Short string identifier
core_sources.time | [1...N] | FLT_1D_TYPE | s | Generic time
core_sources.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_sources.vacuum_toroidal_field.b0 | [core_sources.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_sources.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_transport |  |  |  | Core plasma transport of particles, energy, momentum and poloidal flux. The transport of particles, energy and momentum is described by diffusion coefficients, D, and convection velocities, v. These are defined by the total fluxes of particles, energy and momentum, across a flux surface given by : V' [-D Y' <|grad(rho_tor_norm)|^2gt; + v Y <|grad(rho_tor_norm)|>], where Y represents the particles, energy and momentum density, respectively, while V is the volume inside a flux surface, the primes denote derivatives with respect to rho_tor_norm and < X > is the flux surface average of a quantity X. This formulation remains valid when changing simultaneously rho_tor_norm into rho_tor in the gradient terms and in the derivatives denoted by the prime. The average flux stored in the IDS as sibling of D and v is the total flux described above divided by the flux surface area V' <|grad(rho_tor_norm)|>. Note that the energy flux includes the energy transported by the particle flux.
core_transport.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_transport.code.commit |  | STR_0D |  | Unique commit reference of software
core_transport.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
core_transport.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
core_transport.code.library[:].name |  | STR_0D |  | Name of software
core_transport.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_transport.code.library[:].repository |  | STR_0D |  | URL of software repository
core_transport.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
core_transport.code.name |  | STR_0D |  | Name of software generating IDS
core_transport.code.output_flag | [core_transport.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_transport.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_transport.code.repository |  | STR_0D |  | URL of software repository
core_transport.code.version |  | STR_0D |  | Unique version (tag) of software
core_transport.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_transport.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_transport.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
core_transport.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
core_transport.ids_properties.occurrence |  | INT_0D |  |
core_transport.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
core_transport.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
core_transport.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
core_transport.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
core_transport.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
core_transport.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
core_transport.model | [1...N] | STRUCT_ARRAY |  | Transport is described by a combination of various transport models
core_transport.model[:].code |  | STRUCTURE |  | Code-specific parameters used for this model
core_transport.model[:].code.commit |  | STR_0D |  | Unique commit reference of software
core_transport.model[:].code.name |  | STR_0D |  | Name of software used
core_transport.model[:].code.output_flag |  | STRUCTURE |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_transport.model[:].code.output_flag.data | [core_transport.model[:].code.output_flag.time] | INT_1D |  | Data
core_transport.model[:].code.output_flag.time | [1...N] | FLT_1D_TYPE | s | Time
core_transport.model[:].code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_transport.model[:].code.repository |  | STR_0D |  | URL of software repository
core_transport.model[:].code.version |  | STR_0D |  | Unique version (tag) of software
core_transport.model[:].comment |  | STR_0D |  | Any comment describing the model
core_transport.model[:].flux_multiplier |  | FLT_0D (uncertain) | - | Multiplier applied to the particule flux when adding its contribution in the expression of the heat flux : can be 0, 3/2 or 5/2
core_transport.model[:].identifier |  | STRUCTURE |  | Transport model identifier 0) unspecified : Unspecified transport type 1) combined : Combination of data from available transport models. Representation of the total transport in the system 2) transport_solver : Output from a transport solver 3) background : Background transport level, ad-hoc transport model not directly related to a physics model 4) database : Transport specified by a database entry external to the dynamic evolution of the plasma 5) neoclassical : Neoclassical 6) anomalous : Representation of turbulent transport 19) mhd : Transport arising from MHD frequency modes 20) ntm : Transport arising from the presence of NTMs 21) sawteeth : Transport arising from the presence of sawteeth 22) elm_continuous : Continuous ELM model --- gives the ELM averaged profile 23) elm_resolved : Time resolved ELM model 24) pedestal : Transport level to give edge pedestal 25) not_provided : No data provided
core_transport.model[:].identifier.description |  | STR_0D |  | Verbose description
core_transport.model[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_transport.model[:].identifier.name |  | STR_0D |  | Short string identifier
core_transport.model[:].profiles_1d | [core_transport.model[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Transport coefficient profiles for various time slices. Fluxes and convection are positive (resp. negative) when outwards i.e. towards the LCFS (resp. inwards i.e. towards the magnetic axes).
core_transport.model[:].profiles_1d[:].conductivity_parallel | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_transport.model[:].profiles_1d[:].e_field_radial | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component of the electric field (calculated e.g. by a neoclassical model)
core_transport.model[:].profiles_1d[:].electrons |  | STRUCTURE |  | Transport quantities related to the electrons
core_transport.model[:].profiles_1d[:].electrons.energy |  | STRUCTURE |  | Transport quantities for the electron energy equation
core_transport.model[:].profiles_1d[:].electrons.energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].electrons.energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].electrons.energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].electrons.particles |  | STRUCTURE |  | Transport quantities for the electron density equation
core_transport.model[:].profiles_1d[:].electrons.particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].electrons.particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].electrons.particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].grid_d |  | STRUCTURE |  | Grid for effective diffusivities and parallel conductivity
core_transport.model[:].profiles_1d[:].grid_d.area | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_d.psi | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_d.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_d.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_d.rho_pol_norm | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_transport.model[:].profiles_1d[:].grid_d.rho_tor | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_d.surface | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_transport.model[:].profiles_1d[:].grid_d.volume | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].grid_flux |  | STRUCTURE |  | Grid for fluxes
core_transport.model[:].profiles_1d[:].grid_flux.area | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_flux.psi | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_flux.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_flux.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_flux.rho_pol_norm | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_transport.model[:].profiles_1d[:].grid_flux.rho_tor | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_flux.surface | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_transport.model[:].profiles_1d[:].grid_flux.volume | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].grid_v |  | STRUCTURE |  | Grid for effective convections
core_transport.model[:].profiles_1d[:].grid_v.area | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_v.psi | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_v.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_v.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
core_transport.model[:].profiles_1d[:].grid_v.rho_pol_norm | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
core_transport.model[:].profiles_1d[:].grid_v.rho_tor | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_v.surface | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
core_transport.model[:].profiles_1d[:].grid_v.volume | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion species
core_transport.model[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_transport.model[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_transport.model[:].profiles_1d[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_transport.model[:].profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_transport.model[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_transport.model[:].profiles_1d[:].ion[:].energy |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
core_transport.model[:].profiles_1d[:].ion[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_transport.model[:].profiles_1d[:].ion[:].momentum |  | STRUCTURE |  | Transport coefficients related to the ion momentum equations for various components (directions)
core_transport.model[:].profiles_1d[:].ion[:].momentum.diamagnetic |  | STRUCTURE |  | Diamagnetic component
core_transport.model[:].profiles_1d[:].ion[:].momentum.diamagnetic.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].momentum.diamagnetic.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].momentum.diamagnetic.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].momentum.diamagnetic.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].momentum.parallel |  | STRUCTURE |  | Parallel component
core_transport.model[:].profiles_1d[:].ion[:].momentum.parallel.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].momentum.parallel.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].momentum.parallel.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].momentum.parallel.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].momentum.poloidal |  | STRUCTURE |  | Poloidal component
core_transport.model[:].profiles_1d[:].ion[:].momentum.poloidal.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].momentum.poloidal.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].momentum.poloidal.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].momentum.poloidal.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].momentum.radial |  | STRUCTURE |  | Radial component
core_transport.model[:].profiles_1d[:].ion[:].momentum.radial.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].momentum.radial.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].momentum.radial.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].momentum.radial.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].momentum.toroidal |  | STRUCTURE |  | Toroidal component
core_transport.model[:].profiles_1d[:].ion[:].momentum.toroidal.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].momentum.toroidal.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].momentum.toroidal.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].momentum.toroidal.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_transport.model[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_transport.model[:].profiles_1d[:].ion[:].particles |  | STRUCTURE |  | Transport related to the ion density equation
core_transport.model[:].profiles_1d[:].ion[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].ion[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
core_transport.model[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].is_neutral (obsolescent) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
core_transport.model[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum |  | STRUCTURE |  | Transport coefficients related to the state momentum equations for various components (directions)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.diamagnetic |  | STRUCTURE |  | Diamagnetic component
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.diamagnetic.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.diamagnetic.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.diamagnetic.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.diamagnetic.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.parallel |  | STRUCTURE |  | Parallel component
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.parallel.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.parallel.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.parallel.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.parallel.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.poloidal |  | STRUCTURE |  | Poloidal component
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.poloidal.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.poloidal.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.poloidal.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.poloidal.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.radial |  | STRUCTURE |  | Radial component
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.radial.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.radial.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.radial.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.radial.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.toroidal |  | STRUCTURE |  | Toroidal component
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.toroidal.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.toroidal.flow_damping_rate | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Damping rate for this flow component (e.g. due to collisions, calculated from a neoclassical model)
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.toroidal.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].momentum.toroidal.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type (obsolescent) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.description (obsolescent) |  | STR_0D |  | Verbose description
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.name (obsolescent) |  | STR_0D |  | Short string identifier
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_transport.model[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_transport.model[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
core_transport.model[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_transport.model[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
core_transport.model[:].profiles_1d[:].momentum_tor |  | STRUCTURE |  | Transport coefficients for total toroidal momentum equation
core_transport.model[:].profiles_1d[:].momentum_tor.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].momentum_tor.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].momentum_tor.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various neutral species
core_transport.model[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_transport.model[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_transport.model[:].profiles_1d[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
core_transport.model[:].profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_transport.model[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_transport.model[:].profiles_1d[:].neutral[:].energy |  | STRUCTURE |  | Transport coefficients related to the neutral energy equation
core_transport.model[:].profiles_1d[:].neutral[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_transport.model[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_transport.model[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_transport.model[:].profiles_1d[:].neutral[:].particles |  | STRUCTURE |  | Transport related to the neutral density equation
core_transport.model[:].profiles_1d[:].neutral[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
core_transport.model[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_transport.model[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_transport.model[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_transport.model[:].profiles_1d[:].total_ion_energy |  | STRUCTURE |  | Transport coefficients for the total (summed over ion species) energy equation
core_transport.model[:].profiles_1d[:].total_ion_energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].total_ion_energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].total_ion_energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.time | [1...N] | FLT_1D_TYPE | s | Generic time
core_transport.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_transport.vacuum_toroidal_field.b0 | [core_transport.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_transport.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
cryostat (alpha) |  |  |  | Description of the cryostat surrounding the machine (if any)
cryostat.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
cryostat.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
cryostat.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
cryostat.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
cryostat.code.library[:].name (alpha) |  | STR_0D |  | Name of software
cryostat.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
cryostat.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
cryostat.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
cryostat.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
cryostat.code.output_flag (alpha) | [cryostat.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
cryostat.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
cryostat.code.repository (alpha) |  | STR_0D |  | URL of software repository
cryostat.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
cryostat.description_2d (alpha) | [1...N] | STRUCT_ARRAY |  | Set of 2D cryostat descriptions, for each type of possible physics or engineering configurations necessary
cryostat.description_2d[:].cryostat (alpha) |  | STRUCTURE |  | Mechanical structure of the cryostat. It is described as a set of nested layers with given physics properties; Two representations are admitted for each vessel unit : annular (two contours) or block elements.
cryostat.description_2d[:].cryostat.type (alpha) |  | STRUCTURE |  | Type of the description. index = 0 for the official single/multiple annular representation and 1 for the official block element representation for each unit. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on index=2
cryostat.description_2d[:].cryostat.type.description (alpha) |  | STR_0D |  | Verbose description
cryostat.description_2d[:].cryostat.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
cryostat.description_2d[:].cryostat.type.name (alpha) |  | STR_0D |  | Short string identifier
cryostat.description_2d[:].cryostat.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of units
cryostat.description_2d[:].cryostat.unit[:].annular (alpha) |  | STRUCTURE |  | Annular representation of a layer by two contours, inner and outer. Alternatively, the layer can be described by a centreline and thickness.
cryostat.description_2d[:].cryostat.unit[:].annular.centreline (alpha) |  | STRUCTURE |  | Centreline, i.e. middle of the vessel layer as a series of point. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].cryostat.unit[:].annular.centreline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].cryostat.unit[:].annular.centreline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].cryostat.unit[:].annular.centreline.z (alpha) | [cryostat.description_2d[:].cryostat.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].cryostat.unit[:].annular.outline_inner (alpha) |  | STRUCTURE |  | Inner vessel outline. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].cryostat.unit[:].annular.outline_inner.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].cryostat.unit[:].annular.outline_inner.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].cryostat.unit[:].annular.outline_inner.z (alpha) | [cryostat.description_2d[:].cryostat.unit[:].annular.outline_inner.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].cryostat.unit[:].annular.outline_outer (alpha) |  | STRUCTURE |  | Outer vessel outline. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].cryostat.unit[:].annular.outline_outer.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].cryostat.unit[:].annular.outline_outer.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].cryostat.unit[:].annular.outline_outer.z (alpha) | [cryostat.description_2d[:].cryostat.unit[:].annular.outline_outer.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].cryostat.unit[:].annular.resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the vessel unit
cryostat.description_2d[:].cryostat.unit[:].annular.thickness (alpha) | [cryostat.description_2d[:].cryostat.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Thickness of the vessel layer in the perpendicular direction to the centreline. Thickness(i) is the thickness of the layer between centreline/r(i),z(i) and centreline/r(i+1),z(i+1)
cryostat.description_2d[:].cryostat.unit[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of block elements
cryostat.description_2d[:].cryostat.unit[:].element[:].j_tor (alpha) |  | STRUCTURE | A | Toroidal current induced in this block element
cryostat.description_2d[:].cryostat.unit[:].element[:].j_tor.data (alpha) | [cryostat.description_2d[:].cryostat.unit[:].element[:].j_tor.time] | FLT_1D (uncertain) | A | Data
cryostat.description_2d[:].cryostat.unit[:].element[:].j_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
cryostat.description_2d[:].cryostat.unit[:].element[:].name (alpha) |  | STR_0D |  | Name of the block element
cryostat.description_2d[:].cryostat.unit[:].element[:].outline (alpha) |  | STRUCTURE |  | Outline of the block element. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].cryostat.unit[:].element[:].outline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].cryostat.unit[:].element[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].cryostat.unit[:].element[:].outline.z (alpha) | [cryostat.description_2d[:].cryostat.unit[:].element[:].outline.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].cryostat.unit[:].element[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Resistance of the block element
cryostat.description_2d[:].cryostat.unit[:].element[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the block element
cryostat.description_2d[:].cryostat.unit[:].identifier (alpha) |  | STR_0D |  | Identifier of the unit
cryostat.description_2d[:].cryostat.unit[:].name (alpha) |  | STR_0D |  | Name of the unit
cryostat.description_2d[:].thermal_shield (alpha) |  | STRUCTURE |  | Mechanical structure of the cryostat thermal shield. It is described as a set of nested layers with given physics properties; Two representations are admitted for each vessel unit : annular (two contours) or block elements.
cryostat.description_2d[:].thermal_shield.type (alpha) |  | STRUCTURE |  | Type of the description. index = 0 for the official single/multiple annular representation and 1 for the official block element representation for each unit. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on index=2
cryostat.description_2d[:].thermal_shield.type.description (alpha) |  | STR_0D |  | Verbose description
cryostat.description_2d[:].thermal_shield.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
cryostat.description_2d[:].thermal_shield.type.name (alpha) |  | STR_0D |  | Short string identifier
cryostat.description_2d[:].thermal_shield.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of units
cryostat.description_2d[:].thermal_shield.unit[:].annular (alpha) |  | STRUCTURE |  | Annular representation of a layer by two contours, inner and outer. Alternatively, the layer can be described by a centreline and thickness.
cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline (alpha) |  | STRUCTURE |  | Centreline, i.e. middle of the vessel layer as a series of point. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline.z (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_inner (alpha) |  | STRUCTURE |  | Inner vessel outline. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_inner.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_inner.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_inner.z (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_inner.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_outer (alpha) |  | STRUCTURE |  | Outer vessel outline. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_outer.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_outer.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_outer.z (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].annular.outline_outer.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].thermal_shield.unit[:].annular.resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the vessel unit
cryostat.description_2d[:].thermal_shield.unit[:].annular.thickness (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Thickness of the vessel layer in the perpendicular direction to the centreline. Thickness(i) is the thickness of the layer between centreline/r(i),z(i) and centreline/r(i+1),z(i+1)
cryostat.description_2d[:].thermal_shield.unit[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of block elements
cryostat.description_2d[:].thermal_shield.unit[:].element[:].j_tor (alpha) |  | STRUCTURE | A | Toroidal current induced in this block element
cryostat.description_2d[:].thermal_shield.unit[:].element[:].j_tor.data (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].element[:].j_tor.time] | FLT_1D (uncertain) | A | Data
cryostat.description_2d[:].thermal_shield.unit[:].element[:].j_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
cryostat.description_2d[:].thermal_shield.unit[:].element[:].name (alpha) |  | STR_0D |  | Name of the block element
cryostat.description_2d[:].thermal_shield.unit[:].element[:].outline (alpha) |  | STRUCTURE |  | Outline of the block element. Do NOT repeat the first point for closed contours
cryostat.description_2d[:].thermal_shield.unit[:].element[:].outline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
cryostat.description_2d[:].thermal_shield.unit[:].element[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
cryostat.description_2d[:].thermal_shield.unit[:].element[:].outline.z (alpha) | [cryostat.description_2d[:].thermal_shield.unit[:].element[:].outline.r] | FLT_1D (uncertain) | m | Height
cryostat.description_2d[:].thermal_shield.unit[:].element[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Resistance of the block element
cryostat.description_2d[:].thermal_shield.unit[:].element[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the block element
cryostat.description_2d[:].thermal_shield.unit[:].identifier (alpha) |  | STR_0D |  | Identifier of the unit
cryostat.description_2d[:].thermal_shield.unit[:].name (alpha) |  | STR_0D |  | Name of the unit
cryostat.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
cryostat.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
cryostat.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
cryostat.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
cryostat.ids_properties.occurrence |  | INT_0D |  |
cryostat.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
cryostat.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
cryostat.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
cryostat.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
cryostat.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
cryostat.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
cryostat.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
dataset_description (alpha) |  |  |  | General description of the dataset (collection of all IDSs within the given database entry). Main description text to be put in ids_properties/comment
dataset_description.data_entry (alpha) |  | STRUCTURE |  | Definition of this data entry
dataset_description.data_entry.machine (alpha) |  | STR_0D |  | Name of the experimental device to which this data is related
dataset_description.data_entry.pulse (alpha) |  | INT_0D |  | Pulse number
dataset_description.data_entry.pulse_type (alpha) |  | STR_0D |  | Type of the data entry, e.g. "pulse", "simulation", ...
dataset_description.data_entry.run (alpha) |  | INT_0D |  | Run number
dataset_description.data_entry.user (alpha) |  | STR_0D |  | Username
dataset_description.dd_version (alpha) |  | STR_0D |  | Version of the physics data dictionary of this dataset
dataset_description.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
dataset_description.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
dataset_description.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
dataset_description.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
dataset_description.ids_properties.occurrence |  | INT_0D |  |
dataset_description.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
dataset_description.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
dataset_description.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
dataset_description.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
dataset_description.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
dataset_description.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
dataset_description.imas_version (alpha) |  | STR_0D |  | Version of the IMAS infrastructure used to produce this data entry. Refers to the global IMAS repository which links to versions of every infrastructure tools
dataset_description.parent_entry (alpha) |  | STRUCTURE |  | Definition of the parent data entry, if the present data entry has been generated by applying a given workflow to a unique parent entry
dataset_description.parent_entry.machine (alpha) |  | STR_0D |  | Name of the experimental device to which this data is related
dataset_description.parent_entry.pulse (alpha) |  | INT_0D |  | Pulse number
dataset_description.parent_entry.pulse_type (alpha) |  | STR_0D |  | Type of the data entry, e.g. "pulse", "simulation", ...
dataset_description.parent_entry.run (alpha) |  | INT_0D |  | Run number
dataset_description.parent_entry.user (alpha) |  | STR_0D |  | Username
dataset_description.pulse_time_begin (alpha) |  | STR_0D |  | Date and time (UTC) at which the pulse started on the experiment, expressed in a human readable form (ISO 8601) : the format of the string shall be : YYYY-MM-DDTHH:MM:SSZ. Example : 2020-07-24T14:19:00Z
dataset_description.pulse_time_begin_epoch (alpha) |  | STRUCTURE |  | Time at which the pulse started on the experiment, expressed in Unix Epoch time. Temporarily represented as two integers, since for the moment IMAS is missing 64bits long integers to represent epoch time with nanoseconds resolution
dataset_description.pulse_time_begin_epoch.nanoseconds (alpha) |  | INT_0D |  | Elapsed nanoseconds since the time in seconds indicated above
dataset_description.pulse_time_begin_epoch.seconds (alpha) |  | INT_0D |  | Elapsed seconds since the Unix Epoch time (01/01/1970 00:00:00 UTC)
dataset_description.pulse_time_end_epoch (alpha) |  | STRUCTURE |  | Time at which the pulse ended on the experiment, expressed in Unix Epoch time. Temporarily represented as two integers, since for the moment IMAS is missing 64bits long integers to represent epoch time with nanoseconds resolution
dataset_description.pulse_time_end_epoch.nanoseconds (alpha) |  | INT_0D |  | Elapsed nanoseconds since the time in seconds indicated above
dataset_description.pulse_time_end_epoch.seconds (alpha) |  | INT_0D |  | Elapsed seconds since the Unix Epoch time (01/01/1970 00:00:00 UTC)
dataset_description.simulation (alpha) |  | STRUCTURE |  | Description of the general simulation characteristics, if this data entry has been produced by a simulation. Several nodes describe typical time-dependent simulation with a time evolution as the main loop
dataset_description.simulation.comment_after (alpha) |  | STR_0D |  | Comment made at the end of a simulation
dataset_description.simulation.comment_before (alpha) |  | STR_0D |  | Comment made when launching a simulation
dataset_description.simulation.time_begin (alpha) |  | FLT_0D (uncertain) | s | Start time
dataset_description.simulation.time_begun (alpha) |  | STR_0D | UTC | Actual wall-clock time simulation started
dataset_description.simulation.time_current (alpha) |  | FLT_0D (uncertain) | s | Current time of the simulation
dataset_description.simulation.time_end (alpha) |  | FLT_0D (uncertain) | s | Stop time
dataset_description.simulation.time_ended (alpha) |  | STR_0D | UTC | Actual wall-clock time simulation finished
dataset_description.simulation.time_restart (alpha) |  | FLT_0D (uncertain) | s | Time of the last restart done during the simulation
dataset_description.simulation.time_step (alpha) |  | FLT_0D (uncertain) | s | Time interval between main steps, e.g. storage step (if relevant and constant)
dataset_description.simulation.workflow (alpha) |  | STR_0D |  | Description of the workflow which has been used to produce this data entry (e.g. copy of the Kepler MOML if using Kepler)
dataset_description.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
dataset_fair (alpha) |  |  |  | FAIR metadata related to the dataset, providing inforrmation on licensing, annotations, references using this dataset, versioning and validity, provenance. This IDS is using Dublin Core metadata standard whenever possible
dataset_fair.identifier (alpha) |  | STR_0D |  | Persistent identifier allowing to cite this data in a public and persistent way, should be provided as HTTP URIs
dataset_fair.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
dataset_fair.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
dataset_fair.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
dataset_fair.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
dataset_fair.ids_properties.occurrence |  | INT_0D |  |
dataset_fair.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
dataset_fair.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
dataset_fair.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
dataset_fair.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
dataset_fair.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
dataset_fair.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
dataset_fair.is_referenced_by (alpha) | [1...N] | STR_1D |  | List of documents (e.g. publications) or datasets making use of this data entry (e.g. PIDs of other datasets using this data entry as input)
dataset_fair.is_replaced_by (alpha) |  | STR_0D |  | Persistent identifier referencing the new version of this data (replacing the present version)
dataset_fair.license (alpha) |  | STR_0D |  | License(s) under which the data is made available (license description or, more convenient, publicly accessible URL pointing to the full license text)
dataset_fair.replaces (alpha) |  | STR_0D |  | Persistent identifier referencing the previous version of this data
dataset_fair.rights_holder (alpha) |  | STR_0D |  | The organisation owning or managing rights over this data
dataset_fair.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
dataset_fair.valid (alpha) |  | STR_0D |  | Date range during which the data is or was valid. Expressed as YYYY-MM-DD/YYYY-MM-DD, where the former (resp. latter) date is the data at which the data started (resp. ceased) to be valid. If the data is still valid, the slash should still be present, i.e. indicate the validity start date with YYYY-MM-DD/. If the data ceased being valid but there is no information on the validity start date, indicate /YYYY-MM-DD.

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
disruption (alpha) |  |  |  | Description of physics quantities of specific interest during a disruption, in particular halo currents, etc ...
disruption.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
disruption.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
disruption.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
disruption.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
disruption.code.library[:].name (alpha) |  | STR_0D |  | Name of software
disruption.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
disruption.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
disruption.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
disruption.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
disruption.code.output_flag (alpha) | [disruption.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
disruption.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
disruption.code.repository (alpha) |  | STR_0D |  | URL of software repository
disruption.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
disruption.global_quantities (alpha) |  | STRUCTURE |  | Global quantities
disruption.global_quantities.current_halo_pol (alpha) | [disruption.time] | FLT_1D (uncertain) | A | Poloidal halo current
disruption.global_quantities.current_halo_tor (alpha) | [disruption.time] | FLT_1D (uncertain) | A | Toroidal halo current
disruption.global_quantities.energy_ohm (alpha) | [disruption.time] | FLT_1D (uncertain) | J | Total ohmic cumulated energy (integral of the power over the disruption duration)
disruption.global_quantities.energy_ohm_halo (alpha) | [disruption.time] | FLT_1D (uncertain) | J | Ohmic cumulated energy (integral of the power over the disruption duration) in the halo region
disruption.global_quantities.energy_radiated_electrons_impurities (alpha) | [disruption.time] | FLT_1D (uncertain) | J | Total cumulated energy (integral of the power over the disruption duration) radiated by electrons on impurities
disruption.global_quantities.energy_radiated_electrons_impurities_halo (alpha) | [disruption.time] | FLT_1D (uncertain) | J | Cumulated energy (integral of the power over the disruption duration) radiated by electrons on impurities in the halo region
disruption.global_quantities.power_ohm (alpha) | [disruption.time] | FLT_1D (uncertain) | W | Total ohmic power
disruption.global_quantities.power_ohm_halo (alpha) | [disruption.time] | FLT_1D (uncertain) | W | Ohmic power in the halo region
disruption.global_quantities.power_radiated_electrons_impurities (alpha) | [disruption.time] | FLT_1D (uncertain) | W | Total power radiated by electrons on impurities
disruption.global_quantities.power_radiated_electrons_impurities_halo (alpha) | [disruption.time] | FLT_1D (uncertain) | W | Power radiated by electrons on impurities in the halo region
disruption.halo_currents (alpha) | [disruption.halo_currents[:].time] | STRUCT_ARRAY |  | Halo currents geometry and values for a set of time slices
disruption.halo_currents[:].active_wall_point (alpha) |  | STRUCTURE |  | R,Z position of the point of the plasma boundary in contact with the wall
disruption.halo_currents[:].active_wall_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
disruption.halo_currents[:].active_wall_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
disruption.halo_currents[:].area (alpha) | [1...N] | STRUCT_ARRAY |  | Set of wall areas through which there are halo currents
disruption.halo_currents[:].area[:].current_halo_pol (alpha) |  | FLT_0D (uncertain) | A | Poloidal halo current crossing through this area
disruption.halo_currents[:].area[:].end_point (alpha) |  | STRUCTURE |  | Position of the end point of this area
disruption.halo_currents[:].area[:].end_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
disruption.halo_currents[:].area[:].end_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
disruption.halo_currents[:].area[:].start_point (alpha) |  | STRUCTURE |  | Position of the start point of this area
disruption.halo_currents[:].area[:].start_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
disruption.halo_currents[:].area[:].start_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
disruption.halo_currents[:].time (alpha) |  | FLT_0D | s | Time
disruption.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
disruption.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
disruption.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
disruption.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
disruption.ids_properties.occurrence |  | INT_0D |  |
disruption.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
disruption.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
disruption.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
disruption.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
disruption.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
disruption.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
disruption.profiles_1d (alpha) | [disruption.profiles_1d[:].time] | STRUCT_ARRAY |  | Radial profiles for a set of time slices
disruption.profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
disruption.profiles_1d[:].grid.area (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
disruption.profiles_1d[:].grid.psi (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
disruption.profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
disruption.profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
disruption.profiles_1d[:].grid.rho_pol_norm (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
disruption.profiles_1d[:].grid.rho_tor (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
disruption.profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
disruption.profiles_1d[:].grid.surface (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
disruption.profiles_1d[:].grid.volume (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
disruption.profiles_1d[:].j_runaways (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Runaways parallel current density = average(j.B) / B0, where B0 = Disruption/Vacuum_Toroidal_Field/ B0
disruption.profiles_1d[:].power_density_conductive_losses (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Power density of conductive losses to the wall (positive sign for losses)
disruption.profiles_1d[:].power_density_radiative_losses (alpha) | [disruption.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Power density of radiative losses (positive sign for losses)
disruption.profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
disruption.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
disruption.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
disruption.vacuum_toroidal_field.b0 (alpha) | [disruption.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
disruption.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
distribution_sources (alpha) |  |  |  | Sources of particles for input to kinetic equations, e.g. Fokker-Planck calculation. The sources could originate from e.g. NBI or fusion reactions.
distribution_sources.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
distribution_sources.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
distribution_sources.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
distribution_sources.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
distribution_sources.code.library[:].name (alpha) |  | STR_0D |  | Name of software
distribution_sources.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distribution_sources.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
distribution_sources.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
distribution_sources.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
distribution_sources.code.output_flag (alpha) | [distribution_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
distribution_sources.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distribution_sources.code.repository (alpha) |  | STR_0D |  | URL of software repository
distribution_sources.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
distribution_sources.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
distribution_sources.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
distribution_sources.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
distribution_sources.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
distribution_sources.ids_properties.occurrence |  | INT_0D |  |
distribution_sources.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
distribution_sources.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
distribution_sources.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
distribution_sources.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
distribution_sources.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
distribution_sources.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
distribution_sources.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
distribution_sources.magnetic_axis.r (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | m | Major radius
distribution_sources.magnetic_axis.z (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | m | Height
distribution_sources.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of source/sink terms. A source/sink term corresponds to the particle source due to an NBI injection unit, a nuclear reaction or any combination of them (described in "identifier")
distribution_sources.source[:].ggd (alpha) | [distribution_sources.source[:].ggd[:].time] | STRUCT_ARRAY |  | Source terms in phase space (real space, velocity space, spin state), represented using the ggd, for various time slices
distribution_sources.source[:].ggd[:].discrete (alpha) | [1...N] | INT_1D |  | List of indices of grid spaces (refers to ../grid/space) for which the source is discretely distributed. For example consider a source of 3.5 MeV alpha particles provided on a grid with two coordinates (spaces); rho_tor and energy. To specify that the source is given at energies exactly equal to 3.5 MeV, let discret have length 1 and set discrete(1)=2 since energy is dimension number 2. The source is then proportional to delta( 1 - energy / 3.5MeV ), where delta is the direct delta distribution. Discrete dimensions can only be used when the grid is rectangular.
distribution_sources.source[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
distribution_sources.source[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
distribution_sources.source[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
distribution_sources.source[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
distribution_sources.source[:].ggd[:].grid.space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].ggd[:].grid.space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
distribution_sources.source[:].ggd[:].particles (alpha) | [1...N] | STRUCT_ARRAY | (m.s^-1)^-3.m^-3.s^-1 | Source density of particles in phase space, for various grid subsets
distribution_sources.source[:].ggd[:].particles[:].coefficients (alpha) | [distribution_sources.source[:].ggd[:].particles[:].values, 1...N] | FLT_2D (uncertain) | (m.s^-1)^-3.m^-3.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
distribution_sources.source[:].ggd[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
distribution_sources.source[:].ggd[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
distribution_sources.source[:].ggd[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | (m.s^-1)^-3.m^-3.s^-1 | One scalar value is provided per element in the grid subset.
distribution_sources.source[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].global_quantities (alpha) | [distribution_sources.source[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities for various time slices
distribution_sources.source[:].global_quantities[:].particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle source rate
distribution_sources.source[:].global_quantities[:].power (alpha) |  | FLT_0D (uncertain) | W | Total power of the source
distribution_sources.source[:].global_quantities[:].shinethrough (alpha) |  | STRUCTURE |  | Shinethrough losses
distribution_sources.source[:].global_quantities[:].shinethrough.particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle losses due to shinethrough
distribution_sources.source[:].global_quantities[:].shinethrough.power (alpha) |  | FLT_0D (uncertain) | W | Power losses due to shinethrough
distribution_sources.source[:].global_quantities[:].shinethrough.torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal torque losses due to shinethrough
distribution_sources.source[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].global_quantities[:].torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Total toroidal torque of the source
distribution_sources.source[:].gyro_type (alpha) |  | INT_0D |  | Defines how to interpret the spatial coordinates: 1 = given at the actual particle birth point; 2 =given at the gyro centre of the birth point
distribution_sources.source[:].markers (alpha) | [distribution_sources.source[:].markers[:].time] | STRUCT_ARRAY |  | Source given as a group of markers (test particles) born per second, for various time slices
distribution_sources.source[:].markers[:].coordinate_identifier (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Set of coordinate identifiers, coordinates on which the markers are represented 0) unspecified : unspecified 1) x : First cartesian coordinate in the horizontal plane 2) y : Second cartesian coordinate in the horizontal plane (grad(x) x grad(y) = grad(z)) 3) z : Vertical coordinate z 4) r : Major radius 5) phi : Toroidal angle 10) psi : Poloidal magnetic flux 11) rho_tor : The square root of the toroidal flux, sqrt((Phi-Phi_axis)/pi/B0), where Phi is the toroidal flux and B0 is the vaccum magnetic field 12) rho_tor_norm : The square root of the normalised toroidal flux, sqrt((Phi-Phi_axis)/(Phi_lcf-Phi_axis)), where Phi is the toroidal flux 13) rho_pol : The square root of the poloidal flux, sqrt(psi-psi_axis), where psi is the poloidal flux 14) rho_pol_norm : The square root of the normalised poloidal flux, sqrt((psi-psi_axis)/(psi_lcf-psi_axis)), where psi is the poloidal flux 20) theta : Geometrical poloidal angle around the magnetic axis 21) theta_straight : Straight field line poloidal angle 22) theta_equal_arc : Equal-arc poloidal angle; a differential of the angle is proportional to the length of the corresponding arc in the poloidal plane. 100) velocity : Total velocity; modulus of the velocity vector 101) velocity_x : Velocity component in the x-direction 102) velocity_y : Velocity component in the z-direction 103) velocity_z : Velocity component in the z-direction 104) velocity_phi : Velocity component in the toroidal direction 105) velocity_parallel : Velocity component parallel to the magnetic field 106) velocity_perpendicular : Velocity perpendicular to the magnetic field 107) velocity_thermal : Velocity normalised to the local thermal velocity of the thermal ions (of the relevant species) 200) momentum : Modulus of the relativistic momentum vector 201) momentum_parallel : Component of the relativistic momentum vector parallel to the magnetic field 202) momentum_perpendicular : Component of the relativistic momentum vector perpendicular to the magnetic field 203) canonical_momentum_phi : Canonical toroidal angular momentum 300) energy_hamiltonian : Hamiltonian energy, including both kinetic and potential energy 301) energy_kinetic : Kinetic energy 302) magnetic_moment : magnetic moment 400) lambda : Ratio, magnetic moment over hamiltonian energy 402) pitch_angle : Angle between the magnetic field and the velocity vector 403) pitch : Ratio, parallel velocity over total velocity 404) pitch_at_min_b : Pitch, ratio between the parallel over the perpendicular velocity, at the minimum value of the magnetic field strength along the guiding centre orbit
distribution_sources.source[:].markers[:].coordinate_identifier[:].description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].markers[:].coordinate_identifier[:].index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].markers[:].coordinate_identifier[:].name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].markers[:].positions (alpha) | [distribution_sources.source[:].markers[:].weights, distribution_sources.source[:].markers[:].coordinate_identifier] | FLT_2D (uncertain) | mixed | Position of the markers in the set of coordinates. The first dimension corresponds to the number of markers, the second dimension to the set of coordinates
distribution_sources.source[:].markers[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].markers[:].weights (alpha) | [1...N] | FLT_1D (uncertain) | - | Weight of the markers, i.e. number of real particles represented by each marker. The dimension of the vector correspond to the number of markers
distribution_sources.source[:].process (alpha) | [1...N] | STRUCT_ARRAY |  | Set of processes (NBI units, fusion reactions, ...) that provide the source.
distribution_sources.source[:].process[:].nbi_beamlets_group (alpha) |  | INT_0D |  | Index of the NBI beamlets group considered. Refers to the "unit/beamlets_group" array of the NBI IDS. 0 means sum over all beamlets groups.
distribution_sources.source[:].process[:].nbi_energy (alpha) |  | STRUCTURE |  | For NBI source, energy of the accelerated species considered. index = 0 for a sum over all energies; index = 1 for full energiy; index = 2 for half energy; index = 3 for third energy
distribution_sources.source[:].process[:].nbi_energy.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].nbi_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].process[:].nbi_energy.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].process[:].nbi_unit (alpha) |  | INT_0D |  | Index of the NBI unit considered. Refers to the "unit" array of the NBI IDS. 0 means sum over all NBI units.
distribution_sources.source[:].process[:].reactant_energy (alpha) |  | STRUCTURE |  | For nuclear reaction source, energy of the reactants. index = 0 for a sum over all energies; index = 1 for thermal-thermal; index = 2 for beam-beam; index = 3 for beam-thermal
distribution_sources.source[:].process[:].reactant_energy.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].reactant_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].process[:].reactant_energy.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].process[:].type (alpha) |  | STRUCTURE |  | Process type. index=1 for NBI; index=2 for nuclear reaction (reaction unspecified); index=3 for nuclear reaction: T(d,n)4He [D+T->He4+n]; index=4 for nuclear reaction: He3(d,p)4He [He3+D->He4+p]; index=5 for nuclear reaction: D(d,p)T [D+D->T+p]; index=6 for nuclear reaction: D(d,n)3He [D+D->He3+n]; index=7 for runaway processes 0) unspecified : unspecified 1) NBI : Source from neutral beam injection 100) nuclear : Source from nuclear reaction (reaction type unspecified) 101) H_H_to_D_positron_nu : Source from nuclear reaction: H+H->D+positron+neutrino 102) H_D_to_He3_gamma : Source from nuclear reaction: H+D->He3+gamma 103) H_T_to_He3_n : Source from nuclear reaction: H+T->He3+neutron 104) H_He3_to_He4_positron_nu : Source from nuclear reaction: H+He3->He4+positron+neutrino 105) D_D_to_T_H : Source from nuclear reaction: D+D->T+H 106) D_D_to_He3_n : Source from nuclear reaction: D+D->He3+neutron 107) D_T_to_He4_n : Source from nuclear reaction: T+D->He4+neutron 108) D_He3_to_He4_H : Source from nuclear reaction: He3+D->He4+H 109) T_T_to_He4_n_n : Source from nuclear reaction: T+T->He4+neutron+neutron 110) T_He3_to_He4_H_n : Source from nuclear reaction: He3+T->He4+H+neutron 111) He3_He3_to_He4_H_H : Source from nuclear reaction: He3+He3->He4+neutron+neutron 112) He3_He4_to_Be7_gamma : Source from nuclear reaction: He3+He4->Be7+gamma 113) Li6_n_to_He4_T : Source from nuclear reaction: Li6+n->He4+T 114) Li7_n_to_He4_T_n : Source from nuclear reaction: Li7+n->He4+T+n 1000) runaway : Source from runaway processes
distribution_sources.source[:].process[:].type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].process[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].profiles_1d (alpha) | [distribution_sources.source[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source radial profiles (flux surface averaged quantities) for various time slices
distribution_sources.source[:].profiles_1d[:].energy (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the energy transport equation
distribution_sources.source[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
distribution_sources.source[:].profiles_1d[:].grid.area (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distribution_sources.source[:].profiles_1d[:].grid.psi (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distribution_sources.source[:].profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
distribution_sources.source[:].profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
distribution_sources.source[:].profiles_1d[:].grid.rho_pol_norm (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
distribution_sources.source[:].profiles_1d[:].grid.rho_tor (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
distribution_sources.source[:].profiles_1d[:].grid.surface (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
distribution_sources.source[:].profiles_1d[:].grid.volume (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distribution_sources.source[:].profiles_1d[:].momentum_tor (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source term for the toroidal momentum equation
distribution_sources.source[:].profiles_1d[:].particles (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the density transport equation
distribution_sources.source[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].species (alpha) |  | STRUCTURE |  | Species injected or consumed by this source/sink
distribution_sources.source[:].species.ion (alpha) |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
distribution_sources.source[:].species.ion.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distribution_sources.source[:].species.ion.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distribution_sources.source[:].species.ion.element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distribution_sources.source[:].species.ion.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distribution_sources.source[:].species.ion.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distribution_sources.source[:].species.ion.label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
distribution_sources.source[:].species.ion.state (alpha) |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
distribution_sources.source[:].species.ion.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distribution_sources.source[:].species.ion.state.label (alpha) |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distribution_sources.source[:].species.ion.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distribution_sources.source[:].species.ion.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distribution_sources.source[:].species.ion.state.z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distribution_sources.source[:].species.ion.state.z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distribution_sources.source[:].species.ion.z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
distribution_sources.source[:].species.neutral (alpha) |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
distribution_sources.source[:].species.neutral.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distribution_sources.source[:].species.neutral.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distribution_sources.source[:].species.neutral.element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distribution_sources.source[:].species.neutral.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distribution_sources.source[:].species.neutral.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distribution_sources.source[:].species.neutral.label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
distribution_sources.source[:].species.neutral.state (alpha) |  | STRUCTURE |  | State of the species (energy, excitation, ...)
distribution_sources.source[:].species.neutral.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distribution_sources.source[:].species.neutral.state.label (alpha) |  | STR_0D |  | String identifying neutral state
distribution_sources.source[:].species.neutral.state.neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
distribution_sources.source[:].species.neutral.state.neutral_type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].species.neutral.state.neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].species.neutral.state.neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].species.neutral.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distribution_sources.source[:].species.neutral.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distribution_sources.source[:].species.type (alpha) |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon 0) unspecified : unspecified 1) electron : Electron 2) ion : Ion species in a single/average state; refer to ion-structure 3) ion_state : Ion species in a particular state; refer to ion/state-structure 4) neutral : Neutral species in a single/average state; refer to neutral-structure 5) neutral_state : Neutral species in a particular state; refer to neutral/state-structure 6) neutron : Neutron 7) photon : Photon
distribution_sources.source[:].species.type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].species.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distribution_sources.source[:].species.type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
distribution_sources.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
distribution_sources.vacuum_toroidal_field.b0 (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
distribution_sources.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
distributions (alpha) |  |  |  | Distribution function(s) of one or many particle species. This structure is specifically designed to handle non-Maxwellian distribution function generated during heating and current drive, typically solved using a Fokker-Planck calculation perturbed by a heating scheme (e.g. IC, EC, LH, NBI, or alpha heating) and then relaxed by Coloumb collisions.
distributions.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
distributions.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
distributions.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
distributions.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
distributions.code.library[:].name (alpha) |  | STR_0D |  | Name of software
distributions.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distributions.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
distributions.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
distributions.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
distributions.code.output_flag (alpha) | [distributions.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
distributions.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distributions.code.repository (alpha) |  | STR_0D |  | URL of software repository
distributions.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
distributions.distribution (alpha) | [1...N] | STRUCT_ARRAY |  | Set of distribution functions. Every distribution function has to be associated with only one particle species, specified in distri_vec/species/, but there could be multiple distribution function for each species. In this case, the fast particle populations should be superposed
distributions.distribution[:].ggd (alpha) | [distributions.distribution[:].ggd[:].time] | STRUCT_ARRAY |  | Distribution represented using the ggd, for various time slices
distributions.distribution[:].ggd[:].expansion (alpha) | [1...N] | STRUCT_ARRAY | (m.s^-1)^-3.m^-3.s^-1 | Distribution function expanded into a vector of successive approximations. The first element in the vector (expansion(1)) is the zeroth order distribution function, while the K:th element in the vector (expansion(K)) is the K:th correction, such that the total distribution function is a sum over all elements in the expansion vector.
distributions.distribution[:].ggd[:].expansion[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY | mixed | Values of the distribution function expansion, for various grid subsets
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].coefficients (alpha) | [distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].values (alpha) | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
distributions.distribution[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
distributions.distribution[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
distributions.distribution[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
distributions.distribution[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
distributions.distribution[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
distributions.distribution[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
distributions.distribution[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
distributions.distribution[:].ggd[:].grid.space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].ggd[:].grid.space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
distributions.distribution[:].ggd[:].temperature (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Reference temperature profile used to define the local thermal energy and the thermal velocity (for normalisation of the grid coordinates)
distributions.distribution[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].global_quantities (alpha) | [distributions.distribution[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities (integrated over plasma volume for moments of the distribution, collisional exchange and source terms), for various time slices
distributions.distribution[:].global_quantities[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].global_quantities[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].global_quantities[:].collisions.electrons.power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].global_quantities[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].global_quantities[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].global_quantities[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].global_quantities[:].collisions.ion[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].global_quantities[:].collisions.ion[:].torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].global_quantities[:].current_tor (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal current driven by the distribution
distributions.distribution[:].global_quantities[:].energy (alpha) |  | FLT_0D (uncertain) | J | Total energy in the distribution
distributions.distribution[:].global_quantities[:].energy_fast (alpha) |  | FLT_0D (uncertain) | J | Total energy of the fast particles in the distribution
distributions.distribution[:].global_quantities[:].energy_fast_parallel (alpha) |  | FLT_0D (uncertain) | J | Parallel energy of the fast particles in the distribution
distributions.distribution[:].global_quantities[:].particles_fast_n (alpha) |  | FLT_0D (uncertain) | - | Number of fast particles in the distribution, i.e. the volume integral of the density (note: this is the number of real particles and not markers)
distributions.distribution[:].global_quantities[:].particles_n (alpha) |  | FLT_0D (uncertain) | - | Number of particles in the distribution, i.e. the volume integral of the density (note: this is the number of real particles and not markers)
distributions.distribution[:].global_quantities[:].source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of volume integrated sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].global_quantities[:].source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].global_quantities[:].source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].global_quantities[:].source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].global_quantities[:].source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].global_quantities[:].source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].global_quantities[:].source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].global_quantities[:].source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].global_quantities[:].source[:].particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle source rate
distributions.distribution[:].global_quantities[:].source[:].power (alpha) |  | FLT_0D (uncertain) | W | Total power of the source
distributions.distribution[:].global_quantities[:].source[:].torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Total toroidal torque of the source
distributions.distribution[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].global_quantities[:].torque_tor_j_radial (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal torque due to radial currents
distributions.distribution[:].gyro_type (alpha) |  | INT_0D |  | Defines how to interpret the spatial coordinates: 1 = given at the actual particle birth point; 2 =given at the gyro centre of the birth point
distributions.distribution[:].is_delta_f (alpha) |  | INT_0D |  | If is_delta_f=1, then the distribution represents the deviation from a Maxwellian; is_delta_f=0, then the distribution represents all particles, i.e. the full-f solution
distributions.distribution[:].markers (alpha) | [distributions.distribution[:].markers[:].time] | STRUCT_ARRAY |  | Distribution represented by a set of markers (test particles)
distributions.distribution[:].markers[:].coordinate_identifier (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Set of coordinate identifiers, coordinates on which the markers are represented 0) unspecified : unspecified 1) x : First cartesian coordinate in the horizontal plane 2) y : Second cartesian coordinate in the horizontal plane (grad(x) x grad(y) = grad(z)) 3) z : Vertical coordinate z 4) r : Major radius 5) phi : Toroidal angle 10) psi : Poloidal magnetic flux 11) rho_tor : The square root of the toroidal flux, sqrt((Phi-Phi_axis)/pi/B0), where Phi is the toroidal flux and B0 is the vaccum magnetic field 12) rho_tor_norm : The square root of the normalised toroidal flux, sqrt((Phi-Phi_axis)/(Phi_lcf-Phi_axis)), where Phi is the toroidal flux 13) rho_pol : The square root of the poloidal flux, sqrt(psi-psi_axis), where psi is the poloidal flux 14) rho_pol_norm : The square root of the normalised poloidal flux, sqrt((psi-psi_axis)/(psi_lcf-psi_axis)), where psi is the poloidal flux 20) theta : Geometrical poloidal angle around the magnetic axis 21) theta_straight : Straight field line poloidal angle 22) theta_equal_arc : Equal-arc poloidal angle; a differential of the angle is proportional to the length of the corresponding arc in the poloidal plane. 100) velocity : Total velocity; modulus of the velocity vector 101) velocity_x : Velocity component in the x-direction 102) velocity_y : Velocity component in the z-direction 103) velocity_z : Velocity component in the z-direction 104) velocity_phi : Velocity component in the toroidal direction 105) velocity_parallel : Velocity component parallel to the magnetic field 106) velocity_perpendicular : Velocity perpendicular to the magnetic field 107) velocity_thermal : Velocity normalised to the local thermal velocity of the thermal ions (of the relevant species) 200) momentum : Modulus of the relativistic momentum vector 201) momentum_parallel : Component of the relativistic momentum vector parallel to the magnetic field 202) momentum_perpendicular : Component of the relativistic momentum vector perpendicular to the magnetic field 203) canonical_momentum_phi : Canonical toroidal angular momentum 300) energy_hamiltonian : Hamiltonian energy, including both kinetic and potential energy 301) energy_kinetic : Kinetic energy 302) magnetic_moment : magnetic moment 400) lambda : Ratio, magnetic moment over hamiltonian energy 402) pitch_angle : Angle between the magnetic field and the velocity vector 403) pitch : Ratio, parallel velocity over total velocity 404) pitch_at_min_b : Pitch, ratio between the parallel over the perpendicular velocity, at the minimum value of the magnetic field strength along the guiding centre orbit
distributions.distribution[:].markers[:].coordinate_identifier[:].description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].markers[:].coordinate_identifier[:].index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].markers[:].coordinate_identifier[:].name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].markers[:].positions (alpha) | [distributions.distribution[:].markers[:].weights, distributions.distribution[:].markers[:].coordinate_identifier] | FLT_2D (uncertain) | mixed | Position of the markers in the set of coordinates. The first dimension corresponds to the number of markers, the second dimension to the set of coordinates
distributions.distribution[:].markers[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].markers[:].weights (alpha) | [1...N] | FLT_1D (uncertain) | - | Weight of the markers, i.e. number of real particles represented by each marker. The dimension of the vector correspond to the number of markers
distributions.distribution[:].process (alpha) | [1...N] | STRUCT_ARRAY |  | List all processes (NBI units, fusion reactions, ...) affecting the distribution, identified as in distribution_sources/source(i)/process in the DISTRIBUTION_SOURCES IDS
distributions.distribution[:].process[:].nbi_beamlets_group (alpha) |  | INT_0D |  | Index of the NBI beamlets group considered. Refers to the "unit/beamlets_group" array of the NBI IDS. 0 means sum over all beamlets groups.
distributions.distribution[:].process[:].nbi_energy (alpha) |  | STRUCTURE |  | For NBI source, energy of the accelerated species considered. index = 0 for a sum over all energies; index = 1 for full energiy; index = 2 for half energy; index = 3 for third energy
distributions.distribution[:].process[:].nbi_energy.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].nbi_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].process[:].nbi_energy.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].process[:].nbi_unit (alpha) |  | INT_0D |  | Index of the NBI unit considered. Refers to the "unit" array of the NBI IDS. 0 means sum over all NBI units.
distributions.distribution[:].process[:].reactant_energy (alpha) |  | STRUCTURE |  | For nuclear reaction source, energy of the reactants. index = 0 for a sum over all energies; index = 1 for thermal-thermal; index = 2 for beam-beam; index = 3 for beam-thermal
distributions.distribution[:].process[:].reactant_energy.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].reactant_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].process[:].reactant_energy.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].process[:].type (alpha) |  | STRUCTURE |  | Process type. index=1 for NBI; index=2 for nuclear reaction (reaction unspecified); index=3 for nuclear reaction: T(d,n)4He [D+T->He4+n]; index=4 for nuclear reaction: He3(d,p)4He [He3+D->He4+p]; index=5 for nuclear reaction: D(d,p)T [D+D->T+p]; index=6 for nuclear reaction: D(d,n)3He [D+D->He3+n]; index=7 for runaway processes 0) unspecified : unspecified 1) NBI : Source from neutral beam injection 100) nuclear : Source from nuclear reaction (reaction type unspecified) 101) H_H_to_D_positron_nu : Source from nuclear reaction: H+H->D+positron+neutrino 102) H_D_to_He3_gamma : Source from nuclear reaction: H+D->He3+gamma 103) H_T_to_He3_n : Source from nuclear reaction: H+T->He3+neutron 104) H_He3_to_He4_positron_nu : Source from nuclear reaction: H+He3->He4+positron+neutrino 105) D_D_to_T_H : Source from nuclear reaction: D+D->T+H 106) D_D_to_He3_n : Source from nuclear reaction: D+D->He3+neutron 107) D_T_to_He4_n : Source from nuclear reaction: T+D->He4+neutron 108) D_He3_to_He4_H : Source from nuclear reaction: He3+D->He4+H 109) T_T_to_He4_n_n : Source from nuclear reaction: T+T->He4+neutron+neutron 110) T_He3_to_He4_H_n : Source from nuclear reaction: He3+T->He4+H+neutron 111) He3_He3_to_He4_H_H : Source from nuclear reaction: He3+He3->He4+neutron+neutron 112) He3_He4_to_Be7_gamma : Source from nuclear reaction: He3+He4->Be7+gamma 113) Li6_n_to_He4_T : Source from nuclear reaction: Li6+n->He4+T 114) Li7_n_to_He4_T_n : Source from nuclear reaction: Li7+n->He4+T+n 1000) runaway : Source from runaway processes
distributions.distribution[:].process[:].type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].process[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d (alpha) | [distributions.distribution[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Radial profiles (flux surface averaged quantities) for various time slices
distributions.distribution[:].profiles_1d[:].co_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the co-passing particle part of the distribution.
distributions.distribution[:].profiles_1d[:].co_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].co_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].co_passing.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].co_passing.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].co_passing.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].co_passing.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].co_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].co_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].co_passing.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].co_passing.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].co_passing.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].co_passing.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].co_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].counter_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the counter-passing particle part of the distribution.
distributions.distribution[:].profiles_1d[:].counter_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].counter_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].counter_passing.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].counter_passing.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].counter_passing.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].counter_passing.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].counter_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].counter_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].counter_passing.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].counter_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].fast_filter (alpha) |  | STRUCTURE |  | Description of how the fast and the thermal particle populations are separated
distributions.distribution[:].profiles_1d[:].fast_filter.energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Energy at which the fast and thermal particle populations were separated, as a function of radius
distributions.distribution[:].profiles_1d[:].fast_filter.method (alpha) |  | STRUCTURE |  | Method used to separate the fast and thermal particle population (indices TBD)
distributions.distribution[:].profiles_1d[:].fast_filter.method.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].fast_filter.method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_1d[:].fast_filter.method.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
distributions.distribution[:].profiles_1d[:].grid.area (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distributions.distribution[:].profiles_1d[:].grid.psi (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distributions.distribution[:].profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
distributions.distribution[:].profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
distributions.distribution[:].profiles_1d[:].grid.rho_pol_norm (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
distributions.distribution[:].profiles_1d[:].grid.rho_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
distributions.distribution[:].profiles_1d[:].grid.surface (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
distributions.distribution[:].profiles_1d[:].grid.volume (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distributions.distribution[:].profiles_1d[:].pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].thermalisation (alpha) |  | STRUCTURE |  | Flux surface averaged source of thermal particles, momentum and energy due to thermalisation. Here thermalisation refers to non-thermal particles, sufficiently assimilated to the thermal background to be re-categorised as thermal particles. Note that this source may also be negative if thermal particles are being accelerated such that they form a distinct non-thermal contribution, e.g. due run-away of RF interactions.
distributions.distribution[:].profiles_1d[:].thermalisation.energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density within the thermal particle population due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].thermalisation.momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density within the thermal particle population due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].thermalisation.particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].profiles_1d[:].torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].trapped (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the trapped particle part of the distribution.
distributions.distribution[:].profiles_1d[:].trapped.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].trapped.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].trapped.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].trapped.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].trapped.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].trapped.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].trapped.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].trapped.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].trapped.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].trapped.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].trapped.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].trapped.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].trapped.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d (alpha) | [distributions.distribution[:].profiles_2d[:].time] | STRUCT_ARRAY |  | 2D profiles in the poloidal plane for various time slices
distributions.distribution[:].profiles_2d[:].co_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the co-passing particle part of the distribution.
distributions.distribution[:].profiles_2d[:].co_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].co_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].co_passing.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].co_passing.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].co_passing.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].co_passing.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].co_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].co_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].co_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].counter_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the counter-passing particle part of the distribution.
distributions.distribution[:].profiles_2d[:].counter_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].counter_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].counter_passing.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].counter_passing.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].counter_passing.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].counter_passing.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].counter_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].counter_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].counter_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].grid (alpha) |  | STRUCTURE |  | Grid. The grid has to be rectangular in a pair of coordinates, as specified in type
distributions.distribution[:].profiles_2d[:].grid.area (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distributions.distribution[:].profiles_2d[:].grid.psi (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distributions.distribution[:].profiles_2d[:].grid.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
distributions.distribution[:].profiles_2d[:].grid.rho_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
distributions.distribution[:].profiles_2d[:].grid.theta_geometric (alpha) | [1...N] | FLT_1D (uncertain) | rad | Geometrical poloidal angle
distributions.distribution[:].profiles_2d[:].grid.theta_straight (alpha) | [1...N] | FLT_1D (uncertain) | rad | Straight field line poloidal angle
distributions.distribution[:].profiles_2d[:].grid.type (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | STRUCTURE | m^3 | Grid type: index=0: Rectangular grid in the (R,Z) coordinates; index=1: Rectangular grid in the (radial, theta_geometric) coordinates; index=2: Rectangular grid in the (radial, theta_straight) coordinates.
distributions.distribution[:].profiles_2d[:].grid.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_2d[:].grid.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].profiles_2d[:].grid.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_2d[:].grid.volume (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distributions.distribution[:].profiles_2d[:].grid.z (alpha) | [1...N] | FLT_1D (uncertain) | m | Height
distributions.distribution[:].profiles_2d[:].pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].profiles_2d[:].torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].trapped (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the trapped particle part of the distribution.
distributions.distribution[:].profiles_2d[:].trapped.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].trapped.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].trapped.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].trapped.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].trapped.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].trapped.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].trapped.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].trapped.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].trapped.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].species (alpha) |  | STRUCTURE |  | Species described by this distribution
distributions.distribution[:].species.ion (alpha) |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
distributions.distribution[:].species.ion.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].species.ion.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].species.ion.element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].species.ion.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].species.ion.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].species.ion.label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
distributions.distribution[:].species.ion.state (alpha) |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
distributions.distribution[:].species.ion.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].species.ion.state.label (alpha) |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].species.ion.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].species.ion.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].species.ion.state.z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].species.ion.state.z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].species.ion.z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
distributions.distribution[:].species.neutral (alpha) |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
distributions.distribution[:].species.neutral.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].species.neutral.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].species.neutral.element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
distributions.distribution[:].species.neutral.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].species.neutral.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].species.neutral.label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
distributions.distribution[:].species.neutral.state (alpha) |  | STRUCTURE |  | State of the species (energy, excitation, ...)
distributions.distribution[:].species.neutral.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].species.neutral.state.label (alpha) |  | STR_0D |  | String identifying neutral state
distributions.distribution[:].species.neutral.state.neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
distributions.distribution[:].species.neutral.state.neutral_type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].species.neutral.state.neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].species.neutral.state.neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].species.neutral.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].species.neutral.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].species.type (alpha) |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon 0) unspecified : unspecified 1) electron : Electron 2) ion : Ion species in a single/average state; refer to ion-structure 3) ion_state : Ion species in a particular state; refer to ion/state-structure 4) neutral : Neutral species in a single/average state; refer to neutral-structure 5) neutral_state : Neutral species in a particular state; refer to neutral/state-structure 6) neutron : Neutron 7) photon : Photon
distributions.distribution[:].species.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].species.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].species.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].wave (alpha) | [1...N] | STRUCT_ARRAY |  | List all waves affecting the distribution, identified as in waves/coherent_wave(i)/identifier in the waves IDS
distributions.distribution[:].wave[:].antenna_name (alpha) |  | STR_0D |  | Name of the antenna that launches this wave. Corresponds to the name specified in antennas/ec(i)/name, or antennas/ic(i)/name or antennas/lh(i)/name (depends of antenna/wave type) in the ANTENNAS IDS.
distributions.distribution[:].wave[:].index_in_antenna (alpha) |  | INT_0D |  | Index of the wave (starts at 1), separating different waves generated from a single antenna.
distributions.distribution[:].wave[:].type (alpha) |  | STRUCTURE |  | Wave/antenna type. index=1 for name=EC; index=2 for name=IC; index=3 for name=LH 0) unspecified : unspecified 1) EC : Wave field for electron cyclotron heating and current drive 2) LH : Wave field for lower hybrid heating and current drive 3) IC : Wave field for ion cyclotron frequency heating and current drive
distributions.distribution[:].wave[:].type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].wave[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
distributions.distribution[:].wave[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
distributions.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
distributions.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
distributions.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
distributions.ids_properties.occurrence |  | INT_0D |  |
distributions.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
distributions.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
distributions.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
distributions.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
distributions.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
distributions.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
distributions.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
distributions.magnetic_axis.r (alpha) | [distributions.time] | FLT_1D (uncertain) | m | Major radius
distributions.magnetic_axis.z (alpha) | [distributions.time] | FLT_1D (uncertain) | m | Height
distributions.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
distributions.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
distributions.vacuum_toroidal_field.b0 (alpha) | [distributions.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
distributions.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ec_launchers (alpha) |  |  |  | Launchers for heating and current drive in the electron cyclotron (EC) frequencies.
ec_launchers.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ec_launchers.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ec_launchers.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
ec_launchers.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
ec_launchers.code.library[:].name (alpha) |  | STR_0D |  | Name of software
ec_launchers.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ec_launchers.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
ec_launchers.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
ec_launchers.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ec_launchers.code.output_flag (alpha) | [ec_launchers.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ec_launchers.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ec_launchers.code.repository (alpha) |  | STR_0D |  | URL of software repository
ec_launchers.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ec_launchers.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ec_launchers.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ec_launchers.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
ec_launchers.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
ec_launchers.ids_properties.occurrence |  | INT_0D |  |
ec_launchers.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
ec_launchers.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
ec_launchers.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
ec_launchers.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
ec_launchers.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
ec_launchers.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
ec_launchers.launcher (alpha) | [1...N] | STRUCT_ARRAY |  | Set of Electron Cyclotron launchers
ec_launchers.launcher[:].beam (alpha) |  | STRUCTURE |  | Beam characteristics
ec_launchers.launcher[:].beam.phase (alpha) |  | STRUCTURE |  | Phase ellipse characteristics
ec_launchers.launcher[:].beam.phase.angle (alpha) |  | STRUCTURE | rad | Rotation angle for the phase ellipse
ec_launchers.launcher[:].beam.phase.angle.data (alpha) | [ec_launchers.launcher[:].beam.phase.angle.time] | FLT_1D (uncertain) | rad | Data
ec_launchers.launcher[:].beam.phase.angle.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].beam.phase.curvature (alpha) | [1...2, ec_launchers.launcher[:].beam.phase.curvature.time] | STRUCTURE | m^-1 | Inverse curvature radii for the phase ellipse, positive/negative for divergent/convergent beams
ec_launchers.launcher[:].beam.phase.curvature.data (alpha) | [1...N, ec_launchers.launcher[:].beam.phase.curvature.time] | FLT_2D (uncertain) | m^-1 | Data
ec_launchers.launcher[:].beam.phase.curvature.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].beam.spot (alpha) |  | STRUCTURE |  | Spot ellipse characteristics
ec_launchers.launcher[:].beam.spot.angle (alpha) |  | STRUCTURE | rad | Rotation angle for the spot ellipse
ec_launchers.launcher[:].beam.spot.angle.data (alpha) | [ec_launchers.launcher[:].beam.spot.angle.time] | FLT_1D (uncertain) | rad | Data
ec_launchers.launcher[:].beam.spot.angle.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].beam.spot.size (alpha) | [1...2, ec_launchers.launcher[:].beam.spot.size.time] | STRUCTURE | m | Size of the spot ellipse
ec_launchers.launcher[:].beam.spot.size.data (alpha) | [1...N, ec_launchers.launcher[:].beam.spot.size.time] | FLT_2D (uncertain) | m | Data
ec_launchers.launcher[:].beam.spot.size.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
ec_launchers.launcher[:].frequency.data (alpha) | [ec_launchers.launcher[:].frequency.time] | FLT_1D (uncertain) | Hz | Data
ec_launchers.launcher[:].frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].identifier (alpha) |  | STR_0D |  | Identifier of the launcher (unique within the set of all launchers of the experiment)
ec_launchers.launcher[:].launching_position (alpha) |  | STRUCTURE |  | Launching position of the beam
ec_launchers.launcher[:].launching_position.phi (alpha) | [ec_launchers.launcher[:].launching_position.time] | FLT_1D (uncertain) | rad | Toroidal angle
ec_launchers.launcher[:].launching_position.r (alpha) | [ec_launchers.launcher[:].launching_position.time] | FLT_1D (uncertain) | m | Major radius
ec_launchers.launcher[:].launching_position.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
ec_launchers.launcher[:].launching_position.z (alpha) | [ec_launchers.launcher[:].launching_position.time] | FLT_1D (uncertain) | m | Height
ec_launchers.launcher[:].mode (alpha) |  | STRUCTURE |  | Identifier for the main plasma wave mode excited by the EC beam. For the ordinary mode (O-mode), mode/data=1. For the extraordinary mode (X-mode), mode/data=-1
ec_launchers.launcher[:].mode.data (alpha) | [ec_launchers.launcher[:].mode.time] | INT_1D |  | Data
ec_launchers.launcher[:].mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].name (alpha) |  | STR_0D |  | Name of the launcher (unique within the set of all launchers of the experiment)
ec_launchers.launcher[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this launcher into the vacuum vessel
ec_launchers.launcher[:].power_launched.data (alpha) | [ec_launchers.launcher[:].power_launched.time] | FLT_1D (uncertain) | W | Data
ec_launchers.launcher[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].steering_angle_pol (alpha) |  | STRUCTURE | rad | Steering angle of the EC beam in the R,Z plane (from the -R axis towards the -Z axis), angle_pol=atan2(-k_Z,-k_R), where k_Z and k_R are the Z and R components of the mean wave vector in the EC beam
ec_launchers.launcher[:].steering_angle_pol.data (alpha) | [ec_launchers.launcher[:].steering_angle_pol.time] | FLT_1D (uncertain) | rad | Data
ec_launchers.launcher[:].steering_angle_pol.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.launcher[:].steering_angle_tor (alpha) |  | STRUCTURE | rad | Steering angle of the EC beam away from the poloidal plane that is increasing towards the positive phi axis, angle_tor=arcsin(k_phi/k), where k_phi is the component of the wave vector in the phi direction and k is the length of the wave vector. Here the term wave vector refers to the mean wave vector in the EC beam
ec_launchers.launcher[:].steering_angle_tor.data (alpha) | [ec_launchers.launcher[:].steering_angle_tor.time] | FLT_1D (uncertain) | rad | Data
ec_launchers.launcher[:].steering_angle_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ec_launchers.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ece (alpha) |  |  |  | Electron cyclotron emission diagnostic
ece.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (frequency)
ece.channel[:].delta_position_suprathermal (alpha) |  | STRUCTURE |  | Simple estimate of the difference in position induced by the presence of suprathermal electrons. Position without corrections = position - delta_position_suprathermal
ece.channel[:].delta_position_suprathermal.phi (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ece.channel[:].delta_position_suprathermal.psi (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | W | Poloidal flux
ece.channel[:].delta_position_suprathermal.r (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | m | Major radius
ece.channel[:].delta_position_suprathermal.rho_tor_norm (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate
ece.channel[:].delta_position_suprathermal.theta (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | rad | Poloidal angle (oriented clockwise when viewing the poloidal cross section on the right hand side of the tokamak axis of symmetry, with the origin placed on the plasma magnetic axis)
ece.channel[:].delta_position_suprathermal.z (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | m | Height
ece.channel[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency of the channel
ece.channel[:].frequency.data (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | Hz | Data
ece.channel[:].frequency.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].frequency.validity_timed (alpha) | [ece.channel[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].harmonic (alpha) |  | STRUCTURE |  | Harmonic detected by the channel. 1 corresponds to the "O1" mode, while 2 corresponds to the "X2" mode.
ece.channel[:].harmonic.data (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | ? | Data
ece.channel[:].harmonic.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].harmonic.validity_timed (alpha) | [ece.channel[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
ece.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
ece.channel[:].optical_depth (alpha) |  | STRUCTURE | - | Optical depth of the plasma at the position of the measurement. This parameter is a proxy for the local / non-local character of the ECE emission. It must be greater than 1 to guarantee that the measurement is dominated by local ECE emission (non-local otherwise)
ece.channel[:].optical_depth.data (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | - | Data
ece.channel[:].optical_depth.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].optical_depth.validity_timed (alpha) | [ece.channel[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].position (alpha) |  | STRUCTURE |  | Position of the measurements (taking into account the suprathermal shift)
ece.channel[:].position.phi (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ece.channel[:].position.psi (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | W | Poloidal flux
ece.channel[:].position.r (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | m | Major radius
ece.channel[:].position.rho_tor_norm (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate
ece.channel[:].position.theta (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | rad | Poloidal angle (oriented clockwise when viewing the poloidal cross section on the right hand side of the tokamak axis of symmetry, with the origin placed on the plasma magnetic axis)
ece.channel[:].position.z (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | m | Height
ece.channel[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
ece.channel[:].t_e.data (alpha) | [ece.channel[:].time] | FLT_1D (uncertain) | eV | Data
ece.channel[:].t_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].t_e.validity_timed (alpha) | [ece.channel[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].t_e_voltage (alpha) |  | STRUCTURE | V | Raw voltage measured on each channel, from which the calibrated temperature data is then derived
ece.channel[:].t_e_voltage.data (alpha) | [ece.channel[:].t_e_voltage.time] | FLT_1D (uncertain) | V | Data
ece.channel[:].t_e_voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ece.channel[:].t_e_voltage.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].t_e_voltage.validity_timed (alpha) | [ece.channel[:].t_e_voltage.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.channel[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for the processed dynamic data of this channel
ece.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ece.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ece.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
ece.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
ece.code.library[:].name (alpha) |  | STR_0D |  | Name of software
ece.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ece.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
ece.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
ece.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ece.code.output_flag (alpha) | [ece.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ece.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ece.code.repository (alpha) |  | STR_0D |  | URL of software repository
ece.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ece.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ece.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ece.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
ece.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
ece.ids_properties.occurrence |  | INT_0D |  |
ece.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
ece.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
ece.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
ece.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
ece.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
ece.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
ece.line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the diagnostic (valid for all channels), defined by two points
ece.line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
ece.line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ece.line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ece.line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ece.line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
ece.line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ece.line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ece.line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ece.psi_normalization (alpha) |  | STRUCTURE |  | Quantities to use to normalize psi, as a function of time
ece.psi_normalization.psi_boundary (alpha) | [ece.psi_normalization.time] | FLT_1D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary
ece.psi_normalization.psi_magnetic_axis (alpha) | [ece.psi_normalization.time] | FLT_1D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis
ece.psi_normalization.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
ece.t_e_central (alpha) |  | STRUCTURE | eV | Electron temperature from the closest channel to the magnetic axis, together with its radial location
ece.t_e_central.data (alpha) | [ece.t_e_central.time] | FLT_1D (uncertain) | eV | Data
ece.t_e_central.rho_tor_norm (alpha) | [ece.t_e_central.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of the measurement
ece.t_e_central.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ece.t_e_central.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.t_e_central.validity_timed (alpha) | [ece.t_e_central.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
ece.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_profiles |  |  |  | Edge plasma profiles (includes the scrape-off layer and possibly part of the confined plasma)
edge_profiles.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_profiles.code.commit |  | STR_0D |  | Unique commit reference of software
edge_profiles.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
edge_profiles.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
edge_profiles.code.library[:].name |  | STR_0D |  | Name of software
edge_profiles.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_profiles.code.library[:].repository |  | STR_0D |  | URL of software repository
edge_profiles.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
edge_profiles.code.name |  | STR_0D |  | Name of software generating IDS
edge_profiles.code.output_flag | [edge_profiles.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_profiles.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_profiles.code.repository |  | STR_0D |  | URL of software repository
edge_profiles.code.version |  | STR_0D |  | Unique version (tag) of software
edge_profiles.ggd | [edge_profiles.ggd[:].time] | STRUCT_ARRAY |  | Edge plasma quantities represented using the general grid description, for various time slices. The timebase of this array of structure must be a subset of the ggd_fast timebase (only if the ggd_fast array of structure is used)
edge_profiles.ggd[:].e_field | [1...N] | STRUCT_ARRAY | V.m^-1 | Electric field, given on various grid subsets
edge_profiles.ggd[:].e_field[:].diamagnetic | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].diamagnetic_coefficients | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].e_field[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].e_field[:].parallel | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].parallel_coefficients | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].poloidal | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].poloidal_coefficients | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].radial | [1...N] | FLT_1D (uncertain) | V.m^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].radial_coefficients | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].toroidal | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].toroidal_coefficients | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
edge_profiles.ggd[:].electrons.density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].electrons.density[:].coefficients | [edge_profiles.ggd[:].electrons.density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.density[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.density_fast | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].electrons.density_fast[:].coefficients | [edge_profiles.ggd[:].electrons.density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.density_fast[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.density_fast[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.density_fast[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.distribution_function | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].electrons.distribution_function[:].coefficients | [edge_profiles.ggd[:].electrons.distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.distribution_function[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.distribution_function[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.distribution_function[:].values | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure[:].coefficients | [edge_profiles.ggd[:].electrons.pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure_fast_parallel | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].coefficients | [edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].coefficients | [edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.temperature | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].electrons.temperature[:].coefficients | [edge_profiles.ggd[:].electrons.temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.temperature[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].electrons.velocity[:].diamagnetic | [edge_profiles.ggd[:].electrons.velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].electrons.velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.velocity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.velocity[:].parallel | [edge_profiles.ggd[:].electrons.velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity[:].parallel_coefficients | [edge_profiles.ggd[:].electrons.velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity[:].poloidal | [edge_profiles.ggd[:].electrons.velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity[:].poloidal_coefficients | [edge_profiles.ggd[:].electrons.velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity[:].radial_coefficients | [edge_profiles.ggd[:].electrons.velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity[:].toroidal | [edge_profiles.ggd[:].electrons.velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity[:].toroidal_coefficients | [edge_profiles.ggd[:].electrons.velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
edge_profiles.ggd[:].ion[:].density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal) (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].density[:].coefficients | [edge_profiles.ggd[:].ion[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].density[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].density_fast | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].density_fast[:].coefficients | [edge_profiles.ggd[:].ion[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].density_fast[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].density_fast[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].density_fast[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.ggd[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.ggd[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_profiles.ggd[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.ggd[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.ggd[:].ion[:].energy_density_kinetic | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].coefficients | [edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].values | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].label |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
edge_profiles.ggd[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.ggd[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_profiles.ggd[:].ion[:].pressure | [1...N] | STRUCT_ARRAY | Pa | Pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure[:].coefficients | [edge_profiles.ggd[:].ion[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].pressure_fast_parallel | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].coefficients | [edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].coefficients | [edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
edge_profiles.ggd[:].ion[:].state[:].density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].density[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].density[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].density_fast | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].distribution_function | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].values | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].values | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz_+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].values | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_profiles.ggd[:].ion[:].state[:].pressure | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].temperature | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].temperature[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].temperature[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity[:].diamagnetic | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity[:].parallel | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].parallel_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].poloidal | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].poloidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].toroidal | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].toroidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the diamagnetic drift, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].diamagnetic | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].diamagnetic_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].parallel | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].parallel_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].poloidal | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].poloidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].toroidal | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].toroidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the ExB drift, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].diamagnetic | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].diamagnetic_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].parallel | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].parallel_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].poloidal | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].poloidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].toroidal | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].toroidal_coefficients | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.ggd[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.ggd[:].ion[:].state[:].z_average | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].z_average[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].z_average[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].z_average[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].z_average[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].z_average[:].values | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
edge_profiles.ggd[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
edge_profiles.ggd[:].ion[:].state[:].z_square_average | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].coefficients | [edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].values | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].temperature | [1...N] | STRUCT_ARRAY | eV | Temperature (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].temperature[:].coefficients | [edge_profiles.ggd[:].ion[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].temperature[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].velocity[:].diamagnetic | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].velocity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].velocity[:].parallel | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].parallel_coefficients | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].poloidal | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].poloidal_coefficients | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].radial_coefficients | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].toroidal | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].toroidal_coefficients | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
edge_profiles.ggd[:].j_anomalous | [1...N] | STRUCT_ARRAY | A.m^-2 | Anomalous current density, given on various grid subsets
edge_profiles.ggd[:].j_anomalous[:].diamagnetic | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_anomalous[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_anomalous[:].parallel | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].parallel_coefficients | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].poloidal | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].poloidal_coefficients | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].radial_coefficients | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].toroidal | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].toroidal_coefficients | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the diamgnetic drift, given on various grid subsets
edge_profiles.ggd[:].j_diamagnetic[:].diamagnetic | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_diamagnetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_diamagnetic[:].parallel | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].parallel_coefficients | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].poloidal | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].poloidal_coefficients | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].radial_coefficients | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].toroidal | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].toroidal_coefficients | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the heat viscosity, given on various grid subsets
edge_profiles.ggd[:].j_heat_viscosity[:].diamagnetic | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_heat_viscosity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_heat_viscosity[:].parallel | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].parallel_coefficients | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].poloidal | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].poloidal_coefficients | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].radial_coefficients | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].toroidal | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].toroidal_coefficients | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial | [1...N] | STRUCT_ARRAY | A.m^-2 | Inertial current density, given on various grid subsets
edge_profiles.ggd[:].j_inertial[:].diamagnetic | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_inertial[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_inertial[:].parallel | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].parallel_coefficients | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].poloidal | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].poloidal_coefficients | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].radial_coefficients | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].toroidal | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].toroidal_coefficients | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to ion neutral friction, given on various grid subsets
edge_profiles.ggd[:].j_ion_neutral_friction[:].diamagnetic | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_ion_neutral_friction[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_ion_neutral_friction[:].parallel | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].parallel_coefficients | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].poloidal | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].poloidal_coefficients | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].radial_coefficients | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].toroidal | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].toroidal_coefficients | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the parallel viscosity, given on various grid subsets
edge_profiles.ggd[:].j_parallel_viscosity[:].diamagnetic | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_parallel_viscosity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_parallel_viscosity[:].parallel | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].parallel_coefficients | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].poloidal | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].poloidal_coefficients | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].radial_coefficients | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].toroidal | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].toroidal_coefficients | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the perpendicular viscosity, given on various grid subsets
edge_profiles.ggd[:].j_perpendicular_viscosity[:].diamagnetic | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_perpendicular_viscosity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_perpendicular_viscosity[:].parallel | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].parallel_coefficients | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].poloidal | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].poloidal_coefficients | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial_coefficients | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].toroidal | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].toroidal_coefficients | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to Pfirsch-Schlüter effects, given on various grid subsets
edge_profiles.ggd[:].j_pfirsch_schlueter[:].diamagnetic | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].diamagnetic_coefficients | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_pfirsch_schlueter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_pfirsch_schlueter[:].parallel | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].parallel_coefficients | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].poloidal | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].poloidal_coefficients | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial_coefficients | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].toroidal | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].toroidal_coefficients | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].n_i_total_over_n_e | [1...N] | STRUCT_ARRAY | - | Ratio of total ion density (sum over ion species) over electron density. (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].n_i_total_over_n_e[:].coefficients | [edge_profiles.ggd[:].n_i_total_over_n_e[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].n_i_total_over_n_e[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].n_i_total_over_n_e[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].n_i_total_over_n_e[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
edge_profiles.ggd[:].neutral[:].density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal) (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].density[:].coefficients | [edge_profiles.ggd[:].neutral[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].density[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].density_fast | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].density_fast[:].coefficients | [edge_profiles.ggd[:].neutral[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].density_fast[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].density_fast[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].density_fast[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.ggd[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.ggd[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_profiles.ggd[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.ggd[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.ggd[:].neutral[:].energy_density_kinetic | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].coefficients | [edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].values | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_profiles.ggd[:].neutral[:].label |  | STR_0D |  | String identifying the species (e.g. H, D, T, He, C, D2, DT, CD4, ...)
edge_profiles.ggd[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.ggd[:].neutral[:].pressure | [1...N] | STRUCT_ARRAY | Pa | Pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure[:].coefficients | [edge_profiles.ggd[:].neutral[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].coefficients | [edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].coefficients | [edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
edge_profiles.ggd[:].neutral[:].state[:].density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].density[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].density[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].density_fast | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].values | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].distribution_function | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].values | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].values | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
edge_profiles.ggd[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
edge_profiles.ggd[:].neutral[:].state[:].pressure | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].temperature | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].coefficients | [edge_profiles.ggd[:].neutral[:].state[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].diamagnetic | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].parallel | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].parallel_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].poloidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].poloidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].toroidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].toroidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the diamagnetic drift, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].diamagnetic | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].diamagnetic_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].parallel | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].parallel_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].poloidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].poloidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].toroidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].toroidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the ExB drift, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].diamagnetic | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].diamagnetic_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].parallel | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].parallel_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].poloidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].poloidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].toroidal | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].toroidal_coefficients | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.ggd[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.ggd[:].neutral[:].temperature | [1...N] | STRUCT_ARRAY | eV | Temperature (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].temperature[:].coefficients | [edge_profiles.ggd[:].neutral[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].temperature[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].velocity[:].diamagnetic | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].diamagnetic_coefficients | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].velocity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].velocity[:].parallel | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].parallel_coefficients | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].poloidal | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].poloidal_coefficients | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].radial_coefficients | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].toroidal | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].toroidal_coefficients | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].phi_potential | [1...N] | STRUCT_ARRAY | V | Electric potential, given on various grid subsets
edge_profiles.ggd[:].phi_potential[:].coefficients | [edge_profiles.ggd[:].phi_potential[:].values, 1...N] | FLT_2D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].phi_potential[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].phi_potential[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].phi_potential[:].values | [1...N] | FLT_1D (uncertain) | V | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_parallel | [1...N] | STRUCT_ARRAY | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].pressure_parallel[:].coefficients | [edge_profiles.ggd[:].pressure_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_parallel[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_parallel[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_parallel[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_perpendicular | [1...N] | STRUCT_ARRAY | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].pressure_perpendicular[:].coefficients | [edge_profiles.ggd[:].pressure_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_perpendicular[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_perpendicular[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_perpendicular[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_thermal | [1...N] | STRUCT_ARRAY | Pa | Thermal pressure (electrons+ions), given on various grid subsets
edge_profiles.ggd[:].pressure_thermal[:].coefficients | [edge_profiles.ggd[:].pressure_thermal[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_thermal[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_thermal[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_thermal[:].values | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].t_i_average | [1...N] | STRUCT_ARRAY | eV | Ion temperature (averaged on ion species), given on various grid subsets
edge_profiles.ggd[:].t_i_average[:].coefficients | [edge_profiles.ggd[:].t_i_average[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].t_i_average[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].t_i_average[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].t_i_average[:].values | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].time |  | FLT_0D | s | Time
edge_profiles.ggd[:].zeff | [1...N] | STRUCT_ARRAY | - | Effective charge, given on various grid subsets
edge_profiles.ggd[:].zeff[:].coefficients | [edge_profiles.ggd[:].zeff[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].zeff[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].zeff[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].zeff[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_profiles.ggd_fast | [edge_profiles.ggd_fast[:].time] | STRUCT_ARRAY |  | Quantities provided at a faster sampling rate than the full ggd quantities. These are either integrated quantities or local quantities provided on a reduced set of positions. Positions and integration domains are described by a set of grid_subsets (of size 1 for a position).
edge_profiles.ggd_fast[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
edge_profiles.ggd_fast[:].electrons.density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given at various positions (grid subset of size 1)
edge_profiles.ggd_fast[:].electrons.density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].electrons.density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].electrons.density[:].value |  | FLT_0D (uncertain) | m^-3 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].electrons.temperature | [1...N] | STRUCT_ARRAY | eV | Temperature, given at various positions (grid subset of size 1)
edge_profiles.ggd_fast[:].electrons.temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].electrons.temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].electrons.temperature[:].value |  | FLT_0D (uncertain) | eV | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].energy_thermal | [1...N] | STRUCT_ARRAY | J | Plasma energy content = 3/2 * integral over the volume of the grid subset of the thermal pressure (summed over all species), for various grid subsets
edge_profiles.ggd_fast[:].energy_thermal[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].energy_thermal[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].energy_thermal[:].value |  | FLT_0D (uncertain) | J | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
edge_profiles.ggd_fast[:].ion[:].content | [1...N] | STRUCT_ARRAY | - | Particle content = total number of particles for this ion species in the volume of the grid subset, for various grid subsets
edge_profiles.ggd_fast[:].ion[:].content[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].ion[:].content[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].ion[:].content[:].value |  | FLT_0D (uncertain) | - | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].ion[:].density | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal) (sum over states when multiple states are considered), given at various positions (grid subset of size 1)
edge_profiles.ggd_fast[:].ion[:].density[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].ion[:].density[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].ion[:].density[:].value |  | FLT_0D (uncertain) | m^-3 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.ggd_fast[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.ggd_fast[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_profiles.ggd_fast[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.ggd_fast[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.ggd_fast[:].ion[:].label |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
edge_profiles.ggd_fast[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_profiles.ggd_fast[:].ion[:].temperature | [1...N] | STRUCT_ARRAY | eV | Temperature (average over states when multiple states are considered), given at various positions (grid subset of size 1)
edge_profiles.ggd_fast[:].ion[:].temperature[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd_fast[:].ion[:].temperature[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd_fast[:].ion[:].temperature[:].value |  | FLT_0D (uncertain) | eV | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_profiles.ggd_fast[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
edge_profiles.ggd_fast[:].time |  | FLT_0D | s | Time
edge_profiles.grid_ggd | [edge_profiles.grid_ggd[:].time] | STRUCT_ARRAY |  | Grid (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the ggd timebase
edge_profiles.grid_ggd[:].grid_subset | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_profiles.grid_ggd[:].grid_subset[:].base | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_profiles.grid_ggd[:].grid_subset[:].base[:].jacobian | [edge_profiles.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_profiles.grid_ggd[:].grid_subset[:].base[:].tensor_contravariant | [edge_profiles.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.grid_ggd[:].grid_subset[:].base[:].tensor_covariant | [edge_profiles.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.grid_ggd[:].grid_subset[:].dimension |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_profiles.grid_ggd[:].grid_subset[:].element | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_profiles.grid_ggd[:].grid_subset[:].element[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_profiles.grid_ggd[:].grid_subset[:].element[:].object[:].dimension |  | INT_0D |  | Dimension of the object
edge_profiles.grid_ggd[:].grid_subset[:].element[:].object[:].index |  | INT_0D |  | Object index
edge_profiles.grid_ggd[:].grid_subset[:].element[:].object[:].space |  | INT_0D |  | Index of the space from which that object is taken
edge_profiles.grid_ggd[:].grid_subset[:].identifier |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
edge_profiles.grid_ggd[:].grid_subset[:].identifier.description |  | STR_0D |  | Verbose description
edge_profiles.grid_ggd[:].grid_subset[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.grid_ggd[:].grid_subset[:].identifier.name |  | STR_0D |  | Short string identifier
edge_profiles.grid_ggd[:].grid_subset[:].metric |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_profiles.grid_ggd[:].grid_subset[:].metric.jacobian | [edge_profiles.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_profiles.grid_ggd[:].grid_subset[:].metric.tensor_contravariant | [edge_profiles.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.grid_ggd[:].grid_subset[:].metric.tensor_covariant | [edge_profiles.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.grid_ggd[:].identifier |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
edge_profiles.grid_ggd[:].identifier.description |  | STR_0D |  | Verbose description
edge_profiles.grid_ggd[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.grid_ggd[:].identifier.name |  | STR_0D |  | Short string identifier
edge_profiles.grid_ggd[:].space | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_profiles.grid_ggd[:].space[:].coordinates_type | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
edge_profiles.grid_ggd[:].space[:].geometry_type |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_profiles.grid_ggd[:].space[:].geometry_type.description |  | STR_0D |  | Verbose description
edge_profiles.grid_ggd[:].space[:].geometry_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.grid_ggd[:].space[:].geometry_type.name |  | STR_0D |  | Short string identifier
edge_profiles.grid_ggd[:].space[:].identifier |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
edge_profiles.grid_ggd[:].space[:].identifier.description |  | STR_0D |  | Verbose description
edge_profiles.grid_ggd[:].space[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.grid_ggd[:].space[:].identifier.name |  | STR_0D |  | Short string identifier
edge_profiles.grid_ggd[:].space[:].objects_per_dimension | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_profiles.grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_profiles.grid_ggd[:].time |  | FLT_0D | s | Time
edge_profiles.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_profiles.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
edge_profiles.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
edge_profiles.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
edge_profiles.ids_properties.occurrence |  | INT_0D |  |
edge_profiles.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
edge_profiles.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
edge_profiles.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
edge_profiles.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
edge_profiles.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
edge_profiles.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
edge_profiles.profiles_1d | [edge_profiles.profiles_1d[:].time] | STRUCT_ARRAY |  | SOL radial profiles for various time slices, taken on outboard equatorial mid-plane
edge_profiles.profiles_1d[:].conductivity_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
edge_profiles.profiles_1d[:].current_parallel_inside | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A | Parallel current driven inside the flux surface. Cumulative surface integral of j_total
edge_profiles.profiles_1d[:].e_field |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parallel component, average(E.B) / B0, using edge_profiles/vacuum_toroidal_field/b0
edge_profiles.profiles_1d[:].e_field.diamagnetic | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].e_field.parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
edge_profiles.profiles_1d[:].e_field.poloidal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
edge_profiles.profiles_1d[:].e_field.radial | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
edge_profiles.profiles_1d[:].e_field.toroidal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
edge_profiles.profiles_1d[:].e_field_parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where edge_profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
edge_profiles.profiles_1d[:].electrons.collisionality_norm | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Collisionality normalised to the bounce frequency
edge_profiles.profiles_1d[:].electrons.density | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].electrons.density_fast | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].electrons.density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
edge_profiles.profiles_1d[:].electrons.density_fit.chi_squared | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].electrons.density_fit.local | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].electrons.density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].electrons.density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].electrons.density_fit.reconstructed | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].electrons.density_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].electrons.density_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].electrons.density_fit.source | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].electrons.density_fit.time_measurement_width | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].electrons.density_fit.weight | [edge_profiles.profiles_1d[:].electrons.density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].electrons.density_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
edge_profiles.profiles_1d[:].electrons.density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
edge_profiles.profiles_1d[:].electrons.pressure | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].electrons.pressure_fast_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].electrons.pressure_fast_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].electrons.pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
edge_profiles.profiles_1d[:].electrons.temperature | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].electrons.temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
edge_profiles.profiles_1d[:].electrons.temperature_fit.chi_squared | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].electrons.temperature_fit.local | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].electrons.temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].electrons.temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].electrons.temperature_fit.reconstructed | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].electrons.temperature_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].electrons.temperature_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].electrons.temperature_fit.source | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].electrons.temperature_fit.time_measurement_width | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].electrons.temperature_fit.weight | [edge_profiles.profiles_1d[:].electrons.temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].electrons.temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
edge_profiles.profiles_1d[:].electrons.velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].electrons.velocity.diamagnetic (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].electrons.velocity.parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].electrons.velocity.poloidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].electrons.velocity.radial (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].electrons.velocity.toroidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].electrons.velocity_pol (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
edge_profiles.profiles_1d[:].electrons.velocity_tor (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
edge_profiles.profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
edge_profiles.profiles_1d[:].grid.area | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
edge_profiles.profiles_1d[:].grid.psi | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
edge_profiles.profiles_1d[:].grid.psi_boundary |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
edge_profiles.profiles_1d[:].grid.psi_magnetic_axis |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
edge_profiles.profiles_1d[:].grid.rho_pol_norm | [1...N] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis) / (psi(LCFS)-psi(magnetic_axis)))
edge_profiles.profiles_1d[:].grid.rho_tor | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
edge_profiles.profiles_1d[:].grid.rho_tor_norm | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
edge_profiles.profiles_1d[:].grid.volume | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
edge_profiles.profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
edge_profiles.profiles_1d[:].ion[:].density | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].density_fast | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
edge_profiles.profiles_1d[:].ion[:].density_fit.chi_squared | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].ion[:].density_fit.local | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].ion[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].ion[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].ion[:].density_fit.reconstructed | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].ion[:].density_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].density_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].density_fit.source | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].ion[:].density_fit.time_measurement_width | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].ion[:].density_fit.weight | [edge_profiles.profiles_1d[:].ion[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].ion[:].density_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].density_validity |  | INT_0D |  | Indicator of the validity of the density profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
edge_profiles.profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.profiles_1d[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_profiles.profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_profiles.profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_profiles.profiles_1d[:].ion[:].pressure | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].pressure_fast_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].pressure_fast_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].rotation_frequency_tor | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken) (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
edge_profiles.profiles_1d[:].ion[:].state[:].density | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].ion[:].state[:].density_fast | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit |  | STRUCTURE | m^-3 | Information on the fit used to obtain the density profile
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.chi_squared | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.local | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.reconstructed | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.source | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.time_measurement_width | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.weight | [edge_profiles.profiles_1d[:].ion[:].state[:].density_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].ion[:].state[:].density_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
edge_profiles.profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.profiles_1d[:].ion[:].state[:].ionisation_potential |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz_+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_profiles.profiles_1d[:].ion[:].state[:].pressure | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].ion[:].state[:].pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
edge_profiles.profiles_1d[:].ion[:].state[:].rotation_frequency_tor | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | rad.s^-1 | Toroidal rotation frequency (i.e. toroidal velocity divided by the major radius at which the toroidal velocity is taken)
edge_profiles.profiles_1d[:].ion[:].state[:].temperature | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].ion[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.diamagnetic (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.poloidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.radial (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.toroidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.profiles_1d[:].ion[:].state[:].z_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle, volume averaged over the plasma radius (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].z_average_1d | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Average charge profile of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].z_average_square_1d | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Average square charge profile of the charge state bundle (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
edge_profiles.profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_profiles.profiles_1d[:].ion[:].state[:].z_square_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle, volume averaged over the plasma radius (equal to z_min squared if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].temperature | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].temperature_fit |  | STRUCTURE | eV | Information on the fit used to obtain the temperature profile
edge_profiles.profiles_1d[:].ion[:].temperature_fit.chi_squared | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].ion[:].temperature_fit.local | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].ion[:].temperature_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].ion[:].temperature_fit.reconstructed | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].ion[:].temperature_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].temperature_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].ion[:].temperature_fit.source | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].ion[:].temperature_fit.time_measurement_width | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].ion[:].temperature_fit.weight | [edge_profiles.profiles_1d[:].ion[:].temperature_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].ion[:].temperature_validity |  | INT_0D |  | Indicator of the validity of the temperature profile. 0: valid from automated processing, 1: valid and certified by the RO; - 1 means problem identified in the data processing (request verification by the RO), -2: invalid data, should not be used
edge_profiles.profiles_1d[:].ion[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered) at the position of maximum major radius on every flux surface
edge_profiles.profiles_1d[:].ion[:].velocity.diamagnetic | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].ion[:].velocity.parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].ion[:].velocity.poloidal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].ion[:].velocity.radial | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].ion[:].velocity.toroidal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].ion[:].velocity_pol (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].velocity_tor (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
edge_profiles.profiles_1d[:].ion[:].z_ion_1d | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
edge_profiles.profiles_1d[:].ion[:].z_ion_square_1d | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Average square charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
edge_profiles.profiles_1d[:].j_bootstrap | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = edge_profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_non_inductive | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = edge_profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_ohmic | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = edge_profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_tor | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
edge_profiles.profiles_1d[:].j_total | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = edge_profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].magnetic_shear | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
edge_profiles.profiles_1d[:].momentum_tor | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
edge_profiles.profiles_1d[:].n_i_thermal_total | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Total ion thermal density (sum over species and charge states)
edge_profiles.profiles_1d[:].n_i_total_over_n_e | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
edge_profiles.profiles_1d[:].neutral[:].density | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].density_fast | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].density_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.profiles_1d[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_profiles.profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_profiles.profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying the species (e.g. H, D, T, He, C, D2, DT, CD4, ...)
edge_profiles.profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.profiles_1d[:].neutral[:].pressure | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].pressure_fast_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].pressure_fast_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
edge_profiles.profiles_1d[:].neutral[:].state[:].density | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral[:].state[:].density_fast | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].neutral[:].state[:].density_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m^-3 | Density of thermal particles
edge_profiles.profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal) associated with random motion ~average((v-average(v))^2)
edge_profiles.profiles_1d[:].neutral[:].state[:].temperature | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.diamagnetic (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.poloidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.radial (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.toroidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.profiles_1d[:].neutral[:].temperature | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].velocity (obsolescent) |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].velocity.diamagnetic (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].neutral[:].velocity.parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].neutral[:].velocity.poloidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].neutral[:].velocity.radial (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].neutral[:].velocity.toroidal (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].phi_potential | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | V | Electrostatic potential, averaged on the magnetic flux surface
edge_profiles.profiles_1d[:].pressure_ion_total | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
edge_profiles.profiles_1d[:].pressure_parallel | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
edge_profiles.profiles_1d[:].pressure_perpendicular | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
edge_profiles.profiles_1d[:].pressure_thermal | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
edge_profiles.profiles_1d[:].q | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Safety factor
edge_profiles.profiles_1d[:].rotation_frequency_tor_sonic | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | s^-1 | Derivative of the flux surface averaged electrostatic potential with respect to the poloidal flux, multiplied by -1. This quantity is the toroidal angular rotation frequency due to the ExB drift, introduced in formula (43) of Hinton and Wong, Physics of Fluids 3082 (1985), also referred to as sonic flow in regimes in which the toroidal velocity is dominant over the poloidal velocity
edge_profiles.profiles_1d[:].t_i_average | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
edge_profiles.profiles_1d[:].t_i_average_fit |  | STRUCTURE | eV | Information on the fit used to obtain the t_i_average profile
edge_profiles.profiles_1d[:].t_i_average_fit.chi_squared | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].t_i_average_fit.local | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].t_i_average_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].t_i_average_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].t_i_average_fit.reconstructed | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].t_i_average_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].t_i_average_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].t_i_average_fit.source | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].t_i_average_fit.time_measurement_width | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].t_i_average_fit.weight | [edge_profiles.profiles_1d[:].t_i_average_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.profiles_1d[:].time |  | FLT_0D | s | Time
edge_profiles.profiles_1d[:].zeff | [edge_profiles.profiles_1d[:].grid.rho_pol_norm] | FLT_1D (uncertain) | - | Effective charge
edge_profiles.profiles_1d[:].zeff_fit |  | STRUCTURE | - | Information on the fit used to obtain the zeff profile
edge_profiles.profiles_1d[:].zeff_fit.chi_squared | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Squared error normalized by the weighted standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
edge_profiles.profiles_1d[:].zeff_fit.local | [edge_profiles.profiles_1d[:].zeff_fit.measured] | INT_1D |  | Integer flag : 1 means local measurement, 0 means line-integrated measurement
edge_profiles.profiles_1d[:].zeff_fit.measured | [1...N] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Measured values
edge_profiles.profiles_1d[:].zeff_fit.parameters |  | STR_0D |  | List of the fit specific parameters in XML format
edge_profiles.profiles_1d[:].zeff_fit.reconstructed | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | as_parent for a local measurement, as_parent.m for a line integrated measurement | Value reconstructed from the fit
edge_profiles.profiles_1d[:].zeff_fit.rho_pol_norm | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].zeff_fit.rho_tor_norm | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate of each measurement (local value for a local measurement, minimum value reached by the line of sight for a line measurement)
edge_profiles.profiles_1d[:].zeff_fit.source | [edge_profiles.profiles_1d[:].zeff_fit.measured] | STR_1D |  | Path to the source data for each measurement in the IMAS data dictionary, e.g. ece/channel(i)/t_e for the electron temperature on the i-th channel in the ECE IDS
edge_profiles.profiles_1d[:].zeff_fit.time_measurement | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | Exact time slices used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
edge_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method |  | STRUCTURE |  | Method used to slice the data : index = 0 means using exact time slice of the measurement, 1 means linear interpolation, ...
edge_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.description |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_profiles.profiles_1d[:].zeff_fit.time_measurement_slice_method.name |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].zeff_fit.time_measurement_width | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | s | In case the measurements are averaged over a time interval, this node is the full width of this time interval (empty otherwise). In case the slicing/averaging method doesn't use a hard time interval cutoff, this width is the characteristic time span of the slicing/averaging method. By convention, the time interval starts at time_measurement-time_width and ends at time_measurement.
edge_profiles.profiles_1d[:].zeff_fit.weight | [edge_profiles.profiles_1d[:].zeff_fit.measured] | FLT_1D (uncertain) | - | Weight given to each measured value
edge_profiles.time | [1...N] | FLT_1D_TYPE | s | Generic time
edge_profiles.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
edge_profiles.vacuum_toroidal_field.b0 | [edge_profiles.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
edge_profiles.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_sources |  |  |  | Edge plasma sources. Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
edge_sources.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_sources.code.commit |  | STR_0D |  | Unique commit reference of software
edge_sources.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
edge_sources.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
edge_sources.code.library[:].name |  | STR_0D |  | Name of software
edge_sources.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_sources.code.library[:].repository |  | STR_0D |  | URL of software repository
edge_sources.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
edge_sources.code.name |  | STR_0D |  | Name of software generating IDS
edge_sources.code.output_flag | [edge_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_sources.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_sources.code.repository |  | STR_0D |  | URL of software repository
edge_sources.code.version |  | STR_0D |  | Unique version (tag) of software
edge_sources.grid_ggd | [edge_sources.grid_ggd[:].time] | STRUCT_ARRAY |  | Grid (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the ggd timebases
edge_sources.grid_ggd[:].grid_subset | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_sources.grid_ggd[:].grid_subset[:].base | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_sources.grid_ggd[:].grid_subset[:].base[:].jacobian | [edge_sources.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_sources.grid_ggd[:].grid_subset[:].base[:].tensor_contravariant | [edge_sources.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.grid_ggd[:].grid_subset[:].base[:].tensor_covariant | [edge_sources.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.grid_ggd[:].grid_subset[:].dimension |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_sources.grid_ggd[:].grid_subset[:].element | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_sources.grid_ggd[:].grid_subset[:].element[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_sources.grid_ggd[:].grid_subset[:].element[:].object[:].dimension |  | INT_0D |  | Dimension of the object
edge_sources.grid_ggd[:].grid_subset[:].element[:].object[:].index |  | INT_0D |  | Object index
edge_sources.grid_ggd[:].grid_subset[:].element[:].object[:].space |  | INT_0D |  | Index of the space from which that object is taken
edge_sources.grid_ggd[:].grid_subset[:].identifier |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
edge_sources.grid_ggd[:].grid_subset[:].identifier.description |  | STR_0D |  | Verbose description
edge_sources.grid_ggd[:].grid_subset[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.grid_ggd[:].grid_subset[:].identifier.name |  | STR_0D |  | Short string identifier
edge_sources.grid_ggd[:].grid_subset[:].metric |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_sources.grid_ggd[:].grid_subset[:].metric.jacobian | [edge_sources.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_sources.grid_ggd[:].grid_subset[:].metric.tensor_contravariant | [edge_sources.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.grid_ggd[:].grid_subset[:].metric.tensor_covariant | [edge_sources.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.grid_ggd[:].identifier |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
edge_sources.grid_ggd[:].identifier.description |  | STR_0D |  | Verbose description
edge_sources.grid_ggd[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.grid_ggd[:].identifier.name |  | STR_0D |  | Short string identifier
edge_sources.grid_ggd[:].space | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_sources.grid_ggd[:].space[:].coordinates_type | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
edge_sources.grid_ggd[:].space[:].geometry_type |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_sources.grid_ggd[:].space[:].geometry_type.description |  | STR_0D |  | Verbose description
edge_sources.grid_ggd[:].space[:].geometry_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.grid_ggd[:].space[:].geometry_type.name |  | STR_0D |  | Short string identifier
edge_sources.grid_ggd[:].space[:].identifier |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
edge_sources.grid_ggd[:].space[:].identifier.description |  | STR_0D |  | Verbose description
edge_sources.grid_ggd[:].space[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.grid_ggd[:].space[:].identifier.name |  | STR_0D |  | Short string identifier
edge_sources.grid_ggd[:].space[:].objects_per_dimension | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_sources.grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_sources.grid_ggd[:].time |  | FLT_0D | s | Time
edge_sources.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_sources.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
edge_sources.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
edge_sources.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
edge_sources.ids_properties.occurrence |  | INT_0D |  |
edge_sources.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
edge_sources.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
edge_sources.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
edge_sources.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
edge_sources.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
edge_sources.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
edge_sources.source | [1...N] | STRUCT_ARRAY |  | Set of source terms
edge_sources.source[:].ggd | [edge_sources.source[:].ggd[:].time] | STRUCT_ARRAY |  | Source terms represented using the general grid description, for various time slices
edge_sources.source[:].ggd[:].current | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density source
edge_sources.source[:].ggd[:].current[:].coefficients | [edge_sources.source[:].ggd[:].current[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].current[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].current[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].current[:].values | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].electrons |  | STRUCTURE |  | Sources for electrons
edge_sources.source[:].ggd[:].electrons.energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the electron energy equation, given on various grid subsets
edge_sources.source[:].ggd[:].electrons.energy[:].coefficients | [edge_sources.source[:].ggd[:].electrons.energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].electrons.energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].electrons.energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].electrons.energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].electrons.particles | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Source term for electron density equation, given on various grid subsets
edge_sources.source[:].ggd[:].electrons.particles[:].coefficients | [edge_sources.source[:].ggd[:].electrons.particles[:].values, 1...N] | FLT_2D (uncertain) | m^-3.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].electrons.particles[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].electrons.particles[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].electrons.particles[:].values | [1...N] | FLT_1D (uncertain) | m^-3.s^-1 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion | [1...N] | STRUCT_ARRAY |  | Source terms related to the different ion species
edge_sources.source[:].ggd[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].ggd[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].ggd[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_sources.source[:].ggd[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].ggd[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].ggd[:].ion[:].energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the ion energy transport equation, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].energy[:].coefficients | [edge_sources.source[:].ggd[:].ion[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_sources.source[:].ggd[:].ion[:].momentum | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations (sum over states when multiple states are considered), on various grid subsets
edge_sources.source[:].ggd[:].ion[:].momentum[:].diamagnetic | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].diamagnetic_coefficients | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].momentum[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].momentum[:].parallel | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].parallel_coefficients | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].poloidal | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].poloidal_coefficients | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].radial_coefficients | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].toroidal | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].toroidal_coefficients | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_sources.source[:].ggd[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_sources.source[:].ggd[:].ion[:].particles | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for ion density equation, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].particles[:].coefficients | [edge_sources.source[:].ggd[:].ion[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].particles[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].particles[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].particles[:].values | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (ionisation, energy, excitation, ...)
edge_sources.source[:].ggd[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].ggd[:].ion[:].state[:].energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source terms for the charge state energy transport equation
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_sources.source[:].ggd[:].ion[:].state[:].momentum | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].diamagnetic | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].diamagnetic_coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].parallel | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].parallel_coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].poloidal | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].poloidal_coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial_coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].toroidal | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].toroidal_coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].particles | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for the charge state density transport equation
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].coefficients | [edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].values | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].ggd[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].ggd[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
edge_sources.source[:].ggd[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_sources.source[:].ggd[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_sources.source[:].ggd[:].momentum | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for total momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].momentum[:].diamagnetic | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].diamagnetic_coefficients | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].momentum[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].momentum[:].parallel | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].parallel_coefficients | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].poloidal | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].poloidal_coefficients | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].radial_coefficients | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].toroidal | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].toroidal_coefficients | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral | [1...N] | STRUCT_ARRAY |  | Source terms related to the different neutral species
edge_sources.source[:].ggd[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].ggd[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].ggd[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_sources.source[:].ggd[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].ggd[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].ggd[:].neutral[:].energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the ion energy transport equation, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].energy[:].coefficients | [edge_sources.source[:].ggd[:].neutral[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_sources.source[:].ggd[:].neutral[:].label |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_sources.source[:].ggd[:].neutral[:].momentum | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations (sum over states when multiple states are considered), on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].momentum[:].diamagnetic | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].diamagnetic_coefficients | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].momentum[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].momentum[:].parallel | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].parallel_coefficients | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].poloidal | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].poloidal_coefficients | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial_coefficients | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].toroidal | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].toroidal_coefficients | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_sources.source[:].ggd[:].neutral[:].particles | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for ion density equation, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].particles[:].coefficients | [edge_sources.source[:].ggd[:].neutral[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].particles[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].particles[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].particles[:].values | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (energy, excitation, ...)
edge_sources.source[:].ggd[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].ggd[:].neutral[:].state[:].energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source terms for the charge state energy transport equation
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].diamagnetic | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].diamagnetic_coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].parallel | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].parallel_coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].poloidal | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].poloidal_coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial_coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].toroidal | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].toroidal_coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
edge_sources.source[:].ggd[:].neutral[:].state[:].particles | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for the charge state density transport equation
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].coefficients | [edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].values | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].ggd[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].ggd[:].time |  | FLT_0D | s | Time
edge_sources.source[:].ggd[:].total_ion_energy | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the total (summed over ion species) energy equation, on various grid subsets
edge_sources.source[:].ggd[:].total_ion_energy[:].coefficients | [edge_sources.source[:].ggd[:].total_ion_energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].total_ion_energy[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].total_ion_energy[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].total_ion_energy[:].values | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd_fast | [edge_sources.source[:].ggd_fast[:].time] | STRUCT_ARRAY |  | Quantities provided at a faster sampling rate than the full ggd quantities. These are either integrated quantities or local quantities provided on a reduced set of positions. Positions and integration domains are described by a set of grid_subsets (of size 1 for a position).
edge_sources.source[:].ggd_fast[:].ion | [1...N] | STRUCT_ARRAY |  | Source term integrals related to the various ion species
edge_sources.source[:].ggd_fast[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].ggd_fast[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].ggd_fast[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_sources.source[:].ggd_fast[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].ggd_fast[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].ggd_fast[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_sources.source[:].ggd_fast[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_sources.source[:].ggd_fast[:].ion[:].power | [1...N] | STRUCT_ARRAY | W | Total power source or sink related to this ion species, integrated over the volume of the grid subset, for various grid subsets.
edge_sources.source[:].ggd_fast[:].ion[:].power[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd_fast[:].ion[:].power[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd_fast[:].ion[:].power[:].value |  | FLT_0D (uncertain) | W | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_sources.source[:].ggd_fast[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_sources.source[:].ggd_fast[:].time |  | FLT_0D | s | Time
edge_sources.source[:].identifier |  | STRUCTURE |  | Source term identifier (process causing this source term) 0) unspecified : Unspecified source type 1) total : Combined source excluding time derivative 702) total_linearized : Combined source (linearized) excluding time derivative 703) background : Background source 801) database : Source from database entry 705) prescribed : Source prescribed from code input parameters 706) time_derivative : Source associated with time derivative 707) atomic_ionization : Source from atomic ionization 708) molecular_ionization : Source from molecular ionization/dissociation 709) ionization : Source from ionization (combined) 710) recombination : Source from recombination 305) charge_exchange : Source from charge exchange. Charge exchange losses are negative sources 11) collisional_equipartition : Collisional equipartition 7) ohmic : Source from ohmic heating 200) radiation : Source from line + recombination assisted + bremstrahlung 715) compression : Internal energy source from compression 716) bulk_motion : Internal energy source correction for bulk motion
edge_sources.source[:].identifier.description |  | STR_0D |  | Verbose description
edge_sources.source[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.source[:].identifier.name |  | STR_0D |  | Short string identifier
edge_sources.source[:].species |  | STRUCTURE |  | Species causing this source term (if relevant, e.g. a particular ion or neutral state in case of line radiation)
edge_sources.source[:].species.ion |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
edge_sources.source[:].species.ion.element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].species.ion.element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].species.ion.element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_sources.source[:].species.ion.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].species.ion.element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].species.ion.label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_sources.source[:].species.ion.state |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
edge_sources.source[:].species.ion.state.electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].species.ion.state.label |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_sources.source[:].species.ion.state.vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].species.ion.state.vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].species.ion.state.z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
edge_sources.source[:].species.ion.state.z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
edge_sources.source[:].species.ion.z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_sources.source[:].species.neutral |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
edge_sources.source[:].species.neutral.element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].species.neutral.element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].species.neutral.element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_sources.source[:].species.neutral.element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].species.neutral.element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].species.neutral.label |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_sources.source[:].species.neutral.state |  | STRUCTURE |  | State of the species (energy, excitation, ...)
edge_sources.source[:].species.neutral.state.electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].species.neutral.state.label |  | STR_0D |  | String identifying neutral state
edge_sources.source[:].species.neutral.state.neutral_type |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
edge_sources.source[:].species.neutral.state.neutral_type.description |  | STR_0D |  | Verbose description
edge_sources.source[:].species.neutral.state.neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.source[:].species.neutral.state.neutral_type.name |  | STR_0D |  | Short string identifier
edge_sources.source[:].species.neutral.state.vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].species.neutral.state.vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].species.type |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon 0) unspecified : unspecified 1) electron : Electron 2) ion : Ion species in a single/average state; refer to ion-structure 3) ion_state : Ion species in a particular state; refer to ion/state-structure 4) neutral : Neutral species in a single/average state; refer to neutral-structure 5) neutral_state : Neutral species in a particular state; refer to neutral/state-structure 6) neutron : Neutron 7) photon : Photon
edge_sources.source[:].species.type.description |  | STR_0D |  | Verbose description
edge_sources.source[:].species.type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_sources.source[:].species.type.name |  | STR_0D |  | Short string identifier
edge_sources.time | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_transport |  |  |  | Edge plasma transport. Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
edge_transport.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_transport.code.commit |  | STR_0D |  | Unique commit reference of software
edge_transport.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
edge_transport.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
edge_transport.code.library[:].name |  | STR_0D |  | Name of software
edge_transport.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_transport.code.library[:].repository |  | STR_0D |  | URL of software repository
edge_transport.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
edge_transport.code.name |  | STR_0D |  | Name of software generating IDS
edge_transport.code.output_flag | [edge_transport.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_transport.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_transport.code.repository |  | STR_0D |  | URL of software repository
edge_transport.code.version |  | STR_0D |  | Unique version (tag) of software
edge_transport.grid_ggd | [edge_transport.grid_ggd[:].time] | STRUCT_ARRAY |  | Grid (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the ggd timebases
edge_transport.grid_ggd[:].grid_subset | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_transport.grid_ggd[:].grid_subset[:].base | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_transport.grid_ggd[:].grid_subset[:].base[:].jacobian | [edge_transport.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_transport.grid_ggd[:].grid_subset[:].base[:].tensor_contravariant | [edge_transport.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.grid_ggd[:].grid_subset[:].base[:].tensor_covariant | [edge_transport.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.grid_ggd[:].grid_subset[:].dimension |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_transport.grid_ggd[:].grid_subset[:].element | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_transport.grid_ggd[:].grid_subset[:].element[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_transport.grid_ggd[:].grid_subset[:].element[:].object[:].dimension |  | INT_0D |  | Dimension of the object
edge_transport.grid_ggd[:].grid_subset[:].element[:].object[:].index |  | INT_0D |  | Object index
edge_transport.grid_ggd[:].grid_subset[:].element[:].object[:].space |  | INT_0D |  | Index of the space from which that object is taken
edge_transport.grid_ggd[:].grid_subset[:].identifier |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
edge_transport.grid_ggd[:].grid_subset[:].identifier.description |  | STR_0D |  | Verbose description
edge_transport.grid_ggd[:].grid_subset[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.grid_ggd[:].grid_subset[:].identifier.name |  | STR_0D |  | Short string identifier
edge_transport.grid_ggd[:].grid_subset[:].metric |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_transport.grid_ggd[:].grid_subset[:].metric.jacobian | [edge_transport.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_transport.grid_ggd[:].grid_subset[:].metric.tensor_contravariant | [edge_transport.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.grid_ggd[:].grid_subset[:].metric.tensor_covariant | [edge_transport.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.grid_ggd[:].identifier |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
edge_transport.grid_ggd[:].identifier.description |  | STR_0D |  | Verbose description
edge_transport.grid_ggd[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.grid_ggd[:].identifier.name |  | STR_0D |  | Short string identifier
edge_transport.grid_ggd[:].space | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_transport.grid_ggd[:].space[:].coordinates_type | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
edge_transport.grid_ggd[:].space[:].geometry_type |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_transport.grid_ggd[:].space[:].geometry_type.description |  | STR_0D |  | Verbose description
edge_transport.grid_ggd[:].space[:].geometry_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.grid_ggd[:].space[:].geometry_type.name |  | STR_0D |  | Short string identifier
edge_transport.grid_ggd[:].space[:].identifier |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
edge_transport.grid_ggd[:].space[:].identifier.description |  | STR_0D |  | Verbose description
edge_transport.grid_ggd[:].space[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.grid_ggd[:].space[:].identifier.name |  | STR_0D |  | Short string identifier
edge_transport.grid_ggd[:].space[:].objects_per_dimension | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_transport.grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_transport.grid_ggd[:].time |  | FLT_0D | s | Time
edge_transport.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_transport.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
edge_transport.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
edge_transport.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
edge_transport.ids_properties.occurrence |  | INT_0D |  |
edge_transport.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
edge_transport.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
edge_transport.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
edge_transport.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
edge_transport.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
edge_transport.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
edge_transport.model | [1...N_Models] | STRUCT_ARRAY |  | Transport is described by a combination of various transport models
edge_transport.model[:].code |  | STRUCTURE |  | Code-specific parameters used for this model
edge_transport.model[:].code.commit |  | STR_0D |  | Unique commit reference of software
edge_transport.model[:].code.name |  | STR_0D |  | Name of software used
edge_transport.model[:].code.output_flag |  | STRUCTURE |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_transport.model[:].code.output_flag.data | [edge_transport.model[:].code.output_flag.time] | INT_1D |  | Data
edge_transport.model[:].code.output_flag.time | [1...N] | FLT_1D_TYPE | s | Time
edge_transport.model[:].code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
edge_transport.model[:].code.repository |  | STR_0D |  | URL of software repository
edge_transport.model[:].code.version |  | STR_0D |  | Unique version (tag) of software
edge_transport.model[:].flux_multiplier |  | FLT_0D (uncertain) | - | Multiplier applied to the particule flux when adding its contribution in the expression of the heat flux : can be 0, 3/2 or 5/2
edge_transport.model[:].ggd | [edge_transport.model[:].ggd[:].time] | STRUCT_ARRAY |  | Transport coefficients represented using the general grid description, for various time slices
edge_transport.model[:].ggd[:].conductivity | [1...N] | STRUCT_ARRAY | ohm^-1.m^-1 | Conductivity, on various grid subsets
edge_transport.model[:].ggd[:].conductivity[:].diamagnetic | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].conductivity[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].conductivity[:].parallel | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].parallel_coefficients | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].poloidal | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].radial | [1...N] | FLT_1D (uncertain) | ohm^-1.m^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].radial_coefficients | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].toroidal | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons |  | STRUCTURE |  | Transport quantities related to the electrons
edge_transport.model[:].ggd[:].electrons.energy |  | STRUCTURE |  | Transport quantities for the electron energy equation
edge_transport.model[:].ggd[:].electrons.energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.d[:].coefficients | [edge_transport.model[:].ggd[:].electrons.energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].electrons.energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.v[:].coefficients | [edge_transport.model[:].ggd[:].electrons.energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles |  | STRUCTURE |  | Transport quantities for the electron density equation
edge_transport.model[:].ggd[:].electrons.particles.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.d[:].coefficients | [edge_transport.model[:].ggd[:].electrons.particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.flux | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.flux[:].coefficients | [edge_transport.model[:].ggd[:].electrons.particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.flux[:].values | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.v[:].coefficients | [edge_transport.model[:].ggd[:].electrons.particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion and neutral species
edge_transport.model[:].ggd[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_transport.model[:].ggd[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd[:].ion[:].energy |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
edge_transport.model[:].ggd[:].ion[:].energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.d[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.v[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_transport.model[:].ggd[:].ion[:].momentum |  | STRUCTURE |  | Transport coefficients for the ion momentum equations
edge_transport.model[:].ggd[:].ion[:].momentum.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].parallel | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].parallel | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].parallel | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].parallel | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_transport.model[:].ggd[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_transport.model[:].ggd[:].ion[:].particles |  | STRUCTURE |  | Transport related to the ion density equation
edge_transport.model[:].ggd[:].ion[:].particles.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.d[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.flux | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].values | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.v[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
edge_transport.model[:].ggd[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_transport.model[:].ggd[:].ion[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_transport.model[:].ggd[:].ion[:].state[:].momentum |  | STRUCTURE |  | Transport coefficients related to the momentum equations of the charge state considered
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].parallel | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].parallel | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].parallel | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].diamagnetic | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].parallel | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].parallel_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].poloidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].toroidal | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].values | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].coefficients | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_transport.model[:].ggd[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_transport.model[:].ggd[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
edge_transport.model[:].ggd[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_transport.model[:].ggd[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_transport.model[:].ggd[:].momentum |  | STRUCTURE |  | Transport coefficients for total momentum equation
edge_transport.model[:].ggd[:].momentum.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].momentum.d[:].diamagnetic | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.d[:].parallel | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].parallel_coefficients | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].poloidal | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].radial | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].radial_coefficients | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].toroidal | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].momentum.flux[:].diamagnetic | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.flux[:].parallel | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].parallel_coefficients | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].poloidal | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].radial_coefficients | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].toroidal | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].diamagnetic | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].parallel | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].parallel_coefficients | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].poloidal | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial_coefficients | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].toroidal | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].momentum.v[:].diamagnetic | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.v[:].parallel | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].parallel_coefficients | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].poloidal | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].radial_coefficients | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].toroidal | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion and neutral species
edge_transport.model[:].ggd[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_transport.model[:].ggd[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd[:].neutral[:].energy |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
edge_transport.model[:].ggd[:].neutral[:].energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_transport.model[:].ggd[:].neutral[:].label |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_transport.model[:].ggd[:].neutral[:].momentum |  | STRUCTURE |  | Transport coefficients for the ion momentum equations
edge_transport.model[:].ggd[:].neutral[:].momentum.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_transport.model[:].ggd[:].neutral[:].particles |  | STRUCTURE |  | Transport related to the ion density equation
edge_transport.model[:].ggd[:].neutral[:].particles.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.flux | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].values | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
edge_transport.model[:].ggd[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_transport.model[:].ggd[:].neutral[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum |  | STRUCTURE |  | Transport coefficients related to the momentum equations of the charge state considered
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].diamagnetic | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].diamagnetic_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].parallel | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].parallel_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].poloidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].poloidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].toroidal | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].toroidal_coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
edge_transport.model[:].ggd[:].neutral[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].values | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].coefficients | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_transport.model[:].ggd[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_transport.model[:].ggd[:].time |  | FLT_0D | s | Time
edge_transport.model[:].ggd[:].total_ion_energy |  | STRUCTURE |  | Transport coefficients for the total (summed over ion species) energy equation
edge_transport.model[:].ggd[:].total_ion_energy.d | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.d[:].coefficients | [edge_transport.model[:].ggd[:].total_ion_energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.d[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.d[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.d[:].values | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.flux | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].coefficients | [edge_transport.model[:].ggd[:].total_ion_energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].values | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].coefficients | [edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].values | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.v | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.v[:].coefficients | [edge_transport.model[:].ggd[:].total_ion_energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.v[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.v[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.v[:].values | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd_fast | [edge_transport.model[:].ggd_fast[:].time] | STRUCT_ARRAY |  | Quantities provided at a faster sampling rate than the full ggd quantities. These are either integrated quantities or local quantities provided on a reduced set of positions. Positions and integration domains are described by a set of grid_subsets (of size 1 for a position).
edge_transport.model[:].ggd_fast[:].electrons |  | STRUCTURE |  | Transport quantities and flux integrals related to the electrons
edge_transport.model[:].ggd_fast[:].electrons.particle_flux_integrated | [1...N] | STRUCT_ARRAY | s^-1 | Total number of particles of this species crossing a surface per unit time, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].electrons.particle_flux_integrated[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].electrons.particle_flux_integrated[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].electrons.particle_flux_integrated[:].value |  | FLT_0D (uncertain) | s^-1 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].electrons.power | [1...N] | STRUCT_ARRAY | W | Power carried by this species crossing a surface, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].electrons.power[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].electrons.power[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].electrons.power[:].value |  | FLT_0D (uncertain) | W | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].energy_flux_max | [1...N] | STRUCT_ARRAY | W.m^-2 | Maximum power density over a surface, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].energy_flux_max[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].energy_flux_max[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].energy_flux_max[:].value |  | FLT_0D (uncertain) | W.m^-2 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].ion | [1...N] | STRUCT_ARRAY |  | Transport coefficients and flux integrals related to the various ion species
edge_transport.model[:].ggd_fast[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd_fast[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd_fast[:].ion[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_transport.model[:].ggd_fast[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd_fast[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd_fast[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_transport.model[:].ggd_fast[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_transport.model[:].ggd_fast[:].ion[:].particle_flux_integrated | [1...N] | STRUCT_ARRAY | s^-1 | Total number of particles of this species crossing a surface per unit time, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].ion[:].particle_flux_integrated[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].ion[:].particle_flux_integrated[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].ion[:].particle_flux_integrated[:].value |  | FLT_0D (uncertain) | s^-1 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_transport.model[:].ggd_fast[:].neutral | [1...N] | STRUCT_ARRAY |  | Transport coefficients and flux integrals related to the various ion and neutral species
edge_transport.model[:].ggd_fast[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd_fast[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd_fast[:].neutral[:].element[:].atoms_n |  | INT_0D |  | Number of atoms of this element in the molecule
edge_transport.model[:].ggd_fast[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd_fast[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd_fast[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_transport.model[:].ggd_fast[:].neutral[:].label |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_transport.model[:].ggd_fast[:].neutral[:].particle_flux_integrated | [1...N] | STRUCT_ARRAY | s^-1 | Total number of particles of this species crossing a surface per unit time, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].neutral[:].particle_flux_integrated[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].neutral[:].particle_flux_integrated[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].neutral[:].particle_flux_integrated[:].value |  | FLT_0D (uncertain) | s^-1 | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].power | [1...N] | STRUCT_ARRAY | W | Power (sum over all species) crossing a surface, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].power[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].power[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].power[:].value |  | FLT_0D (uncertain) | W | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].power_ion_total | [1...N] | STRUCT_ARRAY | W | Power carried by all ions (sum over ions species) crossing a surface, for various surfaces (grid subsets)
edge_transport.model[:].ggd_fast[:].power_ion_total[:].grid_index |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd_fast[:].power_ion_total[:].grid_subset_index |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd_fast[:].power_ion_total[:].value |  | FLT_0D (uncertain) | W | Scalar value of the quantity on the grid subset (corresponding to a single local position or to an integrated value over the subset)
edge_transport.model[:].ggd_fast[:].time |  | FLT_0D | s | Time
edge_transport.model[:].identifier |  | STRUCTURE |  | Transport model identifier 0) unspecified : Unspecified transport type 1) combined : Combination of data from all available transport models 100) combined_radial : Combination of data from all available radial transport models 101) background_radial : Background radial transport level 102) database_radial : Radial transport specified by a database entry 103) prescribed_radial : Radial transport model prescribed from code input parameters 200) combined_parallel : Combination of data from all available radial transport models 201) background_parallel : Background radial transport level 202) database_parallel : Radial transport specified by a database entry 203) prescribed_parallel : Radial transport model prescribed from code input parameters 204) twenty_one_moment_parallel : 21 moment fluid closure model 205) braginskii_parallel : Braginskii fluid transport model
edge_transport.model[:].identifier.description |  | STR_0D |  | Verbose description
edge_transport.model[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
edge_transport.model[:].identifier.name |  | STR_0D |  | Short string identifier
edge_transport.time | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
em_coupling (alpha) |  |  |  | Description of the axisymmetric mutual electromagnetics; does not include non-axisymmetric coil systems; the convention is Quantity_Sensor_Source
em_coupling.active_coils (alpha) | [pf_active.coil] | STR_1D |  | List of the names of the active PF+CS coils
em_coupling.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
em_coupling.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
em_coupling.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
em_coupling.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
em_coupling.code.library[:].name (alpha) |  | STR_0D |  | Name of software
em_coupling.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
em_coupling.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
em_coupling.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
em_coupling.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
em_coupling.code.output_flag (alpha) | [em_coupling.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
em_coupling.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
em_coupling.code.repository (alpha) |  | STR_0D |  | URL of software repository
em_coupling.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
em_coupling.field_probes_active (alpha) | [em_coupling.poloidal_probes, em_coupling.active_coils] | FLT_2D (uncertain) | T/A | Poloidal field coupling from active coils to poloidal field probes
em_coupling.field_probes_grid (alpha) | [em_coupling.poloidal_probes, em_coupling.grid_points] | FLT_2D (uncertain) | T/A | Poloidal field coupling from equilibrium grid to poloidal field probes
em_coupling.field_probes_passive (alpha) | [em_coupling.poloidal_probes, em_coupling.passive_loops] | FLT_2D (uncertain) | T/A | Poloidal field coupling from passive loops to poloidal field probes
em_coupling.flux_loops (alpha) | [magnetics.flux_loop] | STR_1D |  | List of the names of the axisymmetric flux loops
em_coupling.grid_points (alpha) | [1...N] | STR_1D |  | List of the names of the plasma region grid points
em_coupling.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
em_coupling.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
em_coupling.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
em_coupling.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
em_coupling.ids_properties.occurrence |  | INT_0D |  |
em_coupling.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
em_coupling.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
em_coupling.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
em_coupling.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
em_coupling.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
em_coupling.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
em_coupling.mutual_active_active (alpha) | [em_coupling.active_coils, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to active coils
em_coupling.mutual_grid_active (alpha) | [em_coupling.grid_points, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to equilibrium grid
em_coupling.mutual_grid_grid (alpha) | [em_coupling.grid_points, em_coupling.grid_points] | FLT_2D (uncertain) | H | Mutual inductance from equilibrium grid to itself
em_coupling.mutual_grid_passive (alpha) | [em_coupling.grid_points, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to equilibrium grid
em_coupling.mutual_loops_active (alpha) | [em_coupling.flux_loops, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to poloidal flux loops
em_coupling.mutual_loops_grid (alpha) | [em_coupling.flux_loops, em_coupling.grid_points] | FLT_2D (uncertain) | H | Mutual inductance from equilibrium grid to poloidal flux loops
em_coupling.mutual_loops_passive (alpha) | [em_coupling.flux_loops, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to poloidal flux loops
em_coupling.mutual_passive_active (alpha) | [em_coupling.passive_loops, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to passive loops
em_coupling.mutual_passive_passive (alpha) | [em_coupling.passive_loops, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to passive loops
em_coupling.passive_loops (alpha) | [pf_passive.loop] | STR_1D |  | List of the names of the passive loops
em_coupling.poloidal_probes (alpha) | [magnetics.bpol_probe] | STR_1D |  | List of the names of poloidal field probes
em_coupling.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
equilibrium |  |  |  | Description of a 2D, axi-symmetric, tokamak equilibrium; result of an equilibrium code.
equilibrium.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
equilibrium.code.commit |  | STR_0D |  | Unique commit reference of software
equilibrium.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
equilibrium.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
equilibrium.code.library[:].name |  | STR_0D |  | Name of software
equilibrium.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
equilibrium.code.library[:].repository |  | STR_0D |  | URL of software repository
equilibrium.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
equilibrium.code.name |  | STR_0D |  | Name of software generating IDS
equilibrium.code.output_flag | [equilibrium.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
equilibrium.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
equilibrium.code.repository |  | STR_0D |  | URL of software repository
equilibrium.code.version |  | STR_0D |  | Unique version (tag) of software
equilibrium.grids_ggd (alpha) | [equilibrium.grids_ggd[:].time] | STRUCT_ARRAY |  | Grids (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the time_slice timebase
equilibrium.grids_ggd[:].grid (alpha) | [1...N] | STRUCT_ARRAY |  | Set of GGD grids for describing the equilibrium, at a given time slice
equilibrium.grids_ggd[:].grid[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
equilibrium.grids_ggd[:].grid[:].grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
equilibrium.grids_ggd[:].grid[:].grid_subset[:].base[:].jacobian (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.grids_ggd[:].grid[:].grid_subset[:].base[:].tensor_contravariant (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.grids_ggd[:].grid[:].grid_subset[:].base[:].tensor_covariant (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.grids_ggd[:].grid[:].grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
equilibrium.grids_ggd[:].grid[:].grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
equilibrium.grids_ggd[:].grid[:].grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
equilibrium.grids_ggd[:].grid[:].grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
equilibrium.grids_ggd[:].grid[:].grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
equilibrium.grids_ggd[:].grid[:].grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
equilibrium.grids_ggd[:].grid[:].grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
equilibrium.grids_ggd[:].grid[:].grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.grids_ggd[:].grid[:].grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.grids_ggd[:].grid[:].grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.grids_ggd[:].grid[:].grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
equilibrium.grids_ggd[:].grid[:].grid_subset[:].metric.jacobian (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.grids_ggd[:].grid[:].grid_subset[:].metric.tensor_contravariant (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.grids_ggd[:].grid[:].grid_subset[:].metric.tensor_covariant (alpha) | [equilibrium.grids_ggd[:].grid[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.grids_ggd[:].grid[:].identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
equilibrium.grids_ggd[:].grid[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.grids_ggd[:].grid[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.grids_ggd[:].grid[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.grids_ggd[:].grid[:].space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
equilibrium.grids_ggd[:].grid[:].space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
equilibrium.grids_ggd[:].grid[:].space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
equilibrium.grids_ggd[:].grid[:].space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.grids_ggd[:].grid[:].space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.grids_ggd[:].grid[:].space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.grids_ggd[:].grid[:].space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
equilibrium.grids_ggd[:].grid[:].space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.grids_ggd[:].grid[:].space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.grids_ggd[:].grid[:].space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
equilibrium.grids_ggd[:].grid[:].space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
equilibrium.grids_ggd[:].time (alpha) |  | FLT_0D | s | Time
equilibrium.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
equilibrium.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
equilibrium.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
equilibrium.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
equilibrium.ids_properties.occurrence |  | INT_0D |  |
equilibrium.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
equilibrium.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
equilibrium.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
equilibrium.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
equilibrium.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
equilibrium.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
equilibrium.time | [1...N] | FLT_1D_TYPE | s | Generic time
equilibrium.time_slice | [equilibrium.time_slice[:].time] | STRUCT_ARRAY |  | Set of equilibria at various time slices
equilibrium.time_slice[:].boundary |  | STRUCTURE |  | Description of the plasma boundary used by fixed-boundary codes and typically chosen at psi_norm = 99.x% of the separatrix
equilibrium.time_slice[:].boundary.active_limiter_point |  | STRUCTURE |  | RZ position of the active limiter point (point of the plasma boundary in contact with the limiter)
equilibrium.time_slice[:].boundary.active_limiter_point.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.active_limiter_point.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.b_flux_pol_norm (obsolescent) |  | FLT_0D (uncertain) | - | Value of the normalised poloidal flux at which the boundary is taken
equilibrium.time_slice[:].boundary.elongation |  | FLT_0D (uncertain) | - | Elongation of the plasma boundary
equilibrium.time_slice[:].boundary.elongation_lower |  | FLT_0D (uncertain) | - | Elongation (lower half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary.elongation_upper |  | FLT_0D (uncertain) | - | Elongation (upper half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary.geometric_axis |  | STRUCTURE |  | RZ position of the geometric axis (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the boundary)
equilibrium.time_slice[:].boundary.geometric_axis.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.geometric_axis.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.lcfs (obsolescent) |  | STRUCTURE |  | RZ description of the plasma boundary
equilibrium.time_slice[:].boundary.lcfs.r (obsolescent) | [1...N] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.lcfs.z (obsolescent) | [equilibrium.time_slice[:].boundary.lcfs.r] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.minor_radius |  | FLT_0D (uncertain) | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
equilibrium.time_slice[:].boundary.outline |  | STRUCTURE |  | RZ outline of the plasma boundary
equilibrium.time_slice[:].boundary.outline.r | [1...N] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.outline.z | [equilibrium.time_slice[:].boundary.outline.r] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.psi |  | FLT_0D (uncertain) | Wb | Value of the poloidal flux at which the boundary is taken
equilibrium.time_slice[:].boundary.psi_norm |  | FLT_0D (uncertain) | - | Value of the normalised poloidal flux at which the boundary is taken (typically 99.x %), the flux being normalised to its value at the separatrix
equilibrium.time_slice[:].boundary.squareness_lower_inner (alpha) |  | FLT_0D (uncertain) | - | Lower inner squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary.squareness_lower_outer (alpha) |  | FLT_0D (uncertain) | - | Lower outer squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary.squareness_upper_inner (alpha) |  | FLT_0D (uncertain) | - | Upper inner squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary.squareness_upper_outer (alpha) |  | FLT_0D (uncertain) | - | Upper outer squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary.strike_point | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary.strike_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.strike_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.triangularity |  | FLT_0D (uncertain) | - | Triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.triangularity_lower |  | FLT_0D (uncertain) | - | Lower triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.triangularity_upper |  | FLT_0D (uncertain) | - | Upper triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.type |  | INT_0D |  | 0 (limiter) or 1 (diverted)
equilibrium.time_slice[:].boundary.x_point | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary.x_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.x_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary_separatrix |  | STRUCTURE |  | Description of the plasma boundary at the separatrix
equilibrium.time_slice[:].boundary_separatrix.active_limiter_point |  | STRUCTURE |  | RZ position of the active limiter point (point of the plasma boundary in contact with the limiter)
equilibrium.time_slice[:].boundary_separatrix.active_limiter_point.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary_separatrix.active_limiter_point.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary_separatrix.elongation |  | FLT_0D (uncertain) | - | Elongation of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.elongation_lower |  | FLT_0D (uncertain) | - | Elongation (lower half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.elongation_upper |  | FLT_0D (uncertain) | - | Elongation (upper half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.geometric_axis |  | STRUCTURE |  | RZ position of the geometric axis (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the boundary)
equilibrium.time_slice[:].boundary_separatrix.geometric_axis.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary_separatrix.geometric_axis.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary_separatrix.minor_radius |  | FLT_0D (uncertain) | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
equilibrium.time_slice[:].boundary_separatrix.outline |  | STRUCTURE |  | RZ outline of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.outline.r | [1...N] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary_separatrix.outline.z | [equilibrium.time_slice[:].boundary_separatrix.outline.r] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].boundary_separatrix.psi |  | FLT_0D (uncertain) | Wb | Value of the poloidal flux at the separatrix
equilibrium.time_slice[:].boundary_separatrix.squareness_lower_inner (alpha) |  | FLT_0D (uncertain) | - | Lower inner squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary_separatrix.squareness_lower_outer (alpha) |  | FLT_0D (uncertain) | - | Lower outer squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary_separatrix.squareness_upper_inner (alpha) |  | FLT_0D (uncertain) | - | Upper inner squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary_separatrix.squareness_upper_outer (alpha) |  | FLT_0D (uncertain) | - | Upper outer squareness of the plasma boundary (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].boundary_separatrix.strike_point | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary_separatrix.strike_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary_separatrix.strike_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary_separatrix.triangularity |  | FLT_0D (uncertain) | - | Triangularity of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.triangularity_lower |  | FLT_0D (uncertain) | - | Lower triangularity of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.triangularity_upper |  | FLT_0D (uncertain) | - | Upper triangularity of the plasma boundary
equilibrium.time_slice[:].boundary_separatrix.type |  | INT_0D |  | 0 (limiter) or 1 (diverted)
equilibrium.time_slice[:].boundary_separatrix.x_point | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary_separatrix.x_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary_separatrix.x_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints (alpha) |  | STRUCTURE |  | In case of equilibrium reconstruction under constraints, measurements used to constrain the equilibrium, reconstructed values and accuracy of the fit. The names of the child nodes correspond to the following definition: the solver aims at minimizing a cost function defined as : J=1/2*sum_i [ weight_i^2 (reconstructed_i - measured_i)^2 / sigma_i^2 ]. in which sigma_i is the standard deviation of the measurement error (to be found in the IDS of the measurement)
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r (alpha) |  | STRUCTURE | T.m | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.chi_squared (alpha) |  | FLT_0D (uncertain) | T.m | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.measured (alpha) |  | FLT_0D (uncertain) | T.m | Measured value
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.reconstructed (alpha) |  | FLT_0D (uncertain) | T.m | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.b_field_tor_vacuum_r.weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.bpol_probe (alpha) | [magnetics.bpol_probe] | STRUCT_ARRAY | T | Set of poloidal field probes
equilibrium.time_slice[:].constraints.bpol_probe[:].chi_squared (alpha) |  | FLT_0D (uncertain) | T | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.bpol_probe[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.bpol_probe[:].measured (alpha) |  | FLT_0D (uncertain) | T | Measured value
equilibrium.time_slice[:].constraints.bpol_probe[:].reconstructed (alpha) |  | FLT_0D (uncertain) | T | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.bpol_probe[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.bpol_probe[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.bpol_probe[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.diamagnetic_flux (alpha) |  | STRUCTURE | Wb | Diamagnetic flux
equilibrium.time_slice[:].constraints.diamagnetic_flux.chi_squared (alpha) |  | FLT_0D (uncertain) | Wb | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.diamagnetic_flux.exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.diamagnetic_flux.measured (alpha) |  | FLT_0D (uncertain) | Wb | Measured value
equilibrium.time_slice[:].constraints.diamagnetic_flux.reconstructed (alpha) |  | FLT_0D (uncertain) | Wb | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.diamagnetic_flux.source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.diamagnetic_flux.time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.diamagnetic_flux.weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.faraday_angle (alpha) | [polarimeter.channel] | STRUCT_ARRAY | rad | Set of faraday angles
equilibrium.time_slice[:].constraints.faraday_angle[:].chi_squared (alpha) |  | FLT_0D (uncertain) | rad | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.faraday_angle[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.faraday_angle[:].measured (alpha) |  | FLT_0D (uncertain) | rad | Measured value
equilibrium.time_slice[:].constraints.faraday_angle[:].reconstructed (alpha) |  | FLT_0D (uncertain) | rad | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.faraday_angle[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.faraday_angle[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.faraday_angle[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.flux_loop (alpha) | [magnetics.flux_loop] | STRUCT_ARRAY | Wb | Set of flux loops
equilibrium.time_slice[:].constraints.flux_loop[:].chi_squared (alpha) |  | FLT_0D (uncertain) | Wb | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.flux_loop[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.flux_loop[:].measured (alpha) |  | FLT_0D (uncertain) | Wb | Measured value
equilibrium.time_slice[:].constraints.flux_loop[:].reconstructed (alpha) |  | FLT_0D (uncertain) | Wb | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.flux_loop[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.flux_loop[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.flux_loop[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.ip (alpha) |  | STRUCTURE | A | Plasma current. Positive sign means anti-clockwise when viewed from above
equilibrium.time_slice[:].constraints.ip.chi_squared (alpha) |  | FLT_0D (uncertain) | A | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.ip.exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.ip.measured (alpha) |  | FLT_0D (uncertain) | A | Measured value
equilibrium.time_slice[:].constraints.ip.reconstructed (alpha) |  | FLT_0D (uncertain) | A | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.ip.source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.ip.time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.ip.weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.iron_core_segment (alpha) | [iron_core.segment] | STRUCT_ARRAY | T | Magnetisation M of a set of iron core segments
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r (alpha) |  | STRUCTURE | T | Magnetisation M of the iron core segment along the major radius axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.chi_squared (alpha) |  | FLT_0D (uncertain) | T | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.measured (alpha) |  | FLT_0D (uncertain) | T | Measured value
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.reconstructed (alpha) |  | FLT_0D (uncertain) | T | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_r.weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z (alpha) |  | STRUCTURE | T | Magnetisation M of the iron core segment along the vertical axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.chi_squared (alpha) |  | FLT_0D (uncertain) | T | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.measured (alpha) |  | FLT_0D (uncertain) | T | Measured value
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.reconstructed (alpha) |  | FLT_0D (uncertain) | T | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.iron_core_segment[:].magnetisation_z.weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.mse_polarisation_angle (alpha) | [mse.channel] | STRUCT_ARRAY | rad | Set of MSE polarisation angles
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].chi_squared (alpha) |  | FLT_0D (uncertain) | rad | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].measured (alpha) |  | FLT_0D (uncertain) | rad | Measured value
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].reconstructed (alpha) |  | FLT_0D (uncertain) | rad | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.mse_polarisation_angle[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.n_e (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Set of local density measurements
equilibrium.time_slice[:].constraints.n_e[:].chi_squared (alpha) |  | FLT_0D (uncertain) | m^-3 | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.n_e[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.n_e[:].measured (alpha) |  | FLT_0D (uncertain) | m^-3 | Measured value
equilibrium.time_slice[:].constraints.n_e[:].reconstructed (alpha) |  | FLT_0D (uncertain) | m^-3 | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.n_e[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.n_e[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.n_e[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.n_e_line (alpha) | [interferometer.channel] | STRUCT_ARRAY | m^-2 | Set of line integrated density measurements
equilibrium.time_slice[:].constraints.n_e_line[:].chi_squared (alpha) |  | FLT_0D (uncertain) | m^-2 | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.n_e_line[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.n_e_line[:].measured (alpha) |  | FLT_0D (uncertain) | m^-2 | Measured value
equilibrium.time_slice[:].constraints.n_e_line[:].reconstructed (alpha) |  | FLT_0D (uncertain) | m^-2 | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.n_e_line[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.n_e_line[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.n_e_line[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.pf_current (alpha) | [pf_active.coil] | STRUCT_ARRAY | A | Current in a set of poloidal field coils
equilibrium.time_slice[:].constraints.pf_current[:].chi_squared (alpha) |  | FLT_0D (uncertain) | A | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.pf_current[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.pf_current[:].measured (alpha) |  | FLT_0D (uncertain) | A | Measured value
equilibrium.time_slice[:].constraints.pf_current[:].reconstructed (alpha) |  | FLT_0D (uncertain) | A | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.pf_current[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.pf_current[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.pf_current[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.pf_passive_current (alpha) | [pf_passive.loop] | STRUCT_ARRAY | A | Current in a set of axisymmetric passive conductors
equilibrium.time_slice[:].constraints.pf_passive_current[:].chi_squared (alpha) |  | FLT_0D (uncertain) | A | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.pf_passive_current[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.pf_passive_current[:].measured (alpha) |  | FLT_0D (uncertain) | A | Measured value
equilibrium.time_slice[:].constraints.pf_passive_current[:].reconstructed (alpha) |  | FLT_0D (uncertain) | A | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.pf_passive_current[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.pf_passive_current[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.pf_passive_current[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Set of total pressure estimates
equilibrium.time_slice[:].constraints.pressure[:].chi_squared (alpha) |  | FLT_0D (uncertain) | Pa | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.pressure[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.pressure[:].measured (alpha) |  | FLT_0D (uncertain) | Pa | Measured value
equilibrium.time_slice[:].constraints.pressure[:].reconstructed (alpha) |  | FLT_0D (uncertain) | Pa | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.pressure[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.pressure[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.pressure[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.q (alpha) | [1...N] | STRUCT_ARRAY | - | Set of safety factor estimates at various positions
equilibrium.time_slice[:].constraints.q[:].chi_squared (alpha) |  | FLT_0D (uncertain) | - | Squared error normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(reconstructed - measured)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.q[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.q[:].measured (alpha) |  | FLT_0D (uncertain) | - | Measured value
equilibrium.time_slice[:].constraints.q[:].position (alpha) |  | STRUCTURE |  | Position at which this measurement is given
equilibrium.time_slice[:].constraints.q[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
equilibrium.time_slice[:].constraints.q[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].constraints.q[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints.q[:].reconstructed (alpha) |  | FLT_0D (uncertain) | - | Value calculated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.q[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.q[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.q[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.strike_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
equilibrium.time_slice[:].constraints.strike_point[:].chi_squared_r (alpha) |  | FLT_0D (uncertain) | m | Squared error on the major radius normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(position_reconstructed/r - position_measured/r)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.strike_point[:].chi_squared_z (alpha) |  | FLT_0D (uncertain) | m | Squared error on the altitude normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(position_reconstructed/z - position_measured/z)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.strike_point[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.strike_point[:].position_measured (alpha) |  | STRUCTURE |  | Measured or estimated position
equilibrium.time_slice[:].constraints.strike_point[:].position_measured.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].constraints.strike_point[:].position_measured.z (alpha) |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints.strike_point[:].position_reconstructed (alpha) |  | STRUCTURE |  | Position estimated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.strike_point[:].position_reconstructed.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].constraints.strike_point[:].position_reconstructed.z (alpha) |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints.strike_point[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.strike_point[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.strike_point[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].constraints.x_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
equilibrium.time_slice[:].constraints.x_point[:].chi_squared_r (alpha) |  | FLT_0D (uncertain) | m | Squared error on the major radius normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(position_reconstructed/r - position_measured/r)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.x_point[:].chi_squared_z (alpha) |  | FLT_0D (uncertain) | m | Squared error on the altitude normalized by the standard deviation considered in the minimization process : chi_squared = weight^2 *(position_reconstructed/z - position_measured/z)^2 / sigma^2, where sigma is the standard deviation of the measurement error
equilibrium.time_slice[:].constraints.x_point[:].exact (alpha) |  | INT_0D |  | Integer flag : 1 means exact data, taken as an exact input without being fitted; 0 means the equilibrium code does a least square fit
equilibrium.time_slice[:].constraints.x_point[:].position_measured (alpha) |  | STRUCTURE |  | Measured or estimated position
equilibrium.time_slice[:].constraints.x_point[:].position_measured.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].constraints.x_point[:].position_measured.z (alpha) |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints.x_point[:].position_reconstructed (alpha) |  | STRUCTURE |  | Position estimated from the reconstructed equilibrium
equilibrium.time_slice[:].constraints.x_point[:].position_reconstructed.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].constraints.x_point[:].position_reconstructed.z (alpha) |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].constraints.x_point[:].source (alpha) |  | STR_0D |  | Path to the source data for this measurement in the IMAS data dictionary
equilibrium.time_slice[:].constraints.x_point[:].time_measurement (alpha) |  | FLT_0D (uncertain) | s | Exact time slice used from the time array of the measurement source data. If the time slice does not exist in the time array of the source data, it means linear interpolation has been used
equilibrium.time_slice[:].constraints.x_point[:].weight (alpha) |  | FLT_0D (uncertain) | - | Weight given to the measurement
equilibrium.time_slice[:].convergence |  | STRUCTURE |  | Convergence details
equilibrium.time_slice[:].convergence.iterations_n |  | INT_0D |  | Number of iterations carried out in the convergence loop
equilibrium.time_slice[:].coordinate_system |  | STRUCTURE |  | Flux surface coordinate system on a square grid of flux and poloidal angle
equilibrium.time_slice[:].coordinate_system.g11_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g11, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g11_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g11, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g12_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g12, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g12_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g12, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g13_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g13, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g13_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g13, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g22_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g22, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g22_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g22, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g23_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g23, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g23_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g23, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g33_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g33, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g33_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g33, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.grid |  | STRUCTURE |  | Definition of the 2D grid
equilibrium.time_slice[:].coordinate_system.grid.dim1 | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
equilibrium.time_slice[:].coordinate_system.grid.dim2 | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
equilibrium.time_slice[:].coordinate_system.grid.volume_element | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
equilibrium.time_slice[:].coordinate_system.grid_type |  | STRUCTURE |  | Type of coordinate system
equilibrium.time_slice[:].coordinate_system.grid_type.description |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].coordinate_system.grid_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].coordinate_system.grid_type.name |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].coordinate_system.jacobian | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | Absolute value of the jacobian of the coordinate system
equilibrium.time_slice[:].coordinate_system.r | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
equilibrium.time_slice[:].coordinate_system.tensor_contravariant | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Contravariant metric tensor on every point of the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.tensor_covariant | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Covariant metric tensor on every point of the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.z | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
equilibrium.time_slice[:].ggd (alpha) | [equilibrium.grids_ggd[:].grid] | STRUCT_ARRAY |  | Set of equilibrium representations using the generic grid description
equilibrium.time_slice[:].ggd[:].b_field_r (alpha) | [1...N] | STRUCT_ARRAY | T | R component of the poloidal magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_r[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_r[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].b_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T | Toroidal component of the magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_tor[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].b_field_z (alpha) | [1...N] | STRUCT_ARRAY | T | Z component of the poloidal magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_z[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_z[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].grid (obsolescent) |  | STRUCTURE |  | Grid description
equilibrium.time_slice[:].ggd[:].grid.grid_subset (obsolescent) | [1...N] | STRUCT_ARRAY |  | Grid subsets
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].jacobian (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].dimension (obsolescent) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (obsolescent) |  | INT_0D |  | Dimension of the object
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (obsolescent) |  | INT_0D |  | Object index
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (obsolescent) |  | INT_0D |  | Index of the space from which that object is taken
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier (obsolescent) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.description (obsolescent) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.name (obsolescent) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric (obsolescent) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.jacobian (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (obsolescent) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.identifier (obsolescent) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
equilibrium.time_slice[:].ggd[:].grid.identifier.description (obsolescent) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.identifier.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].ggd[:].grid.identifier.name (obsolescent) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.space (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
equilibrium.time_slice[:].ggd[:].grid.space[:].coordinates_type (obsolescent) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type (obsolescent) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.description (obsolescent) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.name (obsolescent) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.space[:].identifier (obsolescent) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
equilibrium.time_slice[:].ggd[:].grid.space[:].identifier.description (obsolescent) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.space[:].identifier.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].ggd[:].grid.space[:].identifier.name (obsolescent) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension (obsolescent) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (obsolescent) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (obsolescent) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (obsolescent) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (obsolescent) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (obsolescent) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (obsolescent) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
equilibrium.time_slice[:].ggd[:].j_parallel (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Parallel (to magnetic field) plasma current density, given on various grid subsets
equilibrium.time_slice[:].ggd[:].j_parallel[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].j_parallel[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].j_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].j_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].j_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].j_tor (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Toroidal plasma current density, given on various grid subsets
equilibrium.time_slice[:].ggd[:].j_tor[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].j_tor[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].j_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].j_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].j_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].phi (alpha) | [1...N] | STRUCT_ARRAY | Wb | Values of the toroidal flux, given on various grid subsets
equilibrium.time_slice[:].ggd[:].phi[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].phi[:].values, 1...N] | FLT_2D (uncertain) | Wb | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].phi[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].phi[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].phi[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Wb | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].psi (alpha) | [1...N] | STRUCT_ARRAY | Wb | Values of the poloidal flux, given on various grid subsets
equilibrium.time_slice[:].ggd[:].psi[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].psi[:].values, 1...N] | FLT_2D (uncertain) | Wb | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].psi[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].psi[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].psi[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Wb | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].r (alpha) | [1...N] | STRUCT_ARRAY | m | Values of the major radius on various grid subsets
equilibrium.time_slice[:].ggd[:].r[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].r[:].values, 1...N] | FLT_2D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].theta (alpha) | [1...N] | STRUCT_ARRAY | rad | Values of the poloidal angle, given on various grid subsets
equilibrium.time_slice[:].ggd[:].theta[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].theta[:].values, 1...N] | FLT_2D (uncertain) | rad | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].theta[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].theta[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].theta[:].values (alpha) | [1...N] | FLT_1D (uncertain) | rad | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].z (alpha) | [1...N] | STRUCT_ARRAY | m | Values of the Height on various grid subsets
equilibrium.time_slice[:].ggd[:].z[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].z[:].values, 1...N] | FLT_2D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].global_quantities |  | STRUCTURE |  | 0D parameters of the equilibrium
equilibrium.time_slice[:].global_quantities.area |  | FLT_0D (uncertain) | m^2 | Area of the LCFS poloidal cross section
equilibrium.time_slice[:].global_quantities.beta_normal |  | FLT_0D (uncertain) | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
equilibrium.time_slice[:].global_quantities.beta_pol |  | FLT_0D (uncertain) | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
equilibrium.time_slice[:].global_quantities.beta_tor |  | FLT_0D (uncertain) | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
equilibrium.time_slice[:].global_quantities.energy_mhd |  | FLT_0D (uncertain) | J | Plasma energy content = 3/2 * int(p,dV) with p being the total pressure (thermal + fast particles) [J]. Time-dependent; Scalar
equilibrium.time_slice[:].global_quantities.ip |  | FLT_0D (uncertain) | A | Plasma current (toroidal component). Positive sign means anti-clockwise when viewed from above.
equilibrium.time_slice[:].global_quantities.length_pol |  | FLT_0D (uncertain) | m | Poloidal length of the magnetic surface
equilibrium.time_slice[:].global_quantities.li_3 |  | FLT_0D (uncertain) | - | Internal inductance
equilibrium.time_slice[:].global_quantities.magnetic_axis |  | STRUCTURE |  | Magnetic axis position and toroidal field
equilibrium.time_slice[:].global_quantities.magnetic_axis.b_field_tor |  | FLT_0D (uncertain) | T | Total toroidal magnetic field at the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.b_tor (obsolescent) |  | FLT_0D (uncertain) | T | Total toroidal magnetic field at the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.r |  | FLT_0D (uncertain) | m | Major radius of the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.z |  | FLT_0D (uncertain) | m | Height of the magnetic axis
equilibrium.time_slice[:].global_quantities.psi_axis |  | FLT_0D (uncertain) | Wb | Poloidal flux at the magnetic axis
equilibrium.time_slice[:].global_quantities.psi_boundary |  | FLT_0D (uncertain) | Wb | Poloidal flux at the selected plasma boundary
equilibrium.time_slice[:].global_quantities.q_95 |  | FLT_0D (uncertain) | - | q at the 95% poloidal flux surface (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
equilibrium.time_slice[:].global_quantities.q_axis |  | FLT_0D (uncertain) | - | q at the magnetic axis
equilibrium.time_slice[:].global_quantities.q_min |  | STRUCTURE |  | Minimum q value and position
equilibrium.time_slice[:].global_quantities.q_min.rho_tor_norm |  | FLT_0D (uncertain) | - | Minimum q position in normalised toroidal flux coordinate
equilibrium.time_slice[:].global_quantities.q_min.value |  | FLT_0D (uncertain) | - | Minimum q value
equilibrium.time_slice[:].global_quantities.surface |  | FLT_0D (uncertain) | m^2 | Surface area of the toroidal flux surface
equilibrium.time_slice[:].global_quantities.volume |  | FLT_0D (uncertain) | m^3 | Total plasma volume
equilibrium.time_slice[:].global_quantities.w_mhd (obsolescent) |  | FLT_0D (uncertain) | J | Plasma energy content = 3/2 * int(p,dV) with p being the total pressure (thermal + fast particles) [J]. Time-dependent; Scalar
equilibrium.time_slice[:].profiles_1d |  | STRUCTURE |  | Equilibrium profiles (1D radial grid) as a function of the poloidal flux
equilibrium.time_slice[:].profiles_1d.area | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
equilibrium.time_slice[:].profiles_1d.b_average (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Flux surface averaged B
equilibrium.time_slice[:].profiles_1d.b_field_average | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Flux surface averaged modulus of B (always positive, irrespective of the sign convention for the B-field direction).
equilibrium.time_slice[:].profiles_1d.b_field_max | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Maximum(modulus(B)) on the flux surface (always positive, irrespective of the sign convention for the B-field direction)
equilibrium.time_slice[:].profiles_1d.b_field_min | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Minimum(modulus(B)) on the flux surface (always positive, irrespective of the sign convention for the B-field direction)
equilibrium.time_slice[:].profiles_1d.b_max (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Maximum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.b_min (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Minimum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.beta_pol | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Poloidal beta profile. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
equilibrium.time_slice[:].profiles_1d.darea_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2.Wb^-1 | Radial derivative of the cross-sectional area of the flux surface with respect to psi
equilibrium.time_slice[:].profiles_1d.darea_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial derivative of the cross-sectional area of the flux surface with respect to rho_tor
equilibrium.time_slice[:].profiles_1d.dpressure_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Pa.Wb^-1 | Derivative of pressure w.r.t. psi
equilibrium.time_slice[:].profiles_1d.dpsi_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Wb/m | Derivative of Psi with respect to Rho_Tor
equilibrium.time_slice[:].profiles_1d.dvolume_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^3.Wb^-1 | Radial derivative of the volume enclosed in the flux surface with respect to Psi
equilibrium.time_slice[:].profiles_1d.dvolume_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Radial derivative of the volume enclosed in the flux surface with respect to Rho_Tor
equilibrium.time_slice[:].profiles_1d.elongation | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Elongation
equilibrium.time_slice[:].profiles_1d.f | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T.m | Diamagnetic function (F=R B_Phi)
equilibrium.time_slice[:].profiles_1d.f_df_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^2.m^2/Wb | Derivative of F w.r.t. Psi, multiplied with F
equilibrium.time_slice[:].profiles_1d.geometric_axis |  | STRUCTURE |  | RZ position of the geometric axis of the magnetic surfaces (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the surface)
equilibrium.time_slice[:].profiles_1d.geometric_axis.r | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].profiles_1d.geometric_axis.z | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].profiles_1d.gm1 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-2 | Flux surface averaged 1/R^2
equilibrium.time_slice[:].profiles_1d.gm2 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-2 | Flux surface averaged |grad_rho_tor|^2/R^2
equilibrium.time_slice[:].profiles_1d.gm3 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Flux surface averaged |grad_rho_tor|^2
equilibrium.time_slice[:].profiles_1d.gm4 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^-2 | Flux surface averaged 1/B^2
equilibrium.time_slice[:].profiles_1d.gm5 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^2 | Flux surface averaged B^2
equilibrium.time_slice[:].profiles_1d.gm6 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^-2 | Flux surface averaged |grad_rho_tor|^2/B^2
equilibrium.time_slice[:].profiles_1d.gm7 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Flux surface averaged |grad_rho_tor|
equilibrium.time_slice[:].profiles_1d.gm8 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Flux surface averaged R
equilibrium.time_slice[:].profiles_1d.gm9 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-1 | Flux surface averaged 1/R
equilibrium.time_slice[:].profiles_1d.j_parallel | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | A/m^2 | Flux surface averaged parallel current density = average(j.B) / B0, where B0 = Equilibrium/Global/Toroidal_Field/B0
equilibrium.time_slice[:].profiles_1d.j_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | A.m^-2 | Flux surface averaged toroidal current density = average(j_tor/R) / average(1/R)
equilibrium.time_slice[:].profiles_1d.magnetic_shear | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
equilibrium.time_slice[:].profiles_1d.mass_density | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | kg.m^-3 | Mass density
equilibrium.time_slice[:].profiles_1d.phi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Wb | Toroidal flux
equilibrium.time_slice[:].profiles_1d.pressure | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Pa | Pressure
equilibrium.time_slice[:].profiles_1d.psi | [1...N] | FLT_1D (uncertain) | Wb | Poloidal flux
equilibrium.time_slice[:].profiles_1d.q | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Safety factor (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
equilibrium.time_slice[:].profiles_1d.r_inboard | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial coordinate (major radius) on the inboard side of the magnetic axis
equilibrium.time_slice[:].profiles_1d.r_outboard | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial coordinate (major radius) on the outboard side of the magnetic axis
equilibrium.time_slice[:].profiles_1d.rho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
equilibrium.time_slice[:].profiles_1d.rho_tor_norm | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
equilibrium.time_slice[:].profiles_1d.rho_volume_norm | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Normalised square root of enclosed volume (radial coordinate). The normalizing value is the enclosed volume at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
equilibrium.time_slice[:].profiles_1d.squareness_lower_inner (alpha) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Lower inner squareness (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].profiles_1d.squareness_lower_outer (alpha) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Lower outer squareness (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].profiles_1d.squareness_upper_inner (alpha) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Upper inner squareness (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].profiles_1d.squareness_upper_outer (alpha) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Upper outer squareness (definition from T. Luce, Plasma Phys. Control. Fusion 55 (2013) 095009)
equilibrium.time_slice[:].profiles_1d.surface | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
equilibrium.time_slice[:].profiles_1d.trapped_fraction | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Trapped particle fraction
equilibrium.time_slice[:].profiles_1d.triangularity_lower | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Lower triangularity w.r.t. magnetic axis
equilibrium.time_slice[:].profiles_1d.triangularity_upper | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Upper triangularity w.r.t. magnetic axis
equilibrium.time_slice[:].profiles_1d.volume | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^3 | Volume enclosed in the flux surface
equilibrium.time_slice[:].profiles_2d | [1...N] | STRUCT_ARRAY |  | Equilibrium 2D profiles in the poloidal plane. Multiple 2D representations of the equilibrium can be stored here.
equilibrium.time_slice[:].profiles_2d[:].b_field_r | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | R component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_field_tor | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Toroidal component of the magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_field_z | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Z component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_r (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | R component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_tor (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Toroidal component of the magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_z (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Z component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].grid |  | STRUCTURE |  | Definition of the 2D grid (the content of dim1 and dim2 is defined by the selected grid_type)
equilibrium.time_slice[:].profiles_2d[:].grid.dim1 | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
equilibrium.time_slice[:].profiles_2d[:].grid.dim2 | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
equilibrium.time_slice[:].profiles_2d[:].grid.volume_element | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
equilibrium.time_slice[:].profiles_2d[:].grid_type |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
equilibrium.time_slice[:].profiles_2d[:].grid_type.description |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].profiles_2d[:].grid_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
equilibrium.time_slice[:].profiles_2d[:].grid_type.name |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].profiles_2d[:].j_parallel | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | A.m^-2 | Parallel (to magnetic field) plasma current density
equilibrium.time_slice[:].profiles_2d[:].j_tor | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | A.m^-2 | Toroidal plasma current density
equilibrium.time_slice[:].profiles_2d[:].phi | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | Wb | Toroidal flux
equilibrium.time_slice[:].profiles_2d[:].psi | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | Wb | Values of the poloidal flux at the grid in the poloidal plane
equilibrium.time_slice[:].profiles_2d[:].r | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
equilibrium.time_slice[:].profiles_2d[:].theta | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | rad | Values of the poloidal angle on the grid
equilibrium.time_slice[:].profiles_2d[:].z | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
equilibrium.time_slice[:].time |  | FLT_0D | s | Time
equilibrium.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
equilibrium.vacuum_toroidal_field.b0 | [equilibrium.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
equilibrium.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
gas_injection (alpha) |  |  |  | Gas injection by a system of pipes and valves
gas_injection.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
gas_injection.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
gas_injection.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
gas_injection.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
gas_injection.code.library[:].name (alpha) |  | STR_0D |  | Name of software
gas_injection.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
gas_injection.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
gas_injection.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
gas_injection.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
gas_injection.code.output_flag (alpha) | [gas_injection.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
gas_injection.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
gas_injection.code.repository (alpha) |  | STR_0D |  | URL of software repository
gas_injection.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
gas_injection.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
gas_injection.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
gas_injection.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
gas_injection.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
gas_injection.ids_properties.occurrence |  | INT_0D |  |
gas_injection.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
gas_injection.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
gas_injection.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
gas_injection.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
gas_injection.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
gas_injection.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
gas_injection.pipe (alpha) | [1...N] | STRUCT_ARRAY |  | Set of gas injection pipes
gas_injection.pipe[:].exit_position (alpha) |  | STRUCTURE |  | Exit position of the pipe in the vaccum vessel
gas_injection.pipe[:].exit_position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
gas_injection.pipe[:].exit_position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
gas_injection.pipe[:].exit_position.z (alpha) |  | FLT_0D (uncertain) | m | Height
gas_injection.pipe[:].flow_rate (alpha) |  | STRUCTURE | Pa.m^3.s^-1 | Flow rate at the exit of the pipe
gas_injection.pipe[:].flow_rate.data (alpha) | [gas_injection.pipe[:].flow_rate.time] | FLT_1D (uncertain) | Pa.m^3.s^-1 | Data
gas_injection.pipe[:].flow_rate.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
gas_injection.pipe[:].identifier (alpha) |  | STR_0D |  | ID of the injection pipe
gas_injection.pipe[:].length (alpha) |  | FLT_0D (uncertain) | m | Pipe length
gas_injection.pipe[:].name (alpha) |  | STR_0D |  | Name of the injection pipe
gas_injection.pipe[:].second_point (alpha) |  | STRUCTURE |  | Second point indicating (combined with the exit_position) the direction of the gas injection towards the plasma
gas_injection.pipe[:].second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
gas_injection.pipe[:].second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
gas_injection.pipe[:].second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
gas_injection.pipe[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the pipe (may be more than one in case the valve injects a gas mixture)
gas_injection.pipe[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
gas_injection.pipe[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
gas_injection.pipe[:].species[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
gas_injection.pipe[:].species[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
gas_injection.pipe[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
gas_injection.pipe[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Relative fraction of this species (in molecules) in the gas mixture
gas_injection.pipe[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
gas_injection.pipe[:].valve (alpha) | [1...N] | STRUCT_ARRAY |  | Set of valves connecting a gas bottle the the pipe
gas_injection.pipe[:].valve[:].electron_rate (alpha) |  | STRUCTURE | s^-1 | Number of electrons injected per second
gas_injection.pipe[:].valve[:].electron_rate.data (alpha) | [gas_injection.pipe[:].valve[:].electron_rate.time] | FLT_1D (uncertain) | s^-1 | Data
gas_injection.pipe[:].valve[:].electron_rate.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
gas_injection.pipe[:].valve[:].flow_rate (alpha) |  | STRUCTURE | Pa.m^3.s^-1 | Flow rate at the exit of the valve
gas_injection.pipe[:].valve[:].flow_rate.data (alpha) | [gas_injection.pipe[:].valve[:].flow_rate.time] | FLT_1D (uncertain) | Pa.m^3.s^-1 | Data
gas_injection.pipe[:].valve[:].flow_rate.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
gas_injection.pipe[:].valve[:].flow_rate_max (alpha) |  | FLT_0D (uncertain) | Pa.m^3.s^-1 | Maximum flow rate of the valve
gas_injection.pipe[:].valve[:].flow_rate_min (alpha) |  | FLT_0D (uncertain) | Pa.m^3.s^-1 | Minimum flow rate of the valve
gas_injection.pipe[:].valve[:].identifier (alpha) |  | STR_0D |  | ID of the valve
gas_injection.pipe[:].valve[:].name (alpha) |  | STR_0D |  | Name of the valve
gas_injection.pipe[:].valve[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the valve (may be more than one in case the valve injects a gas mixture)
gas_injection.pipe[:].valve[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
gas_injection.pipe[:].valve[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
gas_injection.pipe[:].valve[:].species[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
gas_injection.pipe[:].valve[:].species[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
gas_injection.pipe[:].valve[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
gas_injection.pipe[:].valve[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Relative fraction of this species (in molecules) in the gas mixture
gas_injection.pipe[:].valve[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
gas_injection.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
gyrokinetics (alpha) |  |  |  | Description of a gyrokinetic simulation (delta-f, flux-tube). All quantities within this IDS are normalised (apart from time), thus independent of rhostar, consistently with the local approximation and a spectral representation is assumed in the perpendicular plane (i.e. homogeneous turbulence). All quantities are given in the laboratory frame, except the moments of the perturbed distribution function which are given in the rotating frame.
gyrokinetics.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
gyrokinetics.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
gyrokinetics.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
gyrokinetics.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
gyrokinetics.code.library[:].name (alpha) |  | STR_0D |  | Name of software
gyrokinetics.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
gyrokinetics.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
gyrokinetics.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
gyrokinetics.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
gyrokinetics.code.output_flag (alpha) | [gyrokinetics.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
gyrokinetics.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
gyrokinetics.code.repository (alpha) |  | STR_0D |  | URL of software repository
gyrokinetics.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
gyrokinetics.collisions (alpha) |  | STRUCTURE |  | Collisions related quantities
gyrokinetics.collisions.collisionality_norm (alpha) | [gyrokinetics.species, gyrokinetics.species] | FLT_2D (uncertain) | - | Normalised collisionality between two species
gyrokinetics.flux_surface (alpha) |  | STRUCTURE |  | Flux surface characteristics
gyrokinetics.flux_surface.b_field_tor_sign (alpha) |  | FLT_0D (uncertain) | - | Sign of the toroidal magnetic field
gyrokinetics.flux_surface.dc_dr_minor_norm (alpha) | [gyrokinetics.flux_surface.shape_coefficients_c] | FLT_1D (uncertain) | - | Derivative of the 'c' shape coefficients with respect to r_minor_norm
gyrokinetics.flux_surface.ds_dr_minor_norm (alpha) | [gyrokinetics.flux_surface.shape_coefficients_s] | FLT_1D (uncertain) | - | Derivative of the 's' shape coefficients with respect to r_minor_norm
gyrokinetics.flux_surface.elongation (alpha) |  | FLT_0D (uncertain) | - | Elongation
gyrokinetics.flux_surface.ip_sign (alpha) |  | FLT_0D (uncertain) | - | Sign of the plasma current
gyrokinetics.flux_surface.magnetic_shear_r_minor (alpha) |  | FLT_0D (uncertain) | - | Magnetic shear, defined as r_minor_norm/q . dq/dr_minor_norm (different definition from the equilibrium IDS)
gyrokinetics.flux_surface.pressure_gradient_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised pressure gradient (derivative with respect to r_minor_norm)
gyrokinetics.flux_surface.q (alpha) |  | FLT_0D (uncertain) | - | Safety factor
gyrokinetics.flux_surface.r_minor_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised minor radius of the flux surface of interest = 1/2 * (max(R) - min(R))/L_ref
gyrokinetics.flux_surface.shape_coefficients_c (alpha) | [1...N] | FLT_1D (uncertain) | - | 'c' coefficients in the formula defining the shape of the flux surface
gyrokinetics.flux_surface.shape_coefficients_s (alpha) | [1...N] | FLT_1D (uncertain) | - | 's' coefficients in the formula defining the shape of the flux surface
gyrokinetics.flux_surface.triangularity_lower (alpha) |  | FLT_0D (uncertain) | - | Lower triangularity
gyrokinetics.flux_surface.triangularity_upper (alpha) |  | FLT_0D (uncertain) | - | Upper triangularity
gyrokinetics.fluxes_integrated_norm (alpha) | [gyrokinetics.species] | STRUCT_ARRAY |  | Normalised fluxes integrated over the kx and ky grids used in a non-linear run (therefore they have no dependence on the wavevector) in the laboratory frame, for a given species
gyrokinetics.fluxes_integrated_norm[:].energy_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the normalised energy flux
gyrokinetics.fluxes_integrated_norm[:].energy_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the normalised energy flux
gyrokinetics.fluxes_integrated_norm[:].energy_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the normalised energy flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_parallel_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the parallel component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_parallel_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the parallel component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_parallel_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the parallel component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_perpendicular_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_perpendicular_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].momentum_tor_perpendicular_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.fluxes_integrated_norm[:].particles_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the normalised particle flux
gyrokinetics.fluxes_integrated_norm[:].particles_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the normalised particle flux
gyrokinetics.fluxes_integrated_norm[:].particles_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the normalised particle flux
gyrokinetics.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
gyrokinetics.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
gyrokinetics.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
gyrokinetics.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
gyrokinetics.ids_properties.occurrence |  | INT_0D |  |
gyrokinetics.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
gyrokinetics.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
gyrokinetics.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
gyrokinetics.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
gyrokinetics.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
gyrokinetics.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
gyrokinetics.model (alpha) |  | STRUCTURE |  | Assumptions of the GK calculations
gyrokinetics.model.collisions_energy_conservation (alpha) |  | INT_0D |  | Flag = 1 if the collision operator conserves energy, 0 otherwise
gyrokinetics.model.collisions_finite_larmor_radius (alpha) |  | INT_0D |  | Flag = 1 if finite larmor radius effects are retained in the collision operator, 0 otherwise
gyrokinetics.model.collisions_momentum_conservation (alpha) |  | INT_0D |  | Flag = 1 if the collision operator conserves momentum, 0 otherwise
gyrokinetics.model.collisions_pitch_only (alpha) |  | INT_0D |  | Flag = 1 if only pitch-angle scattering is retained, 0 otherwise
gyrokinetics.model.include_a_field_parallel (alpha) |  | INT_0D |  | Flag = 1 if fluctuations of the parallel vector potential are retained, 0 otherwise
gyrokinetics.model.include_b_field_parallel (alpha) |  | INT_0D |  | Flag = 1 if fluctuations of the parallel magnetic field are retained, 0 otherwise
gyrokinetics.model.include_centrifugal_effects (alpha) |  | INT_0D |  | Flag = 1 if centrifugal effects are retained, 0 otherwise
gyrokinetics.model.include_full_curvature_drift (alpha) |  | INT_0D |  | Flag = 1 if all contributions to the curvature drift are included (including beta_prime), 0 otherwise. Neglecting the beta_prime contribution (Flag=0) is only recommended together with the neglect of parallel magnetic field fluctuations
gyrokinetics.model.initial_value_run (alpha) |  | INT_0D |  | Flag = 1 if this is an initial value run, 0 for an eigenvalue run
gyrokinetics.model.non_linear_run (alpha) |  | INT_0D |  | Flag = 1 if this is a non-linear run, 0 for a linear run
gyrokinetics.model.time_interval_norm (alpha) | [1...2] | FLT_1D (uncertain) | - | Normalised time interval used to average fluxes and moments from non-linear runs
gyrokinetics.species (alpha) | [1...N] | STRUCT_ARRAY |  | Set of species (including electrons) used in the calculation and related quantities
gyrokinetics.species[:].charge_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised charge
gyrokinetics.species[:].density_log_gradient_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised logarithmic gradient (with respect to r_minor_norm) of the density
gyrokinetics.species[:].density_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised density
gyrokinetics.species[:].mass_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised mass
gyrokinetics.species[:].temperature_log_gradient_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised logarithmic gradient (with respect to r_minor_norm) of the temperature
gyrokinetics.species[:].temperature_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised temperature
gyrokinetics.species[:].velocity_tor_gradient_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised gradient (with respect to r_minor_norm) of the toroidal velocity
gyrokinetics.species_all (alpha) |  | STRUCTURE |  | Physical quantities common to all species
gyrokinetics.species_all.beta_reference (alpha) |  | FLT_0D (uncertain) | - | Reference plasma beta (see detailed documentation at the root of the IDS)
gyrokinetics.species_all.debye_length_reference (alpha) |  | FLT_0D (uncertain) | - | Debye length computed from the reference quantities (see detailed documentation at the root of the IDS)
gyrokinetics.species_all.shearing_rate_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised ExB shearing rate (for non-linear runs only)
gyrokinetics.species_all.velocity_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised toroidal velocity of species (all species are assumed to have a purely toroidal velocity with a common toroidal angular frequency)
gyrokinetics.species_all.zeff (alpha) |  | FLT_0D (uncertain) | - | Effective charge
gyrokinetics.tag (alpha) | [1...N] | STRUCT_ARRAY |  | Set of tags to which this entry belongs
gyrokinetics.tag[:].comment (alpha) |  | STR_0D |  | Any comment describing the content of the tagged list of entries
gyrokinetics.tag[:].name (alpha) |  | STR_0D |  | Name of the tag
gyrokinetics.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
gyrokinetics.wavevector (alpha) | [1...N] | STRUCT_ARRAY |  | Set of wavevectors
gyrokinetics.wavevector[:].binormal_component_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised binormal component of the wavevector
gyrokinetics.wavevector[:].eigenmode (alpha) | [1...N] | STRUCT_ARRAY |  | Set of eigenmode for this wavector
gyrokinetics.wavevector[:].eigenmode[:].a_field_parallel_perturbed_norm_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed parallel vector potential (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].a_field_parallel_perturbed_norm_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed parallel vector potential (real part)
gyrokinetics.wavevector[:].eigenmode[:].a_field_parallel_perturbed_parity (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Parity of the perturbed parallel vector potential with respect to theta = 0 (poloidal angle)
gyrokinetics.wavevector[:].eigenmode[:].a_field_parallel_perturbed_weight (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Amplitude of the perturbed parallel vector potential normalised to the sum of amplitudes of all perturbed fields
gyrokinetics.wavevector[:].eigenmode[:].b_field_parallel_perturbed_norm_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed parallel magnetic field (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].b_field_parallel_perturbed_norm_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed parallel magnetic field (real part)
gyrokinetics.wavevector[:].eigenmode[:].b_field_parallel_perturbed_parity (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Parity of the perturbed parallel magnetic field with respect to theta = 0 (poloidal angle)
gyrokinetics.wavevector[:].eigenmode[:].b_field_parallel_perturbed_weight (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Amplitude of the perturbed parallel magnetic field normalised to the sum of amplitudes of all perturbed fields
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments (alpha) | [gyrokinetics.species] | STRUCT_ARRAY |  | Fluxes and moments of the perturbed distribution function, for this eigenmode and for each species
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm (alpha) |  | STRUCTURE |  | Normalised fluxes in the laboratory frame
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.energy_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the normalised energy flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.energy_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the normalised energy flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.energy_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the normalised energy flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_parallel_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the parallel component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_parallel_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the parallel component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_parallel_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the parallel component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_perpendicular_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_perpendicular_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.momentum_tor_perpendicular_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the perpendicular component of the normalised toroidal momentum flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.particles_a_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel electromagnetic potential to the normalised particle flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.particles_b_field_parallel (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed parallel magnetic field to the normalised particle flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].fluxes_norm.particles_phi_potential (alpha) |  | FLT_0D (uncertain) | - | Contribution of the perturbed electrostatic potential to the normalised particle flux
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame (alpha) |  | STRUCTURE |  | Moments (normalised) of the perturbed distribution function defined in the rotating frame
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.density_gyroaveraged_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised density (gyroaveraged, imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.density_gyroaveraged_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised density (gyroaveraged, real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.density_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised density (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.density_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised density (real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_parallel_gyroaveraged_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel temperature (gyroaveraged, imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_parallel_gyroaveraged_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel temperature (gyroaveraged, real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_parallel_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel temperature (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_parallel_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel temperature (real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_perpendicular_gyroaveraged_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perpendicular temperature (gyroaveraged, imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_perpendicular_gyroaveraged_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perpendicular temperature (gyroaveraged, real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_perpendicular_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perpendicular temperature (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.temperature_perpendicular_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perpendicular temperature (real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.velocity_parallel_gyroaveraged_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel velocity (gyroaveraged, imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.velocity_parallel_gyroaveraged_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel velocity (gyroaveraged, real part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.velocity_parallel_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel velocity (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].fluxes_moments[:].moments_norm_rotating_frame.velocity_parallel_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised parallel velocity (real part)
gyrokinetics.wavevector[:].eigenmode[:].frequency_norm (alpha) |  | FLT_0D (uncertain) | - | Frequency
gyrokinetics.wavevector[:].eigenmode[:].growth_rate_norm (alpha) |  | FLT_0D (uncertain) | - | Growth rate
gyrokinetics.wavevector[:].eigenmode[:].growth_rate_tolerance (alpha) |  | FLT_0D (uncertain) | - | Relative tolerance on the growth rate (convergence of the simulation)
gyrokinetics.wavevector[:].eigenmode[:].phi_potential_perturbed_norm_imaginary (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed electrostatic potential (imaginary part)
gyrokinetics.wavevector[:].eigenmode[:].phi_potential_perturbed_norm_real (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle, gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_2D (uncertain) | - | Normalised perturbed electrostatic potential (real part)
gyrokinetics.wavevector[:].eigenmode[:].phi_potential_perturbed_parity (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Parity of the perturbed electrostatic potential with respect to theta = 0 (poloidal angle)
gyrokinetics.wavevector[:].eigenmode[:].phi_potential_perturbed_weight (alpha) | [gyrokinetics.wavevector[:].eigenmode[:].time_norm] | FLT_1D (uncertain) | - | Amplitude of the perturbed electrostatic potential normalised to the sum of amplitudes of all perturbed fields
gyrokinetics.wavevector[:].eigenmode[:].poloidal_angle (alpha) | [1...N] | FLT_1D (uncertain) | - | Poloidal angle grid (see detailed documentation at the root of the IDS)
gyrokinetics.wavevector[:].eigenmode[:].time_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised time of the gyrokinetic simulation
gyrokinetics.wavevector[:].poloidal_turns (alpha) |  | INT_0D |  | Number of poloidal turns considered in the flux-tube simulation
gyrokinetics.wavevector[:].radial_component_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised radial component of the wavevector

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
hard_x_rays (alpha) |  |  |  | Hard X-rays tomography diagnostic
hard_x_rays.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
hard_x_rays.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
hard_x_rays.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
hard_x_rays.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
hard_x_rays.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
hard_x_rays.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
hard_x_rays.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
hard_x_rays.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
hard_x_rays.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
hard_x_rays.channel[:].aperture[:].outline.x2 (alpha) | [hard_x_rays.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
hard_x_rays.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
hard_x_rays.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
hard_x_rays.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
hard_x_rays.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
hard_x_rays.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
hard_x_rays.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
hard_x_rays.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
hard_x_rays.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
hard_x_rays.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
hard_x_rays.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
hard_x_rays.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
hard_x_rays.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
hard_x_rays.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
hard_x_rays.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
hard_x_rays.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
hard_x_rays.channel[:].detector.outline.x2 (alpha) | [hard_x_rays.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
hard_x_rays.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
hard_x_rays.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
hard_x_rays.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
hard_x_rays.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
hard_x_rays.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
hard_x_rays.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
hard_x_rays.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
hard_x_rays.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
hard_x_rays.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
hard_x_rays.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
hard_x_rays.channel[:].energy_band (alpha) | [1...N] | STRUCT_ARRAY |  | Set of energy bands in which photons are counted by the detector
hard_x_rays.channel[:].energy_band[:].detection_efficiency (alpha) | [hard_x_rays.channel[:].energy_band[:].energies] | FLT_1D (uncertain) | - | Probability of detection of a photon impacting the detector as a function of its energy
hard_x_rays.channel[:].energy_band[:].energies (alpha) | [1...N] | FLT_1D (uncertain) | eV | Array of discrete energy values inside the band
hard_x_rays.channel[:].energy_band[:].lower_bound (alpha) |  | FLT_0D (uncertain) | eV | Lower bound of the energy band
hard_x_rays.channel[:].energy_band[:].upper_bound (alpha) |  | FLT_0D (uncertain) | eV | Upper bound of the energy band
hard_x_rays.channel[:].etendue (alpha) |  | FLT_0D (uncertain) | m^2.str | Etendue (geometric extent) of the channel's optical system
hard_x_rays.channel[:].etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
hard_x_rays.channel[:].etendue_method.description (alpha) |  | STR_0D |  | Verbose description
hard_x_rays.channel[:].etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
hard_x_rays.channel[:].etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
hard_x_rays.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
hard_x_rays.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
hard_x_rays.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
hard_x_rays.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
hard_x_rays.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
hard_x_rays.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
hard_x_rays.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
hard_x_rays.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
hard_x_rays.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
hard_x_rays.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
hard_x_rays.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
hard_x_rays.channel[:].radiance (alpha) | [hard_x_rays.channel[:].energy_band, hard_x_rays.channel[:].radiance.time] | STRUCTURE | (photons).s^-1.m^-2.sr^-1 | Photons received by the detector per unit time, per unit solid angle and per unit area (i.e. photon flux divided by the etendue), in multiple energy bands if available from the detector
hard_x_rays.channel[:].radiance.data (alpha) | [1...N, hard_x_rays.channel[:].radiance.time] | FLT_2D (uncertain) | (photons).s^-1.m^-2.sr^-1 | Data
hard_x_rays.channel[:].radiance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
hard_x_rays.channel[:].radiance.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
hard_x_rays.channel[:].radiance.validity_timed (alpha) | [hard_x_rays.channel[:].radiance.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
hard_x_rays.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
hard_x_rays.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
hard_x_rays.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
hard_x_rays.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
hard_x_rays.code.library[:].name (alpha) |  | STR_0D |  | Name of software
hard_x_rays.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
hard_x_rays.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
hard_x_rays.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
hard_x_rays.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
hard_x_rays.code.output_flag (alpha) | [hard_x_rays.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
hard_x_rays.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
hard_x_rays.code.repository (alpha) |  | STR_0D |  | URL of software repository
hard_x_rays.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
hard_x_rays.emissivity_profile_1d (alpha) | [1...N] | STRUCT_ARRAY |  | Emissivity profile per energy band (assumed common to all channels used in the profile reconstruction)
hard_x_rays.emissivity_profile_1d[:].emissivity (alpha) | [hard_x_rays.emissivity_profile_1d[:].rho_tor_norm, hard_x_rays.emissivity_profile_1d[:].time] | FLT_2D (uncertain) | (photons).m^-3.str^-1.s^-1 | Radial profile of the plasma emissivity in this energy band
hard_x_rays.emissivity_profile_1d[:].half_width_external (alpha) | [hard_x_rays.emissivity_profile_1d[:].time] | FLT_1D (uncertain) | - | External (towards separatrix) half width of the emissivity peak (in normalised toroidal flux)
hard_x_rays.emissivity_profile_1d[:].half_width_internal (alpha) | [hard_x_rays.emissivity_profile_1d[:].time] | FLT_1D (uncertain) | - | Internal (towards magnetic axis) half width of the emissivity peak (in normalised toroidal flux)
hard_x_rays.emissivity_profile_1d[:].lower_bound (alpha) |  | FLT_0D (uncertain) | eV | Lower bound of the energy band
hard_x_rays.emissivity_profile_1d[:].peak_position (alpha) | [hard_x_rays.emissivity_profile_1d[:].time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate position at which the emissivity peaks
hard_x_rays.emissivity_profile_1d[:].rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate grid
hard_x_rays.emissivity_profile_1d[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
hard_x_rays.emissivity_profile_1d[:].upper_bound (alpha) |  | FLT_0D (uncertain) | eV | Upper bound of the energy band
hard_x_rays.emissivity_profile_1d[:].validity_timed (alpha) | [hard_x_rays.emissivity_profile_1d[:].time] | INT_1D |  | Indicator of the validity of the emissivity profile data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
hard_x_rays.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
hard_x_rays.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
hard_x_rays.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
hard_x_rays.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
hard_x_rays.ids_properties.occurrence |  | INT_0D |  |
hard_x_rays.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
hard_x_rays.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
hard_x_rays.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
hard_x_rays.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
hard_x_rays.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
hard_x_rays.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
hard_x_rays.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ic_antennas (alpha) |  |  |  | Antenna systems for heating and current drive in the ion cylcotron (IC) frequencies.
ic_antennas.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of Ion Cyclotron antennas
ic_antennas.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency (average over modules)
ic_antennas.antenna[:].frequency.data (alpha) | [ic_antennas.antenna[:].frequency.time] | FLT_1D (uncertain) | Hz | Data
ic_antennas.antenna[:].frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].identifier (alpha) |  | STR_0D |  | Identifier of the antenna (unique within the set of all antennas of the experiment)
ic_antennas.antenna[:].module (alpha) | [1...N] | STRUCT_ARRAY |  | Set of antenna modules (each module is fed by a single transmission line)
ic_antennas.antenna[:].module[:].current (alpha) | [1...N] | STRUCT_ARRAY | A | Set of current measurements
ic_antennas.antenna[:].module[:].current[:].amplitude (alpha) |  | STRUCTURE | A | Amplitude of the measurement
ic_antennas.antenna[:].module[:].current[:].amplitude.data (alpha) | [ic_antennas.antenna[:].module[:].current[:].amplitude.time] | FLT_1D (uncertain) | A | Data
ic_antennas.antenna[:].module[:].current[:].amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].current[:].identifier (alpha) |  | STR_0D |  | Identifier
ic_antennas.antenna[:].module[:].current[:].name (alpha) |  | STR_0D |  | Name
ic_antennas.antenna[:].module[:].current[:].phase (alpha) |  | STRUCTURE | rad | Phase of the measurement
ic_antennas.antenna[:].module[:].current[:].phase.data (alpha) | [ic_antennas.antenna[:].module[:].current[:].phase.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].current[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].current[:].position (alpha) |  | STRUCTURE |  | Position of the measurement
ic_antennas.antenna[:].module[:].current[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ic_antennas.antenna[:].module[:].current[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ic_antennas.antenna[:].module[:].current[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
ic_antennas.antenna[:].module[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
ic_antennas.antenna[:].module[:].frequency.data (alpha) | [ic_antennas.antenna[:].module[:].frequency.time] | FLT_1D (uncertain) | Hz | Data
ic_antennas.antenna[:].module[:].frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].identifier (alpha) |  | STR_0D |  | Identifier of the module
ic_antennas.antenna[:].module[:].matching_element (alpha) | [1...N] | STRUCT_ARRAY | A | Set of matching elements
ic_antennas.antenna[:].module[:].matching_element[:].capacitance (alpha) |  | STRUCTURE | F | Capacitance of the macthing element
ic_antennas.antenna[:].module[:].matching_element[:].capacitance.data (alpha) | [ic_antennas.antenna[:].module[:].matching_element[:].capacitance.time] | FLT_1D (uncertain) | F | Data
ic_antennas.antenna[:].module[:].matching_element[:].capacitance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].matching_element[:].name (alpha) |  | STR_0D |  | Name
ic_antennas.antenna[:].module[:].matching_element[:].phase (alpha) |  | STRUCTURE | rad | Phase delay induced by the stub
ic_antennas.antenna[:].module[:].matching_element[:].phase.data (alpha) | [ic_antennas.antenna[:].module[:].matching_element[:].phase.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].matching_element[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].matching_element[:].type (alpha) |  | STRUCTURE |  | Type of the matching element. Index = 1 : capacitor (fill capacitance); Index = 2 : stub (fill phase)
ic_antennas.antenna[:].module[:].matching_element[:].type.description (alpha) |  | STR_0D |  | Verbose description
ic_antennas.antenna[:].module[:].matching_element[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
ic_antennas.antenna[:].module[:].matching_element[:].type.name (alpha) |  | STR_0D |  | Short string identifier
ic_antennas.antenna[:].module[:].name (alpha) |  | STR_0D |  | Name of the module
ic_antennas.antenna[:].module[:].phase_forward (alpha) |  | STRUCTURE | rad | Phase of the forward power with respect to the first module
ic_antennas.antenna[:].module[:].phase_forward.data (alpha) | [ic_antennas.antenna[:].module[:].phase_forward.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].phase_forward.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].phase_reflected (alpha) |  | STRUCTURE | rad | Phase of the reflected power with respect to the forward power of this module
ic_antennas.antenna[:].module[:].phase_reflected.data (alpha) | [ic_antennas.antenna[:].module[:].phase_reflected.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].phase_reflected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].power_forward (alpha) |  | STRUCTURE | W | Forward power arriving to the back of the module
ic_antennas.antenna[:].module[:].power_forward.data (alpha) | [ic_antennas.antenna[:].module[:].power_forward.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].module[:].power_forward.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this module into the vacuum vessel
ic_antennas.antenna[:].module[:].power_launched.data (alpha) | [ic_antennas.antenna[:].module[:].power_launched.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].module[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].power_reflected (alpha) |  | STRUCTURE | W | Reflected power
ic_antennas.antenna[:].module[:].power_reflected.data (alpha) | [ic_antennas.antenna[:].module[:].power_reflected.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].module[:].power_reflected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Set of pressure measurements
ic_antennas.antenna[:].module[:].pressure[:].amplitude (alpha) |  | STRUCTURE | Pa | Amplitude of the measurement
ic_antennas.antenna[:].module[:].pressure[:].amplitude.data (alpha) | [ic_antennas.antenna[:].module[:].pressure[:].amplitude.time] | FLT_1D (uncertain) | Pa | Data
ic_antennas.antenna[:].module[:].pressure[:].amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].pressure[:].identifier (alpha) |  | STR_0D |  | Identifier
ic_antennas.antenna[:].module[:].pressure[:].name (alpha) |  | STR_0D |  | Name
ic_antennas.antenna[:].module[:].pressure[:].phase (alpha) |  | STRUCTURE | rad | Phase of the measurement
ic_antennas.antenna[:].module[:].pressure[:].phase.data (alpha) | [ic_antennas.antenna[:].module[:].pressure[:].phase.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].pressure[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].pressure[:].position (alpha) |  | STRUCTURE |  | Position of the measurement
ic_antennas.antenna[:].module[:].pressure[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ic_antennas.antenna[:].module[:].pressure[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ic_antennas.antenna[:].module[:].pressure[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
ic_antennas.antenna[:].module[:].reflection_coefficient (alpha) |  | STRUCTURE | - | Power reflection coefficient
ic_antennas.antenna[:].module[:].reflection_coefficient.data (alpha) | [ic_antennas.antenna[:].module[:].reflection_coefficient.time] | FLT_1D (uncertain) | - | Data
ic_antennas.antenna[:].module[:].reflection_coefficient.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].strap (alpha) | [1...N] | STRUCT_ARRAY |  | Set of IC antenna straps
ic_antennas.antenna[:].module[:].strap[:].current (alpha) |  | STRUCTURE | A | Root mean square current flowing along the strap
ic_antennas.antenna[:].module[:].strap[:].current.data (alpha) | [ic_antennas.antenna[:].module[:].strap[:].current.time] | FLT_1D (uncertain) | A | Data
ic_antennas.antenna[:].module[:].strap[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].strap[:].distance_to_conductor (alpha) |  | FLT_0D (uncertain) | m | Distance to conducting wall or other conductor behind the antenna strap
ic_antennas.antenna[:].module[:].strap[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the strap
ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle (alpha) |  | STRUCTURE |  | Description of the element contour by a set of arcs of circle. For each of these, the position of the start point is given together with the curvature radius. The end point is given by the start point of the next arc of circle.
ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle.curvature_radii (alpha) | [ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Curvature radius of each arc of circle
ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii of the start point of each arc of circle
ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle.z (alpha) | [ic_antennas.antenna[:].module[:].strap[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Height of the start point of each arc of circle
ic_antennas.antenna[:].module[:].strap[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique', 4:'arcs of circle')
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
ic_antennas.antenna[:].module[:].strap[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
ic_antennas.antenna[:].module[:].strap[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element. Do NOT repeat the first point.
ic_antennas.antenna[:].module[:].strap[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
ic_antennas.antenna[:].module[:].strap[:].geometry.outline.z (alpha) | [ic_antennas.antenna[:].module[:].strap[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
ic_antennas.antenna[:].module[:].strap[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
ic_antennas.antenna[:].module[:].strap[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
ic_antennas.antenna[:].module[:].strap[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
ic_antennas.antenna[:].module[:].strap[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
ic_antennas.antenna[:].module[:].strap[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
ic_antennas.antenna[:].module[:].strap[:].outline (alpha) |  | STRUCTURE |  | Strap outline
ic_antennas.antenna[:].module[:].strap[:].outline.phi (alpha) | [ic_antennas.antenna[:].module[:].strap[:].outline.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ic_antennas.antenna[:].module[:].strap[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
ic_antennas.antenna[:].module[:].strap[:].outline.z (alpha) | [ic_antennas.antenna[:].module[:].strap[:].outline.r] | FLT_1D (uncertain) | m | Height
ic_antennas.antenna[:].module[:].strap[:].phase (alpha) |  | STRUCTURE | rad | Phase of the strap current
ic_antennas.antenna[:].module[:].strap[:].phase.data (alpha) | [ic_antennas.antenna[:].module[:].strap[:].phase.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].strap[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].strap[:].width_tor (alpha) |  | FLT_0D (uncertain) | m | Width of strap in the toroidal direction
ic_antennas.antenna[:].module[:].voltage (alpha) | [1...N] | STRUCT_ARRAY | V | Set of voltage measurements
ic_antennas.antenna[:].module[:].voltage[:].amplitude (alpha) |  | STRUCTURE | V | Amplitude of the measurement
ic_antennas.antenna[:].module[:].voltage[:].amplitude.data (alpha) | [ic_antennas.antenna[:].module[:].voltage[:].amplitude.time] | FLT_1D (uncertain) | V | Data
ic_antennas.antenna[:].module[:].voltage[:].amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].voltage[:].identifier (alpha) |  | STR_0D |  | Identifier
ic_antennas.antenna[:].module[:].voltage[:].name (alpha) |  | STR_0D |  | Name
ic_antennas.antenna[:].module[:].voltage[:].phase (alpha) |  | STRUCTURE | rad | Phase of the measurement
ic_antennas.antenna[:].module[:].voltage[:].phase.data (alpha) | [ic_antennas.antenna[:].module[:].voltage[:].phase.time] | FLT_1D (uncertain) | rad | Data
ic_antennas.antenna[:].module[:].voltage[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].module[:].voltage[:].position (alpha) |  | STRUCTURE |  | Position of the measurement
ic_antennas.antenna[:].module[:].voltage[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
ic_antennas.antenna[:].module[:].voltage[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ic_antennas.antenna[:].module[:].voltage[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
ic_antennas.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna (unique within the set of all antennas of the experiment)
ic_antennas.antenna[:].power_forward (alpha) |  | STRUCTURE | W | Forward power arriving to the back of the antenna
ic_antennas.antenna[:].power_forward.data (alpha) | [ic_antennas.antenna[:].power_forward.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].power_forward.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this antenna into the vacuum vessel
ic_antennas.antenna[:].power_launched.data (alpha) | [ic_antennas.antenna[:].power_launched.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].power_reflected (alpha) |  | STRUCTURE | W | Reflected power
ic_antennas.antenna[:].power_reflected.data (alpha) | [ic_antennas.antenna[:].power_reflected.time] | FLT_1D (uncertain) | W | Data
ic_antennas.antenna[:].power_reflected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
ic_antennas.antenna[:].surface_current (alpha) | [ic_antennas.antenna[:].surface_current[:].time] | STRUCT_ARRAY |  | Description of the IC surface current on the antenna straps and on passive components, for every time slice
ic_antennas.antenna[:].surface_current[:].m_pol (alpha) | [1...N] | INT_1D |  | Poloidal mode numbers, used to describe the spectrum of the antenna current. The poloidal angle is defined from the reference point; the angle at a point (R,Z) is given by atan((Z-Zref)/(R-Rref)), where Rref=reference_point/r and Zref=reference_point/z
ic_antennas.antenna[:].surface_current[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers, used to describe the spectrum of the antenna current
ic_antennas.antenna[:].surface_current[:].spectrum (alpha) | [ic_antennas.antenna[:].surface_current[:].m_pol, ic_antennas.antenna[:].surface_current[:].n_tor] | FLT_2D (uncertain) | A | Spectrum of the total surface current on the antenna strap and passive components expressed in poloidal and toroidal modes
ic_antennas.antenna[:].surface_current[:].time (alpha) |  | FLT_0D | s | Time
ic_antennas.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ic_antennas.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ic_antennas.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
ic_antennas.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
ic_antennas.code.library[:].name (alpha) |  | STR_0D |  | Name of software
ic_antennas.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ic_antennas.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
ic_antennas.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
ic_antennas.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ic_antennas.code.output_flag (alpha) | [ic_antennas.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ic_antennas.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ic_antennas.code.repository (alpha) |  | STR_0D |  | URL of software repository
ic_antennas.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ic_antennas.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ic_antennas.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ic_antennas.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
ic_antennas.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
ic_antennas.ids_properties.occurrence |  | INT_0D |  |
ic_antennas.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
ic_antennas.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
ic_antennas.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
ic_antennas.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
ic_antennas.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
ic_antennas.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
ic_antennas.reference_point (alpha) |  | STRUCTURE |  | Reference point used to define the poloidal angle, e.g. the geometrical centre of the vacuum vessel. Used to define the poloidal mode numbers under antenna/surface_current
ic_antennas.reference_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ic_antennas.reference_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ic_antennas.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
interferometer (alpha) |  |  |  | Interferometer diagnostic
interferometer.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
interferometer.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
interferometer.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, defined by two points when the beam is not reflected, a third point is added to define the reflected beam path
interferometer.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
interferometer.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
interferometer.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interferometer.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interferometer.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
interferometer.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
interferometer.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interferometer.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interferometer.channel[:].line_of_sight.third_point (alpha) |  | STRUCTURE |  | Position of the third point
interferometer.channel[:].line_of_sight.third_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
interferometer.channel[:].line_of_sight.third_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interferometer.channel[:].line_of_sight.third_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interferometer.channel[:].n_e_line (alpha) |  | STRUCTURE | m^-2 | Line integrated density, possibly obtained by a combination of multiple interferometry wavelengths. Corresponds to the density integrated along the full line-of-sight (i.e. forward AND return for a reflected channel: NO dividing by 2 correction)
interferometer.channel[:].n_e_line.data (alpha) | [interferometer.channel[:].n_e_line.time] | FLT_1D (uncertain) | m^-2 | Data
interferometer.channel[:].n_e_line.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.channel[:].n_e_line.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.channel[:].n_e_line.validity_timed (alpha) | [interferometer.channel[:].n_e_line.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.channel[:].n_e_line_average (alpha) |  | STRUCTURE | m^-3 | Line average density, possibly obtained by a combination of multiple interferometry wavelengths. Corresponds to the density integrated along the full line-of-sight and then divided by the length of the line-of-sight
interferometer.channel[:].n_e_line_average.data (alpha) | [interferometer.channel[:].n_e_line_average.time] | FLT_1D (uncertain) | m^-3 | Data
interferometer.channel[:].n_e_line_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.channel[:].n_e_line_average.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.channel[:].n_e_line_average.validity_timed (alpha) | [interferometer.channel[:].n_e_line_average.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
interferometer.channel[:].path_length_variation (alpha) |  | STRUCTURE | m | Optical path length variation due to the plasma
interferometer.channel[:].path_length_variation.data (alpha) | [interferometer.channel[:].path_length_variation.time] | FLT_1D (uncertain) | m | Data
interferometer.channel[:].path_length_variation.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.channel[:].wavelength (alpha) | [1...N] | STRUCT_ARRAY |  | Set of wavelengths used for interferometry
interferometer.channel[:].wavelength[:].fringe_jump_correction (alpha) | [interferometer.channel[:].wavelength[:].fringe_jump_correction_times] | INT_1D |  | Signed number of 2pi phase corrections applied to remove a fringe jump, for each time slice on which a correction has been made
interferometer.channel[:].wavelength[:].fringe_jump_correction_times (alpha) | [1...N] | FLT_1D (uncertain) | s | List of time slices of the pulse on which a fringe jump correction has been made
interferometer.channel[:].wavelength[:].phase_corrected (alpha) |  | STRUCTURE | rad | Phase measured for this wavelength, corrected from fringe jumps
interferometer.channel[:].wavelength[:].phase_corrected.data (alpha) | [interferometer.channel[:].wavelength[:].phase_corrected.time] | FLT_1D (uncertain) | rad | Data
interferometer.channel[:].wavelength[:].phase_corrected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.channel[:].wavelength[:].phase_to_n_e_line (alpha) |  | FLT_0D (uncertain) | m^-2.rad^-1 | Conversion factor to be used to convert phase into line density for this wavelength
interferometer.channel[:].wavelength[:].value (alpha) |  | FLT_0D (uncertain) | m | Wavelength value
interferometer.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
interferometer.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
interferometer.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
interferometer.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
interferometer.code.library[:].name (alpha) |  | STR_0D |  | Name of software
interferometer.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
interferometer.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
interferometer.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
interferometer.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
interferometer.code.output_flag (alpha) | [interferometer.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
interferometer.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
interferometer.code.repository (alpha) |  | STR_0D |  | URL of software repository
interferometer.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
interferometer.electrons_n (alpha) |  | STRUCTURE | - | Total number of electrons in the plasma, estimated from the line densities measured by the various channels
interferometer.electrons_n.data (alpha) | [interferometer.electrons_n.time] | FLT_1D (uncertain) | - | Data
interferometer.electrons_n.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.electrons_n.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.electrons_n.validity_timed (alpha) | [interferometer.electrons_n.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
interferometer.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
interferometer.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
interferometer.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
interferometer.ids_properties.occurrence |  | INT_0D |  |
interferometer.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
interferometer.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
interferometer.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
interferometer.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
interferometer.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
interferometer.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
interferometer.n_e_volume_average (alpha) |  | STRUCTURE | m^-3 | Volume average plasma density estimated from the line densities measured by the various channels
interferometer.n_e_volume_average.data (alpha) | [interferometer.n_e_volume_average.time] | FLT_1D (uncertain) | m^-3 | Data
interferometer.n_e_volume_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
interferometer.n_e_volume_average.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.n_e_volume_average.validity_timed (alpha) | [interferometer.n_e_volume_average.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
interferometer.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
iron_core (alpha) |  |  |  | Iron core description
iron_core.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
iron_core.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
iron_core.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
iron_core.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
iron_core.code.library[:].name (alpha) |  | STR_0D |  | Name of software
iron_core.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
iron_core.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
iron_core.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
iron_core.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
iron_core.code.output_flag (alpha) | [iron_core.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
iron_core.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
iron_core.code.repository (alpha) |  | STR_0D |  | URL of software repository
iron_core.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
iron_core.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
iron_core.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
iron_core.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
iron_core.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
iron_core.ids_properties.occurrence |  | INT_0D |  |
iron_core.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
iron_core.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
iron_core.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
iron_core.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
iron_core.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
iron_core.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
iron_core.segment (alpha) | [1...N] | STRUCT_ARRAY |  | The iron core is describred as a set of segments
iron_core.segment[:].b_field (alpha) | [1...N] | FLT_1D (uncertain) | T | Array of magnetic field values, for each of which the relative permeability is given
iron_core.segment[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the segment
iron_core.segment[:].geometry.arcs_of_circle (alpha) |  | STRUCTURE |  | Description of the element contour by a set of arcs of circle. For each of these, the position of the start point is given together with the curvature radius. The end point is given by the start point of the next arc of circle.
iron_core.segment[:].geometry.arcs_of_circle.curvature_radii (alpha) | [iron_core.segment[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Curvature radius of each arc of circle
iron_core.segment[:].geometry.arcs_of_circle.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii of the start point of each arc of circle
iron_core.segment[:].geometry.arcs_of_circle.z (alpha) | [iron_core.segment[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Height of the start point of each arc of circle
iron_core.segment[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique', 4:'arcs of circle')
iron_core.segment[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
iron_core.segment[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
iron_core.segment[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
iron_core.segment[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
iron_core.segment[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
iron_core.segment[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
iron_core.segment[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
iron_core.segment[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element. Do NOT repeat the first point.
iron_core.segment[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
iron_core.segment[:].geometry.outline.z (alpha) | [iron_core.segment[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
iron_core.segment[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
iron_core.segment[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
iron_core.segment[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
iron_core.segment[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
iron_core.segment[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
iron_core.segment[:].identifier (alpha) |  | STR_0D |  | ID of the segment
iron_core.segment[:].magnetisation_r (alpha) |  | STRUCTURE | T | Magnetisation M of the iron segment along the major radius axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_r.data (alpha) | [iron_core.segment[:].magnetisation_r.time] | FLT_1D (uncertain) | T | Data
iron_core.segment[:].magnetisation_r.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
iron_core.segment[:].magnetisation_z (alpha) |  | STRUCTURE | T | Magnetisation M of the iron segment along the vertical axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_z.data (alpha) | [iron_core.segment[:].magnetisation_z.time] | FLT_1D (uncertain) | T | Data
iron_core.segment[:].magnetisation_z.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
iron_core.segment[:].name (alpha) |  | STR_0D |  | Name of the segment
iron_core.segment[:].permeability_relative (alpha) | [iron_core.segment[:].b_field] | FLT_1D (uncertain) | - | Relative permeability of the iron segment
iron_core.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
langmuir_probes (alpha) |  |  |  | Langmuir probes
langmuir_probes.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
langmuir_probes.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
langmuir_probes.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
langmuir_probes.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
langmuir_probes.code.library[:].name (alpha) |  | STR_0D |  | Name of software
langmuir_probes.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
langmuir_probes.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
langmuir_probes.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
langmuir_probes.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
langmuir_probes.code.output_flag (alpha) | [langmuir_probes.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
langmuir_probes.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
langmuir_probes.code.repository (alpha) |  | STR_0D |  | URL of software repository
langmuir_probes.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
langmuir_probes.embedded (alpha) | [1...N] | STRUCT_ARRAY |  | Set of embedded (in a plasma facing component) probes or probe pins
langmuir_probes.embedded[:].b_field_angle (alpha) |  | STRUCTURE | rad | Incident angle of the magnetic field with respect to PFC surface
langmuir_probes.embedded[:].b_field_angle.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | rad | Data
langmuir_probes.embedded[:].b_field_angle.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].b_field_angle.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].distance_separatrix (alpha) |  | STRUCTURE | m | Distance of the measurement position to the separatrix (positive means the measurement is outside of the separatrix)
langmuir_probes.embedded[:].distance_separatrix.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | m | Data
langmuir_probes.embedded[:].distance_separatrix.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].distance_separatrix.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].heat_flux_parallel (alpha) |  | STRUCTURE | W.m^-2 | Parallel heat flux at the probe position
langmuir_probes.embedded[:].heat_flux_parallel.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | W.m^-2 | Data
langmuir_probes.embedded[:].heat_flux_parallel.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].heat_flux_parallel.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].identifier (alpha) |  | STR_0D |  | ID of the probe
langmuir_probes.embedded[:].ion_saturation_current (alpha) |  | STRUCTURE | A | Ion saturation current measured by the probe
langmuir_probes.embedded[:].ion_saturation_current.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | A | Data
langmuir_probes.embedded[:].ion_saturation_current.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].ion_saturation_current.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].j_i_parallel (alpha) |  | STRUCTURE | A.m^-2 | Ion parallel current density at the probe position
langmuir_probes.embedded[:].j_i_parallel.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | A.m^-2 | Data
langmuir_probes.embedded[:].j_i_parallel.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].j_i_parallel.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].multi_temperature_fits (alpha) | [1...N] | STRUCT_ARRAY |  | Set of temperatures describing the electron and ion distribution functions in case of multi-temperature fits
langmuir_probes.embedded[:].multi_temperature_fits[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
langmuir_probes.embedded[:].multi_temperature_fits[:].t_e.data (alpha) | [langmuir_probes.embedded[:].multi_temperature_fits[:].time] | FLT_1D (uncertain) | eV | Data
langmuir_probes.embedded[:].multi_temperature_fits[:].t_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].multi_temperature_fits[:].t_e.validity_timed (alpha) | [langmuir_probes.embedded[:].multi_temperature_fits[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].multi_temperature_fits[:].t_i (alpha) |  | STRUCTURE | eV | Ion temperature
langmuir_probes.embedded[:].multi_temperature_fits[:].t_i.data (alpha) | [langmuir_probes.embedded[:].multi_temperature_fits[:].time] | FLT_1D (uncertain) | eV | Data
langmuir_probes.embedded[:].multi_temperature_fits[:].t_i.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].multi_temperature_fits[:].t_i.validity_timed (alpha) | [langmuir_probes.embedded[:].multi_temperature_fits[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].multi_temperature_fits[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for the dynamic nodes of this probe located at this level of the IDS structure
langmuir_probes.embedded[:].n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
langmuir_probes.embedded[:].n_e.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | m^-3 | Data
langmuir_probes.embedded[:].n_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].n_e.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].name (alpha) |  | STR_0D |  | Name of the probe
langmuir_probes.embedded[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
langmuir_probes.embedded[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
langmuir_probes.embedded[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
langmuir_probes.embedded[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
langmuir_probes.embedded[:].surface_area (alpha) |  | FLT_0D (uncertain) | m^2 | Area of the probe surface exposed to the plasma
langmuir_probes.embedded[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
langmuir_probes.embedded[:].t_e.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | eV | Data
langmuir_probes.embedded[:].t_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].t_e.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].t_i (alpha) |  | STRUCTURE | eV | Ion temperature
langmuir_probes.embedded[:].t_i.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | eV | Data
langmuir_probes.embedded[:].t_i.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].t_i.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for the dynamic nodes of this probe located at this level of the IDS structure
langmuir_probes.embedded[:].v_floating (alpha) |  | STRUCTURE | V | Floating potential
langmuir_probes.embedded[:].v_floating.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | V | Data
langmuir_probes.embedded[:].v_floating.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].v_floating.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].v_plasma (alpha) |  | STRUCTURE | V | Plasma potential
langmuir_probes.embedded[:].v_plasma.data (alpha) | [langmuir_probes.embedded[:].time] | FLT_1D (uncertain) | V | Data
langmuir_probes.embedded[:].v_plasma.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.embedded[:].v_plasma.validity_timed (alpha) | [langmuir_probes.embedded[:].time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
langmuir_probes.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
langmuir_probes.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
langmuir_probes.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
langmuir_probes.ids_properties.occurrence |  | INT_0D |  |
langmuir_probes.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
langmuir_probes.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
langmuir_probes.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
langmuir_probes.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
langmuir_probes.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
langmuir_probes.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
langmuir_probes.reciprocating (alpha) | [1...N] | STRUCT_ARRAY |  | Set of reciprocating probes or probe pins
langmuir_probes.reciprocating[:].identifier (alpha) |  | STR_0D |  | ID of the probe
langmuir_probes.reciprocating[:].name (alpha) |  | STR_0D |  | Name of the probe
langmuir_probes.reciprocating[:].plunge (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time] | STRUCT_ARRAY |  | Set of plunges of this probe during the pulse, each plunge being recorded as a time slice from the Access Layer point of view. The time child node corresponds to the time of maximum penetration of the probe during a given plunge. The dynamics of physicas quantities within the plunge are described via the time_within_plunge vector.
langmuir_probes.reciprocating[:].plunge[:].b_field_angle (alpha) |  | STRUCTURE | rad | Incident angle of the magnetic field with respect to PFC surface
langmuir_probes.reciprocating[:].plunge[:].b_field_angle.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | rad | Data
langmuir_probes.reciprocating[:].plunge[:].b_field_angle.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].b_field_angle.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].distance_separatrix (alpha) |  | STRUCTURE | m | Distance of the measurement position to the separatrix (positive means the measurement is outside of the separatrix)
langmuir_probes.reciprocating[:].plunge[:].distance_separatrix.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | m | Data
langmuir_probes.reciprocating[:].plunge[:].distance_separatrix.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].distance_separatrix.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].heat_flux_parallel (alpha) |  | STRUCTURE | W.m^-2 | Parallel heat flux at the probe position
langmuir_probes.reciprocating[:].plunge[:].heat_flux_parallel.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | W.m^-2 | Data
langmuir_probes.reciprocating[:].plunge[:].heat_flux_parallel.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].heat_flux_parallel.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].ion_saturation_current (alpha) |  | STRUCTURE | A | Ion saturation current measured by the probe
langmuir_probes.reciprocating[:].plunge[:].ion_saturation_current.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | A | Data
langmuir_probes.reciprocating[:].plunge[:].ion_saturation_current.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].ion_saturation_current.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].j_i_parallel (alpha) |  | STRUCTURE | A.m^-2 | Ion parallel current density at the probe position
langmuir_probes.reciprocating[:].plunge[:].j_i_parallel.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | A.m^-2 | Data
langmuir_probes.reciprocating[:].plunge[:].j_i_parallel.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].j_i_parallel.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].mach_number_parallel (alpha) |  | STRUCTURE | - | Parallel Mach number
langmuir_probes.reciprocating[:].plunge[:].mach_number_parallel.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | - | Data
langmuir_probes.reciprocating[:].plunge[:].mach_number_parallel.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].mach_number_parallel.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
langmuir_probes.reciprocating[:].plunge[:].n_e.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | m^-3 | Data
langmuir_probes.reciprocating[:].plunge[:].n_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].n_e.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
langmuir_probes.reciprocating[:].plunge[:].position.phi (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | rad | Toroidal angle
langmuir_probes.reciprocating[:].plunge[:].position.r (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | m | Major radius
langmuir_probes.reciprocating[:].plunge[:].position.validity (alpha) |  | INT_0D |  | Indicator of the validity of the position data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].position.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].position.time_within_plunge] | INT_1D |  | Indicator of the validity of the position data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].position.z (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | m | Height
langmuir_probes.reciprocating[:].plunge[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
langmuir_probes.reciprocating[:].plunge[:].t_e.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | eV | Data
langmuir_probes.reciprocating[:].plunge[:].t_e.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].t_e.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].t_i (alpha) |  | STRUCTURE | eV | Ion temperature
langmuir_probes.reciprocating[:].plunge[:].t_i.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | eV | Data
langmuir_probes.reciprocating[:].plunge[:].t_i.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].t_i.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].time (alpha) |  | FLT_0D | s | Time of maximum penetration of the probe during a given plunge
langmuir_probes.reciprocating[:].plunge[:].time_within_plunge (alpha) | [1...N] | FLT_1D (uncertain) | s | Time vector for describing the dynamics within the plunge
langmuir_probes.reciprocating[:].plunge[:].v_floating (alpha) |  | STRUCTURE | V | Floating potential
langmuir_probes.reciprocating[:].plunge[:].v_floating.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | V | Data
langmuir_probes.reciprocating[:].plunge[:].v_floating.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].v_floating.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].v_plasma (alpha) |  | STRUCTURE | V | Plasma potential
langmuir_probes.reciprocating[:].plunge[:].v_plasma.data (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | FLT_1D (uncertain) | V | Data
langmuir_probes.reciprocating[:].plunge[:].v_plasma.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole plunge. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.reciprocating[:].plunge[:].v_plasma.validity_timed (alpha) | [langmuir_probes.reciprocating[:].plunge[:].time_within_plunge] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
langmuir_probes.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
lh_antennas (alpha) |  |  |  | Antenna systems for heating and current drive in the Lower Hybrid (LH) frequencies. In the definitions below, the front (or mouth) of the antenna refers to the plasma facing side of the antenna, while the back refers to the waveguides connected side of the antenna (towards the RF generators).
lh_antennas.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of Lower Hybrid antennas
lh_antennas.antenna[:].distance_to_antenna (alpha) | [1...N] | FLT_1D (uncertain) | m | Radial distance to the antenna mouth (grid for the electron density profile). 0 at antenna mouth, increasing towards the plasma
lh_antennas.antenna[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency
lh_antennas.antenna[:].identifier (alpha) |  | STR_0D |  | Identifier of the antenna (unique within the set of all antennas of the experiment)
lh_antennas.antenna[:].model_name (alpha) |  | STR_0D |  | Name of the antenna model used for antenna spectrum computation
lh_antennas.antenna[:].module (alpha) | [1...N] | STRUCT_ARRAY |  | Set of antenna modules
lh_antennas.antenna[:].module[:].identifier (alpha) |  | STR_0D |  | Identifier of the module
lh_antennas.antenna[:].module[:].name (alpha) |  | STR_0D |  | Name of the module
lh_antennas.antenna[:].module[:].phase (alpha) |  | STRUCTURE | rad | Phase of the forward power arriving at the back of this module
lh_antennas.antenna[:].module[:].phase.data (alpha) | [lh_antennas.antenna[:].module[:].phase.time] | FLT_1D (uncertain) | rad | Data
lh_antennas.antenna[:].module[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].module[:].power_forward (alpha) |  | STRUCTURE | W | Forward power arriving to the back of the module
lh_antennas.antenna[:].module[:].power_forward.data (alpha) | [lh_antennas.antenna[:].module[:].power_forward.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].module[:].power_forward.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].module[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this module into the vacuum vessel
lh_antennas.antenna[:].module[:].power_launched.data (alpha) | [lh_antennas.antenna[:].module[:].power_launched.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].module[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].module[:].power_reflected (alpha) |  | STRUCTURE | W | Reflected power
lh_antennas.antenna[:].module[:].power_reflected.data (alpha) | [lh_antennas.antenna[:].module[:].power_reflected.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].module[:].power_reflected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].module[:].reflection_coefficient (alpha) |  | STRUCTURE | - | Power reflection coefficient
lh_antennas.antenna[:].module[:].reflection_coefficient.data (alpha) | [lh_antennas.antenna[:].module[:].reflection_coefficient.time] | FLT_1D (uncertain) | - | Data
lh_antennas.antenna[:].module[:].reflection_coefficient.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].n_e (alpha) | [lh_antennas.antenna[:].distance_to_antenna] | STRUCTURE | m^-3 | Electron density profile in front of the antenna
lh_antennas.antenna[:].n_e.data (alpha) | [1...N, lh_antennas.antenna[:].n_e.time] | FLT_2D (uncertain) | m^-3 | Data
lh_antennas.antenna[:].n_e.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].n_parallel_peak (alpha) |  | STRUCTURE | - | Peak parallel refractive index of the launched wave spectrum (simple estimate based on the measured phase difference)
lh_antennas.antenna[:].n_parallel_peak.data (alpha) | [lh_antennas.antenna[:].n_parallel_peak.time] | FLT_1D (uncertain) | - | Data
lh_antennas.antenna[:].n_parallel_peak.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna (unique within the set of all antennas of the experiment)
lh_antennas.antenna[:].phase_average (alpha) |  | STRUCTURE | rad | Phase difference between two neighbouring modules (average over modules), at the mouth (front) of the antenna
lh_antennas.antenna[:].phase_average.data (alpha) | [lh_antennas.antenna[:].phase_average.time] | FLT_1D (uncertain) | rad | Data
lh_antennas.antenna[:].phase_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].position (alpha) |  | STRUCTURE |  | Position of a reference point on the antenna (allowing also tracking the possible movements of the antenna)
lh_antennas.antenna[:].position.definition (alpha) |  | STR_0D |  | Definition of the reference point
lh_antennas.antenna[:].position.phi (alpha) |  | STRUCTURE | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
lh_antennas.antenna[:].position.phi.data (alpha) | [lh_antennas.antenna[:].position.phi.time] | FLT_1D (uncertain) | rad | Data
lh_antennas.antenna[:].position.phi.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].position.r (alpha) |  | STRUCTURE | m | Major radius
lh_antennas.antenna[:].position.r.data (alpha) | [lh_antennas.antenna[:].position.r.time] | FLT_1D (uncertain) | m | Data
lh_antennas.antenna[:].position.r.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].position.z (alpha) |  | STRUCTURE | m | Height
lh_antennas.antenna[:].position.z.data (alpha) | [lh_antennas.antenna[:].position.z.time] | FLT_1D (uncertain) | m | Data
lh_antennas.antenna[:].position.z.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].power_forward (alpha) |  | STRUCTURE | W | Forward power arriving at the back of the antenna
lh_antennas.antenna[:].power_forward.data (alpha) | [lh_antennas.antenna[:].power_forward.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].power_forward.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this antenna into the vacuum vessel
lh_antennas.antenna[:].power_launched.data (alpha) | [lh_antennas.antenna[:].power_launched.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].power_reflected (alpha) |  | STRUCTURE | W | Reflected power
lh_antennas.antenna[:].power_reflected.data (alpha) | [lh_antennas.antenna[:].power_reflected.time] | FLT_1D (uncertain) | W | Data
lh_antennas.antenna[:].power_reflected.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].pressure_tank (alpha) |  | STRUCTURE | Pa | Pressure in the vacuum tank of the antenna
lh_antennas.antenna[:].pressure_tank.data (alpha) | [lh_antennas.antenna[:].pressure_tank.time] | FLT_1D (uncertain) | Pa | Data
lh_antennas.antenna[:].pressure_tank.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].reflection_coefficient (alpha) |  | STRUCTURE | - | Power reflection coefficient, averaged over modules
lh_antennas.antenna[:].reflection_coefficient.data (alpha) | [lh_antennas.antenna[:].reflection_coefficient.time] | FLT_1D (uncertain) | - | Data
lh_antennas.antenna[:].reflection_coefficient.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.antenna[:].row (alpha) | [1...N] | STRUCT_ARRAY |  | Set of horizontal rows of waveguides (corresponding to different poloidal positions). A power spectrum is provided for each row.
lh_antennas.antenna[:].row[:].n_pol (alpha) | [lh_antennas.antenna[:].row[:].time] | FLT_1D (uncertain) | - | Refraction index in the poloidal direction. The poloidal angle is defined from the reference point; the angle at a point (R,Z) is given by atan((Z-Zref)/(R-Rref)), where Rref=reference_point/r and Zref=reference_point/z
lh_antennas.antenna[:].row[:].n_tor (alpha) | [lh_antennas.antenna[:].row[:].time] | FLT_1D (uncertain) | - | Refraction index in the toroidal direction
lh_antennas.antenna[:].row[:].name (alpha) |  | STR_0D |  | Name of the row
lh_antennas.antenna[:].row[:].position (alpha) |  | STRUCTURE |  | Position of the middle on the row
lh_antennas.antenna[:].row[:].position.phi (alpha) | [lh_antennas.antenna[:].row[:].position.time] | FLT_1D (uncertain) | rad | Toroidal angle
lh_antennas.antenna[:].row[:].position.r (alpha) | [lh_antennas.antenna[:].row[:].position.time] | FLT_1D (uncertain) | m | Major radius
lh_antennas.antenna[:].row[:].position.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
lh_antennas.antenna[:].row[:].position.z (alpha) | [lh_antennas.antenna[:].row[:].position.time] | FLT_1D (uncertain) | m | Height
lh_antennas.antenna[:].row[:].power_density_spectrum_1d (alpha) | [lh_antennas.antenna[:].row[:].n_tor, lh_antennas.antenna[:].row[:].time] | FLT_2D (uncertain) | W | 1D power density spectrum dP/dn_tor, as a function of time
lh_antennas.antenna[:].row[:].power_density_spectrum_2d (alpha) | [lh_antennas.antenna[:].row[:].n_tor, lh_antennas.antenna[:].row[:].n_pol, lh_antennas.antenna[:].row[:].time] | FLT_3D (uncertain) | W | 2D power density spectrum d2P/(dn_tor.dn_pol), as a function of time
lh_antennas.antenna[:].row[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for the dynamic nodes of this probe located at this level of the IDS structure
lh_antennas.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
lh_antennas.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
lh_antennas.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
lh_antennas.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
lh_antennas.code.library[:].name (alpha) |  | STR_0D |  | Name of software
lh_antennas.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
lh_antennas.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
lh_antennas.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
lh_antennas.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
lh_antennas.code.output_flag (alpha) | [lh_antennas.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
lh_antennas.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
lh_antennas.code.repository (alpha) |  | STR_0D |  | URL of software repository
lh_antennas.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
lh_antennas.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
lh_antennas.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
lh_antennas.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
lh_antennas.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
lh_antennas.ids_properties.occurrence |  | INT_0D |  |
lh_antennas.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
lh_antennas.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
lh_antennas.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
lh_antennas.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
lh_antennas.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
lh_antennas.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
lh_antennas.power (alpha) |  | STRUCTURE | W | Power coupled to the plasma by the whole LH system (sum over antennas)
lh_antennas.power.data (alpha) | [lh_antennas.power.time] | FLT_1D (uncertain) | W | Data
lh_antennas.power.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
lh_antennas.reference_point (alpha) |  | STRUCTURE |  | Reference point used to define the poloidal angle, e.g. the geometrical centre of the vacuum vessel. Used to define the poloidal refraction index under antenna/row
lh_antennas.reference_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
lh_antennas.reference_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
lh_antennas.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
magnetics |  |  |  | Magnetic diagnostics for equilibrium identification and plasma shape control.
magnetics.b_field_pol_probe | [1...N] | STRUCT_ARRAY |  | Poloidal field probes
magnetics.b_field_pol_probe[:].area |  | FLT_0D (uncertain) | m^2 | Area of each turn of the sensor; becomes effective area when multiplied by the turns
magnetics.b_field_pol_probe[:].bandwidth_3db | [1...2] | FLT_1D (uncertain) | Hz | 3dB bandwith (first index : lower frequency bound, second index : upper frequency bound)
magnetics.b_field_pol_probe[:].field |  | STRUCTURE | T | Magnetic field component in direction of sensor normal axis (n) averaged over sensor volume defined by area and length, where n = cos(poloidal_angle)*cos(toroidal_angle)*grad(R) - sin(poloidal_angle)*grad(Z) + cos(poloidal_angle)*sin(toroidal_angle)*grad(Phi)/norm(grad(Phi))
magnetics.b_field_pol_probe[:].field.data | [magnetics.b_field_pol_probe[:].field.time] | FLT_1D (uncertain) | T | Data
magnetics.b_field_pol_probe[:].field.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.b_field_pol_probe[:].field.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_pol_probe[:].field.validity_timed | [magnetics.b_field_pol_probe[:].field.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_pol_probe[:].identifier |  | STR_0D |  | ID of the probe
magnetics.b_field_pol_probe[:].indices_differential | [1...2] | INT_1D |  | Indices (from the bpol_probe array of structure) of the two probes used to build the field difference field(second index) - field(first index). Use only if ../type/index = 6, leave empty otherwise
magnetics.b_field_pol_probe[:].length |  | FLT_0D (uncertain) | m | Length of the sensor along it's normal vector (n)
magnetics.b_field_pol_probe[:].name |  | STR_0D |  | Name of the probe
magnetics.b_field_pol_probe[:].non_linear_response |  | STRUCTURE |  | Non-linear response of the probe (typically in case of a Hall probe)
magnetics.b_field_pol_probe[:].non_linear_response.b_field_linear | [1...N] | FLT_1D (uncertain) | T | Array of magnetic field values (corresponding to the assumption of a linear relation between magnetic field and probe coil current), for each of which the probe non-linear response is given in ../b_field_non_linear
magnetics.b_field_pol_probe[:].non_linear_response.b_field_non_linear | [magnetics.b_field_pol_probe[:].non_linear_response.b_field_linear] | FLT_1D (uncertain) | T | Magnetic field value taking into account the non-linear response of the probe
magnetics.b_field_pol_probe[:].poloidal_angle |  | FLT_0D (uncertain) | rad | Angle of the sensor normal vector (n) with respect to horizontal plane (clockwise as in cocos=11 theta-like angle). Zero if sensor normal vector fully in the horizontal plane and oriented towards increasing major radius. Values in [0 , 2Pi]
magnetics.b_field_pol_probe[:].position |  | STRUCTURE |  | R, Z, Phi position of the coil centre
magnetics.b_field_pol_probe[:].position.phi |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
magnetics.b_field_pol_probe[:].position.r |  | FLT_0D (uncertain) | m | Major radius
magnetics.b_field_pol_probe[:].position.z |  | FLT_0D (uncertain) | m | Height
magnetics.b_field_pol_probe[:].toroidal_angle |  | FLT_0D (uncertain) | rad | Angle of the projection of the sensor normal vector (n) in the horizontal plane with the increasing R direction (i.e. grad(R)) (angle is counter-clockwise from above as in cocos=11 phi-like angle). Values should be taken modulo pi with values within (-pi/2,pi/2]. Zero if projected sensor normal is parallel to grad(R), pi/2 if it is parallel to grad(phi).
magnetics.b_field_pol_probe[:].turns |  | INT_0D |  | Turns in the coil, including sign
magnetics.b_field_pol_probe[:].type |  | STRUCTURE |  | Probe type 1) position : Position measurement probe 2) mirnov : Mirnov probe 3) hall : Hall probe 4) flux_gate : Flux gate probe 5) faraday_fiber : Faraday fiber 6) differential : Differential probe
magnetics.b_field_pol_probe[:].type.description |  | STR_0D |  | Verbose description
magnetics.b_field_pol_probe[:].type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
magnetics.b_field_pol_probe[:].type.name |  | STR_0D |  | Short string identifier
magnetics.b_field_pol_probe[:].voltage |  | STRUCTURE | V | Voltage on the coil terminals
magnetics.b_field_pol_probe[:].voltage.data | [magnetics.b_field_pol_probe[:].voltage.time] | FLT_1D (uncertain) | V | Data
magnetics.b_field_pol_probe[:].voltage.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.b_field_pol_probe[:].voltage.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_pol_probe[:].voltage.validity_timed | [magnetics.b_field_pol_probe[:].voltage.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_tor_probe | [1...N] | STRUCT_ARRAY |  | Toroidal field probes
magnetics.b_field_tor_probe[:].area |  | FLT_0D (uncertain) | m^2 | Area of each turn of the sensor; becomes effective area when multiplied by the turns
magnetics.b_field_tor_probe[:].bandwidth_3db | [1...2] | FLT_1D (uncertain) | Hz | 3dB bandwith (first index : lower frequency bound, second index : upper frequency bound)
magnetics.b_field_tor_probe[:].field |  | STRUCTURE | T | Magnetic field component in direction of sensor normal axis (n) averaged over sensor volume defined by area and length, where n = cos(poloidal_angle)*cos(toroidal_angle)*grad(R) - sin(poloidal_angle)*grad(Z) + cos(poloidal_angle)*sin(toroidal_angle)*grad(Phi)/norm(grad(Phi))
magnetics.b_field_tor_probe[:].field.data | [magnetics.b_field_tor_probe[:].field.time] | FLT_1D (uncertain) | T | Data
magnetics.b_field_tor_probe[:].field.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.b_field_tor_probe[:].field.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_tor_probe[:].field.validity_timed | [magnetics.b_field_tor_probe[:].field.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_tor_probe[:].identifier |  | STR_0D |  | ID of the probe
magnetics.b_field_tor_probe[:].indices_differential | [1...2] | INT_1D |  | Indices (from the bpol_probe array of structure) of the two probes used to build the field difference field(second index) - field(first index). Use only if ../type/index = 6, leave empty otherwise
magnetics.b_field_tor_probe[:].length |  | FLT_0D (uncertain) | m | Length of the sensor along it's normal vector (n)
magnetics.b_field_tor_probe[:].name |  | STR_0D |  | Name of the probe
magnetics.b_field_tor_probe[:].non_linear_response |  | STRUCTURE |  | Non-linear response of the probe (typically in case of a Hall probe)
magnetics.b_field_tor_probe[:].non_linear_response.b_field_linear | [1...N] | FLT_1D (uncertain) | T | Array of magnetic field values (corresponding to the assumption of a linear relation between magnetic field and probe coil current), for each of which the probe non-linear response is given in ../b_field_non_linear
magnetics.b_field_tor_probe[:].non_linear_response.b_field_non_linear | [magnetics.b_field_tor_probe[:].non_linear_response.b_field_linear] | FLT_1D (uncertain) | T | Magnetic field value taking into account the non-linear response of the probe
magnetics.b_field_tor_probe[:].poloidal_angle |  | FLT_0D (uncertain) | rad | Angle of the sensor normal vector (n) with respect to horizontal plane (clockwise as in cocos=11 theta-like angle). Zero if sensor normal vector fully in the horizontal plane and oriented towards increasing major radius. Values in [0 , 2Pi]
magnetics.b_field_tor_probe[:].position |  | STRUCTURE |  | R, Z, Phi position of the coil centre
magnetics.b_field_tor_probe[:].position.phi |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
magnetics.b_field_tor_probe[:].position.r |  | FLT_0D (uncertain) | m | Major radius
magnetics.b_field_tor_probe[:].position.z |  | FLT_0D (uncertain) | m | Height
magnetics.b_field_tor_probe[:].toroidal_angle |  | FLT_0D (uncertain) | rad | Angle of the projection of the sensor normal vector (n) in the horizontal plane with the increasing R direction (i.e. grad(R)) (angle is counter-clockwise from above as in cocos=11 phi-like angle). Values should be taken modulo pi with values within (-pi/2,pi/2]. Zero if projected sensor normal is parallel to grad(R), pi/2 if it is parallel to grad(phi).
magnetics.b_field_tor_probe[:].turns |  | INT_0D |  | Turns in the coil, including sign
magnetics.b_field_tor_probe[:].type |  | STRUCTURE |  | Probe type 1) position : Position measurement probe 2) mirnov : Mirnov probe 3) hall : Hall probe 4) flux_gate : Flux gate probe 5) faraday_fiber : Faraday fiber 6) differential : Differential probe
magnetics.b_field_tor_probe[:].type.description |  | STR_0D |  | Verbose description
magnetics.b_field_tor_probe[:].type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
magnetics.b_field_tor_probe[:].type.name |  | STR_0D |  | Short string identifier
magnetics.b_field_tor_probe[:].voltage |  | STRUCTURE | V | Voltage on the coil terminals
magnetics.b_field_tor_probe[:].voltage.data | [magnetics.b_field_tor_probe[:].voltage.time] | FLT_1D (uncertain) | V | Data
magnetics.b_field_tor_probe[:].voltage.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.b_field_tor_probe[:].voltage.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.b_field_tor_probe[:].voltage.validity_timed | [magnetics.b_field_tor_probe[:].voltage.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.bpol_probe (obsolescent) | [1...N] | STRUCT_ARRAY |  | Poloidal field probes
magnetics.bpol_probe[:].area (obsolescent) |  | FLT_0D (uncertain) | m^2 | Area of each turn of the sensor; becomes effective area when multiplied by the turns
magnetics.bpol_probe[:].bandwidth_3db (obsolescent) | [1...2] | FLT_1D (uncertain) | Hz | 3dB bandwith (first index : lower frequency bound, second index : upper frequency bound)
magnetics.bpol_probe[:].field (obsolescent) |  | STRUCTURE | T | Magnetic field component in direction of sensor normal axis (n) averaged over sensor volume defined by area and length, where n = cos(poloidal_angle)*cos(toroidal_angle)*grad(R) - sin(poloidal_angle)*grad(Z) + cos(poloidal_angle)*sin(toroidal_angle)*grad(Phi)/norm(grad(Phi))
magnetics.bpol_probe[:].field.data (obsolescent) | [magnetics.bpol_probe[:].field.time] | FLT_1D (uncertain) | T | Data
magnetics.bpol_probe[:].field.time (obsolescent) | [1...N] | FLT_1D_TYPE | s | Time
magnetics.bpol_probe[:].field.validity (obsolescent) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.bpol_probe[:].field.validity_timed (obsolescent) | [magnetics.bpol_probe[:].field.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.bpol_probe[:].identifier (obsolescent) |  | STR_0D |  | ID of the probe
magnetics.bpol_probe[:].indices_differential (obsolescent) | [1...2] | INT_1D |  | Indices (from the bpol_probe array of structure) of the two probes used to build the field difference field(second index) - field(first index). Use only if ../type/index = 6, leave empty otherwise
magnetics.bpol_probe[:].length (obsolescent) |  | FLT_0D (uncertain) | m | Length of the sensor along it's normal vector (n)
magnetics.bpol_probe[:].name (obsolescent) |  | STR_0D |  | Name of the probe
magnetics.bpol_probe[:].non_linear_response (obsolescent) |  | STRUCTURE |  | Non-linear response of the probe (typically in case of a Hall probe)
magnetics.bpol_probe[:].non_linear_response.b_field_linear (obsolescent) | [1...N] | FLT_1D (uncertain) | T | Array of magnetic field values (corresponding to the assumption of a linear relation between magnetic field and probe coil current), for each of which the probe non-linear response is given in ../b_field_non_linear
magnetics.bpol_probe[:].non_linear_response.b_field_non_linear (obsolescent) | [magnetics.bpol_probe[:].non_linear_response.b_field_linear] | FLT_1D (uncertain) | T | Magnetic field value taking into account the non-linear response of the probe
magnetics.bpol_probe[:].poloidal_angle (obsolescent) |  | FLT_0D (uncertain) | rad | Angle of the sensor normal vector (n) with respect to horizontal plane (clockwise as in cocos=11 theta-like angle). Zero if sensor normal vector fully in the horizontal plane and oriented towards increasing major radius. Values in [0 , 2Pi]
magnetics.bpol_probe[:].position (obsolescent) |  | STRUCTURE |  | R, Z, Phi position of the coil centre
magnetics.bpol_probe[:].position.phi (obsolescent) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
magnetics.bpol_probe[:].position.r (obsolescent) |  | FLT_0D (uncertain) | m | Major radius
magnetics.bpol_probe[:].position.z (obsolescent) |  | FLT_0D (uncertain) | m | Height
magnetics.bpol_probe[:].toroidal_angle (obsolescent) |  | FLT_0D (uncertain) | rad | Angle of the projection of the sensor normal vector (n) in the horizontal plane with the increasing R direction (i.e. grad(R)) (angle is counter-clockwise from above as in cocos=11 phi-like angle). Values should be taken modulo pi with values within (-pi/2,pi/2]. Zero if projected sensor normal is parallel to grad(R), pi/2 if it is parallel to grad(phi).
magnetics.bpol_probe[:].turns (obsolescent) |  | INT_0D |  | Turns in the coil, including sign
magnetics.bpol_probe[:].type (obsolescent) |  | STRUCTURE |  | Probe type 1) position : Position measurement probe 2) mirnov : Mirnov probe 3) hall : Hall probe 4) flux_gate : Flux gate probe 5) faraday_fiber : Faraday fiber 6) differential : Differential probe
magnetics.bpol_probe[:].type.description (obsolescent) |  | STR_0D |  | Verbose description
magnetics.bpol_probe[:].type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
magnetics.bpol_probe[:].type.name (obsolescent) |  | STR_0D |  | Short string identifier
magnetics.bpol_probe[:].voltage (obsolescent) |  | STRUCTURE | V | Voltage on the coil terminals
magnetics.bpol_probe[:].voltage.data (obsolescent) | [magnetics.bpol_probe[:].voltage.time] | FLT_1D (uncertain) | V | Data
magnetics.bpol_probe[:].voltage.time (obsolescent) | [1...N] | FLT_1D_TYPE | s | Time
magnetics.bpol_probe[:].voltage.validity (obsolescent) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.bpol_probe[:].voltage.validity_timed (obsolescent) | [magnetics.bpol_probe[:].voltage.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
magnetics.code.commit |  | STR_0D |  | Unique commit reference of software
magnetics.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
magnetics.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
magnetics.code.library[:].name |  | STR_0D |  | Name of software
magnetics.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
magnetics.code.library[:].repository |  | STR_0D |  | URL of software repository
magnetics.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
magnetics.code.name |  | STR_0D |  | Name of software generating IDS
magnetics.code.output_flag | [magnetics.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
magnetics.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
magnetics.code.repository |  | STR_0D |  | URL of software repository
magnetics.code.version |  | STR_0D |  | Unique version (tag) of software
magnetics.diamagnetic_flux | [1...N] | STRUCT_ARRAY | Wb | Diamagnetic flux. The array of structure corresponds to a set of calculation methods (starting with the generally recommended method).
magnetics.diamagnetic_flux[:].data | [magnetics.diamagnetic_flux[:].time] | FLT_1D (uncertain) | Wb | Data
magnetics.diamagnetic_flux[:].method_name |  | STR_0D |  | Name of the calculation method
magnetics.diamagnetic_flux[:].time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.flux_loop | [1...N] | STRUCT_ARRAY |  | Flux loops; partial flux loops can be described
magnetics.flux_loop[:].area |  | FLT_0D (uncertain) | m^2 | Effective area (ratio between flux and average magnetic field over the loop)
magnetics.flux_loop[:].flux |  | STRUCTURE | Wb | Measured magnetic flux over loop in which Z component of normal to loop is directed downwards (negative grad Z direction)
magnetics.flux_loop[:].flux.data | [magnetics.flux_loop[:].flux.time] | FLT_1D (uncertain) | Wb | Data
magnetics.flux_loop[:].flux.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.flux_loop[:].flux.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.flux_loop[:].flux.validity_timed | [magnetics.flux_loop[:].flux.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.flux_loop[:].gm9 |  | FLT_0D (uncertain) | m | Integral of 1/R over the loop area (ratio between flux and magnetic rigidity R0.B0). Use only if ../type/index = 3 to 6, leave empty otherwise.
magnetics.flux_loop[:].identifier |  | STR_0D |  | ID of the flux loop
magnetics.flux_loop[:].indices_differential | [1...2] | INT_1D |  | Indices (from the flux_loop array of structure) of the two flux loops used to build the flux difference flux(second index) - flux(first index). Use only if ../type/index = 6, leave empty otherwise
magnetics.flux_loop[:].name |  | STR_0D |  | Name of the flux loop
magnetics.flux_loop[:].position | [1...N] | STRUCT_ARRAY |  | List of (R,Z,phi) points defining the position of the loop (see data structure documentation FLUXLOOPposition.pdf)
magnetics.flux_loop[:].position[:].phi |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
magnetics.flux_loop[:].position[:].r |  | FLT_0D (uncertain) | m | Major radius
magnetics.flux_loop[:].position[:].z |  | FLT_0D (uncertain) | m | Height
magnetics.flux_loop[:].type |  | STRUCTURE |  | Flux loop type 1) toroidal : Toroidal flux loop 2) saddle : Saddle loop 3) diamagnetic_internal : Diamagnetic internal loop 4) diamagnetic_external : Diamagnetic external loop 5) diamagnetic_compensation : Diamagnetic compensation loop 6) diamagnetic_differential : Diamagnetic differential loop
magnetics.flux_loop[:].type.description |  | STR_0D |  | Verbose description
magnetics.flux_loop[:].type.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
magnetics.flux_loop[:].type.name |  | STR_0D |  | Short string identifier
magnetics.flux_loop[:].voltage |  | STRUCTURE | V | Measured voltage between the loop terminals
magnetics.flux_loop[:].voltage.data | [magnetics.flux_loop[:].voltage.time] | FLT_1D (uncertain) | V | Data
magnetics.flux_loop[:].voltage.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.flux_loop[:].voltage.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.flux_loop[:].voltage.validity_timed | [magnetics.flux_loop[:].voltage.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
magnetics.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
magnetics.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
magnetics.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
magnetics.ids_properties.occurrence |  | INT_0D |  |
magnetics.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
magnetics.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
magnetics.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
magnetics.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
magnetics.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
magnetics.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
magnetics.ip | [1...N] | STRUCT_ARRAY | A | Plasma current. Positive sign means anti-clockwise when viewed from above. The array of structure corresponds to a set of calculation methods (starting with the generally recommended method).
magnetics.ip[:].data | [magnetics.ip[:].time] | FLT_1D (uncertain) | A | Data
magnetics.ip[:].method_name |  | STR_0D |  | Name of the calculation method
magnetics.ip[:].time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.method (obsolescent) | [1...N] | STRUCT_ARRAY |  | A method generating processed quantities derived from the magnetic measurements
magnetics.method[:].ip (obsolescent) |  | STRUCTURE | A | Plasma current. Positive sign means anti-clockwise when viewed from above.
magnetics.method[:].ip.data (obsolescent) | [magnetics.method[:].ip.time] | FLT_1D (uncertain) | A | Data
magnetics.method[:].ip.time (obsolescent) | [1...N] | FLT_1D_TYPE | s | Time
magnetics.method[:].name (obsolescent) |  | STR_0D |  | Name of the data processing method
magnetics.rogowski_coil | [1...N] | STRUCT_ARRAY |  | Set of Rogowski coils
magnetics.rogowski_coil[:].area |  | FLT_0D (uncertain) | m^2 | Effective area of the loop wrapped around the guiding centre. In case of multiple layers, sum of the areas of each layer
magnetics.rogowski_coil[:].current |  | STRUCTURE | A | Measured current inside the Rogowski coil contour. The normal direction to the Rogowski coil is defined by the order of points in the list of guiding centre positions. The current is positive when oriented in the same direction as the normal.
magnetics.rogowski_coil[:].current.data | [magnetics.rogowski_coil[:].current.time] | FLT_1D (uncertain) | A | Data
magnetics.rogowski_coil[:].current.time | [1...N] | FLT_1D_TYPE | s | Time
magnetics.rogowski_coil[:].current.validity |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.rogowski_coil[:].current.validity_timed | [magnetics.rogowski_coil[:].current.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
magnetics.rogowski_coil[:].identifier |  | STR_0D |  | ID of the coil
magnetics.rogowski_coil[:].indices_compound | [1...N] | INT_1D |  | Indices (from the rogowski_coil array of structure) of the partial Rogoswkis used to build the coumpound signal (sum of the partial Rogoswki signals) Use only if ../measure_quantity/index = 5, leave empty otherwise
magnetics.rogowski_coil[:].measured_quantity |  | STRUCTURE |  | Quantity measured by the sensor 1) plasma : Plasma current 2) plasma_eddy : Plasma and eddy currents 3) eddy : Eddy currents 4) halo : Halo currents 5) compound : Sensor composed of multiple partial Rogowskis
magnetics.rogowski_coil[:].measured_quantity.description |  | STR_0D |  | Verbose description
magnetics.rogowski_coil[:].measured_quantity.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
magnetics.rogowski_coil[:].measured_quantity.name |  | STR_0D |  | Short string identifier
magnetics.rogowski_coil[:].name |  | STR_0D |  | Name of the coil
magnetics.rogowski_coil[:].position | [1...N] | STRUCT_ARRAY |  | List of (R,Z,phi) points defining the position of the coil guiding centre
magnetics.rogowski_coil[:].position[:].phi |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
magnetics.rogowski_coil[:].position[:].r |  | FLT_0D (uncertain) | m | Major radius
magnetics.rogowski_coil[:].position[:].z |  | FLT_0D (uncertain) | m | Height
magnetics.rogowski_coil[:].turns_per_metre |  | FLT_0D (uncertain) | m^-1 | Number of turns per unit length. In case of multiple layers, turns are counted for a single layer
magnetics.time | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
mhd (alpha) |  |  |  | Magnetohydrodynamic activity, description of perturbed fields and profiles using the Generic Grid Description.
mhd.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
mhd.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
mhd.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
mhd.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
mhd.code.library[:].name (alpha) |  | STR_0D |  | Name of software
mhd.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mhd.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
mhd.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
mhd.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
mhd.code.output_flag (alpha) | [mhd.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
mhd.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mhd.code.repository (alpha) |  | STR_0D |  | URL of software repository
mhd.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
mhd.ggd (alpha) | [mhd.ggd[:].time] | STRUCT_ARRAY |  | Edge plasma quantities represented using the general grid description, for various time slices.
mhd.ggd[:].a_field_r (alpha) | [1...N] | STRUCT_ARRAY | T.m | R component of the magnetic vector potential, given on various grid subsets
mhd.ggd[:].a_field_r[:].coefficients (alpha) | [mhd.ggd[:].a_field_r[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].a_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].a_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].a_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
mhd.ggd[:].a_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T.m | Toroidal component of the magnetic vector potential, given on various grid subsets
mhd.ggd[:].a_field_tor[:].coefficients (alpha) | [mhd.ggd[:].a_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].a_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].a_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].a_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
mhd.ggd[:].a_field_z (alpha) | [1...N] | STRUCT_ARRAY | T.m | Z component of the magnetic vector potential, given on various grid subsets
mhd.ggd[:].a_field_z[:].coefficients (alpha) | [mhd.ggd[:].a_field_z[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].a_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].a_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].a_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
mhd.ggd[:].b_field_r (alpha) | [1...N] | STRUCT_ARRAY | T | R component of the magnetic field, given on various grid subsets
mhd.ggd[:].b_field_r[:].coefficients (alpha) | [mhd.ggd[:].b_field_r[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].b_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].b_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].b_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
mhd.ggd[:].b_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T | Toroidal component of the magnetic field, given on various grid subsets
mhd.ggd[:].b_field_tor[:].coefficients (alpha) | [mhd.ggd[:].b_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].b_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].b_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].b_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
mhd.ggd[:].b_field_z (alpha) | [1...N] | STRUCT_ARRAY | T | Z component of the magnetic field, given on various grid subsets
mhd.ggd[:].b_field_z[:].coefficients (alpha) | [mhd.ggd[:].b_field_z[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].b_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].b_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].b_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
mhd.ggd[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
mhd.ggd[:].electrons.temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
mhd.ggd[:].electrons.temperature[:].coefficients (alpha) | [mhd.ggd[:].electrons.temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].electrons.temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].electrons.temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].electrons.temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
mhd.ggd[:].j_r (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | R component of the current density, given on various grid subsets
mhd.ggd[:].j_r[:].coefficients (alpha) | [mhd.ggd[:].j_r[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].j_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].j_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].j_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].j_tor (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Toroidal component of the current density, given on various grid subsets
mhd.ggd[:].j_tor[:].coefficients (alpha) | [mhd.ggd[:].j_tor[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].j_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].j_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].j_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].j_z (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Z component of the current density, given on various grid subsets
mhd.ggd[:].j_z[:].coefficients (alpha) | [mhd.ggd[:].j_z[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].j_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].j_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].j_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].mass_density (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-3 | Mass density, given on various grid subsets
mhd.ggd[:].mass_density[:].coefficients (alpha) | [mhd.ggd[:].mass_density[:].values, 1...N] | FLT_2D (uncertain) | kg.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].mass_density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].mass_density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].mass_density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-3 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].n_i_total (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Total ion density (sum over ion species and thermal+non-thermal), given on various grid subsets
mhd.ggd[:].n_i_total[:].coefficients (alpha) | [mhd.ggd[:].n_i_total[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].n_i_total[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].n_i_total[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].n_i_total[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].phi_potential (alpha) | [1...N] | STRUCT_ARRAY | V | Electric potential, given on various grid subsets
mhd.ggd[:].phi_potential[:].coefficients (alpha) | [mhd.ggd[:].phi_potential[:].values, 1...N] | FLT_2D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].phi_potential[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].phi_potential[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].phi_potential[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V | One scalar value is provided per element in the grid subset.
mhd.ggd[:].psi (alpha) | [1...N] | STRUCT_ARRAY | Wb | Poloidal flux, given on various grid subsets
mhd.ggd[:].psi[:].coefficients (alpha) | [mhd.ggd[:].psi[:].values, 1...N] | FLT_2D (uncertain) | Wb | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].psi[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].psi[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].psi[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Wb | One scalar value is provided per element in the grid subset.
mhd.ggd[:].t_i_average (alpha) | [1...N] | STRUCT_ARRAY | eV | Ion temperature (averaged on ion species), given on various grid subsets
mhd.ggd[:].t_i_average[:].coefficients (alpha) | [mhd.ggd[:].t_i_average[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].t_i_average[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].t_i_average[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].t_i_average[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
mhd.ggd[:].time (alpha) |  | FLT_0D | s | Time
mhd.ggd[:].velocity_parallel (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Parallel (to magnetic field) component of the plasma velocity, given on various grid subsets
mhd.ggd[:].velocity_parallel[:].coefficients (alpha) | [mhd.ggd[:].velocity_parallel[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].velocity_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].velocity_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].velocity_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].velocity_r (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | R component of the plasma velocity, given on various grid subsets
mhd.ggd[:].velocity_r[:].coefficients (alpha) | [mhd.ggd[:].velocity_r[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].velocity_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].velocity_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].velocity_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].velocity_tor (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Toroidal component of the plasma velocity, given on various grid subsets
mhd.ggd[:].velocity_tor[:].coefficients (alpha) | [mhd.ggd[:].velocity_tor[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].velocity_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].velocity_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].velocity_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].velocity_z (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Z component of the plasma velocity, given on various grid subsets
mhd.ggd[:].velocity_z[:].coefficients (alpha) | [mhd.ggd[:].velocity_z[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].velocity_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].velocity_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].velocity_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].vorticity (alpha) | [1...N] | STRUCT_ARRAY | s^-1 | Vorticity, given on various grid subsets
mhd.ggd[:].vorticity[:].coefficients (alpha) | [mhd.ggd[:].vorticity[:].values, 1...N] | FLT_2D (uncertain) | s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].vorticity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].vorticity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].vorticity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | s^-1 | One scalar value is provided per element in the grid subset.
mhd.ggd[:].zeff (alpha) | [1...N] | STRUCT_ARRAY | - | Effective charge, given on various grid subsets
mhd.ggd[:].zeff[:].coefficients (alpha) | [mhd.ggd[:].zeff[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
mhd.ggd[:].zeff[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
mhd.ggd[:].zeff[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
mhd.ggd[:].zeff[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
mhd.grid_ggd (alpha) | [mhd.grid_ggd[:].time] | STRUCT_ARRAY |  | Grid (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the ggd timebase
mhd.grid_ggd[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
mhd.grid_ggd[:].grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
mhd.grid_ggd[:].grid_subset[:].base[:].jacobian (alpha) | [mhd.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
mhd.grid_ggd[:].grid_subset[:].base[:].tensor_contravariant (alpha) | [mhd.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
mhd.grid_ggd[:].grid_subset[:].base[:].tensor_covariant (alpha) | [mhd.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
mhd.grid_ggd[:].grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
mhd.grid_ggd[:].grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
mhd.grid_ggd[:].grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
mhd.grid_ggd[:].grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
mhd.grid_ggd[:].grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
mhd.grid_ggd[:].grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
mhd.grid_ggd[:].grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
mhd.grid_ggd[:].grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
mhd.grid_ggd[:].grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd.grid_ggd[:].grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
mhd.grid_ggd[:].grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
mhd.grid_ggd[:].grid_subset[:].metric.jacobian (alpha) | [mhd.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
mhd.grid_ggd[:].grid_subset[:].metric.tensor_contravariant (alpha) | [mhd.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
mhd.grid_ggd[:].grid_subset[:].metric.tensor_covariant (alpha) | [mhd.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
mhd.grid_ggd[:].identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
mhd.grid_ggd[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
mhd.grid_ggd[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd.grid_ggd[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
mhd.grid_ggd[:].space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
mhd.grid_ggd[:].space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
mhd.grid_ggd[:].space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
mhd.grid_ggd[:].space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
mhd.grid_ggd[:].space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd.grid_ggd[:].space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd.grid_ggd[:].space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
mhd.grid_ggd[:].space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
mhd.grid_ggd[:].space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd.grid_ggd[:].space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
mhd.grid_ggd[:].space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
mhd.grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
mhd.grid_ggd[:].time (alpha) |  | FLT_0D | s | Time
mhd.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
mhd.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
mhd.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
mhd.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
mhd.ids_properties.occurrence |  | INT_0D |  |
mhd.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
mhd.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
mhd.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
mhd.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
mhd.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
mhd.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
mhd.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
mhd_linear (alpha) |  |  |  | Magnetohydronamic linear stability
mhd_linear.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
mhd_linear.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
mhd_linear.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
mhd_linear.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
mhd_linear.code.library[:].name (alpha) |  | STR_0D |  | Name of software
mhd_linear.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mhd_linear.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
mhd_linear.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
mhd_linear.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
mhd_linear.code.output_flag (alpha) | [mhd_linear.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
mhd_linear.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mhd_linear.code.repository (alpha) |  | STR_0D |  | URL of software repository
mhd_linear.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
mhd_linear.equations (alpha) |  | STRUCTURE |  | Type of MHD equations used to populate this IDS 1) reduced : Reduced MHD 11) reduced_kinetic : Reduced MHD and kinetic hybrid 2) full : Full MHD 21) full_kinetic : Full MHD and kinetic hybrid
mhd_linear.equations.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.equations.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.equations.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.fluids_n (alpha) |  | INT_0D |  | Number of fluids considered in the model
mhd_linear.ideal_flag (alpha) |  | INT_0D |  | 1 if ideal MHD is used to populate this IDS, 0 for non-ideal MHD
mhd_linear.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
mhd_linear.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
mhd_linear.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
mhd_linear.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
mhd_linear.ids_properties.occurrence |  | INT_0D |  |
mhd_linear.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
mhd_linear.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
mhd_linear.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
mhd_linear.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
mhd_linear.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
mhd_linear.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
mhd_linear.model_type (alpha) |  | STRUCTURE |  | Type of model used to populate this IDS 1) global : Global calculation 2) local : Local calculation 3) analytical : Analytical estimate
mhd_linear.model_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.model_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.model_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
mhd_linear.time_slice (alpha) | [mhd_linear.time_slice[:].time] | STRUCT_ARRAY |  | Core plasma radial profiles for various time slices
mhd_linear.time_slice[:].time (alpha) |  | FLT_0D | s | Time
mhd_linear.time_slice[:].toroidal_mode (alpha) | [1...N] | STRUCT_ARRAY |  | Vector of toroidal modes. Each mode is described as exp(i(n_tor.phi - m_pol.theta - 2.pi.frequency.t - phase))
mhd_linear.time_slice[:].toroidal_mode[:].amplitude_multiplier (alpha) |  | FLT_0D (uncertain) | mixed | Multiplier that is needed to convert the linear mode structures to the amplitude of a non-linearly saturated mode in physical units. If empty, it means that the structures contains no information about non-linearly saturated mode
mhd_linear.time_slice[:].toroidal_mode[:].ballooning_type (alpha) |  | STRUCTURE |  | Ballooning type of the mode : ballooning 0; anti-ballooning:1; flute-like:2 1) TAE : Toroidal Alfven Eigenmode 2) EAE : Ellipticity-induced Alfven Eigenmode 3) NAE : Non-circular triangularity induced Alfven Eigenmode 4) RSAE : Reversed Shear Alfven Eigenmode 5) BAE : Beta induced Alfven Eigenmode 6) BAAE : Beta induced Alfven Acoustic Eigenmode 7) EPM : Energetic particle mode, outside any shear Alfven gap 8) GAE : Global Alfven Eingenmode 9) GAM : Geodesic Acoustic Mode 10) EGAM : Energetic particle-driven Geodesic Acoustic Mode 11) iKINK : Internal KINK mode 12) eKINK : External KINK mode 13) Tearing : Tearing mode 14) Double_Tearing : Double Tearing mode
mhd_linear.time_slice[:].toroidal_mode[:].ballooning_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].ballooning_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].ballooning_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].energy_perturbed (alpha) |  | FLT_0D (uncertain) | J | Perturbed energy associated to the mode
mhd_linear.time_slice[:].toroidal_mode[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency of the mode
mhd_linear.time_slice[:].toroidal_mode[:].growthrate (alpha) |  | FLT_0D (uncertain) | Hz | Linear growthrate of the mode
mhd_linear.time_slice[:].toroidal_mode[:].m_pol_dominant (alpha) |  | FLT_0D (uncertain) | - | Dominant poloidal mode number defining the mode rational surface; for TAEs the lower of the two main m's has to be specified
mhd_linear.time_slice[:].toroidal_mode[:].n_tor (alpha) |  | INT_0D |  | Toroidal mode number of the MHD mode
mhd_linear.time_slice[:].toroidal_mode[:].perturbation_type (alpha) |  | STRUCTURE |  | Type of the perturbation 1) TAE : Toroidal Alfven Eigenmode 2) EAE : Ellipticity-induced Alfven Eigenmode 3) NAE : Non-circular triangularity induced Alfven Eigenmode 4) RSAE : Reversed Shear Alfven Eigenmode 5) BAE : Beta induced Alfven Eigenmode 6) BAAE : Beta induced Alfven Acoustic Eigenmode 7) EPM : Energetic particle mode, outside any shear Alfven gap 8) GAE : Global Alfven Eingenmode 9) GAM : Geodesic Acoustic Mode 10) EGAM : Energetic particle-driven Geodesic Acoustic Mode 11) iKINK : Internal KINK mode 12) eKINK : External KINK mode 13) Tearing : Tearing mode 14) Double_Tearing : Double Tearing mode
mhd_linear.time_slice[:].toroidal_mode[:].perturbation_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].perturbation_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].perturbation_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].phase (alpha) |  | FLT_0D (uncertain) | rad | Additional phase offset of mode
mhd_linear.time_slice[:].toroidal_mode[:].plasma (alpha) |  | STRUCTURE |  | MHD modes in the confined plasma
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed (alpha) |  | STRUCTURE | T.m | Pertubed vector potential for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T.m | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T.m | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T.m | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.alfven_frequency_spectrum (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1] | STRUCT_ARRAY |  | Local shear Alfven spectrum as a function of radius (only in case grid/dim1 is a radial coordinate)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.alfven_frequency_spectrum[:].imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.alfven_frequency_spectrum[:].real] | FLT_1D (uncertain) | s^-1 | Imaginary part of the frequency, for a given radial position and every root found at this position
mhd_linear.time_slice[:].toroidal_mode[:].plasma.alfven_frequency_spectrum[:].real (alpha) | [1...N] | FLT_1D (uncertain) | s^-1 | Real part of the frequency, for a given radial position and every root found at this position
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed (alpha) |  | STRUCTURE | T | Pertubed magnetic field for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system (alpha) |  | STRUCTURE |  | Flux surface coordinate system of the equilibrium used for the MHD calculation on a square grid of flux and poloidal angle
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.jacobian (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | Absolute value of the jacobian of the coordinate system
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.r (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.tensor_contravariant (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Contravariant metric tensor on every point of the grid described by grid_type
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.tensor_covariant (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Covariant metric tensor on every point of the grid described by grid_type
mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.z (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel (alpha) |  | STRUCTURE | m | Parallel displacement of the modes
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular (alpha) |  | STRUCTURE | m | Perpendicular displacement of the modes
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid (the content of dim1 and dim2 is defined by the selected grid_type)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed (alpha) |  | STRUCTURE | kg.m^-3 | Perturbed mass density for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | kg.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | kg.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | kg.m^-3 | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | kg.m^-3 | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.ntv (alpha) |  | STRUCTURE |  | Neoclassical toroidal viscosity tensor
mhd_linear.time_slice[:].toroidal_mode[:].plasma.ntv.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Imaginary part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.ntv.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Real part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.phi_potential_perturbed (alpha) |  | STRUCTURE | V | Perturbed electrostatic potential for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.phi_potential_perturbed.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.phi_potential_perturbed.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.phi_potential_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | V | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.phi_potential_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | V | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed (alpha) |  | STRUCTURE | Pa | Perturbed pressure for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | Pa | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | Pa | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.psi_potential_perturbed (alpha) |  | STRUCTURE | V | Perturbed electromagnetic super-potential for given toroidal mode number, see ref [Antonsen/Lane Phys Fluids 23(6) 1980, formula 34], so that A_field_parallel=1/(i*2pi*frequency) (grad psi_potential)_parallel
mhd_linear.time_slice[:].toroidal_mode[:].plasma.psi_potential_perturbed.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.psi_potential_perturbed.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.psi_potential_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | V | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.psi_potential_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | V | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_maxwell (alpha) |  | STRUCTURE |  | Maxwell stress tensor
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_maxwell.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Imaginary part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_maxwell.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Real part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_reynolds (alpha) |  | STRUCTURE |  | Reynolds stress tensor
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_reynolds.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Imaginary part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.stress_reynolds.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, 1...N, 1...N] | FLT_3D (uncertain) | N.m^-2 | Real part of the stress tensor, for various radial positions
mhd_linear.time_slice[:].toroidal_mode[:].plasma.tau_alfven (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1] | FLT_1D (uncertain) | s | Alven time=R/vA=R0 sqrt(mi ni(rho))/B0
mhd_linear.time_slice[:].toroidal_mode[:].plasma.tau_resistive (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1] | FLT_1D (uncertain) | s | Resistive time = mu_0 rho*rho/1.22/eta_neo
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed (alpha) |  | STRUCTURE | eV | Perturbed temperature for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | eV | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | eV | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed (alpha) |  | STRUCTURE | m/s | Pertubed velocity for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1 (alpha) |  | STRUCTURE | m/s | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2 (alpha) |  | STRUCTURE | m/s | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3 (alpha) |  | STRUCTURE | m/s | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2, 1...N] | FLT_3D (uncertain) | m/s | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].radial_mode_number (alpha) |  | FLT_0D (uncertain) | - | Radial mode number
mhd_linear.time_slice[:].toroidal_mode[:].vacuum (alpha) |  | STRUCTURE |  | MHD modes in the vacuum
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed (alpha) |  | STRUCTURE | T.m | Pertubed vector potential for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T.m | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate1.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate1.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T.m | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate2.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate2.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T.m | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate3.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate3.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.a_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed (alpha) |  | STRUCTURE | T | Pertubed magnetic field for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate1.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate1.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate2.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate2.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate3.coefficients_imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (imaginary part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate3.coefficients_real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2, 1...N] | FLT_3D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity (real part) with finite elements, provided on the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.b_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system (alpha) |  | STRUCTURE |  | Flux surface coordinate system of the equilibrium used for the MHD calculation on a square grid of flux and poloidal angle
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.jacobian (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | Absolute value of the jacobian of the coordinate system
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.r (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.tensor_contravariant (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Contravariant metric tensor on every point of the grid described by grid_type
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.tensor_covariant (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Covariant metric tensor on every point of the grid described by grid_type
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.z (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid (the content of dim1 and dim2 is defined by the selected grid_type)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
mhd_linear.time_slice[:].toroidal_mode[:].vacuum.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
mhd_linear.vacuum_toroidal_field.b0 (alpha) | [mhd_linear.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
mhd_linear.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
mse (alpha) |  |  |  | Motional Stark Effect diagnostic
mse.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines of sight)
mse.channel[:].active_spatial_resolution (alpha) | [mse.channel[:].active_spatial_resolution[:].time] | STRUCT_ARRAY |  | Spatial resolution of the measurement, calculated as a convolution of the atomic smearing, magnetic and beam geometry smearing and detector projection, for a set of time slices (use a single time slice for the whole pulse if the beam and the line of sight are not moving during the pulse)
mse.channel[:].active_spatial_resolution[:].centre (alpha) |  | STRUCTURE |  | Position of the centre of the spatially resolved zone
mse.channel[:].active_spatial_resolution[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].active_spatial_resolution[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].active_spatial_resolution[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].active_spatial_resolution[:].geometric_coefficients (alpha) | [1...9] | FLT_1D (uncertain) | mixed | Set of 9 geometric coefficients providing the MSE polarisation angle as a function of the local electric and magnetic field components (these are related to the angle between beam and line of sight). The list is ordered as follows : coefficients of BZ, BR, Bphi, ER (numerator of the MSE angle expression); coefficients of BZ, BR, Bphi, ER, EZ (denominator)
mse.channel[:].active_spatial_resolution[:].time (alpha) |  | FLT_0D | s | Time
mse.channel[:].active_spatial_resolution[:].width (alpha) |  | STRUCTURE |  | Full width of the spatially resolved zone in the R, Z and phi directions
mse.channel[:].active_spatial_resolution[:].width.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].active_spatial_resolution[:].width.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].active_spatial_resolution[:].width.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
mse.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
mse.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
mse.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
mse.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
mse.channel[:].aperture[:].outline.x2 (alpha) | [mse.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
mse.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
mse.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
mse.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
mse.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
mse.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
mse.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
mse.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
mse.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
mse.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
mse.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
mse.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
mse.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
mse.channel[:].detector.outline.x2 (alpha) | [mse.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
mse.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
mse.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
mse.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
mse.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
mse.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
mse.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
mse.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
mse.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
mse.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
mse.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
mse.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
mse.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
mse.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
mse.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
mse.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
mse.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
mse.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
mse.channel[:].polarisation_angle (alpha) |  | STRUCTURE | rad | MSE polarisation angle
mse.channel[:].polarisation_angle.data (alpha) | [mse.channel[:].polarisation_angle.time] | FLT_1D (uncertain) | rad | Data
mse.channel[:].polarisation_angle.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
mse.channel[:].polarisation_angle.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
mse.channel[:].polarisation_angle.validity_timed (alpha) | [mse.channel[:].polarisation_angle.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
mse.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
mse.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
mse.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
mse.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
mse.code.library[:].name (alpha) |  | STR_0D |  | Name of software
mse.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mse.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
mse.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
mse.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
mse.code.output_flag (alpha) | [mse.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
mse.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mse.code.repository (alpha) |  | STR_0D |  | URL of software repository
mse.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
mse.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
mse.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
mse.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
mse.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
mse.ids_properties.occurrence |  | INT_0D |  |
mse.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
mse.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
mse.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
mse.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
mse.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
mse.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
mse.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
nbi (alpha) |  |  |  | Neutral Beam Injection systems and description of the fast neutrals that arrive into the torus
nbi.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
nbi.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
nbi.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
nbi.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
nbi.code.library[:].name (alpha) |  | STR_0D |  | Name of software
nbi.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
nbi.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
nbi.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
nbi.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
nbi.code.output_flag (alpha) | [nbi.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
nbi.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
nbi.code.repository (alpha) |  | STR_0D |  | URL of software repository
nbi.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
nbi.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
nbi.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
nbi.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
nbi.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
nbi.ids_properties.occurrence |  | INT_0D |  |
nbi.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
nbi.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
nbi.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
nbi.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
nbi.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
nbi.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
nbi.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
nbi.unit (alpha) | [1...N] | STRUCT_ARRAY |  | The NBI system is described as a set of units of which the power can be controlled individually.
nbi.unit[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures through which the beam is launched
nbi.unit[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
nbi.unit[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
nbi.unit[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
nbi.unit[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
nbi.unit[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
nbi.unit[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
nbi.unit[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
nbi.unit[:].aperture[:].outline.x2 (alpha) | [nbi.unit[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
nbi.unit[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
nbi.unit[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
nbi.unit[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
nbi.unit[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
nbi.unit[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
nbi.unit[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
nbi.unit[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
nbi.unit[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].beam_current_fraction (alpha) | [1...3, nbi.unit[:].beam_current_fraction.time] | STRUCTURE | - | Fractions of beam current distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_current_fraction.data (alpha) | [1...N, nbi.unit[:].beam_current_fraction.time] | FLT_2D (uncertain) | - | Data
nbi.unit[:].beam_current_fraction.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
nbi.unit[:].beam_power_fraction (alpha) | [1...3, nbi.unit[:].beam_power_fraction.time] | STRUCTURE | - | Fractions of beam power distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_power_fraction.data (alpha) | [1...N, nbi.unit[:].beam_power_fraction.time] | FLT_2D (uncertain) | - | Data
nbi.unit[:].beam_power_fraction.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
nbi.unit[:].beamlets_group (alpha) | [1...N] | STRUCT_ARRAY |  | Group of beamlets with common vertical and horizontal focal point. If there are no common focal points, then select small groups of beamlets such that a focal point description of the beamlets group provides a fair description
nbi.unit[:].beamlets_group[:].angle (alpha) |  | FLT_0D (uncertain) | rad | Angle of inclination between a beamlet at the centre of the injection unit surface and the horiontal plane
nbi.unit[:].beamlets_group[:].beamlets (alpha) |  | STRUCTURE |  | Detailed information on beamlets
nbi.unit[:].beamlets_group[:].beamlets.angles (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | rad | Angle of inclination between a line at the centre of a beamlet and the horizontal plane, for each beamlet
nbi.unit[:].beamlets_group[:].beamlets.positions (alpha) |  | STRUCTURE |  | Position of each beamlet
nbi.unit[:].beamlets_group[:].beamlets.positions.phi (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
nbi.unit[:].beamlets_group[:].beamlets.positions.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
nbi.unit[:].beamlets_group[:].beamlets.positions.z (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | m | Height
nbi.unit[:].beamlets_group[:].beamlets.power_fractions (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | rad | Fraction of power of a unit injected by each beamlet
nbi.unit[:].beamlets_group[:].beamlets.tangency_radii (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | m | Tangency radius (major radius where the central line of a beamlet is tangent to a circle around the torus), for each beamlet
nbi.unit[:].beamlets_group[:].direction (alpha) |  | INT_0D |  | Direction of the beam seen from above the torus: -1 = clockwise; 1 = counter clockwise
nbi.unit[:].beamlets_group[:].divergence_component (alpha) | [1...N] | STRUCT_ARRAY |  | Detailed information on beamlet divergence. Divergence is described as a superposition of Gaussian components with amplitide "particles_fraction" and vertical/horizontal divergence. Note that for positive ion NBI the divergence is well described by a single Gaussian
nbi.unit[:].beamlets_group[:].divergence_component[:].horizontal (alpha) |  | FLT_0D (uncertain) | rad | The horiztonal beamlet divergence of the component. Here the divergence is defined for Gaussian beams as the angel where the beam density is reduced by a factor 1/e compared to the maximum density. For non-Gaussian beams the divergence is sqrt(2)*mean((x-mean(x))**2), where x is the angle and the mean should be performed over the beam density, P(x): mean(y)=int(y*P(x)*dx).
nbi.unit[:].beamlets_group[:].divergence_component[:].particles_fraction (alpha) |  | FLT_0D (uncertain) | - | Fraction of injected particles in the component
nbi.unit[:].beamlets_group[:].divergence_component[:].vertical (alpha) |  | FLT_0D (uncertain) | rad | The vertical beamlet divergence of the component. Here the divergence is defined for Gaussian beams as the angel where the beam density is reduced by a factor 1/e compared to the maximum density. For non-Gaussian beams the divergence is sqrt(2)*mean((x-mean(x))**2), where x is the angle and the mean should be performed over the beam density, P(x): mean(y)=int(y*P(x)*dx).
nbi.unit[:].beamlets_group[:].focus (alpha) |  | STRUCTURE |  | Describes how the beamlet group is focused
nbi.unit[:].beamlets_group[:].focus.focal_length_horizontal (alpha) |  | FLT_0D (uncertain) | m | Horizontal focal length along the beam line, i.e. the point along the centre of the beamlet-group where the beamlet-group has its minimum horizontal width
nbi.unit[:].beamlets_group[:].focus.focal_length_vertical (alpha) |  | FLT_0D (uncertain) | m | Vertical focal length along the beam line, i.e. the point along the centre of the beamlet-group where the beamlet-group has its minimum vertical width
nbi.unit[:].beamlets_group[:].focus.width_min_horizontal (alpha) |  | FLT_0D (uncertain) | m | The horizontal width of the beamlets group at the at the horizontal focal point
nbi.unit[:].beamlets_group[:].focus.width_min_vertical (alpha) |  | FLT_0D (uncertain) | m | The vertical width of the beamlets group at the at the vertical focal point
nbi.unit[:].beamlets_group[:].position (alpha) |  | STRUCTURE |  | R, Z, Phi position of the beamlet group centre
nbi.unit[:].beamlets_group[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
nbi.unit[:].beamlets_group[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
nbi.unit[:].beamlets_group[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
nbi.unit[:].beamlets_group[:].tangency_radius (alpha) |  | FLT_0D (uncertain) | m | Tangency radius (major radius where the central line of a NBI unit is tangent to a circle around the torus)
nbi.unit[:].beamlets_group[:].tilting (alpha) | [nbi.unit[:].beamlets_group[:].tilting[:].time] | STRUCT_ARRAY |  | In case of dynamic beam tilting (i.e. during the pulse), e.g. for some Beam Emission Spectroscopy use cases, variations of position, tangency radius and angle with respect to their static value, for various time slices
nbi.unit[:].beamlets_group[:].tilting[:].delta_angle (alpha) |  | FLT_0D (uncertain) | rad | Variation of the angle of inclination between a beamlet at the centre of the injection unit surface and the horiontal plane
nbi.unit[:].beamlets_group[:].tilting[:].delta_position (alpha) |  | STRUCTURE |  | Variation of the position of the beamlet group centre
nbi.unit[:].beamlets_group[:].tilting[:].delta_position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
nbi.unit[:].beamlets_group[:].tilting[:].delta_position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
nbi.unit[:].beamlets_group[:].tilting[:].delta_position.z (alpha) |  | FLT_0D (uncertain) | m | Height
nbi.unit[:].beamlets_group[:].tilting[:].delta_tangency_radius (alpha) |  | FLT_0D (uncertain) | m | Variation of the tangency radius (major radius where the central line of a NBI unit is tangent to a circle around the torus)
nbi.unit[:].beamlets_group[:].tilting[:].time (alpha) |  | FLT_0D | s | Time
nbi.unit[:].beamlets_group[:].width_horizontal (alpha) |  | FLT_0D (uncertain) | m | Horizontal width of the beam group at the injection unit surface (or grounded grid)
nbi.unit[:].beamlets_group[:].width_vertical (alpha) |  | FLT_0D (uncertain) | m | Vertical width of the beam group at the injection unit surface (or grounded grid)
nbi.unit[:].energy (alpha) |  | STRUCTURE | eV | Full energy of the injected species (acceleration of a single atom)
nbi.unit[:].energy.data (alpha) | [nbi.unit[:].energy.time] | FLT_1D (uncertain) | eV | Data
nbi.unit[:].energy.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
nbi.unit[:].identifier (alpha) |  | STR_0D |  | ID of the NBI unit
nbi.unit[:].name (alpha) |  | STR_0D |  | Name of the NBI unit
nbi.unit[:].power_launched (alpha) |  | STRUCTURE | W | Power launched from this unit into the vacuum vessel
nbi.unit[:].power_launched.data (alpha) | [nbi.unit[:].power_launched.time] | FLT_1D (uncertain) | W | Data
nbi.unit[:].power_launched.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
nbi.unit[:].source (alpha) |  | STRUCTURE |  | Description of the surface of the ion source from which the beam is extracted
nbi.unit[:].source.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
nbi.unit[:].source.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
nbi.unit[:].source.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
nbi.unit[:].source.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
nbi.unit[:].source.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
nbi.unit[:].source.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
nbi.unit[:].source.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
nbi.unit[:].source.outline.x2 (alpha) | [nbi.unit[:].source.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
nbi.unit[:].source.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
nbi.unit[:].source.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
nbi.unit[:].source.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
nbi.unit[:].source.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].source.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].source.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].source.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
nbi.unit[:].source.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
nbi.unit[:].source.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].source.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].source.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].source.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
nbi.unit[:].source.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
nbi.unit[:].source.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
nbi.unit[:].source.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
nbi.unit[:].source.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
nbi.unit[:].species (alpha) |  | STRUCTURE |  | Injected species
nbi.unit[:].species.a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
nbi.unit[:].species.label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, T, ...)
nbi.unit[:].species.z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
neutron_diagnostic (alpha) |  |  |  | Neutron diagnostic such as DNFM, NFM or MFC
neutron_diagnostic.characteristics (alpha) |  | STRUCTURE |  | Description of Diagnostic's module detection characteristics for differen plasma modes based on Design Description
neutron_diagnostic.characteristics.dead_time (alpha) |  | FLT_0D (uncertain) | s | Dead time of detectors
neutron_diagnostic.characteristics.pulse_length (alpha) |  | FLT_0D (uncertain) | s | Lower counting limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction (alpha) | [neutron_diagnostic.characteristics.reaction[:].index] | STRUCT_ARRAY |  | Plasma reaction (1 -'DT'; 2 - 'DD')
neutron_diagnostic.characteristics.reaction[:].error (alpha) |  | FLT_0D (uncertain) | - | Diagnostic's relative uncertainty for recent plasma reaction
neutron_diagnostic.characteristics.reaction[:].index (alpha) |  | INT_0D |  | Index of plasma reaction type
neutron_diagnostic.characteristics.reaction[:].mode (alpha) | [neutron_diagnostic.characteristics.reaction[:].mode[:].index] | STRUCT_ARRAY |  | Characteristics of counting linear limits in recent Measuring modes for recent Plasma reaction type
neutron_diagnostic.characteristics.reaction[:].mode[:].count_limit_max (alpha) |  | FLT_0D (uncertain) | cps | Maximum count limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction[:].mode[:].count_limit_min (alpha) |  | FLT_0D (uncertain) | cps | Minimum count limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction[:].mode[:].index (alpha) |  | INT_0D |  | Index of Measuring Mode
neutron_diagnostic.characteristics.reaction[:].mode[:].name (alpha) |  | STR_0D |  | Name of Measuring Mode
neutron_diagnostic.characteristics.reaction[:].probability_overlap (alpha) |  | FLT_0D (uncertain) | - | Pulse probability overlap for recent plasma reaction
neutron_diagnostic.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
neutron_diagnostic.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
neutron_diagnostic.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
neutron_diagnostic.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
neutron_diagnostic.code.library[:].name (alpha) |  | STR_0D |  | Name of software
neutron_diagnostic.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
neutron_diagnostic.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
neutron_diagnostic.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
neutron_diagnostic.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
neutron_diagnostic.code.output_flag (alpha) | [neutron_diagnostic.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
neutron_diagnostic.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
neutron_diagnostic.code.repository (alpha) |  | STR_0D |  | URL of software repository
neutron_diagnostic.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
neutron_diagnostic.detectors (alpha) | [1...N] | STRUCT_ARRAY |  | Description of Detectors properties and Data in Neutron Diagnostic Module
neutron_diagnostic.detectors[:].adc (alpha) |  | STRUCTURE |  | Description of analogic-digital converter
neutron_diagnostic.detectors[:].adc.bias (alpha) |  | FLT_0D (uncertain) | V | ADC signal bias
neutron_diagnostic.detectors[:].adc.discriminator_level_lower (alpha) |  | INT_0D |  | Lower level discriminator of ADC
neutron_diagnostic.detectors[:].adc.discriminator_level_upper (alpha) |  | INT_0D |  | Upper level discriminator of ADC
neutron_diagnostic.detectors[:].adc.impedance (alpha) |  | FLT_0D (uncertain) | ohm | ADC impedance
neutron_diagnostic.detectors[:].adc.input_range (alpha) |  | FLT_0D (uncertain) | V | ADC input range
neutron_diagnostic.detectors[:].adc.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].adc.sampling_rate (alpha) |  | INT_0D |  | Number of samples recorded per second
neutron_diagnostic.detectors[:].amplitude_peak (alpha) |  | STRUCTURE | V | Processed peak amplitude of the measured signal
neutron_diagnostic.detectors[:].amplitude_peak.data (alpha) | [neutron_diagnostic.detectors[:].amplitude_peak.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].amplitude_peak.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].amplitude_raw (alpha) |  | STRUCTURE | V | Raw amplitude of the measured signal
neutron_diagnostic.detectors[:].amplitude_raw.data (alpha) | [neutron_diagnostic.detectors[:].amplitude_raw.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].amplitude_raw.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
neutron_diagnostic.detectors[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
neutron_diagnostic.detectors[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
neutron_diagnostic.detectors[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.detectors[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.detectors[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
neutron_diagnostic.detectors[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
neutron_diagnostic.detectors[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
neutron_diagnostic.detectors[:].aperture[:].outline.x2 (alpha) | [neutron_diagnostic.detectors[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
neutron_diagnostic.detectors[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
neutron_diagnostic.detectors[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
neutron_diagnostic.detectors[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
neutron_diagnostic.detectors[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
neutron_diagnostic.detectors[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
neutron_diagnostic.detectors[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
neutron_diagnostic.detectors[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
neutron_diagnostic.detectors[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].b_field_sensor (alpha) |  | STRUCTURE |  | Magnetic field sensor
neutron_diagnostic.detectors[:].b_field_sensor.amplitude (alpha) |  | STRUCTURE | V | Generated signal amplitude
neutron_diagnostic.detectors[:].b_field_sensor.amplitude.data (alpha) | [neutron_diagnostic.detectors[:].b_field_sensor.amplitude.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].b_field_sensor.amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].b_field_sensor.fall_time (alpha) |  | FLT_0D (uncertain) | s | Peak fall time
neutron_diagnostic.detectors[:].b_field_sensor.frequency (alpha) |  | STRUCTURE | Hz | Generated signal frequency
neutron_diagnostic.detectors[:].b_field_sensor.frequency.data (alpha) | [neutron_diagnostic.detectors[:].b_field_sensor.frequency.time] | FLT_1D (uncertain) | Hz | Data
neutron_diagnostic.detectors[:].b_field_sensor.frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].b_field_sensor.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].b_field_sensor.rise_time (alpha) |  | FLT_0D (uncertain) | s | Peak rise time
neutron_diagnostic.detectors[:].b_field_sensor.shape (alpha) |  | STRUCTURE |  | Signal shape. Index : 1 – rectangular, 2 – gaussian
neutron_diagnostic.detectors[:].b_field_sensor.shape.description (alpha) |  | STR_0D |  | Verbose description
neutron_diagnostic.detectors[:].b_field_sensor.shape.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
neutron_diagnostic.detectors[:].b_field_sensor.shape.name (alpha) |  | STR_0D |  | Short string identifier
neutron_diagnostic.detectors[:].detector (alpha) |  | STRUCTURE |  | Detector description
neutron_diagnostic.detectors[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
neutron_diagnostic.detectors[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
neutron_diagnostic.detectors[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.detectors[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.detectors[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
neutron_diagnostic.detectors[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
neutron_diagnostic.detectors[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
neutron_diagnostic.detectors[:].detector.outline.x2 (alpha) | [neutron_diagnostic.detectors[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
neutron_diagnostic.detectors[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
neutron_diagnostic.detectors[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
neutron_diagnostic.detectors[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
neutron_diagnostic.detectors[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
neutron_diagnostic.detectors[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
neutron_diagnostic.detectors[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
neutron_diagnostic.detectors[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
neutron_diagnostic.detectors[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
neutron_diagnostic.detectors[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
neutron_diagnostic.detectors[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
neutron_diagnostic.detectors[:].end_time (alpha) |  | FLT_0D (uncertain) | s | Time stamp of the moment diagnostic ends recording data
neutron_diagnostic.detectors[:].energy_band (alpha) | [1...N] | STRUCT_ARRAY |  | Set of energy bands in which neutrons are counted by the detector
neutron_diagnostic.detectors[:].energy_band[:].detection_efficiency (alpha) | [neutron_diagnostic.detectors[:].energy_band[:].energies] | FLT_1D (uncertain) | - | Probability of detection of a photon impacting the detector as a function of its energy
neutron_diagnostic.detectors[:].energy_band[:].energies (alpha) | [1...N] | FLT_1D (uncertain) | eV | Array of discrete energy values inside the band
neutron_diagnostic.detectors[:].energy_band[:].lower_bound (alpha) |  | FLT_0D (uncertain) | eV | Lower bound of the energy band
neutron_diagnostic.detectors[:].energy_band[:].upper_bound (alpha) |  | FLT_0D (uncertain) | eV | Upper bound of the energy band
neutron_diagnostic.detectors[:].mode (alpha) | [1...N] | STRUCT_ARRAY |  | Measuring Mode Properties and Data
neutron_diagnostic.detectors[:].mode[:].counting (alpha) |  | STRUCTURE | cps | Counting in Measuring Mode in Dynamic
neutron_diagnostic.detectors[:].mode[:].counting.data (alpha) | [neutron_diagnostic.detectors[:].mode[:].counting.time] | FLT_1D (uncertain) | cps | Data
neutron_diagnostic.detectors[:].mode[:].counting.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].mode[:].name (alpha) |  | STR_0D |  | Name of Measuring Mode
neutron_diagnostic.detectors[:].name (alpha) |  | STR_0D |  | Name of Detector
neutron_diagnostic.detectors[:].position (alpha) |  | STRUCTURE |  | Detector Position Data SHOULD BE REMOVED, REDUNDANT WITH THE NEW DETECTOR DESCRIPTION
neutron_diagnostic.detectors[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
neutron_diagnostic.detectors[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.detectors[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.detectors[:].radiation (alpha) | [neutron_diagnostic.detectors[:].radiation[:].index] | STRUCT_ARRAY |  | Radiation type on detector's converter (1 - 'neutrons'; 2 - 'gamma-rays')
neutron_diagnostic.detectors[:].radiation[:].converter_name (alpha) |  | STR_0D |  | Name of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].converter_nuclear_density (alpha) |  | FLT_0D (uncertain) | m^-3 | Nuclear density of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].converter_temperature (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | K | Temperature of detector's converter
neutron_diagnostic.detectors[:].radiation[:].converter_volume (alpha) |  | FLT_0D (uncertain) | m^3 | Volume of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].index (alpha) |  | INT_0D |  | Index of radiation type
neutron_diagnostic.detectors[:].spectrum (alpha) | [neutron_diagnostic.detectors[:].energy_band, neutron_diagnostic.detectors[:].spectrum.time] | STRUCTURE |  | Detected count per energy channel as a function of time
neutron_diagnostic.detectors[:].spectrum.data (alpha) | [neutron_diagnostic.detectors[:].spectrum.data.as_parent, neutron_diagnostic.detectors[:].spectrum.time] | INT_2D |  | Data
neutron_diagnostic.detectors[:].spectrum.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].spectrum_sampling_time (alpha) |  | FLT_0D (uncertain) | s | Sampling time used to obtain one spectrum time slice
neutron_diagnostic.detectors[:].spectrum_total (alpha) | [neutron_diagnostic.detectors[:].energy_band] | INT_1D |  | Detected count per energy channel, integrated over the whole acquisition duration
neutron_diagnostic.detectors[:].start_time (alpha) |  | FLT_0D (uncertain) | s | Time stamp of the moment diagnostic starts recording data
neutron_diagnostic.detectors[:].supply_high_voltage (alpha) |  | STRUCTURE |  | Description of high voltage power supply
neutron_diagnostic.detectors[:].supply_high_voltage.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_out (alpha) |  | STRUCTURE | V | Voltage at the supply output
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_out.data (alpha) | [neutron_diagnostic.detectors[:].supply_high_voltage.voltage_out.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_out.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_set (alpha) |  | STRUCTURE | V | Voltage set
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_set.data (alpha) | [neutron_diagnostic.detectors[:].supply_high_voltage.voltage_set.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].supply_high_voltage.voltage_set.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].supply_low_voltage (alpha) |  | STRUCTURE |  | Description of low voltage power supply
neutron_diagnostic.detectors[:].supply_low_voltage.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_out (alpha) |  | STRUCTURE | V | Voltage at the supply output
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_out.data (alpha) | [neutron_diagnostic.detectors[:].supply_low_voltage.voltage_out.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_out.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_set (alpha) |  | STRUCTURE | V | Voltage set
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_set.data (alpha) | [neutron_diagnostic.detectors[:].supply_low_voltage.voltage_set.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].supply_low_voltage.voltage_set.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].temperature_sensor (alpha) |  | STRUCTURE |  | Temperature sensor
neutron_diagnostic.detectors[:].temperature_sensor.amplitude (alpha) |  | STRUCTURE | V | Generated signal amplitude
neutron_diagnostic.detectors[:].temperature_sensor.amplitude.data (alpha) | [neutron_diagnostic.detectors[:].temperature_sensor.amplitude.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].temperature_sensor.amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].temperature_sensor.fall_time (alpha) |  | FLT_0D (uncertain) | s | Peak fall time
neutron_diagnostic.detectors[:].temperature_sensor.frequency (alpha) |  | STRUCTURE | Hz | Generated signal frequency
neutron_diagnostic.detectors[:].temperature_sensor.frequency.data (alpha) | [neutron_diagnostic.detectors[:].temperature_sensor.frequency.time] | FLT_1D (uncertain) | Hz | Data
neutron_diagnostic.detectors[:].temperature_sensor.frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].temperature_sensor.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].temperature_sensor.rise_time (alpha) |  | FLT_0D (uncertain) | s | Peak rise time
neutron_diagnostic.detectors[:].temperature_sensor.shape (alpha) |  | STRUCTURE |  | Signal shape. Index : 1 – rectangular, 2 – gaussian
neutron_diagnostic.detectors[:].temperature_sensor.shape.description (alpha) |  | STR_0D |  | Verbose description
neutron_diagnostic.detectors[:].temperature_sensor.shape.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
neutron_diagnostic.detectors[:].temperature_sensor.shape.name (alpha) |  | STR_0D |  | Short string identifier
neutron_diagnostic.detectors[:].test_generator (alpha) |  | STRUCTURE |  | Test generator characteristics
neutron_diagnostic.detectors[:].test_generator.amplitude (alpha) |  | STRUCTURE | V | Generated signal amplitude
neutron_diagnostic.detectors[:].test_generator.amplitude.data (alpha) | [neutron_diagnostic.detectors[:].test_generator.amplitude.time] | FLT_1D (uncertain) | V | Data
neutron_diagnostic.detectors[:].test_generator.amplitude.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].test_generator.fall_time (alpha) |  | FLT_0D (uncertain) | s | Peak fall time
neutron_diagnostic.detectors[:].test_generator.frequency (alpha) |  | STRUCTURE | Hz | Generated signal frequency
neutron_diagnostic.detectors[:].test_generator.frequency.data (alpha) | [neutron_diagnostic.detectors[:].test_generator.frequency.time] | FLT_1D (uncertain) | Hz | Data
neutron_diagnostic.detectors[:].test_generator.frequency.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
neutron_diagnostic.detectors[:].test_generator.power_switch (alpha) |  | INT_0D |  | Power switch (1=on, 0=off)
neutron_diagnostic.detectors[:].test_generator.rise_time (alpha) |  | FLT_0D (uncertain) | s | Peak rise time
neutron_diagnostic.detectors[:].test_generator.shape (alpha) |  | STRUCTURE |  | Signal shape. Index : 1 – rectangular, 2 – gaussian
neutron_diagnostic.detectors[:].test_generator.shape.description (alpha) |  | STR_0D |  | Verbose description
neutron_diagnostic.detectors[:].test_generator.shape.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
neutron_diagnostic.detectors[:].test_generator.shape.name (alpha) |  | STR_0D |  | Short string identifier
neutron_diagnostic.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
neutron_diagnostic.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
neutron_diagnostic.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
neutron_diagnostic.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
neutron_diagnostic.ids_properties.occurrence |  | INT_0D |  |
neutron_diagnostic.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
neutron_diagnostic.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
neutron_diagnostic.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
neutron_diagnostic.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
neutron_diagnostic.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
neutron_diagnostic.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
neutron_diagnostic.synthetic_signals (alpha) |  | STRUCTURE |  | Output Data from Neutron Diagnostic's Module
neutron_diagnostic.synthetic_signals.fusion_power (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | W | Fusion Power
neutron_diagnostic.synthetic_signals.total_neutron_flux (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | s^-1 | Total Neutron Flux in Dynamic
neutron_diagnostic.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
neutron_diagnostic.unit_source (alpha) | [1...N] | STRUCT_ARRAY |  | Unit ring sources description
neutron_diagnostic.unit_source[:].position (alpha) |  | STRUCTURE |  | Position of ring unit sources inside ITER vacuum vessel
neutron_diagnostic.unit_source[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.unit_source[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.unit_source[:].radiation (alpha) | [1...2] | STRUCT_ARRAY |  | Radiation type on detector's converter (1 - 'neutrons'; 2 - 'gamma-rays')
neutron_diagnostic.unit_source[:].radiation[:].index (alpha) |  | INT_0D |  | Index of radiation type. TO BE REMOVED, since it is given by the index of the radiation array above.
neutron_diagnostic.unit_source[:].radiation[:].reaction (alpha) | [1...2] | STRUCT_ARRAY |  | Plasma reaction (1 - 'DT'; 2 - 'DD')
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].d2flux_drdz (alpha) | [neutron_diagnostic.detectors, neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy] | FLT_2D (uncertain) | m^-4 | Second deriviation of Radiation flux from Unit Ring Source in recent detector's converter for "spline" reconstruction
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy (alpha) | [1...N] | FLT_1D (uncertain) | eV | Energy boundaries for Detector Radiator Flux
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].flux (alpha) | [neutron_diagnostic.detectors, neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy] | FLT_2D (uncertain) | m^-2 | Radiation flux from Unit Ring Source in recent detector's converter
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].index (alpha) |  | INT_0D |  | Index of plasma reaction type. To be removed, since it is given by the index of the reaction array above.
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].reaction_rate (alpha) | [neutron_diagnostic.detectors, neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy] | FLT_2D (uncertain) | m^-3 | Reaction Rate on converter's material from Unit Ring Source in recent detector's converter
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].sensitivity (alpha) | [neutron_diagnostic.detectors, neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy] | FLT_2D (uncertain) | cps.m^2.s | Sensitivity of converter's material in recent detector's converter

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ntms (alpha) |  |  |  | Description of neoclassical tearing modes
ntms.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ntms.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ntms.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
ntms.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
ntms.code.library[:].name (alpha) |  | STR_0D |  | Name of software
ntms.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ntms.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
ntms.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
ntms.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ntms.code.output_flag (alpha) | [ntms.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ntms.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ntms.code.repository (alpha) |  | STR_0D |  | URL of software repository
ntms.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ntms.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ntms.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ntms.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
ntms.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
ntms.ids_properties.occurrence |  | INT_0D |  |
ntms.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
ntms.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
ntms.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
ntms.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
ntms.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
ntms.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
ntms.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
ntms.time_slice (alpha) | [ntms.time_slice[:].time] | STRUCT_ARRAY |  | Description of neoclassical tearing modes for various time slices
ntms.time_slice[:].mode (alpha) | [1...N] | STRUCT_ARRAY |  | List of the various NTM modes appearing during the simulation. If a mode appears several times, use several indices in this array of structure with the same m,n values.
ntms.time_slice[:].mode[:].calculation_method (alpha) |  | STR_0D |  | Description of how the mode evolution is calculated
ntms.time_slice[:].mode[:].delta_diff (alpha) | [1...3] | FLT_1D (uncertain) | m^2.s^-1 | Extra diffusion coefficient for the transport equations of Te, ne, Ti
ntms.time_slice[:].mode[:].deltaw (alpha) | [1...N] | STRUCT_ARRAY |  | deltaw contributions to the Rutherford equation
ntms.time_slice[:].mode[:].deltaw[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].deltaw[:].value (alpha) |  | FLT_0D (uncertain) | m^-1 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution (alpha) |  | STRUCTURE |  | Detailed NTM evolution on a finer timebase than the time_slice array of structure
ntms.time_slice[:].mode[:].detailed_evolution.calculation_method (alpha) |  | STR_0D |  | Description of how the mode evolution is calculated
ntms.time_slice[:].mode[:].detailed_evolution.delta_diff (alpha) | [1...3, ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_2D (uncertain) | m^2.s^-1 | Extra diffusion coefficient for the transport equations of Te, ne, Ti
ntms.time_slice[:].mode[:].detailed_evolution.deltaw (alpha) | [1...N] | STRUCT_ARRAY |  | deltaw contributions to the Rutherford equation
ntms.time_slice[:].mode[:].detailed_evolution.deltaw[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.deltaw[:].value (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m^-1 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.dfrequency_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | s^-2 | Time derivative of the frequency of the mode
ntms.time_slice[:].mode[:].detailed_evolution.dphase_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | rad/s | Time derivative of the phase of the mode
ntms.time_slice[:].mode[:].detailed_evolution.dwidth_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m/s | Time derivative of the full width of the mode
ntms.time_slice[:].mode[:].detailed_evolution.frequency (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | Hz | Frequency of the mode
ntms.time_slice[:].mode[:].detailed_evolution.m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].detailed_evolution.n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].detailed_evolution.phase (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | rad | Phase of the mode
ntms.time_slice[:].mode[:].detailed_evolution.rho_tor (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m | Flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].detailed_evolution.rho_tor_norm (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | - | Normalised flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].detailed_evolution.time_detailed (alpha) | [1...N] | FLT_1D (uncertain) | s | Time array used to describe the detailed evolution of the NTM
ntms.time_slice[:].mode[:].detailed_evolution.torque (alpha) | [1...N] | STRUCT_ARRAY |  | torque contributions to the Rutherford equation
ntms.time_slice[:].mode[:].detailed_evolution.torque[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.torque[:].value (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | kg.m^2.s^-2 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.width (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m | Full width of the mode
ntms.time_slice[:].mode[:].dfrequency_dt (alpha) |  | FLT_0D (uncertain) | s^-2 | Time derivative of the frequency of the mode
ntms.time_slice[:].mode[:].dphase_dt (alpha) |  | FLT_0D (uncertain) | rad/s | Time derivative of the phase of the mode
ntms.time_slice[:].mode[:].dwidth_dt (alpha) |  | FLT_0D (uncertain) | m/s | Time derivative of the full width of the mode
ntms.time_slice[:].mode[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency of the mode
ntms.time_slice[:].mode[:].m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].onset (alpha) |  | STRUCTURE |  | NTM onset characteristics
ntms.time_slice[:].mode[:].onset.cause (alpha) |  | STR_0D |  | Cause of the mode onset
ntms.time_slice[:].mode[:].onset.m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].onset.n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].onset.phase (alpha) |  | FLT_0D (uncertain) | rad | Phase of the mode at onset
ntms.time_slice[:].mode[:].onset.time_offset (alpha) |  | FLT_0D (uncertain) | s | Offset time (when a mode disappears). If the mode reappears later in the simulation, use another index of the mode array of structure
ntms.time_slice[:].mode[:].onset.time_onset (alpha) |  | FLT_0D (uncertain) | s | Onset time
ntms.time_slice[:].mode[:].onset.width (alpha) |  | FLT_0D (uncertain) | m | Seed island full width at onset time
ntms.time_slice[:].mode[:].phase (alpha) |  | FLT_0D (uncertain) | rad | Phase of the mode
ntms.time_slice[:].mode[:].rho_tor (alpha) |  | FLT_0D (uncertain) | m | Flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].torque (alpha) | [1...N] | STRUCT_ARRAY |  | torque contributions to the Rutherford equation
ntms.time_slice[:].mode[:].torque[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].torque[:].value (alpha) |  | FLT_0D (uncertain) | kg.m^2.s^-2 | Value of the contribution
ntms.time_slice[:].mode[:].width (alpha) |  | FLT_0D (uncertain) | m | Full width of the mode
ntms.time_slice[:].time (alpha) |  | FLT_0D | s | Time
ntms.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
ntms.vacuum_toroidal_field.b0 (alpha) | [ntms.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
ntms.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
numerics (alpha) |  |  |  | Numeric parameters passed as argument to a component or a workflow. Most quantities are dynamic in this IDS in order to record the history of the numerics parameters at each execution of the component or workflow (so one time index = one execution of the component). Provide as input to the component a single time slice from this IDS containing the relevant parameters.
numerics.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
numerics.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
numerics.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
numerics.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
numerics.ids_properties.occurrence |  | INT_0D |  |
numerics.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
numerics.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
numerics.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
numerics.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
numerics.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
numerics.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
numerics.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
numerics.time_end (alpha) | [numerics.time] | FLT_1D (uncertain) | s | End time
numerics.time_start (alpha) | [numerics.time] | FLT_1D (uncertain) | s | Start time
numerics.time_step (alpha) | [numerics.time] | FLT_1D (uncertain) | s | Time interval between main steps (if relevant and constant during one execution of the component)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pellets (alpha) |  |  |  | Description of pellets launched into the plasma
pellets.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pellets.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pellets.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
pellets.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
pellets.code.library[:].name (alpha) |  | STR_0D |  | Name of software
pellets.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pellets.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
pellets.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
pellets.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pellets.code.output_flag (alpha) | [pellets.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pellets.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pellets.code.repository (alpha) |  | STR_0D |  | URL of software repository
pellets.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pellets.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pellets.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pellets.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
pellets.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
pellets.ids_properties.occurrence |  | INT_0D |  |
pellets.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
pellets.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
pellets.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
pellets.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
pellets.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
pellets.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
pellets.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
pellets.time_slice (alpha) | [pellets.time_slice[:].time] | STRUCT_ARRAY |  | Description of the pellets launched at various time slices. The time of this structure corresponds to the full ablation of the pellet inside the plasma.
pellets.time_slice[:].pellet (alpha) | [1...N] | STRUCT_ARRAY |  | Set of pellets ablated in the plasma at a given time
pellets.time_slice[:].pellet[:].path_geometry (alpha) |  | STRUCTURE |  | Geometry of the pellet path in the vaccuum chamber
pellets.time_slice[:].pellet[:].path_geometry.first_point (alpha) |  | STRUCTURE |  | Position of the first point
pellets.time_slice[:].pellet[:].path_geometry.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
pellets.time_slice[:].pellet[:].path_geometry.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_geometry.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_geometry.second_point (alpha) |  | STRUCTURE |  | Position of the second point
pellets.time_slice[:].pellet[:].path_geometry.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
pellets.time_slice[:].pellet[:].path_geometry.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_geometry.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_profiles (alpha) |  | STRUCTURE |  | 1-D profiles of plasma and pellet along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.ablated_particles (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Number of ablated particles (electrons) along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.ablation_rate (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | s^-1 | Ablation rate (electrons) along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.distance (alpha) | [1...N] | FLT_1D (uncertain) | m | Distance along the pellet path, with the origin taken at path_geometry/first_point. Used as the main coordinate for the path_profiles structure
pellets.time_slice[:].pellet[:].path_profiles.n_e (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | m^-3 | Electron density along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.position (alpha) |  | STRUCTURE |  | Position along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.position.phi (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.position.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
pellets.time_slice[:].pellet[:].path_profiles.position.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_profiles.position.z (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.position.r] | FLT_1D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_profiles.psi (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | Wb | Poloidal flux along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.rho_tor_norm (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Normalised toroidal coordinate along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.rho_tor_norm_drift (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Difference to due ExB drifts between the ablation and the final deposition locations, in terms of the normalised toroidal flux coordinate
pellets.time_slice[:].pellet[:].path_profiles.t_e (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | eV | Electron temperature along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.velocity (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | m.s^-1 | Pellet velocity along the pellet path
pellets.time_slice[:].pellet[:].shape (alpha) |  | STRUCTURE |  | Initial shape of a pellet at launch
pellets.time_slice[:].pellet[:].shape.size (alpha) | [1...N] | FLT_1D (uncertain) | m | Size of the pellet in the various dimensions, depending on the shape type. Spherical pellets: size(1) is the radius of the pellet. Cylindrical pellets: size(1) is the radius and size(2) is the height of the cylinder. Rectangular pellets: size(1) is the height, size(2) is the width and size(3) is the length
pellets.time_slice[:].pellet[:].shape.type (alpha) |  | STRUCTURE |  | Identifier structure for the shape type: 1-spherical; 2-cylindrical; 3-rectangular
pellets.time_slice[:].pellet[:].shape.type.description (alpha) |  | STR_0D |  | Verbose description
pellets.time_slice[:].pellet[:].shape.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pellets.time_slice[:].pellet[:].shape.type.name (alpha) |  | STR_0D |  | Short string identifier
pellets.time_slice[:].pellet[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Set of species included in the pellet composition
pellets.time_slice[:].pellet[:].species[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pellets.time_slice[:].pellet[:].species[:].density (alpha) |  | FLT_0D (uncertain) | - | Material density of the species in the pellet
pellets.time_slice[:].pellet[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Fraction of the species atoms in the pellet
pellets.time_slice[:].pellet[:].species[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, T, ...)
pellets.time_slice[:].pellet[:].species[:].sublimation_energy (alpha) |  | FLT_0D (uncertain) | eV | Sublimation energy per atom
pellets.time_slice[:].pellet[:].species[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pellets.time_slice[:].pellet[:].velocity_initial (alpha) |  | FLT_0D (uncertain) | m.s^-1 | Initial velocity of the pellet as it enters the vaccum chamber
pellets.time_slice[:].time (alpha) |  | FLT_0D | s | Time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pf_active (alpha) |  |  |  | Description of the axisymmetric active poloidal field (PF) coils and supplies; includes the limits of these systems; includes the forces on them; does not include non-axisymmetric coil systems
pf_active.circuit (alpha) | [1...N] | STRUCT_ARRAY |  | Circuits, connecting multiple PF coils to multiple supplies, defining the current and voltage relationships in the system
pf_active.circuit[:].connections (alpha) | [1...N, 1...N] | INT_2D |  | Description of the supplies and coils connections (nodes) across the circuit. Nodes of the circuit are listed as the first dimension of the matrix. Supplies (listed first) and coils (listed second) SIDES are listed as the second dimension. Thus the second dimension has a size equal to 2*(N_supplies+N_coils). N_supplies (resp. N_coils) is the total number of supplies (resp. coils) listed in the supply (resp.coil) array of structure, i.e. including also supplies/coils that are not part of the actual circuit. The (i,j) matrix elements are 1 if the j-th supply or coil side is connected to the i-th node, or 0 otherwise. For coils, sides are listed so that a current flowing from side 1 to side 2 (inside the coil) is positive (i.e. counter-clockwise when seen from above).
pf_active.circuit[:].current (alpha) |  | STRUCTURE | A | Current in the circuit between the sides of the group of supplies (only for circuits with a single supply or in which supplies are grouped)
pf_active.circuit[:].current.data (alpha) | [pf_active.circuit[:].current.time] | FLT_1D (uncertain) | A | Data
pf_active.circuit[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.circuit[:].identifier (alpha) |  | STR_0D |  | ID of the circuit
pf_active.circuit[:].name (alpha) |  | STR_0D |  | Name of the circuit
pf_active.circuit[:].type (alpha) |  | STR_0D |  | Type of the circuit
pf_active.circuit[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the circuit between the sides of the group of supplies (only for circuits with a single supply or in which supplies are grouped)
pf_active.circuit[:].voltage.data (alpha) | [pf_active.circuit[:].voltage.time] | FLT_1D (uncertain) | V | Data
pf_active.circuit[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pf_active.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_active.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
pf_active.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_active.code.library[:].name (alpha) |  | STR_0D |  | Name of software
pf_active.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_active.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
pf_active.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_active.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pf_active.code.output_flag (alpha) | [pf_active.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pf_active.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_active.code.repository (alpha) |  | STR_0D |  | URL of software repository
pf_active.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_active.coil (alpha) | [1...N] | STRUCT_ARRAY |  | Active PF coils
pf_active.coil[:].b_field_max (alpha) | [1...N] | FLT_1D (uncertain) | T | List of values of the maximum magnetic field on the conductor surface (coordinate for current_limit_max)
pf_active.coil[:].b_field_max_timed (alpha) |  | STRUCTURE | T | Maximum absolute value of the magnetic field on the conductor surface
pf_active.coil[:].b_field_max_timed.data (alpha) | [pf_active.coil[:].b_field_max_timed.time] | FLT_1D (uncertain) | T | Data
pf_active.coil[:].b_field_max_timed.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.coil[:].current (alpha) |  | STRUCTURE | A | Current in the coil, positive when counter-clockwise when seen from above
pf_active.coil[:].current.data (alpha) | [pf_active.coil[:].current.time] | FLT_1D (uncertain) | A | Data
pf_active.coil[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.coil[:].current_limit_max (alpha) | [pf_active.coil[:].b_field_max, pf_active.coil[:].temperature] | FLT_2D (uncertain) | A | Maximum tolerable current in the conductor
pf_active.coil[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Each PF coil is comprised of a number of cross-section elements described individually
pf_active.coil[:].element[:].area (alpha) |  | FLT_0D (uncertain) | m^2 | Cross-sectional areas of the element
pf_active.coil[:].element[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the element
pf_active.coil[:].element[:].geometry.arcs_of_circle (alpha) |  | STRUCTURE |  | Description of the element contour by a set of arcs of circle. For each of these, the position of the start point is given together with the curvature radius. The end point is given by the start point of the next arc of circle.
pf_active.coil[:].element[:].geometry.arcs_of_circle.curvature_radii (alpha) | [pf_active.coil[:].element[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Curvature radius of each arc of circle
pf_active.coil[:].element[:].geometry.arcs_of_circle.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii of the start point of each arc of circle
pf_active.coil[:].element[:].geometry.arcs_of_circle.z (alpha) | [pf_active.coil[:].element[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Height of the start point of each arc of circle
pf_active.coil[:].element[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique', 4:'arcs of circle')
pf_active.coil[:].element[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
pf_active.coil[:].element[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
pf_active.coil[:].element[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
pf_active.coil[:].element[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
pf_active.coil[:].element[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_active.coil[:].element[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
pf_active.coil[:].element[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_active.coil[:].element[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element. Do NOT repeat the first point.
pf_active.coil[:].element[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pf_active.coil[:].element[:].geometry.outline.z (alpha) | [pf_active.coil[:].element[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
pf_active.coil[:].element[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
pf_active.coil[:].element[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
pf_active.coil[:].element[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_active.coil[:].element[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
pf_active.coil[:].element[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_active.coil[:].element[:].identifier (alpha) |  | STR_0D |  | Identifier of this element
pf_active.coil[:].element[:].name (alpha) |  | STR_0D |  | Name of this element
pf_active.coil[:].element[:].turns_with_sign (alpha) |  | FLT_0D (uncertain) | - | Number of effective turns in the element for calculating magnetic fields of the coil/loop; includes the sign of the number of turns (positive means current is counter-clockwise when seen from above)
pf_active.coil[:].energy_limit_max (alpha) |  | FLT_0D (uncertain) | J | Maximum Energy to be dissipated in the coil
pf_active.coil[:].identifier (alpha) |  | STR_0D |  | Alphanumeric identifier of coils used for convenience
pf_active.coil[:].name (alpha) |  | STR_0D |  | Name of the coil
pf_active.coil[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Coil resistance
pf_active.coil[:].temperature (alpha) | [1...N] | FLT_1D (uncertain) | K | List of values of the conductor temperature (coordinate for current_limit_max)
pf_active.coil[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the coil terminals (Vside1-Vside2)
pf_active.coil[:].voltage.data (alpha) | [pf_active.coil[:].voltage.time] | FLT_1D (uncertain) | V | Data
pf_active.coil[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pf_active.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pf_active.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
pf_active.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
pf_active.ids_properties.occurrence |  | INT_0D |  |
pf_active.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
pf_active.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
pf_active.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
pf_active.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
pf_active.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
pf_active.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
pf_active.radial_force (alpha) | [1...N] | STRUCT_ARRAY |  | Radial forces on the axisymmetric PF coil system
pf_active.radial_force[:].combination (alpha) | [1...N] | FLT_1D (uncertain) | - | Coils involved in the force combinations. Normally the force would be the full set of coils, but in some cases, we want to have a difference in forces, such as a CS coil separation force. We therefore give each coil a force weight which we call the combination
pf_active.radial_force[:].force (alpha) |  | STRUCTURE | N | Force (positive when upwards for a vertical force, positive when outwards for a radial force)
pf_active.radial_force[:].force.data (alpha) | [pf_active.radial_force[:].force.time] | FLT_1D (uncertain) | N | Data
pf_active.radial_force[:].force.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.radial_force[:].limit_max (alpha) |  | FLT_0D (uncertain) | N | Maximum force combination limit
pf_active.radial_force[:].limit_min (alpha) |  | FLT_0D (uncertain) | N | Minimum force combination limit
pf_active.radial_force[:].name (alpha) |  | STR_0D |  | Name of the force combination
pf_active.supply (alpha) | [1...N] | STRUCT_ARRAY |  | PF power supplies
pf_active.supply[:].current (alpha) |  | STRUCTURE | A | Current at the supply output, defined positive if it flows from point 1 to point 2 in the circuit connected to the supply (outside the supply)
pf_active.supply[:].current.data (alpha) | [pf_active.supply[:].current.time] | FLT_1D (uncertain) | A | Data
pf_active.supply[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.supply[:].current_limit_max (alpha) |  | FLT_0D (uncertain) | A | Maximum current in the supply
pf_active.supply[:].current_limit_min (alpha) |  | FLT_0D (uncertain) | A | Minimum current in the supply
pf_active.supply[:].current_limiter_gain (alpha) |  | FLT_0D (uncertain) | V | Gain to prevent overcurrent in a linear model of the supply
pf_active.supply[:].delay (alpha) |  | FLT_0D (uncertain) | s | Pure delay in the supply
pf_active.supply[:].energy_limit_max (alpha) |  | FLT_0D (uncertain) | J | Maximum energy to be dissipated in the supply during a pulse
pf_active.supply[:].filter_denominator (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Coefficients of the denominator, in increasing order : b0 + b1*s + ... + bm*s^m; used for a linear supply description
pf_active.supply[:].filter_numerator (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Coefficients of the numerator, in increasing order : a0 + a1*s + ... + an*s^n; used for a linear supply description
pf_active.supply[:].identifier (alpha) |  | STR_0D |  | Identifier of the supply
pf_active.supply[:].name (alpha) |  | STR_0D |  | Name of the PF supply
pf_active.supply[:].nonlinear_model (alpha) |  | STR_0D |  | Description of the nonlinear transfer function of the supply
pf_active.supply[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Power supply internal resistance
pf_active.supply[:].type (alpha) |  | INT_0D |  | Type of the supply; TBD add free description of non-linear power supplies
pf_active.supply[:].voltage (alpha) |  | STRUCTURE | V | Voltage at the supply output (Vside1-Vside2)
pf_active.supply[:].voltage.data (alpha) | [pf_active.supply[:].voltage.time] | FLT_1D (uncertain) | V | Data
pf_active.supply[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.supply[:].voltage_limit_max (alpha) |  | FLT_0D (uncertain) | V | Maximum voltage from the supply
pf_active.supply[:].voltage_limit_min (alpha) |  | FLT_0D (uncertain) | V | Minimum voltage from the supply
pf_active.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
pf_active.vertical_force (alpha) | [1...N] | STRUCT_ARRAY |  | Vertical forces on the axisymmetric PF coil system
pf_active.vertical_force[:].combination (alpha) | [1...N] | FLT_1D (uncertain) | - | Coils involved in the force combinations. Normally the force would be the full set of coils, but in some cases, we want to have a difference in forces, such as a CS coil separation force. We therefore give each coil a force weight which we call the combination
pf_active.vertical_force[:].force (alpha) |  | STRUCTURE | N | Force (positive when upwards for a vertical force, positive when outwards for a radial force)
pf_active.vertical_force[:].force.data (alpha) | [pf_active.vertical_force[:].force.time] | FLT_1D (uncertain) | N | Data
pf_active.vertical_force[:].force.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pf_active.vertical_force[:].limit_max (alpha) |  | FLT_0D (uncertain) | N | Maximum force combination limit
pf_active.vertical_force[:].limit_min (alpha) |  | FLT_0D (uncertain) | N | Minimum force combination limit
pf_active.vertical_force[:].name (alpha) |  | STR_0D |  | Name of the force combination

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pf_passive (alpha) |  |  |  | Description of the axisymmetric passive conductors, currents flowing in them
pf_passive.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pf_passive.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_passive.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
pf_passive.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_passive.code.library[:].name (alpha) |  | STR_0D |  | Name of software
pf_passive.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_passive.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
pf_passive.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_passive.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pf_passive.code.output_flag (alpha) | [pf_passive.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pf_passive.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_passive.code.repository (alpha) |  | STR_0D |  | URL of software repository
pf_passive.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_passive.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pf_passive.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pf_passive.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
pf_passive.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
pf_passive.ids_properties.occurrence |  | INT_0D |  |
pf_passive.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
pf_passive.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
pf_passive.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
pf_passive.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
pf_passive.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
pf_passive.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
pf_passive.loop (alpha) | [1...N] | STRUCT_ARRAY |  | Passive axisymmetric conductor description in the form of non-connected loops; any connected loops are expressed as active coil circuits with no power supply attached.
pf_passive.loop[:].current (alpha) | [pf_passive.loop[:].time] | FLT_1D (uncertain) | A | Passive loop current
pf_passive.loop[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Each loop is comprised of a number of cross-section elements described individually
pf_passive.loop[:].element[:].area (alpha) |  | FLT_0D (uncertain) | m^2 | Cross-sectional areas of the element
pf_passive.loop[:].element[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the element
pf_passive.loop[:].element[:].geometry.arcs_of_circle (alpha) |  | STRUCTURE |  | Description of the element contour by a set of arcs of circle. For each of these, the position of the start point is given together with the curvature radius. The end point is given by the start point of the next arc of circle.
pf_passive.loop[:].element[:].geometry.arcs_of_circle.curvature_radii (alpha) | [pf_passive.loop[:].element[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Curvature radius of each arc of circle
pf_passive.loop[:].element[:].geometry.arcs_of_circle.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii of the start point of each arc of circle
pf_passive.loop[:].element[:].geometry.arcs_of_circle.z (alpha) | [pf_passive.loop[:].element[:].geometry.arcs_of_circle.r] | FLT_1D (uncertain) | m | Height of the start point of each arc of circle
pf_passive.loop[:].element[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique', 4:'arcs of circle')
pf_passive.loop[:].element[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
pf_passive.loop[:].element[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
pf_passive.loop[:].element[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
pf_passive.loop[:].element[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
pf_passive.loop[:].element[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_passive.loop[:].element[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
pf_passive.loop[:].element[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_passive.loop[:].element[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element. Do NOT repeat the first point.
pf_passive.loop[:].element[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pf_passive.loop[:].element[:].geometry.outline.z (alpha) | [pf_passive.loop[:].element[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
pf_passive.loop[:].element[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
pf_passive.loop[:].element[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
pf_passive.loop[:].element[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_passive.loop[:].element[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
pf_passive.loop[:].element[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_passive.loop[:].element[:].identifier (alpha) |  | STR_0D |  | Identifier of this element
pf_passive.loop[:].element[:].name (alpha) |  | STR_0D |  | Name of this element
pf_passive.loop[:].element[:].turns_with_sign (alpha) |  | FLT_0D (uncertain) | - | Number of effective turns in the element for calculating magnetic fields of the coil/loop; includes the sign of the number of turns (positive means current is counter-clockwise when seen from above)
pf_passive.loop[:].name (alpha) |  | STR_0D |  | Name of the loop
pf_passive.loop[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Passive loop resistance
pf_passive.loop[:].resistivity (alpha) |  | FLT_0D (uncertain) | Ohm.m | Passive loop resistivity
pf_passive.loop[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for the dynamic nodes of this loop located at this level of the IDS structure
pf_passive.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
polarimeter (alpha) |  |  |  | Polarimeter diagnostic
polarimeter.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
polarimeter.channel[:].ellipticity (alpha) |  | STRUCTURE | - | Ellipticity
polarimeter.channel[:].ellipticity.data (alpha) | [polarimeter.channel[:].ellipticity.time] | FLT_1D (uncertain) | - | Data
polarimeter.channel[:].ellipticity.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
polarimeter.channel[:].ellipticity.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
polarimeter.channel[:].ellipticity.validity_timed (alpha) | [polarimeter.channel[:].ellipticity.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
polarimeter.channel[:].ellipticity_initial (alpha) |  | FLT_0D (uncertain) | m | Initial ellipticity before entering the plasma
polarimeter.channel[:].faraday_angle (alpha) |  | STRUCTURE | rad | Faraday angle (variation of the Faraday angle induced by crossing the plasma)
polarimeter.channel[:].faraday_angle.data (alpha) | [polarimeter.channel[:].faraday_angle.time] | FLT_1D (uncertain) | rad | Data
polarimeter.channel[:].faraday_angle.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
polarimeter.channel[:].faraday_angle.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
polarimeter.channel[:].faraday_angle.validity_timed (alpha) | [polarimeter.channel[:].faraday_angle.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
polarimeter.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
polarimeter.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, defined by two points when the beam is not reflected, a third point is added to define the reflected beam path
polarimeter.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
polarimeter.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
polarimeter.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
polarimeter.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
polarimeter.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
polarimeter.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
polarimeter.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
polarimeter.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
polarimeter.channel[:].line_of_sight.third_point (alpha) |  | STRUCTURE |  | Position of the third point
polarimeter.channel[:].line_of_sight.third_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
polarimeter.channel[:].line_of_sight.third_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
polarimeter.channel[:].line_of_sight.third_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
polarimeter.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
polarimeter.channel[:].polarisation_initial (alpha) |  | FLT_0D (uncertain) | m | Initial polarisation vector before entering the plasma
polarimeter.channel[:].wavelength (alpha) |  | FLT_0D (uncertain) | m | Wavelength used for polarimetry
polarimeter.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
polarimeter.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
polarimeter.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
polarimeter.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
polarimeter.code.library[:].name (alpha) |  | STR_0D |  | Name of software
polarimeter.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
polarimeter.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
polarimeter.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
polarimeter.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
polarimeter.code.output_flag (alpha) | [polarimeter.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
polarimeter.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
polarimeter.code.repository (alpha) |  | STR_0D |  | URL of software repository
polarimeter.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
polarimeter.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
polarimeter.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
polarimeter.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
polarimeter.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
polarimeter.ids_properties.occurrence |  | INT_0D |  |
polarimeter.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
polarimeter.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
polarimeter.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
polarimeter.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
polarimeter.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
polarimeter.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
polarimeter.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pulse_schedule (alpha) |  |  |  | Description of Pulse Schedule, described by subsystems waveform references and an enveloppe around them. The controllers, pulse schedule and SDN are defined in separate IDSs. All names and identifiers of subsystems appearing in the pulse_schedule must be identical to those used in the IDSs describing the related subsystems.
pulse_schedule.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pulse_schedule.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pulse_schedule.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
pulse_schedule.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
pulse_schedule.code.library[:].name (alpha) |  | STR_0D |  | Name of software
pulse_schedule.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pulse_schedule.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
pulse_schedule.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
pulse_schedule.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pulse_schedule.code.output_flag (alpha) | [pulse_schedule.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pulse_schedule.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pulse_schedule.code.repository (alpha) |  | STR_0D |  | URL of software repository
pulse_schedule.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pulse_schedule.density_control (alpha) |  | STRUCTURE |  | Gas injection system and density control references
pulse_schedule.density_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.density_control.mode.data (alpha) | [pulse_schedule.density_control.mode.time] | INT_1D |  | Data
pulse_schedule.density_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.n_e_line (alpha) |  | STRUCTURE | m^-2 | Line integrated electron density
pulse_schedule.density_control.n_e_line.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_e_line.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.density_control.n_e_line.reference.data (alpha) | [pulse_schedule.density_control.n_e_line.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.density_control.n_e_line.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.n_e_line.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_e_line.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.n_h_over_n_d (alpha) |  | STRUCTURE | - | Average ratio of hydrogen over deuterium density
pulse_schedule.density_control.n_h_over_n_d.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_h_over_n_d.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.density_control.n_h_over_n_d.reference.data (alpha) | [pulse_schedule.density_control.n_h_over_n_d.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.density_control.n_h_over_n_d.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.n_h_over_n_d.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_h_over_n_d.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.n_t_over_n_d (alpha) |  | STRUCTURE | - | Average ratio of tritium over deuterium density
pulse_schedule.density_control.n_t_over_n_d.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_t_over_n_d.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.density_control.n_t_over_n_d.reference.data (alpha) | [pulse_schedule.density_control.n_t_over_n_d.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.density_control.n_t_over_n_d.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.n_t_over_n_d.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_t_over_n_d.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.valve (alpha) | [1...N] | STRUCT_ARRAY |  | Set of injection valves. Time-dependent
pulse_schedule.density_control.valve[:].flow_rate (alpha) |  | STRUCTURE | Pa.m^3.s^-1 | Flow rate of the valve
pulse_schedule.density_control.valve[:].flow_rate.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.valve[:].flow_rate.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.density_control.valve[:].flow_rate.reference.data (alpha) | [pulse_schedule.density_control.valve[:].flow_rate.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.density_control.valve[:].flow_rate.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.valve[:].flow_rate.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.valve[:].flow_rate.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.valve[:].identifier (alpha) |  | STR_0D |  | Identifier of the valve
pulse_schedule.density_control.valve[:].name (alpha) |  | STR_0D |  | Name of the valve
pulse_schedule.density_control.valve[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the valve (may be more than one in case the valve injects a gas mixture)
pulse_schedule.density_control.valve[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
pulse_schedule.density_control.valve[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pulse_schedule.density_control.valve[:].species[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
pulse_schedule.density_control.valve[:].species[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
pulse_schedule.density_control.valve[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pulse_schedule.density_control.valve[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Relative fraction of this species (in molecules) in the gas mixture
pulse_schedule.density_control.valve[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
pulse_schedule.density_control.zeff (alpha) |  | STRUCTURE | - | Line average effective charge
pulse_schedule.density_control.zeff.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.zeff.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.density_control.zeff.reference.data (alpha) | [pulse_schedule.density_control.zeff.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.density_control.zeff.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.density_control.zeff.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.zeff.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec (alpha) |  | STRUCTURE |  | Electron cyclotron heating and current drive system
pulse_schedule.ec.launcher (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ECRH launchers
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm (alpha) |  | STRUCTURE | - | Normalised toroidal flux coordinate at which the main deposition should occur
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference.data (alpha) | [pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.launcher[:].deposition_rho_tor_norm.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.launcher[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.ec.launcher[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.launcher[:].frequency.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ec.launcher[:].frequency.reference.data (alpha) | [pulse_schedule.ec.launcher[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ec.launcher[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ec.launcher[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.launcher[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.launcher[:].identifier (alpha) |  | STR_0D |  | Identifier of the launcher
pulse_schedule.ec.launcher[:].name (alpha) |  | STR_0D |  | Name of the launcher
pulse_schedule.ec.launcher[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.ec.launcher[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.launcher[:].power.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ec.launcher[:].power.reference.data (alpha) | [pulse_schedule.ec.launcher[:].power.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ec.launcher[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ec.launcher[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.launcher[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.launcher[:].power_type (alpha) |  | STRUCTURE |  | Type of power used in the sibling power node (defining which power is referred to in this pulse_schedule). Index = 1: power _launched, 2: power_forward
pulse_schedule.ec.launcher[:].power_type.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.ec.launcher[:].power_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.ec.launcher[:].power_type.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.ec.launcher[:].steering_angle_pol (alpha) |  | STRUCTURE | rad | Steering angle of the EC beam in the R,Z plane (from the -R axis towards the -Z axis), angle_pol=atan2(-k_Z,-k_R), where k_Z and k_R are the Z and R components of the mean wave vector in the EC beam
pulse_schedule.ec.launcher[:].steering_angle_pol.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.launcher[:].steering_angle_pol.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ec.launcher[:].steering_angle_pol.reference.data (alpha) | [pulse_schedule.ec.launcher[:].steering_angle_pol.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ec.launcher[:].steering_angle_pol.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ec.launcher[:].steering_angle_pol.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.launcher[:].steering_angle_pol.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.launcher[:].steering_angle_tor (alpha) |  | STRUCTURE | rad | Steering angle of the EC beam away from the poloidal plane that is increasing towards the positive phi axis, angle_tor=arcsin(k_phi/k), where k_phi is the component of the wave vector in the phi direction and k is the length of the wave vector. Here the term wave vector refers to the mean wave vector in the EC beam
pulse_schedule.ec.launcher[:].steering_angle_tor.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.launcher[:].steering_angle_tor.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ec.launcher[:].steering_angle_tor.reference.data (alpha) | [pulse_schedule.ec.launcher[:].steering_angle_tor.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ec.launcher[:].steering_angle_tor.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ec.launcher[:].steering_angle_tor.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.launcher[:].steering_angle_tor.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ec.mode.data (alpha) | [pulse_schedule.ec.mode.time] | INT_1D |  | Data
pulse_schedule.ec.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.event (alpha) | [1...N] | STRUCT_ARRAY |  | List of events, either predefined triggers or events recorded during the pulse
pulse_schedule.event[:].acquisition_state (alpha) |  | STRUCTURE |  | Acquisition state of the related system : index = 1 : armed; index = 2 : on; index = 3 : off; index = 4 : closed
pulse_schedule.event[:].acquisition_state.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.event[:].acquisition_state.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.event[:].acquisition_state.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.event[:].acquisition_strategy (alpha) |  | STRUCTURE |  | Acquisition strategy related to this event: index = 1 : on-trigger; index = 2 : pre-trigger; index = 3 : post-trigger
pulse_schedule.event[:].acquisition_strategy.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.event[:].acquisition_strategy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.event[:].acquisition_strategy.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.event[:].duration (alpha) |  | FLT_0D (uncertain) | s | Duration of this event
pulse_schedule.event[:].identifier (alpha) |  | STR_0D |  | Unique identifier of this event provided by the scheduling / event handler
pulse_schedule.event[:].listeners (alpha) | [1...N] | STR_1D |  | Systems listening to this event
pulse_schedule.event[:].provider (alpha) |  | STR_0D |  | System having generated this event
pulse_schedule.event[:].time_stamp (alpha) |  | FLT_0D (uncertain) | s | Time stamp of this event
pulse_schedule.event[:].type (alpha) |  | STRUCTURE |  | Type of this event
pulse_schedule.event[:].type.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.event[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.event[:].type.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.flux_control (alpha) |  | STRUCTURE |  | Magnetic flux control references
pulse_schedule.flux_control.beta_normal (alpha) |  | STRUCTURE | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
pulse_schedule.flux_control.beta_normal.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.beta_normal.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.flux_control.beta_normal.reference.data (alpha) | [pulse_schedule.flux_control.beta_normal.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.flux_control.beta_normal.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.flux_control.beta_normal.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.beta_normal.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.i_plasma (alpha) |  | STRUCTURE | A | Plasma current
pulse_schedule.flux_control.i_plasma.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.i_plasma.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.flux_control.i_plasma.reference.data (alpha) | [pulse_schedule.flux_control.i_plasma.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.flux_control.i_plasma.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.flux_control.i_plasma.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.i_plasma.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.li_3 (alpha) |  | STRUCTURE | - | Internal inductance
pulse_schedule.flux_control.li_3.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.li_3.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.flux_control.li_3.reference.data (alpha) | [pulse_schedule.flux_control.li_3.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.flux_control.li_3.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.flux_control.li_3.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.li_3.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.loop_voltage (alpha) |  | STRUCTURE | V | Loop voltage
pulse_schedule.flux_control.loop_voltage.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.loop_voltage.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.flux_control.loop_voltage.reference.data (alpha) | [pulse_schedule.flux_control.loop_voltage.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.flux_control.loop_voltage.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.flux_control.loop_voltage.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.loop_voltage.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.flux_control.mode.data (alpha) | [pulse_schedule.flux_control.mode.time] | INT_1D |  | Data
pulse_schedule.flux_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ic (alpha) |  | STRUCTURE |  | Ion cyclotron heating and current drive system
pulse_schedule.ic.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ICRH antennas
pulse_schedule.ic.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.ic.antenna[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].frequency.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ic.antenna[:].frequency.reference.data (alpha) | [pulse_schedule.ic.antenna[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ic.antenna[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ic.antenna[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.antenna[:].identifier (alpha) |  | STR_0D |  | Identifier of the antenna
pulse_schedule.ic.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna
pulse_schedule.ic.antenna[:].phase (alpha) |  | STRUCTURE | rad | Phase
pulse_schedule.ic.antenna[:].phase.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].phase.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ic.antenna[:].phase.reference.data (alpha) | [pulse_schedule.ic.antenna[:].phase.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ic.antenna[:].phase.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ic.antenna[:].phase.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].phase.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.antenna[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.ic.antenna[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].power.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.ic.antenna[:].power.reference.data (alpha) | [pulse_schedule.ic.antenna[:].power.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.ic.antenna[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ic.antenna[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.antenna[:].power_type (alpha) |  | STRUCTURE |  | Type of power used in the sibling power node (defining which power is referred to in this pulse_schedule). Index = 1: power _launched, 2: power_forward
pulse_schedule.ic.antenna[:].power_type.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.ic.antenna[:].power_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.ic.antenna[:].power_type.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.ic.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ic.mode.data (alpha) | [pulse_schedule.ic.mode.time] | INT_1D |  | Data
pulse_schedule.ic.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pulse_schedule.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pulse_schedule.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
pulse_schedule.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
pulse_schedule.ids_properties.occurrence |  | INT_0D |  |
pulse_schedule.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
pulse_schedule.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
pulse_schedule.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
pulse_schedule.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
pulse_schedule.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
pulse_schedule.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
pulse_schedule.lh (alpha) |  | STRUCTURE |  | Lower Hybrid heating and current drive system
pulse_schedule.lh.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of LH antennas
pulse_schedule.lh.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.lh.antenna[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].frequency.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.lh.antenna[:].frequency.reference.data (alpha) | [pulse_schedule.lh.antenna[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.lh.antenna[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.lh.antenna[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].identifier (alpha) |  | STR_0D |  | Identifier of the antenna
pulse_schedule.lh.antenna[:].n_parallel (alpha) |  | STRUCTURE | - | Main parallel refractive index of the injected wave power spectrum
pulse_schedule.lh.antenna[:].n_parallel.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].n_parallel.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.lh.antenna[:].n_parallel.reference.data (alpha) | [pulse_schedule.lh.antenna[:].n_parallel.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.lh.antenna[:].n_parallel.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.lh.antenna[:].n_parallel.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].n_parallel.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna
pulse_schedule.lh.antenna[:].phase (alpha) |  | STRUCTURE | rad | Phasing between neighbour waveguides (in the toroidal direction)
pulse_schedule.lh.antenna[:].phase.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].phase.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.lh.antenna[:].phase.reference.data (alpha) | [pulse_schedule.lh.antenna[:].phase.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.lh.antenna[:].phase.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.lh.antenna[:].phase.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].phase.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.lh.antenna[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].power.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.lh.antenna[:].power.reference.data (alpha) | [pulse_schedule.lh.antenna[:].power.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.lh.antenna[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.lh.antenna[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].power_type (alpha) |  | STRUCTURE |  | Type of power used in the sibling power node (defining which power is referred to in this pulse_schedule). Index = 1: power _launched, 2: power_forward
pulse_schedule.lh.antenna[:].power_type.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.lh.antenna[:].power_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.lh.antenna[:].power_type.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.lh.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.lh.mode.data (alpha) | [pulse_schedule.lh.mode.time] | INT_1D |  | Data
pulse_schedule.lh.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.nbi (alpha) |  | STRUCTURE |  | Neutral beam heating and current drive system
pulse_schedule.nbi.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.nbi.mode.data (alpha) | [pulse_schedule.nbi.mode.time] | INT_1D |  | Data
pulse_schedule.nbi.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.nbi.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of NBI units
pulse_schedule.nbi.unit[:].energy (alpha) |  | STRUCTURE | eV | Full energy of the injected species (acceleration of a single atom)
pulse_schedule.nbi.unit[:].energy.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.nbi.unit[:].energy.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.nbi.unit[:].energy.reference.data (alpha) | [pulse_schedule.nbi.unit[:].energy.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.nbi.unit[:].energy.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.nbi.unit[:].energy.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.nbi.unit[:].energy.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.nbi.unit[:].identifier (alpha) |  | STR_0D |  | Identifier of the NBI unit
pulse_schedule.nbi.unit[:].name (alpha) |  | STR_0D |  | Name of the NBI unit
pulse_schedule.nbi.unit[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.nbi.unit[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.nbi.unit[:].power.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.nbi.unit[:].power.reference.data (alpha) | [pulse_schedule.nbi.unit[:].power.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.nbi.unit[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.nbi.unit[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.nbi.unit[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.nbi.unit[:].power_type (alpha) |  | STRUCTURE |  | Type of power used in the sibling power node (defining which power is referred to in this pulse_schedule). Index = 1: power _launched, 2: power_forward
pulse_schedule.nbi.unit[:].power_type.description (alpha) |  | STR_0D |  | Verbose description
pulse_schedule.nbi.unit[:].power_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
pulse_schedule.nbi.unit[:].power_type.name (alpha) |  | STR_0D |  | Short string identifier
pulse_schedule.nbi.unit[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the NBI unit (may be more than one in case the unit injects a gas mixture)
pulse_schedule.nbi.unit[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
pulse_schedule.nbi.unit[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pulse_schedule.nbi.unit[:].species[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
pulse_schedule.nbi.unit[:].species[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
pulse_schedule.nbi.unit[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pulse_schedule.nbi.unit[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Relative fraction of this species (in molecules) in the gas mixture
pulse_schedule.nbi.unit[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
pulse_schedule.position_control (alpha) |  | STRUCTURE |  | Plasma position and shape control references
pulse_schedule.position_control.active_limiter_point (alpha) |  | STRUCTURE |  | RZ position of the active limiter point (point of the plasma boundary in contact with the limiter)
pulse_schedule.position_control.active_limiter_point.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.active_limiter_point.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.active_limiter_point.r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.active_limiter_point.r.reference.data (alpha) | [pulse_schedule.position_control.active_limiter_point.r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.active_limiter_point.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.active_limiter_point.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.active_limiter_point.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.active_limiter_point.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.active_limiter_point.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.active_limiter_point.z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.active_limiter_point.z.reference.data (alpha) | [pulse_schedule.position_control.active_limiter_point.z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.active_limiter_point.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.active_limiter_point.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.active_limiter_point.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.boundary_outline (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (R,Z) points defining the outline of the plasma boundary
pulse_schedule.position_control.boundary_outline[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.boundary_outline[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.boundary_outline[:].r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.boundary_outline[:].r.reference.data (alpha) | [pulse_schedule.position_control.boundary_outline[:].r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.boundary_outline[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.boundary_outline[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.boundary_outline[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.boundary_outline[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.boundary_outline[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.boundary_outline[:].z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.boundary_outline[:].z.reference.data (alpha) | [pulse_schedule.position_control.boundary_outline[:].z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.boundary_outline[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.boundary_outline[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.boundary_outline[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation (alpha) |  | STRUCTURE | - | Elongation of the plasma boundary
pulse_schedule.position_control.elongation.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.elongation.reference.data (alpha) | [pulse_schedule.position_control.elongation.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.elongation.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.elongation.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation_lower (alpha) |  | STRUCTURE | - | Elongation (lower half w.r.t. geometric axis) of the plasma boundary
pulse_schedule.position_control.elongation_lower.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation_lower.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.elongation_lower.reference.data (alpha) | [pulse_schedule.position_control.elongation_lower.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.elongation_lower.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.elongation_lower.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation_lower.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation_upper (alpha) |  | STRUCTURE | - | Elongation (upper half w.r.t. geometric axis) of the plasma boundary
pulse_schedule.position_control.elongation_upper.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation_upper.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.elongation_upper.reference.data (alpha) | [pulse_schedule.position_control.elongation_upper.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.elongation_upper.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.elongation_upper.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation_upper.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.gap (alpha) | [1...N] | STRUCT_ARRAY |  | Set of gaps, defined by a reference point and a direction.
pulse_schedule.position_control.gap[:].angle (alpha) |  | FLT_0D (uncertain) | rad | Angle between the direction in which the gap is measured (in the poloidal cross-section) and the horizontal axis.
pulse_schedule.position_control.gap[:].identifier (alpha) |  | STR_0D |  | Identifier of the gap
pulse_schedule.position_control.gap[:].name (alpha) |  | STR_0D |  | Name of the gap
pulse_schedule.position_control.gap[:].r (alpha) |  | FLT_0D (uncertain) | m | Major radius of the reference point
pulse_schedule.position_control.gap[:].value (alpha) |  | STRUCTURE | m | Value of the gap, i.e. distance between the reference point and the separatrix along the gap direction
pulse_schedule.position_control.gap[:].value.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.gap[:].value.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.gap[:].value.reference.data (alpha) | [pulse_schedule.position_control.gap[:].value.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.gap[:].value.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.gap[:].value.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.gap[:].value.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.gap[:].z (alpha) |  | FLT_0D (uncertain) | m | Height of the reference point
pulse_schedule.position_control.geometric_axis (alpha) |  | STRUCTURE |  | RZ position of the geometric axis (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the boundary)
pulse_schedule.position_control.geometric_axis.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.geometric_axis.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.geometric_axis.r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.geometric_axis.r.reference.data (alpha) | [pulse_schedule.position_control.geometric_axis.r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.geometric_axis.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.geometric_axis.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.geometric_axis.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.geometric_axis.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.geometric_axis.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.geometric_axis.z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.geometric_axis.z.reference.data (alpha) | [pulse_schedule.position_control.geometric_axis.z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.geometric_axis.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.geometric_axis.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.geometric_axis.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position
pulse_schedule.position_control.magnetic_axis.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.magnetic_axis.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.magnetic_axis.r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.magnetic_axis.r.reference.data (alpha) | [pulse_schedule.position_control.magnetic_axis.r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.magnetic_axis.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.magnetic_axis.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.magnetic_axis.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.magnetic_axis.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.magnetic_axis.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.magnetic_axis.z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.magnetic_axis.z.reference.data (alpha) | [pulse_schedule.position_control.magnetic_axis.z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.magnetic_axis.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.magnetic_axis.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.magnetic_axis.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.minor_radius (alpha) |  | STRUCTURE | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
pulse_schedule.position_control.minor_radius.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.minor_radius.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.minor_radius.reference.data (alpha) | [pulse_schedule.position_control.minor_radius.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.minor_radius.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.minor_radius.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.minor_radius.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.position_control.mode.data (alpha) | [pulse_schedule.position_control.mode.time] | INT_1D |  | Data
pulse_schedule.position_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.strike_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
pulse_schedule.position_control.strike_point[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.strike_point[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.strike_point[:].r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.strike_point[:].r.reference.data (alpha) | [pulse_schedule.position_control.strike_point[:].r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.strike_point[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.strike_point[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.strike_point[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.strike_point[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.strike_point[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.strike_point[:].z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.strike_point[:].z.reference.data (alpha) | [pulse_schedule.position_control.strike_point[:].z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.strike_point[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.strike_point[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.strike_point[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity (alpha) |  | STRUCTURE | - | Triangularity of the plasma boundary
pulse_schedule.position_control.triangularity.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.triangularity.reference.data (alpha) | [pulse_schedule.position_control.triangularity.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.triangularity.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.triangularity.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity_lower (alpha) |  | STRUCTURE | - | Lower triangularity of the plasma boundary
pulse_schedule.position_control.triangularity_lower.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity_lower.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.triangularity_lower.reference.data (alpha) | [pulse_schedule.position_control.triangularity_lower.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.triangularity_lower.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.triangularity_lower.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity_lower.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity_upper (alpha) |  | STRUCTURE | - | Upper triangularity of the plasma boundary
pulse_schedule.position_control.triangularity_upper.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity_upper.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.triangularity_upper.reference.data (alpha) | [pulse_schedule.position_control.triangularity_upper.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.triangularity_upper.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.triangularity_upper.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity_upper.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.x_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
pulse_schedule.position_control.x_point[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.x_point[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.x_point[:].r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.x_point[:].r.reference.data (alpha) | [pulse_schedule.position_control.x_point[:].r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.x_point[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.x_point[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.x_point[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.x_point[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.x_point[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.x_point[:].z.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.position_control.x_point[:].z.reference.data (alpha) | [pulse_schedule.position_control.x_point[:].z.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.position_control.x_point[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.position_control.x_point[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.x_point[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.tf (alpha) |  | STRUCTURE |  | Toroidal field references
pulse_schedule.tf.b_field_tor_vacuum_r (alpha) |  | STRUCTURE | T.m | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
pulse_schedule.tf.b_field_tor_vacuum_r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.tf.b_field_tor_vacuum_r.reference (alpha) |  | STRUCTURE | mixed | Reference waveform
pulse_schedule.tf.b_field_tor_vacuum_r.reference.data (alpha) | [pulse_schedule.tf.b_field_tor_vacuum_r.reference.time] | FLT_1D (uncertain) | mixed | Data
pulse_schedule.tf.b_field_tor_vacuum_r.reference.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.tf.b_field_tor_vacuum_r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.tf.b_field_tor_vacuum_r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.tf.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.tf.mode.data (alpha) | [pulse_schedule.tf.mode.time] | INT_1D |  | Data
pulse_schedule.tf.mode.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
pulse_schedule.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
radiation (alpha) |  |  |  | Radiation emitted by the plasma and neutrals
radiation.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
radiation.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
radiation.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
radiation.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
radiation.code.library[:].name (alpha) |  | STR_0D |  | Name of software
radiation.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
radiation.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
radiation.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
radiation.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
radiation.code.output_flag (alpha) | [radiation.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
radiation.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
radiation.code.repository (alpha) |  | STR_0D |  | URL of software repository
radiation.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
radiation.grid_ggd (alpha) | [radiation.grid_ggd[:].time] | STRUCT_ARRAY |  | Grid (using the Generic Grid Description), for various time slices. The timebase of this array of structure must be a subset of the process/ggd timebases
radiation.grid_ggd[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
radiation.grid_ggd[:].grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
radiation.grid_ggd[:].grid_subset[:].base[:].jacobian (alpha) | [radiation.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
radiation.grid_ggd[:].grid_subset[:].base[:].tensor_contravariant (alpha) | [radiation.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
radiation.grid_ggd[:].grid_subset[:].base[:].tensor_covariant (alpha) | [radiation.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
radiation.grid_ggd[:].grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
radiation.grid_ggd[:].grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
radiation.grid_ggd[:].grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
radiation.grid_ggd[:].grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
radiation.grid_ggd[:].grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
radiation.grid_ggd[:].grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
radiation.grid_ggd[:].grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
radiation.grid_ggd[:].grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
radiation.grid_ggd[:].grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.grid_ggd[:].grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
radiation.grid_ggd[:].grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
radiation.grid_ggd[:].grid_subset[:].metric.jacobian (alpha) | [radiation.grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
radiation.grid_ggd[:].grid_subset[:].metric.tensor_contravariant (alpha) | [radiation.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
radiation.grid_ggd[:].grid_subset[:].metric.tensor_covariant (alpha) | [radiation.grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
radiation.grid_ggd[:].identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
radiation.grid_ggd[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
radiation.grid_ggd[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.grid_ggd[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
radiation.grid_ggd[:].space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
radiation.grid_ggd[:].space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
radiation.grid_ggd[:].space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
radiation.grid_ggd[:].space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
radiation.grid_ggd[:].space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.grid_ggd[:].space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
radiation.grid_ggd[:].space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
radiation.grid_ggd[:].space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
radiation.grid_ggd[:].space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.grid_ggd[:].space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
radiation.grid_ggd[:].space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
radiation.grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
radiation.grid_ggd[:].time (alpha) |  | FLT_0D | s | Time
radiation.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
radiation.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
radiation.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
radiation.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
radiation.ids_properties.occurrence |  | INT_0D |  |
radiation.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
radiation.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
radiation.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
radiation.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
radiation.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
radiation.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
radiation.process (alpha) | [1...N] | STRUCT_ARRAY |  | Set of emission processes. The radiation characteristics are described at the level of the originating entity: 1/ line radiation from neutrals under neutral 2/ line and recombination radiation under ion 3/ bremsstrahlung radiation under neutral and ion 4/ possibly recombination and bremsstrahlung under ion
radiation.process[:].ggd (alpha) | [radiation.process[:].ggd[:].time] | STRUCT_ARRAY |  | Emissivities represented using the general grid description, for various time slices
radiation.process[:].ggd[:].electrons (alpha) |  | STRUCTURE |  | Process terms related to electrons
radiation.process[:].ggd[:].electrons.emissivity (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Emissivity from this species, on various grid subsets
radiation.process[:].ggd[:].electrons.emissivity[:].coefficients (alpha) | [radiation.process[:].ggd[:].electrons.emissivity[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
radiation.process[:].ggd[:].electrons.emissivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
radiation.process[:].ggd[:].electrons.emissivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
radiation.process[:].ggd[:].electrons.emissivity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
radiation.process[:].ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different ion species
radiation.process[:].ggd[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
radiation.process[:].ggd[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
radiation.process[:].ggd[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
radiation.process[:].ggd[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
radiation.process[:].ggd[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
radiation.process[:].ggd[:].ion[:].emissivity (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Emissivity from this species, on various grid subsets
radiation.process[:].ggd[:].ion[:].emissivity[:].coefficients (alpha) | [radiation.process[:].ggd[:].ion[:].emissivity[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
radiation.process[:].ggd[:].ion[:].emissivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
radiation.process[:].ggd[:].ion[:].emissivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
radiation.process[:].ggd[:].ion[:].emissivity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
radiation.process[:].ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
radiation.process[:].ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
radiation.process[:].ggd[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
radiation.process[:].ggd[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different charge states of the species (ionisation, energy, excitation, ...)
radiation.process[:].ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
radiation.process[:].ggd[:].ion[:].state[:].emissivity (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Emissivity from this state, on various grid subsets
radiation.process[:].ggd[:].ion[:].state[:].emissivity[:].coefficients (alpha) | [radiation.process[:].ggd[:].ion[:].state[:].emissivity[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
radiation.process[:].ggd[:].ion[:].state[:].emissivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
radiation.process[:].ggd[:].ion[:].state[:].emissivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
radiation.process[:].ggd[:].ion[:].state[:].emissivity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
radiation.process[:].ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
radiation.process[:].ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
radiation.process[:].ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
radiation.process[:].ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
radiation.process[:].ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
radiation.process[:].ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
radiation.process[:].ggd[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different neutral species
radiation.process[:].ggd[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
radiation.process[:].ggd[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
radiation.process[:].ggd[:].neutral[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
radiation.process[:].ggd[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
radiation.process[:].ggd[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
radiation.process[:].ggd[:].neutral[:].emissivity (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Emissivity from this species, on various grid subsets
radiation.process[:].ggd[:].neutral[:].emissivity[:].coefficients (alpha) | [radiation.process[:].ggd[:].neutral[:].emissivity[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
radiation.process[:].ggd[:].neutral[:].emissivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
radiation.process[:].ggd[:].neutral[:].emissivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
radiation.process[:].ggd[:].neutral[:].emissivity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
radiation.process[:].ggd[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
radiation.process[:].ggd[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying the neutral species (e.g. H, D, T, He, C, ...)
radiation.process[:].ggd[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
radiation.process[:].ggd[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different charge states of the species (energy, excitation, ...)
radiation.process[:].ggd[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
radiation.process[:].ggd[:].neutral[:].state[:].emissivity (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Emissivity from this state, on various grid subsets
radiation.process[:].ggd[:].neutral[:].state[:].emissivity[:].coefficients (alpha) | [radiation.process[:].ggd[:].neutral[:].state[:].emissivity[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
radiation.process[:].ggd[:].neutral[:].state[:].emissivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
radiation.process[:].ggd[:].neutral[:].state[:].emissivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
radiation.process[:].ggd[:].neutral[:].state[:].emissivity[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
radiation.process[:].ggd[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
radiation.process[:].ggd[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
radiation.process[:].ggd[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
radiation.process[:].ggd[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.process[:].ggd[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
radiation.process[:].ggd[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
radiation.process[:].ggd[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
radiation.process[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
radiation.process[:].global_quantities (alpha) | [radiation.process[:].global_quantities[:].time] | STRUCT_ARRAY |  | Scalar volume integrated quantities
radiation.process[:].global_quantities[:].inside_lcfs (alpha) |  | STRUCTURE |  | Emissions from the core plasma, inside the last closed flux surface
radiation.process[:].global_quantities[:].inside_lcfs.power (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all species
radiation.process[:].global_quantities[:].inside_lcfs.power_electrons (alpha) |  | FLT_0D (uncertain) | W | Power emitted by electrons
radiation.process[:].global_quantities[:].inside_lcfs.power_ion_total (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all ion species
radiation.process[:].global_quantities[:].inside_lcfs.power_neutral_total (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all neutral species
radiation.process[:].global_quantities[:].inside_vessel (alpha) |  | STRUCTURE |  | Total emissions inside the vacuum vessel
radiation.process[:].global_quantities[:].inside_vessel.power (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all species
radiation.process[:].global_quantities[:].inside_vessel.power_electrons (alpha) |  | FLT_0D (uncertain) | W | Power emitted by electrons
radiation.process[:].global_quantities[:].inside_vessel.power_ion_total (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all ion species
radiation.process[:].global_quantities[:].inside_vessel.power_neutral_total (alpha) |  | FLT_0D (uncertain) | W | Total power emitted by all neutral species
radiation.process[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
radiation.process[:].identifier (alpha) |  | STRUCTURE |  | Process identifier 0) unspecified : Unspecified emission process 6) nuclear_decay : Emission from nuclear decay 8) bremsstrahlung : Emission from bremsstrahlung 9) synchrotron_radiation : Emission from synchrotron radiation 10) line_radiation : Emission from line radiation 11) recombination : Emission from recombination 501) runaways : Emission from run-away processes; includes both electron and ion run-away 901) custom_1 : Custom emission 1; content to be decided by data provided 902) custom_2 : Custom emission 2; content to be decided by data provided 903) custom_3 : Custom emission 3; content to be decided by data provided 904) custom_4 : Custom emission 4; content to be decided by data provided 905) custom_5 : Custom emission 5; content to be decided by data provided 906) custom_6 : Custom emission 6; content to be decided by data provided 907) custom_7 : Custom emission 7; content to be decided by data provided 908) custom_8 : Custom emission 8; content to be decided by data provided 909) custom_9 : Custom emission 9; content to be decided by data provided
radiation.process[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
radiation.process[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.process[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
radiation.process[:].profiles_1d (alpha) | [radiation.process[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Emissivity radial profiles for various time slices
radiation.process[:].profiles_1d[:].electrons (alpha) |  | STRUCTURE |  | Processs terms related to electrons
radiation.process[:].profiles_1d[:].electrons.emissivity (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity from this species
radiation.process[:].profiles_1d[:].electrons.power_inside (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Radiated power from inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].emissivity_ion_total (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity (summed over ion species)
radiation.process[:].profiles_1d[:].emissivity_neutral_total (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity (summed over neutral species)
radiation.process[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
radiation.process[:].profiles_1d[:].grid.area (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
radiation.process[:].profiles_1d[:].grid.psi (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
radiation.process[:].profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
radiation.process[:].profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
radiation.process[:].profiles_1d[:].grid.rho_pol_norm (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
radiation.process[:].profiles_1d[:].grid.rho_tor (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
radiation.process[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
radiation.process[:].profiles_1d[:].grid.surface (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
radiation.process[:].profiles_1d[:].grid.volume (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
radiation.process[:].profiles_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different ion species
radiation.process[:].profiles_1d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
radiation.process[:].profiles_1d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
radiation.process[:].profiles_1d[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
radiation.process[:].profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
radiation.process[:].profiles_1d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
radiation.process[:].profiles_1d[:].ion[:].emissivity (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity from this species
radiation.process[:].profiles_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
radiation.process[:].profiles_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
radiation.process[:].profiles_1d[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
radiation.process[:].profiles_1d[:].ion[:].power_inside (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Radiated power from inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different charge states of the species (ionisation, energy, excitation, ...)
radiation.process[:].profiles_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
radiation.process[:].profiles_1d[:].ion[:].state[:].emissivity (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity from this species
radiation.process[:].profiles_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
radiation.process[:].profiles_1d[:].ion[:].state[:].power_inside (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Radiated power from inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
radiation.process[:].profiles_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
radiation.process[:].profiles_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
radiation.process[:].profiles_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
radiation.process[:].profiles_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
radiation.process[:].profiles_1d[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different neutral species
radiation.process[:].profiles_1d[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
radiation.process[:].profiles_1d[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
radiation.process[:].profiles_1d[:].neutral[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
radiation.process[:].profiles_1d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
radiation.process[:].profiles_1d[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
radiation.process[:].profiles_1d[:].neutral[:].emissivity (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity from this species
radiation.process[:].profiles_1d[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
radiation.process[:].profiles_1d[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying the neutral species (e.g. H, D, T, He, C, ...)
radiation.process[:].profiles_1d[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
radiation.process[:].profiles_1d[:].neutral[:].power_inside (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Radiated power from inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Process terms related to the different charge states of the species (energy, excitation, ...)
radiation.process[:].profiles_1d[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
radiation.process[:].profiles_1d[:].neutral[:].state[:].emissivity (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Emissivity from this species
radiation.process[:].profiles_1d[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
radiation.process[:].profiles_1d[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI 1) cold : Cold neutrals 2) thermal : Thermal neutrals 3) fast : Fast neutrals 4) nbi : NBI neutrals
radiation.process[:].profiles_1d[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
radiation.process[:].profiles_1d[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
radiation.process[:].profiles_1d[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
radiation.process[:].profiles_1d[:].neutral[:].state[:].power_inside (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Radiated power from inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
radiation.process[:].profiles_1d[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
radiation.process[:].profiles_1d[:].power_inside_ion_total (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total power from ion species (summed over ion species) inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].power_inside_neutral_total (alpha) | [radiation.process[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total power from ion species (summed over neutral species) inside the flux surface (volume integral of the emissivity inside the flux surface)
radiation.process[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
radiation.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
radiation.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
radiation.vacuum_toroidal_field.b0 (alpha) | [radiation.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
radiation.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
reflectometer_profile (alpha) |  |  |  | Profile reflectometer diagnostic. Multiple reflectometers are considered as independent diagnostics to be handled with different occurrence numbers
reflectometer_profile.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels, e.g. different reception antennas or frequency bandwidths of the reflectometer
reflectometer_profile.channel[:].frequencies (alpha) | [1...N] | FLT_1D (uncertain) | Hz | Array of frequencies scanned during a sweep
reflectometer_profile.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
reflectometer_profile.channel[:].line_of_sight_detection (alpha) |  | STRUCTURE |  | Description of the line of sight of the detection antenna, to be filled only if its position is distinct from the emission antenna. The first point corresponds to the antenna mouth. The second point correspond to the interception of the line of sight with the reflection surface on the inner wall.
reflectometer_profile.channel[:].line_of_sight_detection.first_point (alpha) |  | STRUCTURE |  | Position of the first point
reflectometer_profile.channel[:].line_of_sight_detection.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
reflectometer_profile.channel[:].line_of_sight_detection.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
reflectometer_profile.channel[:].line_of_sight_detection.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
reflectometer_profile.channel[:].line_of_sight_detection.second_point (alpha) |  | STRUCTURE |  | Position of the second point
reflectometer_profile.channel[:].line_of_sight_detection.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
reflectometer_profile.channel[:].line_of_sight_detection.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
reflectometer_profile.channel[:].line_of_sight_detection.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
reflectometer_profile.channel[:].line_of_sight_emission (alpha) |  | STRUCTURE |  | Description of the line of sight of the emission antenna. The first point corresponds to the antenna mouth. The second point correspond to the interception of the line of sight with the reflection surface on the inner wall.
reflectometer_profile.channel[:].line_of_sight_emission.first_point (alpha) |  | STRUCTURE |  | Position of the first point
reflectometer_profile.channel[:].line_of_sight_emission.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
reflectometer_profile.channel[:].line_of_sight_emission.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
reflectometer_profile.channel[:].line_of_sight_emission.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
reflectometer_profile.channel[:].line_of_sight_emission.second_point (alpha) |  | STRUCTURE |  | Position of the second point
reflectometer_profile.channel[:].line_of_sight_emission.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
reflectometer_profile.channel[:].line_of_sight_emission.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
reflectometer_profile.channel[:].line_of_sight_emission.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
reflectometer_profile.channel[:].mode (alpha) |  | STR_0D |  | Detection mode "X" or "O"
reflectometer_profile.channel[:].n_e (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | STRUCTURE | m^-3 | Electron density
reflectometer_profile.channel[:].n_e.data (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | m^-3 | Data
reflectometer_profile.channel[:].n_e.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
reflectometer_profile.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
reflectometer_profile.channel[:].phase (alpha) | [reflectometer_profile.channel[:].frequencies, reflectometer_profile.channel[:].phase.time] | STRUCTURE | rad | Measured phase of the probing wave for each frequency and time slice (corresponding to the begin time of a sweep), relative to the phase at launch
reflectometer_profile.channel[:].phase.data (alpha) | [1...N, reflectometer_profile.channel[:].phase.time] | FLT_2D (uncertain) | rad | Data
reflectometer_profile.channel[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
reflectometer_profile.channel[:].position (alpha) |  | STRUCTURE |  | Position of the density measurements
reflectometer_profile.channel[:].position.phi (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
reflectometer_profile.channel[:].position.psi (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | W | Poloidal flux
reflectometer_profile.channel[:].position.r (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | m | Major radius
reflectometer_profile.channel[:].position.rho_tor_norm (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | - | Normalised toroidal flux coordinate
reflectometer_profile.channel[:].position.theta (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | rad | Poloidal angle (oriented clockwise when viewing the poloidal cross section on the right hand side of the tokamak axis of symmetry, with the origin placed on the plasma magnetic axis)
reflectometer_profile.channel[:].position.z (alpha) | [1...N, reflectometer_profile.channel[:].n_e.time] | FLT_2D (uncertain) | m | Height
reflectometer_profile.channel[:].sweep_time (alpha) |  | FLT_0D (uncertain) | s | Duration of a sweep
reflectometer_profile.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
reflectometer_profile.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
reflectometer_profile.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
reflectometer_profile.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
reflectometer_profile.code.library[:].name (alpha) |  | STR_0D |  | Name of software
reflectometer_profile.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
reflectometer_profile.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
reflectometer_profile.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
reflectometer_profile.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
reflectometer_profile.code.output_flag (alpha) | [reflectometer_profile.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
reflectometer_profile.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
reflectometer_profile.code.repository (alpha) |  | STR_0D |  | URL of software repository
reflectometer_profile.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
reflectometer_profile.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
reflectometer_profile.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
reflectometer_profile.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
reflectometer_profile.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
reflectometer_profile.ids_properties.occurrence |  | INT_0D |  |
reflectometer_profile.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
reflectometer_profile.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
reflectometer_profile.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
reflectometer_profile.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
reflectometer_profile.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
reflectometer_profile.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
reflectometer_profile.psi_normalization (alpha) |  | STRUCTURE |  | Quantities to use to normalize psi, as a function of time
reflectometer_profile.psi_normalization.psi_boundary (alpha) | [reflectometer_profile.psi_normalization.time] | FLT_1D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary
reflectometer_profile.psi_normalization.psi_magnetic_axis (alpha) | [reflectometer_profile.psi_normalization.time] | FLT_1D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis
reflectometer_profile.psi_normalization.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
reflectometer_profile.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
reflectometer_profile.type (alpha) |  | STR_0D |  | Type of reflectometer (frequency_swept, radar, ...)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
sawteeth (alpha) |  |  |  | Description of sawtooth events. This IDS must be used in homogeneous_time = 1 mode
sawteeth.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
sawteeth.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
sawteeth.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
sawteeth.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
sawteeth.code.library[:].name (alpha) |  | STR_0D |  | Name of software
sawteeth.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sawteeth.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
sawteeth.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
sawteeth.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
sawteeth.code.output_flag (alpha) | [sawteeth.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
sawteeth.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sawteeth.code.repository (alpha) |  | STR_0D |  | URL of software repository
sawteeth.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
sawteeth.crash_trigger (alpha) | [sawteeth.time] | INT_1D |  | Flag indicating whether a crash condition has been satisfied : 0 = no crash. N(>0) = crash triggered due to condition N as follows. 1: crash triggered by the ideal kink criterion; 2: crash triggered by the ideal kink criterion including kinetic effects from fast particles; 31: crash triggered by the resistive kink criterion (meeting necessary conditions for reconnection); 32: crash triggered by the resistive kink criterion (resistive kink mode is unstable). The distinction between 31 and 32 only indicates whether (31) or (32) was the last criterion to be satisfied
sawteeth.diagnostics (alpha) |  | STRUCTURE |  | Detailed information about the sawtooth characteristics
sawteeth.diagnostics.magnetic_shear_q1 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Magnetic shear at surface q = 1, defined as rho_tor/q . dq/drho_tor
sawteeth.diagnostics.previous_crash_time (alpha) | [sawteeth.time] | FLT_1D (uncertain) | s | Time at which the previous sawtooth crash occured
sawteeth.diagnostics.previous_crash_trigger (alpha) | [sawteeth.time] | INT_1D |  | Previous crash trigger. Flag indicating whether a crash condition has been satisfied : 0 = no crash. N(>0) = crash triggered due to condition N
sawteeth.diagnostics.previous_period (alpha) | [sawteeth.time] | FLT_1D (uncertain) | s | Previous sawtooth period
sawteeth.diagnostics.rho_tor_norm_inversion (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at inversion radius
sawteeth.diagnostics.rho_tor_norm_mixing (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at mixing radius
sawteeth.diagnostics.rho_tor_norm_q1 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at surface q = 1
sawteeth.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
sawteeth.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
sawteeth.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
sawteeth.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
sawteeth.ids_properties.occurrence |  | INT_0D |  |
sawteeth.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
sawteeth.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
sawteeth.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
sawteeth.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
sawteeth.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
sawteeth.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
sawteeth.profiles_1d (alpha) | [sawteeth.profiles_1d[:].time] | STRUCT_ARRAY |  | Core profiles after sawtooth crash for various time slices
sawteeth.profiles_1d[:].conductivity_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
sawteeth.profiles_1d[:].e_field_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
sawteeth.profiles_1d[:].grid.area (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
sawteeth.profiles_1d[:].grid.psi (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
sawteeth.profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
sawteeth.profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
sawteeth.profiles_1d[:].grid.rho_pol_norm (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
sawteeth.profiles_1d[:].grid.rho_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
sawteeth.profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
sawteeth.profiles_1d[:].grid.surface (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
sawteeth.profiles_1d[:].grid.volume (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
sawteeth.profiles_1d[:].j_bootstrap (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_non_inductive (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_ohmic (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
sawteeth.profiles_1d[:].j_total (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].magnetic_shear (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
sawteeth.profiles_1d[:].momentum_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m/s | Total plasma toroidal momentum, summed over ion species and electrons
sawteeth.profiles_1d[:].n_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Electron density (thermal+non-thermal)
sawteeth.profiles_1d[:].n_e_fast (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) electrons
sawteeth.profiles_1d[:].n_i_total_over_n_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
sawteeth.profiles_1d[:].p_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Electron pressure
sawteeth.profiles_1d[:].p_e_fast_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) electron parallel pressure
sawteeth.profiles_1d[:].p_e_fast_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) electron perpendicular pressure
sawteeth.profiles_1d[:].p_i_total (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total ion pressure (sum over the ion species)
sawteeth.profiles_1d[:].p_i_total_fast_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) total ion (sum over the ion species) parallel pressure
sawteeth.profiles_1d[:].p_i_total_fast_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) total ion (sum over the ion species) perpendicular pressure
sawteeth.profiles_1d[:].phi (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Toroidal flux
sawteeth.profiles_1d[:].pressure_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
sawteeth.profiles_1d[:].pressure_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
sawteeth.profiles_1d[:].pressure_thermal (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
sawteeth.profiles_1d[:].psi_star_post_crash (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Psi* = psi - phi, after the sawtooth crash
sawteeth.profiles_1d[:].psi_star_pre_crash (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Psi* = psi - phi, just before the sawtooth crash
sawteeth.profiles_1d[:].q (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor
sawteeth.profiles_1d[:].t_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Electron temperature
sawteeth.profiles_1d[:].t_i_average (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
sawteeth.profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
sawteeth.profiles_1d[:].zeff (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
sawteeth.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
sawteeth.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
sawteeth.vacuum_toroidal_field.b0 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
sawteeth.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
sdn (alpha) |  |  |  | Description of the Synchronous Data Network parameters and the signals on it
sdn.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
sdn.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
sdn.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
sdn.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
sdn.code.library[:].name (alpha) |  | STR_0D |  | Name of software
sdn.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sdn.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
sdn.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
sdn.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
sdn.code.output_flag (alpha) | [sdn.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
sdn.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sdn.code.repository (alpha) |  | STR_0D |  | URL of software repository
sdn.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
sdn.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
sdn.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
sdn.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
sdn.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
sdn.ids_properties.occurrence |  | INT_0D |  |
sdn.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
sdn.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
sdn.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
sdn.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
sdn.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
sdn.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
sdn.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
sdn.topic (alpha) | [1...N] | STRUCT_ARRAY |  | List of topics. SDN signals are grouped by topic
sdn.topic[:].name (alpha) |  | STR_0D |  | Topic name
sdn.topic[:].signal (alpha) | [1...N] | STRUCT_ARRAY |  | List of signals which can be allocated to the SDN
sdn.topic[:].signal[:].allocated_position (alpha) |  | INT_0D |  | Allocation of signal to a position in the SDN (1..N); this will be implementation specific
sdn.topic[:].signal[:].definition (alpha) |  | STR_0D |  | Signal definition
sdn.topic[:].signal[:].name (alpha) |  | STR_0D |  | Signal name
sdn.topic[:].signal[:].quality (alpha) |  | STRUCTURE |  | Indicator of the quality of the signal. Following ITER PCS documentation (https://user.iter.org/?uid=354SJ3&action=get_document), possible values are: 1 - GOOD (the nominal state); 2 - INVALID (data no usable); 3 - DATA INTEGRITY ERROR (e.g. out of bounds with respect to expectations, calibration error,...)
sdn.topic[:].signal[:].quality.data (alpha) | [sdn.topic[:].signal[:].quality.time] | INT_1D |  | Data
sdn.topic[:].signal[:].quality.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
sdn.topic[:].signal[:].value (alpha) |  | STRUCTURE | mixed | Signal value
sdn.topic[:].signal[:].value.data (alpha) | [sdn.topic[:].signal[:].value.time] | FLT_1D (uncertain) | mixed | Data
sdn.topic[:].signal[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
soft_x_rays (alpha) |  |  |  | Soft X-rays tomography diagnostic
soft_x_rays.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
soft_x_rays.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
soft_x_rays.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
soft_x_rays.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
soft_x_rays.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
soft_x_rays.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
soft_x_rays.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
soft_x_rays.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
soft_x_rays.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
soft_x_rays.channel[:].aperture[:].outline.x2 (alpha) | [soft_x_rays.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
soft_x_rays.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
soft_x_rays.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
soft_x_rays.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
soft_x_rays.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
soft_x_rays.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
soft_x_rays.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
soft_x_rays.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
soft_x_rays.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].brightness (alpha) | [soft_x_rays.channel[:].energy_band, soft_x_rays.channel[:].brightness.time] | STRUCTURE | W.m^-2.sr^-1 | Power flux received by the detector, per unit solid angle and per unit area (i.e. power divided by the etendue), in multiple energy bands if available from the detector
soft_x_rays.channel[:].brightness.data (alpha) | [1...N, soft_x_rays.channel[:].brightness.time] | FLT_2D (uncertain) | W.m^-2.sr^-1 | Data
soft_x_rays.channel[:].brightness.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
soft_x_rays.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
soft_x_rays.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
soft_x_rays.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
soft_x_rays.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
soft_x_rays.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
soft_x_rays.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
soft_x_rays.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
soft_x_rays.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
soft_x_rays.channel[:].detector.outline.x2 (alpha) | [soft_x_rays.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
soft_x_rays.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
soft_x_rays.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
soft_x_rays.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
soft_x_rays.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
soft_x_rays.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
soft_x_rays.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
soft_x_rays.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
soft_x_rays.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
soft_x_rays.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
soft_x_rays.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
soft_x_rays.channel[:].energy_band (alpha) | [1...N] | STRUCT_ARRAY |  | Set of energy bands in which photons are counted by the detector
soft_x_rays.channel[:].energy_band[:].detection_efficiency (alpha) | [soft_x_rays.channel[:].energy_band[:].energies] | FLT_1D (uncertain) | - | Probability of detection of a photon impacting the detector as a function of its energy
soft_x_rays.channel[:].energy_band[:].energies (alpha) | [1...N] | FLT_1D (uncertain) | eV | Array of discrete energy values inside the band
soft_x_rays.channel[:].energy_band[:].lower_bound (alpha) |  | FLT_0D (uncertain) | eV | Lower bound of the energy band
soft_x_rays.channel[:].energy_band[:].upper_bound (alpha) |  | FLT_0D (uncertain) | eV | Upper bound of the energy band
soft_x_rays.channel[:].etendue (alpha) |  | FLT_0D (uncertain) | m^2.sr | Etendue (geometric extent) of the channel's optical system
soft_x_rays.channel[:].etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
soft_x_rays.channel[:].etendue_method.description (alpha) |  | STR_0D |  | Verbose description
soft_x_rays.channel[:].etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
soft_x_rays.channel[:].etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
soft_x_rays.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
soft_x_rays.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
soft_x_rays.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
soft_x_rays.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
soft_x_rays.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
soft_x_rays.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
soft_x_rays.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
soft_x_rays.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
soft_x_rays.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
soft_x_rays.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
soft_x_rays.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
soft_x_rays.channel[:].power (alpha) | [soft_x_rays.channel[:].energy_band, soft_x_rays.channel[:].power.time] | STRUCTURE | W | Power received on the detector, in multiple energy bands if available from the detector
soft_x_rays.channel[:].power.data (alpha) | [1...N, soft_x_rays.channel[:].power.time] | FLT_2D (uncertain) | W | Data
soft_x_rays.channel[:].power.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
soft_x_rays.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
soft_x_rays.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
soft_x_rays.channel[:].validity_timed.data (alpha) | [soft_x_rays.channel[:].validity_timed.time] | INT_1D |  | Data
soft_x_rays.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
soft_x_rays.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
soft_x_rays.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
soft_x_rays.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
soft_x_rays.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
soft_x_rays.code.library[:].name (alpha) |  | STR_0D |  | Name of software
soft_x_rays.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
soft_x_rays.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
soft_x_rays.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
soft_x_rays.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
soft_x_rays.code.output_flag (alpha) | [soft_x_rays.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
soft_x_rays.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
soft_x_rays.code.repository (alpha) |  | STR_0D |  | URL of software repository
soft_x_rays.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
soft_x_rays.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
soft_x_rays.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
soft_x_rays.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
soft_x_rays.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
soft_x_rays.ids_properties.occurrence |  | INT_0D |  |
soft_x_rays.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
soft_x_rays.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
soft_x_rays.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
soft_x_rays.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
soft_x_rays.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
soft_x_rays.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
soft_x_rays.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
spectrometer_mass (alpha) |  |  |  | Mass spectrometer diagnostic
spectrometer_mass.a (alpha) | [1...N] | FLT_1D (uncertain) | Atomic Mass Unit | Array of atomic masses for which partial pressures are recorded by the spectrometer
spectrometer_mass.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
spectrometer_mass.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_mass.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
spectrometer_mass.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_mass.code.library[:].name (alpha) |  | STR_0D |  | Name of software
spectrometer_mass.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_mass.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_mass.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_mass.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
spectrometer_mass.code.output_flag (alpha) | [spectrometer_mass.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
spectrometer_mass.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_mass.code.repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_mass.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_mass.identifier (alpha) |  | STR_0D |  | ID of the spectrometer
spectrometer_mass.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
spectrometer_mass.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
spectrometer_mass.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
spectrometer_mass.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
spectrometer_mass.ids_properties.occurrence |  | INT_0D |  |
spectrometer_mass.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
spectrometer_mass.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
spectrometer_mass.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
spectrometer_mass.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
spectrometer_mass.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
spectrometer_mass.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
spectrometer_mass.name (alpha) |  | STR_0D |  | Name of the spectrometer
spectrometer_mass.pressures_partial (alpha) | [spectrometer_mass.a] | STRUCTURE | Pa | Partial pressures recorded by the spectrometer
spectrometer_mass.pressures_partial.data (alpha) | [1...N, spectrometer_mass.pressures_partial.time] | FLT_2D (uncertain) | Pa | Data
spectrometer_mass.pressures_partial.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_mass.pressures_partial.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_mass.pressures_partial.validity_timed (alpha) | [spectrometer_mass.pressures_partial.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_mass.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
spectrometer_uv (alpha) |  |  |  | Spectrometer in uv light range diagnostic
spectrometer_uv.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
spectrometer_uv.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
spectrometer_uv.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
spectrometer_uv.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
spectrometer_uv.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
spectrometer_uv.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_uv.channel[:].aperture[:].outline.x2 (alpha) | [spectrometer_uv.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_uv.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
spectrometer_uv.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
spectrometer_uv.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_uv.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
spectrometer_uv.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_uv.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
spectrometer_uv.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
spectrometer_uv.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].detector (alpha) |  | STRUCTURE |  | Description of the front face of the micro channel plate
spectrometer_uv.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
spectrometer_uv.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
spectrometer_uv.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
spectrometer_uv.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_uv.channel[:].detector.outline.x2 (alpha) | [spectrometer_uv.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_uv.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
spectrometer_uv.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
spectrometer_uv.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_uv.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
spectrometer_uv.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_uv.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
spectrometer_uv.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
spectrometer_uv.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].detector_layout (alpha) |  | STRUCTURE |  | Dimensions of pixels and detector
spectrometer_uv.channel[:].detector_layout.detector_dimensions (alpha) | [1...2] | FLT_1D (uncertain) | m | Total detector dimension in each direction (horizontal, vertical)
spectrometer_uv.channel[:].detector_layout.pixel_dimensions (alpha) | [1...2] | FLT_1D (uncertain) | m | Pixel dimension in each direction (horizontal, vertical)
spectrometer_uv.channel[:].detector_layout.pixel_n (alpha) | [1...2] | INT_1D |  | Number of pixels in each direction (horizontal, vertical)
spectrometer_uv.channel[:].detector_position_parameter (alpha) |  | STRUCTURE | mixed | In case of detector moving during a pulse, position parameter allowing to record and compute the detector position as a function of time
spectrometer_uv.channel[:].detector_position_parameter.data (alpha) | [spectrometer_uv.channel[:].detector_position_parameter.time] | FLT_1D (uncertain) | mixed | Data
spectrometer_uv.channel[:].detector_position_parameter.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
spectrometer_uv.channel[:].grating (alpha) |  | STRUCTURE |  | Description of the grating
spectrometer_uv.channel[:].grating.centre (alpha) |  | STRUCTURE |  | Centre of the grating sphere (if grating is spherical) or torus (if grating is toric)
spectrometer_uv.channel[:].grating.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].grating.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].grating.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].grating.curvature_radius (alpha) |  | FLT_0D (uncertain) | m | Curvature radius of the spherical grating
spectrometer_uv.channel[:].grating.geometry_type (alpha) |  | STRUCTURE |  | Grating geometry. Index = 1 : spherical. Index = 2 : toric
spectrometer_uv.channel[:].grating.geometry_type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_uv.channel[:].grating.geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_uv.channel[:].grating.geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_uv.channel[:].grating.groove_density (alpha) |  | FLT_0D (uncertain) | m^-1 | Number of grooves per unit length
spectrometer_uv.channel[:].grating.image_field (alpha) |  | STRUCTURE |  | Surface on which the grating image is focused
spectrometer_uv.channel[:].grating.image_field.centre (alpha) |  | STRUCTURE |  | Centre of the image surface in case it is spherical, or position of a point on the surface in case it is a plane
spectrometer_uv.channel[:].grating.image_field.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].grating.image_field.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].grating.image_field.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].grating.image_field.curvature_radius (alpha) |  | FLT_0D (uncertain) | m | Curvature radius of the image surface
spectrometer_uv.channel[:].grating.image_field.geometry_type (alpha) |  | STRUCTURE |  | Surface geometry. Index = 1 : spherical. Index = 2 : plane
spectrometer_uv.channel[:].grating.image_field.geometry_type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_uv.channel[:].grating.image_field.geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_uv.channel[:].grating.image_field.geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_uv.channel[:].grating.image_field.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the surface ( in case it is plane) and oriented towards the plasma.
spectrometer_uv.channel[:].grating.image_field.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].grating.image_field.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].grating.image_field.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].grating.outline (alpha) |  | STRUCTURE |  | List of the 4 extreme points of the spherical grating in the (X1, X2) coordinate system, using the summit as the origin. Do NOT repeat the first point.
spectrometer_uv.channel[:].grating.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_uv.channel[:].grating.outline.x2 (alpha) | [spectrometer_uv.channel[:].grating.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_uv.channel[:].grating.summit (alpha) |  | STRUCTURE |  | Position of the grating summit (defined as the point of contact of its concave side if the grating were put on a table). Used as the origin of the x1, x2, x3 vectors defined below
spectrometer_uv.channel[:].grating.summit.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].grating.summit.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].grating.summit.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].grating.type (alpha) |  | STRUCTURE |  | Grating type. Index = 1 : ruled. Index = 2 : holographic
spectrometer_uv.channel[:].grating.type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_uv.channel[:].grating.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_uv.channel[:].grating.type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_uv.channel[:].grating.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_uv.channel[:].grating.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].grating.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].grating.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].grating.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_uv.channel[:].grating.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].grating.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].grating.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].grating.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the grating at its summit and oriented towards the plasma.
spectrometer_uv.channel[:].grating.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_uv.channel[:].grating.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_uv.channel[:].grating.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_uv.channel[:].intensity_spectrum (alpha) | [spectrometer_uv.channel[:].wavelengths, spectrometer_uv.channel[:].intensity_spectrum.time] | STRUCTURE | (counts) s^-1 | Intensity spectrum (not calibrated), i.e. number of photoelectrons detected by unit time by a wavelength pixel of the channel, taking into account electronic gain compensation and channels relative calibration
spectrometer_uv.channel[:].intensity_spectrum.data (alpha) | [1...N, spectrometer_uv.channel[:].intensity_spectrum.time] | FLT_2D (uncertain) | (counts) s^-1 | Data
spectrometer_uv.channel[:].intensity_spectrum.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points. The 2nd point is allowed to evolve in case of dynamic line of sight.
spectrometer_uv.channel[:].line_of_sight.amplitude_parameter (alpha) |  | FLT_0D (uncertain) | mixed | Amplitude of the line of sight position parameter oscillation (in case moving_mode/index = 1)
spectrometer_uv.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
spectrometer_uv.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_uv.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_uv.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_uv.channel[:].line_of_sight.moving_mode (alpha) |  | STRUCTURE |  | Moving mode of the line of sight. Index = 0 : no movement, fixed position. Index = 1 : oscillating
spectrometer_uv.channel[:].line_of_sight.moving_mode.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_uv.channel[:].line_of_sight.moving_mode.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_uv.channel[:].line_of_sight.moving_mode.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_uv.channel[:].line_of_sight.period (alpha) |  | FLT_0D (uncertain) | s | Period of the line of sight oscillation (in case moving_mode/index = 1)
spectrometer_uv.channel[:].line_of_sight.position_parameter (alpha) |  | STRUCTURE | mixed | In case of line of sight moving during a pulse, position parameter allowing to record and compute the line of sight position as a function of time
spectrometer_uv.channel[:].line_of_sight.position_parameter.data (alpha) | [spectrometer_uv.channel[:].line_of_sight.position_parameter.time] | FLT_1D (uncertain) | mixed | Data
spectrometer_uv.channel[:].line_of_sight.position_parameter.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point (possibly dynamic)
spectrometer_uv.channel[:].line_of_sight.second_point.phi (alpha) | [spectrometer_uv.channel[:].line_of_sight.second_point.time] | FLT_1D (uncertain) | rad | Toroidal angle
spectrometer_uv.channel[:].line_of_sight.second_point.r (alpha) | [spectrometer_uv.channel[:].line_of_sight.second_point.time] | FLT_1D (uncertain) | m | Major radius
spectrometer_uv.channel[:].line_of_sight.second_point.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
spectrometer_uv.channel[:].line_of_sight.second_point.z (alpha) | [spectrometer_uv.channel[:].line_of_sight.second_point.time] | FLT_1D (uncertain) | m | Height
spectrometer_uv.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
spectrometer_uv.channel[:].processed_line (alpha) | [1...N] | STRUCT_ARRAY |  | Set of processed spectral lines
spectrometer_uv.channel[:].processed_line[:].intensity (alpha) |  | STRUCTURE | s^-1 | Non-calibrated intensity (integrated over the spectrum for this line)
spectrometer_uv.channel[:].processed_line[:].intensity.data (alpha) | [spectrometer_uv.channel[:].processed_line[:].intensity.time] | FLT_1D (uncertain) | s^-1 | Data
spectrometer_uv.channel[:].processed_line[:].intensity.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].processed_line[:].label (alpha) |  | STR_0D |  | String identifying the processed line. To avoid ambiguities, the following syntax is used : element with ionization state_wavelength in Angstrom (e.g. WI_4000)
spectrometer_uv.channel[:].processed_line[:].radiance (alpha) |  | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated, background subtracted radiance (integrated over the spectrum for this line)
spectrometer_uv.channel[:].processed_line[:].radiance.data (alpha) | [spectrometer_uv.channel[:].processed_line[:].radiance.time] | FLT_1D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_uv.channel[:].processed_line[:].radiance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].processed_line[:].wavelength_central (alpha) |  | FLT_0D (uncertain) | m | Central wavelength of the processed line
spectrometer_uv.channel[:].radiance_calibration (alpha) | [spectrometer_uv.channel[:].wavelengths] | FLT_1D (uncertain) | m^-3.sr^-1 | Radiance calibration
spectrometer_uv.channel[:].radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
spectrometer_uv.channel[:].radiance_spectral (alpha) | [spectrometer_uv.channel[:].wavelengths, spectrometer_uv.channel[:].radiance_spectral.time] | STRUCTURE | (photons).m^-2.s^-1.sr^-1.m^-1 | Calibrated spectral radiance (radiance per unit wavelength)
spectrometer_uv.channel[:].radiance_spectral.data (alpha) | [1...N, spectrometer_uv.channel[:].radiance_spectral.time] | FLT_2D (uncertain) | (photons).m^-2.s^-1.sr^-1.m^-1 | Data
spectrometer_uv.channel[:].radiance_spectral.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].supply_high_voltage (alpha) | [1...N] | STRUCT_ARRAY |  | Set of high voltage power supplies applied to various parts of the diagnostic
spectrometer_uv.channel[:].supply_high_voltage[:].object (alpha) |  | STR_0D |  | Name of the object connected to the power supply
spectrometer_uv.channel[:].supply_high_voltage[:].voltage_set (alpha) |  | STRUCTURE | V | Voltage set at the power supply
spectrometer_uv.channel[:].supply_high_voltage[:].voltage_set.data (alpha) | [spectrometer_uv.channel[:].supply_high_voltage[:].voltage_set.time] | FLT_1D (uncertain) | V | Data
spectrometer_uv.channel[:].supply_high_voltage[:].voltage_set.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_uv.channel[:].validity_timed (alpha) | [spectrometer_uv.channel[:].wavelengths] | STRUCTURE |  | Indicator of the validity of the data for each wavelength and each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_uv.channel[:].validity_timed.data (alpha) | [spectrometer_uv.channel[:].validity_timed.data.as_parent, spectrometer_uv.channel[:].validity_timed.time] | INT_2D |  | Data
spectrometer_uv.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_uv.channel[:].wavelength_calibration (alpha) |  | STRUCTURE |  | Wavelength calibration data. The wavelength is obtained from the pixel index k by: wavelength = k * gain + offset. k is starting from 1.
spectrometer_uv.channel[:].wavelength_calibration.gain (alpha) |  | FLT_0D (uncertain) | m | Gain
spectrometer_uv.channel[:].wavelength_calibration.offset (alpha) |  | FLT_0D (uncertain) | m | Offset
spectrometer_uv.channel[:].wavelength_calibration_date (alpha) |  | STR_0D |  | Date of the wavelength calibration (yyyy_mm_dd)
spectrometer_uv.channel[:].wavelengths (alpha) | [1...N] | FLT_1D (uncertain) | m | Measured wavelengths
spectrometer_uv.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
spectrometer_uv.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_uv.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
spectrometer_uv.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_uv.code.library[:].name (alpha) |  | STR_0D |  | Name of software
spectrometer_uv.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_uv.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_uv.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_uv.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
spectrometer_uv.code.output_flag (alpha) | [spectrometer_uv.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
spectrometer_uv.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_uv.code.repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_uv.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_uv.etendue (alpha) |  | FLT_0D (uncertain) | m^2.sr | Etendue (geometric extent) of the optical system
spectrometer_uv.etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
spectrometer_uv.etendue_method.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_uv.etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_uv.etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_uv.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
spectrometer_uv.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
spectrometer_uv.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
spectrometer_uv.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
spectrometer_uv.ids_properties.occurrence |  | INT_0D |  |
spectrometer_uv.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
spectrometer_uv.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
spectrometer_uv.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
spectrometer_uv.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
spectrometer_uv.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
spectrometer_uv.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
spectrometer_uv.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
spectrometer_visible (alpha) |  |  |  | Spectrometer in visible light range diagnostic
spectrometer_visible.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
spectrometer_visible.channel[:].active_spatial_resolution (alpha) | [spectrometer_visible.channel[:].active_spatial_resolution[:].time] | STRUCT_ARRAY |  | In case of active spectroscopy, describes the spatial resolution of the measurement, calculated as a convolution of the atomic smearing, magnetic and beam geometry smearing and detector projection, for a set of time slices
spectrometer_visible.channel[:].active_spatial_resolution[:].centre (alpha) |  | STRUCTURE |  | Position of the centre of the spatially resolved zone
spectrometer_visible.channel[:].active_spatial_resolution[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].active_spatial_resolution[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].active_spatial_resolution[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].active_spatial_resolution[:].time (alpha) |  | FLT_0D | s | Time
spectrometer_visible.channel[:].active_spatial_resolution[:].width (alpha) |  | STRUCTURE |  | Full width of the spatially resolved zone in the R, Z and phi directions
spectrometer_visible.channel[:].active_spatial_resolution[:].width.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].active_spatial_resolution[:].width.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].active_spatial_resolution[:].width.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
spectrometer_visible.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
spectrometer_visible.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
spectrometer_visible.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
spectrometer_visible.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_visible.channel[:].aperture[:].outline.x2 (alpha) | [spectrometer_visible.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_visible.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
spectrometer_visible.channel[:].aperture[:].surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
spectrometer_visible.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_visible.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].aperture[:].x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_visible.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].aperture[:].x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
spectrometer_visible.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
spectrometer_visible.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
spectrometer_visible.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
spectrometer_visible.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
spectrometer_visible.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_visible.channel[:].detector.outline.x2 (alpha) | [spectrometer_visible.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_visible.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
spectrometer_visible.channel[:].detector.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
spectrometer_visible.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_visible.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].detector.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_visible.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].detector.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
spectrometer_visible.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].detector_image (alpha) |  | STRUCTURE |  | Image of the detector or pixel on the focal plane of the optical system
spectrometer_visible.channel[:].detector_image.circular (alpha) |  | STRUCTURE |  | Description of circular or elliptic image
spectrometer_visible.channel[:].detector_image.circular.ellipticity (alpha) |  | FLT_0D (uncertain) | - | Ellipticity
spectrometer_visible.channel[:].detector_image.circular.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle
spectrometer_visible.channel[:].detector_image.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the image (1:'outline', 2:'circular')
spectrometer_visible.channel[:].detector_image.outline (alpha) |  | STRUCTURE |  | Coordinates of the points shaping the polygon of the image
spectrometer_visible.channel[:].detector_image.outline.phi (alpha) | [spectrometer_visible.channel[:].detector_image.outline.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].detector_image.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
spectrometer_visible.channel[:].detector_image.outline.z (alpha) | [spectrometer_visible.channel[:].detector_image.outline.r] | FLT_1D (uncertain) | m | Height
spectrometer_visible.channel[:].etendue (alpha) |  | FLT_0D (uncertain) | m^2.str | Etendue (geometric extent) of the channel's optical system
spectrometer_visible.channel[:].etendue_method (alpha) |  | STRUCTURE |  | Method used to calculate the etendue. Index = 0 : exact calculation with a 4D integral; 1 : approximation with first order formula (detector surface times solid angle subtended by the apertures); 2 : other methods
spectrometer_visible.channel[:].etendue_method.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_visible.channel[:].etendue_method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_visible.channel[:].etendue_method.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_visible.channel[:].fibre_image (alpha) |  | STRUCTURE |  | Image of the optical fibre on the focal plane of the optical system
spectrometer_visible.channel[:].fibre_image.circular (alpha) |  | STRUCTURE |  | Description of circular or elliptic image
spectrometer_visible.channel[:].fibre_image.circular.ellipticity (alpha) |  | FLT_0D (uncertain) | - | Ellipticity
spectrometer_visible.channel[:].fibre_image.circular.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle
spectrometer_visible.channel[:].fibre_image.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the image (1:'outline', 2:'circular')
spectrometer_visible.channel[:].fibre_image.outline (alpha) |  | STRUCTURE |  | Coordinates of the points shaping the polygon of the image
spectrometer_visible.channel[:].fibre_image.outline.phi (alpha) | [spectrometer_visible.channel[:].fibre_image.outline.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].fibre_image.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
spectrometer_visible.channel[:].fibre_image.outline.z (alpha) | [spectrometer_visible.channel[:].fibre_image.outline.r] | FLT_1D (uncertain) | m | Height
spectrometer_visible.channel[:].filter_spectrometer (alpha) |  | STRUCTURE |  | Quantities measured by the channel if connected to a filter spectrometer
spectrometer_visible.channel[:].filter_spectrometer.calibrated_line_integrals (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.calibrated_lines ] | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated line gross areas integrals
spectrometer_visible.channel[:].filter_spectrometer.calibrated_line_integrals.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.calibrated_line_integrals.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.calibrated_line_integrals.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.calibrated_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the calibrated lines
spectrometer_visible.channel[:].filter_spectrometer.exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
spectrometer_visible.channel[:].filter_spectrometer.line_intensities (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.raw_lines ] | STRUCTURE | m^-2.s^-1.sr^-1 | Line gross integral intensities
spectrometer_visible.channel[:].filter_spectrometer.line_intensities.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.line_intensities.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.line_intensities.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.line_labels (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.processed_lines] | STR_1D |  | String identifying the processed line. To avoid ambiguities, the following syntax is used : element with ionization state_wavelength in Angstrom (e.g. WI_4000)
spectrometer_visible.channel[:].filter_spectrometer.line_power_radiances (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.processed_lines ] | STRUCTURE | W.m^-2.sr^-1 | Calibrated, background subtracted power radiances
spectrometer_visible.channel[:].filter_spectrometer.line_power_radiances.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.line_power_radiances.time] | FLT_2D (uncertain) | W.m^-2.sr^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.line_power_radiances.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.line_radiances (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.processed_lines ] | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated, background subtracted line integrals
spectrometer_visible.channel[:].filter_spectrometer.line_radiances.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.line_radiances.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.line_radiances.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.line_radiances_adjusted (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.processed_lines ] | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated, background subtracted line integrals, adjusted as if the line was centred at the peak responsivity of the system (for this line)
spectrometer_visible.channel[:].filter_spectrometer.line_radiances_adjusted.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.line_radiances_adjusted.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.line_radiances_adjusted.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.output_voltage (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.raw_lines ] | STRUCTURE | V | Raw voltage output of the whole acquisition chain for each raw line
spectrometer_visible.channel[:].filter_spectrometer.output_voltage.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.output_voltage.time] | FLT_2D (uncertain) | V | Data
spectrometer_visible.channel[:].filter_spectrometer.output_voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.photoelectric_voltage (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.raw_lines ] | STRUCTURE | V | Gain corrected and background subtracted voltage for each raw line
spectrometer_visible.channel[:].filter_spectrometer.photoelectric_voltage.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.photoelectric_voltage.time] | FLT_2D (uncertain) | V | Data
spectrometer_visible.channel[:].filter_spectrometer.photoelectric_voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.photon_count (alpha) | [spectrometer_visible.channel[:].filter_spectrometer.raw_lines ] | STRUCTURE | s^-1 | Detected photon count for each raw line
spectrometer_visible.channel[:].filter_spectrometer.photon_count.data (alpha) | [1...N, spectrometer_visible.channel[:].filter_spectrometer.photon_count.time] | FLT_2D (uncertain) | s^-1 | Data
spectrometer_visible.channel[:].filter_spectrometer.photon_count.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].filter_spectrometer.processed_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the processed lines
spectrometer_visible.channel[:].filter_spectrometer.radiance_calibration (alpha) |  | FLT_0D (uncertain) | m^-2.sr^-1 | Radiance calibration
spectrometer_visible.channel[:].filter_spectrometer.radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].filter_spectrometer.raw_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the raw lines
spectrometer_visible.channel[:].grating_spectrometer (alpha) |  | STRUCTURE |  | Quantities measured by the channel if connected to a grating spectrometer
spectrometer_visible.channel[:].grating_spectrometer.exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
spectrometer_visible.channel[:].grating_spectrometer.grating (alpha) |  | FLT_0D (uncertain) | m^-1 | Number of grating lines per unit length
spectrometer_visible.channel[:].grating_spectrometer.intensity_spectrum (alpha) | [spectrometer_visible.channel[:].grating_spectrometer.wavelengths, spectrometer_visible.channel[:].grating_spectrometer.intensity_spectrum.time] | STRUCTURE | (counts) s^-1 | Intensity spectrum (not calibrated), i.e. number of photoelectrons detected by unit time by a wavelength pixel of the channel, taking into account electronic gain compensation and channels relative calibration
spectrometer_visible.channel[:].grating_spectrometer.intensity_spectrum.data (alpha) | [1...N, spectrometer_visible.channel[:].grating_spectrometer.intensity_spectrum.time] | FLT_2D (uncertain) | (counts) s^-1 | Data
spectrometer_visible.channel[:].grating_spectrometer.intensity_spectrum.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].grating_spectrometer.processed_line (alpha) | [1...N] | STRUCT_ARRAY |  | Set of processed spectral lines
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].intensity (alpha) |  | STRUCTURE | s^-1 | Non-calibrated intensity (integrated over the spectrum for this line)
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].intensity.data (alpha) | [spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].intensity.time] | FLT_1D (uncertain) | s^-1 | Data
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].intensity.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].label (alpha) |  | STR_0D |  | String identifying the processed line. To avoid ambiguities, the following syntax is used : element with ionization state_wavelength in Angstrom (e.g. WI_4000)
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].radiance (alpha) |  | STRUCTURE | m^-2.s^-1.sr^-1 | Calibrated, background subtracted radiance (integrated over the spectrum for this line)
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].radiance.data (alpha) | [spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].radiance.time] | FLT_1D (uncertain) | m^-2.s^-1.sr^-1 | Data
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].radiance.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].grating_spectrometer.processed_line[:].wavelength_central (alpha) |  | FLT_0D (uncertain) | m | Central wavelength of the processed line
spectrometer_visible.channel[:].grating_spectrometer.radiance_calibration (alpha) | [spectrometer_visible.channel[:].grating_spectrometer.wavelengths] | FLT_1D (uncertain) | m^-3.sr^-1 | Radiance calibration
spectrometer_visible.channel[:].grating_spectrometer.radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].grating_spectrometer.radiance_spectral (alpha) | [spectrometer_visible.channel[:].grating_spectrometer.wavelengths, spectrometer_visible.channel[:].grating_spectrometer.radiance_spectral.time] | STRUCTURE | (photons).m^-2.s^-1.sr^-1.m^-1 | Calibrated spectral radiance (radiance per unit wavelength)
spectrometer_visible.channel[:].grating_spectrometer.radiance_spectral.data (alpha) | [1...N, spectrometer_visible.channel[:].grating_spectrometer.radiance_spectral.time] | FLT_2D (uncertain) | (photons).m^-2.s^-1.sr^-1.m^-1 | Data
spectrometer_visible.channel[:].grating_spectrometer.radiance_spectral.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.channel[:].grating_spectrometer.slit_width (alpha) |  | FLT_0D (uncertain) | m | Width of the slit (placed in the object focal plane)
spectrometer_visible.channel[:].grating_spectrometer.wavelength_calibration (alpha) |  | STRUCTURE |  | Wavelength calibration data. The wavelength is obtained from the pixel index k by: wavelength = k * gain + offset. k is starting from 1.
spectrometer_visible.channel[:].grating_spectrometer.wavelength_calibration.gain (alpha) |  | FLT_0D (uncertain) | m | Gain
spectrometer_visible.channel[:].grating_spectrometer.wavelength_calibration.offset (alpha) |  | FLT_0D (uncertain) | m | Offset
spectrometer_visible.channel[:].grating_spectrometer.wavelength_calibration_date (alpha) |  | STR_0D |  | Date of the wavelength calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].grating_spectrometer.wavelengths (alpha) | [1...N] | FLT_1D (uncertain) | m | Measured wavelengths
spectrometer_visible.channel[:].isotope_ratios (alpha) |  | STRUCTURE |  | Isotope ratios and related information
spectrometer_visible.channel[:].isotope_ratios.isotope (alpha) | [1...N] | STRUCT_ARRAY |  | Set of isotopes
spectrometer_visible.channel[:].isotope_ratios.isotope[:].cold_neutrals_fraction (alpha) | [spectrometer_visible.channel[:].isotope_ratios.isotope[:].time] | FLT_1D (uncertain) | - | Fraction of cold neutrals for this isotope (n_cold_neutrals/(n_cold_neutrals+n_hot_neutrals))
spectrometer_visible.channel[:].isotope_ratios.isotope[:].cold_neutrals_temperature (alpha) | [spectrometer_visible.channel[:].isotope_ratios.isotope[:].time] | FLT_1D (uncertain) | eV | Temperature of cold neutrals for this isotope
spectrometer_visible.channel[:].isotope_ratios.isotope[:].density_ratio (alpha) | [spectrometer_visible.channel[:].isotope_ratios.isotope[:].time] | FLT_1D (uncertain) | - | Ratio of the density of neutrals of this isotope over the summed neutral densities of all other isotopes described in the ../isotope array
spectrometer_visible.channel[:].isotope_ratios.isotope[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
spectrometer_visible.channel[:].isotope_ratios.isotope[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
spectrometer_visible.channel[:].isotope_ratios.isotope[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
spectrometer_visible.channel[:].isotope_ratios.isotope[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
spectrometer_visible.channel[:].isotope_ratios.isotope[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
spectrometer_visible.channel[:].isotope_ratios.isotope[:].hot_neutrals_fraction (alpha) | [spectrometer_visible.channel[:].isotope_ratios.isotope[:].time] | FLT_1D (uncertain) | - | Fraction of hot neutrals for this isotope (n_hot_neutrals/(n_cold_neutrals+n_hot_neutrals))
spectrometer_visible.channel[:].isotope_ratios.isotope[:].hot_neutrals_temperature (alpha) | [spectrometer_visible.channel[:].isotope_ratios.isotope[:].time] | FLT_1D (uncertain) | eV | Temperature of hot neutrals for this isotope
spectrometer_visible.channel[:].isotope_ratios.isotope[:].label (alpha) |  | STR_0D |  | String identifying the species (H, D, T, He3, He4)
spectrometer_visible.channel[:].isotope_ratios.isotope[:].time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for dynamic quantities at this level of the data structure
spectrometer_visible.channel[:].isotope_ratios.method (alpha) |  | STRUCTURE |  | Fitting method used to calculate isotope ratios 1) multi_gaussian : Multi-gaussian fitting 2) exp_times_multi_gaussian : Experimental signal multiplied by multi-gaussian ratio
spectrometer_visible.channel[:].isotope_ratios.method.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_visible.channel[:].isotope_ratios.method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_visible.channel[:].isotope_ratios.method.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_visible.channel[:].isotope_ratios.signal_to_noise (alpha) | [spectrometer_visible.channel[:].isotope_ratios.time] | FLT_1D (uncertain) | dB | Log10 of the ratio of the powers in two bands, one with the spectral lines of interest (signal) the other without spectral lines (noise).
spectrometer_visible.channel[:].isotope_ratios.time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for dynamic quantities at this level of the data structure
spectrometer_visible.channel[:].isotope_ratios.validity (alpha) |  | INT_0D |  | Indicator of the validity of the isotope ratios for the whole acquisition period (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].isotope_ratios.validity_timed (alpha) | [spectrometer_visible.channel[:].isotope_ratios.time] | INT_1D |  | Indicator of the validity of the isotope ratios as a function of time (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].light_collection_efficiencies (alpha) |  | STRUCTURE |  | Light collection efficiencies (fraction of the local emission detected by the optical system) for a list of points defining regions of interest. To be used for non-pinhole optics.
spectrometer_visible.channel[:].light_collection_efficiencies.positions (alpha) |  | STRUCTURE |  | List of positions for which the light collection efficiencies are provided
spectrometer_visible.channel[:].light_collection_efficiencies.positions.phi (alpha) | [spectrometer_visible.channel[:].light_collection_efficiencies.positions.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].light_collection_efficiencies.positions.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
spectrometer_visible.channel[:].light_collection_efficiencies.positions.z (alpha) | [spectrometer_visible.channel[:].light_collection_efficiencies.positions.r] | FLT_1D (uncertain) | m | Height
spectrometer_visible.channel[:].light_collection_efficiencies.values (alpha) | [spectrometer_visible.channel[:].light_collection_efficiencies.positions.r] | FLT_1D (uncertain) | - | Values of the light collection efficiencies
spectrometer_visible.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
spectrometer_visible.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
spectrometer_visible.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
spectrometer_visible.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
spectrometer_visible.channel[:].object_observed (alpha) |  | STR_0D |  | Main object observed by the channel
spectrometer_visible.channel[:].polarization_spectroscopy (alpha) |  | STRUCTURE |  | Physics quantities measured from polarized light spectroscopy
spectrometer_visible.channel[:].polarization_spectroscopy.b_field_modulus (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | T | Modulus of the magnetic field (always positive, irrespective of the sign convention for the B-field direction), obtained from Zeeman effect fit
spectrometer_visible.channel[:].polarization_spectroscopy.e_field_lh_r (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | V.m^-1 | Lower Hybrid electric field component in the major radius direction
spectrometer_visible.channel[:].polarization_spectroscopy.e_field_lh_tor (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | V.m^-1 | Lower Hybrid electric field component in the toroidal direction
spectrometer_visible.channel[:].polarization_spectroscopy.e_field_lh_z (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | V.m^-1 | Lower Hybrid electric field component in the vertical direction
spectrometer_visible.channel[:].polarization_spectroscopy.n_e (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | m^-3 | Electron density, obtained from Stark broadening fit
spectrometer_visible.channel[:].polarization_spectroscopy.temperature_cold_neutrals (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | eV | Fit of cold neutrals temperature
spectrometer_visible.channel[:].polarization_spectroscopy.temperature_hot_neutrals (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | eV | Fit of hot neutrals temperature
spectrometer_visible.channel[:].polarization_spectroscopy.time (alpha) | [1...N] | FLT_1D_TYPE | s | Timebase for dynamic quantities at this level of the data structure
spectrometer_visible.channel[:].polarization_spectroscopy.velocity_cold_neutrals (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | m.s^-1 | Projection of the cold neutral velocity along the line of sight, positive when going from first point to second point of the line of sight
spectrometer_visible.channel[:].polarization_spectroscopy.velocity_hot_neutrals (alpha) | [spectrometer_visible.channel[:].polarization_spectroscopy.time] | FLT_1D (uncertain) | m.s^-1 | Projection of the hot neutral velocity along the line of sight, positive when going from first point to second point of the line of sight
spectrometer_visible.channel[:].polarizer (alpha) |  | STRUCTURE |  | Polarizer description
spectrometer_visible.channel[:].polarizer.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the centre of the circle. If geometry_type=1 or 3, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
spectrometer_visible.channel[:].polarizer.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_visible.channel[:].polarizer.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].polarizer.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].polarizer.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular', 3:'rectangle'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3. In case of 'rectangle', the surface is a rectangle defined by its centre, widths in the X1 and X2 directions, and normal vector oriented towards the plasma X3.
spectrometer_visible.channel[:].polarizer.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system. Do NOT repeat the first point.
spectrometer_visible.channel[:].polarizer.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
spectrometer_visible.channel[:].polarizer.outline.x2 (alpha) | [spectrometer_visible.channel[:].polarizer.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
spectrometer_visible.channel[:].polarizer.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
spectrometer_visible.channel[:].polarizer.surface (alpha) |  | FLT_0D (uncertain) | m^2 | Surface of the detector/aperture, derived from the above geometric data
spectrometer_visible.channel[:].polarizer.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented in the positive phi direction (counter-clockwise when viewing from above).
spectrometer_visible.channel[:].polarizer.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].polarizer.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].polarizer.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].polarizer.x1_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X1 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].polarizer.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
spectrometer_visible.channel[:].polarizer.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].polarizer.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].polarizer.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].polarizer.x2_width (alpha) |  | FLT_0D (uncertain) | m | Full width of the aperture in the X2 direction, used only if geometry_type = 3
spectrometer_visible.channel[:].polarizer.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
spectrometer_visible.channel[:].polarizer.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_visible.channel[:].polarizer.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_visible.channel[:].polarizer.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_visible.channel[:].polarizer_active (alpha) |  | INT_0D |  | Indicator of whether a polarizer is present and active in the optical system (set to 1 in this case, set to 0 or leave empty ottherwise)
spectrometer_visible.channel[:].type (alpha) |  | STRUCTURE |  | Type of spectrometer the channel is connected to (index=1: grating, 2: filter)
spectrometer_visible.channel[:].type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_visible.channel[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_visible.channel[:].type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_visible.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].validity_timed.data (alpha) | [spectrometer_visible.channel[:].validity_timed.time] | INT_1D |  | Data
spectrometer_visible.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_visible.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
spectrometer_visible.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_visible.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
spectrometer_visible.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_visible.code.library[:].name (alpha) |  | STR_0D |  | Name of software
spectrometer_visible.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_visible.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_visible.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_visible.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
spectrometer_visible.code.output_flag (alpha) | [spectrometer_visible.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
spectrometer_visible.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_visible.code.repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_visible.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_visible.detector_layout (alpha) |  | STR_0D |  | Layout of the detector grid employed. Ex: '4x16', '4x32', '1x18'
spectrometer_visible.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
spectrometer_visible.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
spectrometer_visible.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
spectrometer_visible.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
spectrometer_visible.ids_properties.occurrence |  | INT_0D |  |
spectrometer_visible.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
spectrometer_visible.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
spectrometer_visible.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
spectrometer_visible.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
spectrometer_visible.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
spectrometer_visible.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
spectrometer_visible.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
spectrometer_x_ray_crystal (alpha) |  |  |  | X-crystal spectrometer diagnostic
spectrometer_x_ray_crystal.camera (alpha) |  | STRUCTURE |  | Characteristics of the camera used
spectrometer_x_ray_crystal.camera.camera_dimensions (alpha) | [1...2] | FLT_1D (uncertain) | m | Total camera dimension in each direction (horizontal, vertical)
spectrometer_x_ray_crystal.camera.centre (alpha) |  | STRUCTURE |  | Position of the camera centre
spectrometer_x_ray_crystal.camera.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_x_ray_crystal.camera.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_x_ray_crystal.camera.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_x_ray_crystal.camera.pixel_dimensions (alpha) | [1...2] | FLT_1D (uncertain) | m | Pixel dimension in each direction (horizontal, vertical)
spectrometer_x_ray_crystal.camera.pixel_n (alpha) | [1...2] | INT_1D |  | Number of pixels in each direction (horizontal, vertical)
spectrometer_x_ray_crystal.camera.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the camera plane and oriented towards the plasma.
spectrometer_x_ray_crystal.camera.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_x_ray_crystal.camera.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_x_ray_crystal.camera.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_x_ray_crystal.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
spectrometer_x_ray_crystal.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_x_ray_crystal.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
spectrometer_x_ray_crystal.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_x_ray_crystal.code.library[:].name (alpha) |  | STR_0D |  | Name of software
spectrometer_x_ray_crystal.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_x_ray_crystal.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_x_ray_crystal.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_x_ray_crystal.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
spectrometer_x_ray_crystal.code.output_flag (alpha) | [spectrometer_x_ray_crystal.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
spectrometer_x_ray_crystal.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_x_ray_crystal.code.repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_x_ray_crystal.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_x_ray_crystal.crystal (alpha) |  | STRUCTURE |  | Characteristics of the crystal used
spectrometer_x_ray_crystal.crystal.angle_bragg (alpha) |  | FLT_0D (uncertain) | rad | Bragg angle of the crystal
spectrometer_x_ray_crystal.crystal.angular_span_horizontal (alpha) |  | FLT_0D (uncertain) | rad | Angular span in the horizontal direction, to be filled only for geometry_type/index = 2, 3 or 4
spectrometer_x_ray_crystal.crystal.angular_span_vertical (alpha) |  | FLT_0D (uncertain) | rad | Angular span in the vertical direction, to be filled only for geometry_type/index = 4
spectrometer_x_ray_crystal.crystal.curvature_horizontal (alpha) |  | FLT_0D (uncertain) | m | Radius of curvature in the horizontal direction, to be filled only for shape/index = 2, 3 or 4
spectrometer_x_ray_crystal.crystal.curvature_vertical (alpha) |  | FLT_0D (uncertain) | m | Radius of curvature in the vertical direction, to be filled only for geometry_type/index = 4
spectrometer_x_ray_crystal.crystal.geometry_type (alpha) |  | STRUCTURE |  | Geometry of the crystal 1) planar : Planar 2) cylindrical : Cylindrical 3) spherical : Spherical 4) elliptical : Elliptical
spectrometer_x_ray_crystal.crystal.geometry_type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_x_ray_crystal.crystal.geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
spectrometer_x_ray_crystal.crystal.geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_x_ray_crystal.crystal.height (alpha) |  | FLT_0D (uncertain) | m | Height of the crystal (vertical direction)
spectrometer_x_ray_crystal.crystal.material (alpha) |  | STR_0D |  | Material of the crystal
spectrometer_x_ray_crystal.crystal.summit (alpha) |  | STRUCTURE |  | Position of the middle point on the crystal surface
spectrometer_x_ray_crystal.crystal.summit.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
spectrometer_x_ray_crystal.crystal.summit.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_x_ray_crystal.crystal.summit.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_x_ray_crystal.crystal.wavelength_bragg (alpha) |  | FLT_0D (uncertain) | m | Bragg wavelength of the crystal
spectrometer_x_ray_crystal.crystal.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal width of the crystal
spectrometer_x_ray_crystal.crystal.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the crystal plane and oriented towards the plasma.
spectrometer_x_ray_crystal.crystal.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
spectrometer_x_ray_crystal.crystal.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
spectrometer_x_ray_crystal.crystal.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
spectrometer_x_ray_crystal.energy_bound_lower (alpha) | [1...N, spectrometer_x_ray_crystal.z_frames] | FLT_2D (uncertain) | eV | Lower energy bound for the photon detection, for each pixel (horizontal, vertical)
spectrometer_x_ray_crystal.energy_bound_upper (alpha) | [1...N, spectrometer_x_ray_crystal.z_frames] | FLT_2D (uncertain) | eV | Upper energy bound for the photon detection, for each pixel (horizontal, vertical)
spectrometer_x_ray_crystal.filter_window (alpha) |  | STRUCTURE |  | Characteristics of the filter window
spectrometer_x_ray_crystal.filter_window.material (alpha) |  | STR_0D |  | Material of the filter window
spectrometer_x_ray_crystal.filter_window.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness of the filter window
spectrometer_x_ray_crystal.frame (alpha) | [spectrometer_x_ray_crystal.frame[:].time] | STRUCT_ARRAY |  | Set of frames
spectrometer_x_ray_crystal.frame[:].photon_count (alpha) | [1...N, spectrometer_x_ray_crystal.z_frames] | FLT_2D (uncertain) | (counts).s^-1 | Detected photon count per unit time on each pixel of the frame
spectrometer_x_ray_crystal.frame[:].time (alpha) |  | FLT_0D | s | Time
spectrometer_x_ray_crystal.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
spectrometer_x_ray_crystal.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
spectrometer_x_ray_crystal.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
spectrometer_x_ray_crystal.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
spectrometer_x_ray_crystal.ids_properties.occurrence |  | INT_0D |  |
spectrometer_x_ray_crystal.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
spectrometer_x_ray_crystal.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
spectrometer_x_ray_crystal.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
spectrometer_x_ray_crystal.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
spectrometer_x_ray_crystal.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
spectrometer_x_ray_crystal.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
spectrometer_x_ray_crystal.integration_time (alpha) |  | FLT_0D (uncertain) | s | Integration time of the measurement
spectrometer_x_ray_crystal.t_e_proxy (alpha) | [spectrometer_x_ray_crystal.z_frames] | STRUCTURE | eV | Electron temperature (proxy estimated directly from the camera, without tomographic inversion)
spectrometer_x_ray_crystal.t_e_proxy.data (alpha) | [1...N, spectrometer_x_ray_crystal.t_e_proxy.time] | FLT_2D (uncertain) | eV | Data
spectrometer_x_ray_crystal.t_e_proxy.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_x_ray_crystal.t_e_proxy.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.t_e_proxy.validity_timed (alpha) | [spectrometer_x_ray_crystal.t_e_proxy.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.t_i_proxy (alpha) | [spectrometer_x_ray_crystal.z_frames] | STRUCTURE | eV | Ion temperature (proxy estimated directly from the camera, without tomographic inversion)
spectrometer_x_ray_crystal.t_i_proxy.data (alpha) | [1...N, spectrometer_x_ray_crystal.t_i_proxy.time] | FLT_2D (uncertain) | eV | Data
spectrometer_x_ray_crystal.t_i_proxy.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_x_ray_crystal.t_i_proxy.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.t_i_proxy.validity_timed (alpha) | [spectrometer_x_ray_crystal.t_i_proxy.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
spectrometer_x_ray_crystal.velocity_tor_proxy (alpha) | [spectrometer_x_ray_crystal.z_frames] | STRUCTURE | m.s^-1 | Toroidal velocity (proxy estimated directly from the camera, without tomographic inversion)
spectrometer_x_ray_crystal.velocity_tor_proxy.data (alpha) | [1...N, spectrometer_x_ray_crystal.velocity_tor_proxy.time] | FLT_2D (uncertain) | m.s^-1 | Data
spectrometer_x_ray_crystal.velocity_tor_proxy.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
spectrometer_x_ray_crystal.velocity_tor_proxy.validity (alpha) |  | INT_0D |  | Indicator of the validity of the data for the whole acquisition period. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.velocity_tor_proxy.validity_timed (alpha) | [spectrometer_x_ray_crystal.velocity_tor_proxy.time] | INT_1D |  | Indicator of the validity of the data for each time slice. 0: valid from automated processing, 1: valid and certified by the diagnostic RO; - 1 means problem identified in the data processing (request verification by the diagnostic RO), -2: invalid data, should not be used (values lower than -2 have a code-specific meaning detailing the origin of their invalidity)
spectrometer_x_ray_crystal.wavelength_frames (alpha) | [1...N, spectrometer_x_ray_crystal.z_frames] | FLT_2D (uncertain) | m | Wavelength of incoming photons on each pixel of the frames, mainly varying accross the horizontal dimension of the frame. However a 2D map of the wavelength is given since it is not constant vertically due to the elliptical curvature of the photon iso-surfaces
spectrometer_x_ray_crystal.z_frames (alpha) | [1...N] | FLT_1D (uncertain) | m | Height of the observed zone at the focal plane in the plasma, corresponding to the vertical dimension of the frame

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
summary |  |  |  | Summary of physics quantities from a simulation or an experiment. Dynamic quantities are either taken at given time slices (indicated in the "time" vector) or time-averaged over an interval (in such case the "time_width" of the interval is indicated and the "time" vector represents the end of each time interval).
summary.boundary |  | STRUCTURE |  | Description of the plasma boundary
summary.boundary.elongation |  | STRUCTURE | - | Elongation of the plasma boundary
summary.boundary.elongation.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.elongation.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.boundary.gap_limiter_wall |  | STRUCTURE | m | Distance between the separatrix and the nearest limiter or wall element
summary.boundary.gap_limiter_wall.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.gap_limiter_wall.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.geometric_axis_r |  | STRUCTURE | m | R position of the geometric axis (defined as (Rmax+Rmin) / 2 of the boundary)
summary.boundary.geometric_axis_r.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.geometric_axis_r.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.geometric_axis_z |  | STRUCTURE | m | Z position of the geometric axis (defined as (Zmax+Zmin) / 2 of the boundary)
summary.boundary.geometric_axis_z.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.geometric_axis_z.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.magnetic_axis_r |  | STRUCTURE | m | R position of the magnetic axis
summary.boundary.magnetic_axis_r.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.magnetic_axis_r.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.magnetic_axis_z |  | STRUCTURE | m | Z position of the magnetic axis
summary.boundary.magnetic_axis_z.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.magnetic_axis_z.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.minor_radius |  | STRUCTURE | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
summary.boundary.minor_radius.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.minor_radius.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.strike_point_configuration |  | STRUCTURE |  | String describing the configuration of the strike points (constant, may need to become dynamic when available)
summary.boundary.strike_point_configuration.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.strike_point_configuration.value |  | STR_0D |  | Value
summary.boundary.strike_point_inner_r |  | STRUCTURE | m | R position of the inner strike point
summary.boundary.strike_point_inner_r.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.strike_point_inner_r.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.strike_point_inner_z |  | STRUCTURE | m | Z position of the inner strike point
summary.boundary.strike_point_inner_z.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.strike_point_inner_z.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.strike_point_outer_r |  | STRUCTURE | m | R position of the outer strike point
summary.boundary.strike_point_outer_r.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.strike_point_outer_r.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.strike_point_outer_z |  | STRUCTURE | m | Z position of the outer strike point
summary.boundary.strike_point_outer_z.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.strike_point_outer_z.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.boundary.triangularity_lower |  | STRUCTURE | - | Lower triangularity of the plasma boundary
summary.boundary.triangularity_lower.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.triangularity_lower.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.boundary.triangularity_upper |  | STRUCTURE | - | Upper triangularity of the plasma boundary
summary.boundary.triangularity_upper.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.triangularity_upper.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.boundary.type |  | STRUCTURE |  | 0 (limiter), 1 (diverted), 11 (LSN), 12 (USN), 13 (DN)
summary.boundary.type.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.boundary.type.value | [summary.time] | INT_1D |  | Value
summary.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
summary.code.commit |  | STR_0D |  | Unique commit reference of software
summary.code.library | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
summary.code.library[:].commit |  | STR_0D |  | Unique commit reference of software
summary.code.library[:].name |  | STR_0D |  | Name of software
summary.code.library[:].parameters |  | STR_0D |  | List of the code specific parameters in XML format
summary.code.library[:].repository |  | STR_0D |  | URL of software repository
summary.code.library[:].version |  | STR_0D |  | Unique version (tag) of software
summary.code.name |  | STR_0D |  | Name of software generating IDS
summary.code.output_flag | [summary.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
summary.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
summary.code.repository |  | STR_0D |  | URL of software repository
summary.code.version |  | STR_0D |  | Unique version (tag) of software
summary.configuration |  | STRUCTURE |  | Device configuration (the content may be device-specific)
summary.configuration.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.configuration.value |  | STR_0D |  | Value
summary.disruption |  | STRUCTURE |  | Disruption characteristics, if the pulse is terminated by a disruption
summary.disruption.mitigation_valve |  | STRUCTURE |  | Flag indicating whether any disruption mitigation valve has been used (1) or none (0)
summary.disruption.mitigation_valve.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.mitigation_valve.value |  | INT_0D |  | Value
summary.disruption.time |  | STRUCTURE | s | Time of the disruption
summary.disruption.time.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time.value |  | FLT_0D (uncertain) | s | Value
summary.disruption.time_half_ip |  | STRUCTURE | s | Time at which the plasma current has fallen to half of the initial current at the start of the disruption, relative to the time of the disruption
summary.disruption.time_half_ip.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time_half_ip.value |  | FLT_0D (uncertain) | s | Value
summary.disruption.time_radiated_power_max |  | STRUCTURE | s | Time of maximum radiated power, relative to the time of the disruption
summary.disruption.time_radiated_power_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time_radiated_power_max.value |  | FLT_0D (uncertain) | s | Value
summary.disruption.vertical_displacement |  | STRUCTURE | s | Direction of the plasma vertical displacement just before the disruption 1 (upwards) / 0 (no displacement)/ -1 (downwards)
summary.disruption.vertical_displacement.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.vertical_displacement.value |  | INT_0D |  | Value
summary.elms |  | STRUCTURE |  | Edge Localized Modes related quantities
summary.elms.frequency |  | STRUCTURE | Hz | ELMs frequency
summary.elms.frequency.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.elms.frequency.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.elms.type |  | STRUCTURE |  | ELMs type (I, II, III, ...)
summary.elms.type.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.elms.type.value | [summary.time] | INT_1D |  | Value
summary.fusion |  | STRUCTURE |  | Fusion reactions
summary.fusion.current |  | STRUCTURE | A | Parallel current driven by this fusion reactions
summary.fusion.current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.fusion.neutron_fluxes |  | STRUCTURE |  | Neutron fluxes from various reactions
summary.fusion.neutron_fluxes.dd |  | STRUCTURE |  | Neutron fluxes from DD reactions
summary.fusion.neutron_fluxes.dd.beam_beam |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.dd.beam_beam.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.beam_beam.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.beam_thermal |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.dd.beam_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.beam_thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.thermal |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.dd.thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.total |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.dd.total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.total.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt |  | STRUCTURE |  | Neutron fluxes from DT reactions
summary.fusion.neutron_fluxes.dt.beam_beam |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.dt.beam_beam.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.beam_beam.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.beam_thermal |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.dt.beam_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.beam_thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.thermal |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.dt.thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.total |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.dt.total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.total.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.thermal |  | STRUCTURE | Hz | Neutron flux from all plasma thermal reactions
summary.fusion.neutron_fluxes.thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.total |  | STRUCTURE | Hz | Total neutron flux from all reactions
summary.fusion.neutron_fluxes.total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.total.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt |  | STRUCTURE |  | Neutron fluxes from TT reactions
summary.fusion.neutron_fluxes.tt.beam_beam |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.tt.beam_beam.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.beam_beam.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.beam_thermal |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.tt.beam_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.beam_thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.thermal |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.tt.thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.thermal.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.total |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.tt.total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.total.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_power_total |  | STRUCTURE | W | Total neutron power (from all reactions)
summary.fusion.neutron_power_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_power_total.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.fusion.power |  | STRUCTURE | W | Power coupled to the plasma by fusion reactions
summary.fusion.power.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.power.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.gas_injection_rates |  | STRUCTURE | electrons.s^-1 | Gas injection rates in equivalent electrons.s^-1
summary.gas_injection_rates.ammonia |  | STRUCTURE |  | Ammonia (NH3)
summary.gas_injection_rates.ammonia.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.ammonia.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.ammonia_deuterated |  | STRUCTURE |  | Deuterated ammonia (ND3)
summary.gas_injection_rates.ammonia_deuterated.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.ammonia_deuterated.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.argon |  | STRUCTURE |  | Argon
summary.gas_injection_rates.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.argon.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.beryllium |  | STRUCTURE |  | Beryllium
summary.gas_injection_rates.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.beryllium.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.bottom |  | STRUCTURE |  | Gas injection rate from all valves located near near the bottom of the vaccuum chamber
summary.gas_injection_rates.bottom.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.bottom.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.carbon |  | STRUCTURE |  | Carbon
summary.gas_injection_rates.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.carbon.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.deuterium |  | STRUCTURE |  | Deuterium
summary.gas_injection_rates.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.deuterium.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.ethane |  | STRUCTURE |  | Ethane (C2H6)
summary.gas_injection_rates.ethane.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.ethane.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.ethylene |  | STRUCTURE |  | Ethylene (C2H4)
summary.gas_injection_rates.ethylene.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.ethylene.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.gas_injection_rates.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.helium_3.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.gas_injection_rates.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.helium_4.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.hydrogen |  | STRUCTURE |  | Hydrogen
summary.gas_injection_rates.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.hydrogen.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.impurity_seeding |  | STRUCTURE | Hz | Flag set to 1 if any gas other than H, D, T, He is puffed during the pulse, 0 otherwise
summary.gas_injection_rates.impurity_seeding.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.impurity_seeding.value |  | INT_0D |  | Value
summary.gas_injection_rates.krypton |  | STRUCTURE |  | Krypton
summary.gas_injection_rates.krypton.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.krypton.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.lithium |  | STRUCTURE |  | Lithium
summary.gas_injection_rates.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.lithium.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.methane |  | STRUCTURE |  | Methane (CH4)
summary.gas_injection_rates.methane.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.methane.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.methane_carbon_13 |  | STRUCTURE |  | Methane (CH4 with carbon 13)
summary.gas_injection_rates.methane_carbon_13.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.methane_carbon_13.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.methane_deuterated |  | STRUCTURE |  | Deuterated methane (CD4)
summary.gas_injection_rates.methane_deuterated.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.methane_deuterated.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.midplane |  | STRUCTURE |  | Gas injection rate from all valves located near the equatorial midplane
summary.gas_injection_rates.midplane.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.midplane.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.neon |  | STRUCTURE |  | Neon
summary.gas_injection_rates.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.neon.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.nitrogen |  | STRUCTURE |  | Nitrogen
summary.gas_injection_rates.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.nitrogen.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.oxygen |  | STRUCTURE |  | Oxygen
summary.gas_injection_rates.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.oxygen.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.propane |  | STRUCTURE |  | Propane (C3H8)
summary.gas_injection_rates.propane.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.propane.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.silane |  | STRUCTURE |  | Silane (SiH4)
summary.gas_injection_rates.silane.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.silane.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.top |  | STRUCTURE |  | Gas injection rate from all valves located near the top of the vaccuum chamber
summary.gas_injection_rates.top.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.top.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.total |  | STRUCTURE |  | Total gas injection rate (sum over species)
summary.gas_injection_rates.total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.total.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.tritium |  | STRUCTURE |  | Tritium
summary.gas_injection_rates.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.tritium.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.gas_injection_rates.xenon |  | STRUCTURE |  | Xenon
summary.gas_injection_rates.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.gas_injection_rates.xenon.value | [summary.time] | FLT_1D (uncertain) | electrons.s^-1 | Value
summary.global_quantities |  | STRUCTURE |  | Various global quantities derived from the profiles
summary.global_quantities.b0 |  | STRUCTURE | T | Vacuum toroidal field at R0. Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
summary.global_quantities.b0.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.b0.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.global_quantities.beta_pol |  | STRUCTURE | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
summary.global_quantities.beta_pol.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_pol.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_pol_mhd |  | STRUCTURE | - | Poloidal beta estimated from the pressure determined by an equilibrium reconstruction code. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
summary.global_quantities.beta_pol_mhd.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_pol_mhd.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor |  | STRUCTURE | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
summary.global_quantities.beta_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor_mhd |  | STRUCTURE | - | Toroidal beta, using the pressure determined by an equilibrium reconstruction code
summary.global_quantities.beta_tor_mhd.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor_mhd.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor_norm |  | STRUCTURE | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
summary.global_quantities.beta_tor_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor_norm.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor_norm_mhd |  | STRUCTURE | - | Normalised toroidal beta, using the pressure determined by an equilibrium reconstruction code
summary.global_quantities.beta_tor_norm_mhd.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor_norm_mhd.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor_thermal_norm |  | STRUCTURE | - | Normalised toroidal beta from thermal pressure only, defined as 100 * beta_tor_thermal * a[m] * B0 [T] / ip [MA]
summary.global_quantities.beta_tor_thermal_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor_thermal_norm.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.current_alignment |  | STRUCTURE | A | Figure of merit of the alignment of the current profile sources, defined in the following reference: http://iopscience.iop.org/article/10.1088/0029-5515/43/7/318
summary.global_quantities.current_alignment.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_alignment.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_bootstrap |  | STRUCTURE | A | Bootstrap current (toroidal component). Positive sign means anti-clockwise when viewed from above.
summary.global_quantities.current_bootstrap.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_bootstrap.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_non_inductive |  | STRUCTURE | A | Total non-inductive current (toroidal component). Positive sign means anti-clockwise when viewed from above.
summary.global_quantities.current_non_inductive.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_non_inductive.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_ohm |  | STRUCTURE | A | Ohmic current (toroidal component). Positive sign means anti-clockwise when viewed from above.
summary.global_quantities.current_ohm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_ohm.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.denergy_diamagnetic_dt |  | STRUCTURE | W | Time derivative of the diamagnetic plasma energy content
summary.global_quantities.denergy_diamagnetic_dt.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.denergy_diamagnetic_dt.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.denergy_thermal_dt |  | STRUCTURE | W | Time derivative of the thermal plasma energy content
summary.global_quantities.denergy_thermal_dt.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.denergy_thermal_dt.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.energy_b_field_pol |  | STRUCTURE | J | Poloidal magnetic plasma energy content = 1/(2.mu0) * integral over the plasma volume of b_field_pol^2
summary.global_quantities.energy_b_field_pol.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_b_field_pol.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_diamagnetic |  | STRUCTURE | J | Plasma diamagnetic energy content = 3/2 * integral over the plasma volume of the total perpendicular pressure
summary.global_quantities.energy_diamagnetic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_diamagnetic.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_electrons_thermal |  | STRUCTURE | J | Thermal electron plasma energy content = 3/2 * integral over the plasma volume of the thermal electron pressure
summary.global_quantities.energy_electrons_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_electrons_thermal.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_fast_parallel |  | STRUCTURE | J | Fast particles parallel energy content = 3/2 * integral over the plasma volume of the fast parallel pressure
summary.global_quantities.energy_fast_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_fast_parallel.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_fast_perpendicular |  | STRUCTURE | J | Fast particles perpendicular energy content = 3/2 * integral over the plasma volume of the fast perpendicular pressure
summary.global_quantities.energy_fast_perpendicular.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_fast_perpendicular.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_ion_total_thermal |  | STRUCTURE | J | Thermal ion plasma energy content (sum over the ion species) = 3/2 * integral over the plasma volume of the thermal ion pressure
summary.global_quantities.energy_ion_total_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_ion_total_thermal.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_mhd |  | STRUCTURE | J | Plasma energy content = 3/2 * integral over the plasma volume of the total kinetic pressure (pressure determined by an equilibrium reconstruction code)
summary.global_quantities.energy_mhd.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_mhd.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_thermal |  | STRUCTURE | J | Thermal plasma energy content = 3/2 * integral over the plasma volume of the thermal pressure
summary.global_quantities.energy_thermal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_thermal.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_total |  | STRUCTURE | J | Plasma energy content = 3/2 * integral over the plasma volume of the total kinetic pressure
summary.global_quantities.energy_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_total.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.fusion_gain |  | STRUCTURE | - | Fusion gain : ratio of the power provided by fusion reactions to the auxiliary power needed to heat the plasma. Often noted as Q in the litterature.
summary.global_quantities.fusion_gain.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.fusion_gain.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.greenwald_fraction |  | STRUCTURE | - | Greenwald fraction =line_average/n_e/value divided by (global_quantities/ip/value *1e6 * pi * minor_radius^2)
summary.global_quantities.greenwald_fraction.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.greenwald_fraction.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.h_98 |  | STRUCTURE | - | Energy confinement time enhancement factor over the IPB98(y,2) scaling
summary.global_quantities.h_98.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.h_98.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.h_mode |  | STRUCTURE |  | H-mode flag: 0 when the plasma is in L-mode and 1 when in H-mode
summary.global_quantities.h_mode.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.h_mode.value | [summary.time] | INT_1D |  | Value
summary.global_quantities.ip |  | STRUCTURE | A | Total plasma current (toroidal component). Positive sign means anti-clockwise when viewed from above.
summary.global_quantities.ip.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.ip.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.li |  | STRUCTURE | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
summary.global_quantities.li.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.li.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.li_mhd |  | STRUCTURE | - | Internal inductance as determined by an equilibrium reconstruction code. Use this only when the li node above is used for another estimation method and there is a need to store a second value of li (determined by an equilibrium reconstruction code). The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
summary.global_quantities.li_mhd.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.li_mhd.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.power_bremsstrahlung |  | STRUCTURE | W | Radiated power from Bremsstrahlung
summary.global_quantities.power_bremsstrahlung.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_bremsstrahlung.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_line |  | STRUCTURE | W | Radiated power from line radiation
summary.global_quantities.power_line.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_line.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_loss |  | STRUCTURE | W | Power through separatrix
summary.global_quantities.power_loss.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_loss.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_ohm |  | STRUCTURE | W | Ohmic power
summary.global_quantities.power_ohm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_ohm.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_radiated |  | STRUCTURE | W | Radiated power
summary.global_quantities.power_radiated.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_radiated.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_steady |  | STRUCTURE | W | Total power coupled to the plasma minus dW/dt (correcting from transient energy content)
summary.global_quantities.power_steady.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_steady.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.power_synchrotron |  | STRUCTURE | W | Radiated power from synchrotron radiation
summary.global_quantities.power_synchrotron.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.power_synchrotron.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities.q_95 |  | STRUCTURE | - | q at the 95% poloidal flux surface (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
summary.global_quantities.q_95.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.q_95.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.r0 |  | STRUCTURE | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)
summary.global_quantities.r0.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.r0.value |  | FLT_0D (uncertain) | m | Value
summary.global_quantities.ratio_tau_helium_fuel |  | STRUCTURE | - | Ratio of Helium confinement time to fuel confinement time
summary.global_quantities.ratio_tau_helium_fuel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.ratio_tau_helium_fuel.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.resistance |  | STRUCTURE | ohm | Plasma electric resistance
summary.global_quantities.resistance.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.resistance.value | [summary.time] | FLT_1D (uncertain) | ohm | Value
summary.global_quantities.tau_energy |  | STRUCTURE | s | Energy confinement time
summary.global_quantities.tau_energy.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_energy.value | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.tau_energy_98 |  | STRUCTURE | s | Energy confinement time estimated from the IPB98(y,2) scaling
summary.global_quantities.tau_energy_98.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_energy_98.value | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.tau_helium |  | STRUCTURE | s | Helium confinement time
summary.global_quantities.tau_helium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_helium.value | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.tau_resistive |  | STRUCTURE | s | Current diffusion characteristic time
summary.global_quantities.tau_resistive.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_resistive.value | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.v_loop |  | STRUCTURE | V | LCFS loop voltage (positive value drives positive ohmic current that flows anti-clockwise when viewed from above)
summary.global_quantities.v_loop.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.v_loop.value | [summary.time] | FLT_1D (uncertain) | V | Value
summary.global_quantities.volume |  | STRUCTURE | m^3 | Volume of the confined plasma
summary.global_quantities.volume.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.volume.value | [summary.time] | FLT_1D (uncertain) | m^3 | Value
summary.heating_current_drive |  | STRUCTURE |  | Heating and current drive parameters
summary.heating_current_drive.ec | [1...N] | STRUCT_ARRAY |  | Set of ECRH/ECCD launchers
summary.heating_current_drive.ec[:].angle_pol |  | STRUCTURE | rad | Poloidal angle of ECRH at resonance
summary.heating_current_drive.ec[:].angle_pol.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].angle_pol.value | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ec[:].angle_tor |  | STRUCTURE | rad | Toroidal angle of ECRH at resonance
summary.heating_current_drive.ec[:].angle_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].angle_tor.value | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ec[:].current |  | STRUCTURE | A | Parallel current driven by EC waves
summary.heating_current_drive.ec[:].current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.ec[:].energy_fast |  | STRUCTURE | J | Fast particle energy content driven by EC waves
summary.heating_current_drive.ec[:].energy_fast.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].energy_fast.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.ec[:].frequency |  | STRUCTURE | Hz | ECRH frequency
summary.heating_current_drive.ec[:].frequency.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].frequency.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.ec[:].harmonic |  | STRUCTURE |  | Harmonic number of the absorbed ECRH waves
summary.heating_current_drive.ec[:].harmonic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].harmonic.value | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ec[:].polarisation |  | STRUCTURE |  | Polarisation of the ECRH waves (0 = O mode, 1 = X mode)
summary.heating_current_drive.ec[:].polarisation.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].polarisation.value | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ec[:].position |  | STRUCTURE | - | Position of the maximum of the ECRH power deposition, in rho_tor_norm
summary.heating_current_drive.ec[:].position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ec[:].power |  | STRUCTURE | W | Electron cyclotron heating power coupled to the plasma from this launcher
summary.heating_current_drive.ec[:].power.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].power.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.ec[:].power_launched |  | STRUCTURE | W | Electron cyclotron heating power launched into the vacuum vessel from this launcher
summary.heating_current_drive.ec[:].power_launched.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].power_launched.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.ic | [1...N] | STRUCT_ARRAY |  | Set of ICRH launchers
summary.heating_current_drive.ic[:].current |  | STRUCTURE | A | Parallel current driven by IC waves
summary.heating_current_drive.ic[:].current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio |  | STRUCTURE | - | Average E+/E- power ratio of IC waves
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ic[:].energy_fast |  | STRUCTURE | J | Fast particle energy content driven by IC waves
summary.heating_current_drive.ic[:].energy_fast.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].energy_fast.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.ic[:].frequency |  | STRUCTURE | Hz | ICRH frequency
summary.heating_current_drive.ic[:].frequency.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].frequency.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.ic[:].harmonic |  | STRUCTURE |  | Harmonic number of the absorbed ICRH waves
summary.heating_current_drive.ic[:].harmonic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].harmonic.value | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ic[:].k_perpendicular |  | STRUCTURE | m^-1 | Main perpendicular wave number of IC waves
summary.heating_current_drive.ic[:].k_perpendicular.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].k_perpendicular.value | [summary.time] | FLT_1D (uncertain) | m^-1 | Value
summary.heating_current_drive.ic[:].n_tor |  | STRUCTURE |  | Main toroidal mode number of IC waves
summary.heating_current_drive.ic[:].n_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].n_tor.value | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ic[:].phase |  | STRUCTURE | rad | Phase between straps
summary.heating_current_drive.ic[:].phase.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].phase.value | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ic[:].position |  | STRUCTURE | - | Position of the maximum of the ICRH power deposition, in rho_tor_norm
summary.heating_current_drive.ic[:].position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ic[:].power |  | STRUCTURE | W | IC heating power coupled to the plasma from this launcher
summary.heating_current_drive.ic[:].power.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].power.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.ic[:].power_launched |  | STRUCTURE | W | IC heating power launched into the vacuum vessel from this launcher
summary.heating_current_drive.ic[:].power_launched.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].power_launched.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.lh | [1...N] | STRUCT_ARRAY |  | Set of LHCD launchers
summary.heating_current_drive.lh[:].current |  | STRUCTURE | A | Parallel current driven by LH waves
summary.heating_current_drive.lh[:].current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.lh[:].energy_fast |  | STRUCTURE | J | Fast particle energy content driven by LH waves
summary.heating_current_drive.lh[:].energy_fast.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].energy_fast.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.lh[:].frequency |  | STRUCTURE | Hz | LH wave frequency
summary.heating_current_drive.lh[:].frequency.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].frequency.value | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.lh[:].n_parallel |  | STRUCTURE | - | Main parallel refractive index of LH waves at launch
summary.heating_current_drive.lh[:].n_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].n_parallel.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.lh[:].position |  | STRUCTURE | - | Position of the maximum of the LH power deposition, in rho_tor_norm
summary.heating_current_drive.lh[:].position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.lh[:].power |  | STRUCTURE | W | LH heating power coupled to the plasma from this launcher
summary.heating_current_drive.lh[:].power.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].power.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.lh[:].power_launched |  | STRUCTURE | W | LH heating power launched into the vacuum vessel from this launcher
summary.heating_current_drive.lh[:].power_launched.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].power_launched.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.nbi | [1...N] | STRUCT_ARRAY |  | Set of NBI units
summary.heating_current_drive.nbi[:].angle |  | STRUCTURE | rad | Angle of inclination between a beamlet at the centre of the injection unit surface and the horiontal plane
summary.heating_current_drive.nbi[:].angle.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].angle.value |  | FLT_0D (uncertain) | rad | Value
summary.heating_current_drive.nbi[:].beam_current_fraction |  | STRUCTURE | - | Fractions of beam current distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
summary.heating_current_drive.nbi[:].beam_current_fraction.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].beam_current_fraction.value | [1...3, summary.time] | FLT_2D (uncertain) | - | Value
summary.heating_current_drive.nbi[:].beam_power_fraction |  | STRUCTURE | - | Fractions of beam power distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
summary.heating_current_drive.nbi[:].beam_power_fraction.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].beam_power_fraction.value | [1...3, summary.time] | FLT_2D (uncertain) | - | Value
summary.heating_current_drive.nbi[:].current |  | STRUCTURE | A | Parallel current driven by this NBI unit
summary.heating_current_drive.nbi[:].current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.nbi[:].direction |  | STRUCTURE |  | Direction of the beam seen from above the torus: -1 = clockwise; 1 = counter clockwise
summary.heating_current_drive.nbi[:].direction.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].direction.value |  | INT_0D |  | Value
summary.heating_current_drive.nbi[:].energy |  | STRUCTURE | eV | Full energy of the injected species (acceleration of a single atom)
summary.heating_current_drive.nbi[:].energy.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].energy.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.heating_current_drive.nbi[:].position |  | STRUCTURE |  | R, Z, Phi position of the NBI unit centre
summary.heating_current_drive.nbi[:].position.phi |  | STRUCTURE | rad | Toroidal angle
summary.heating_current_drive.nbi[:].position.phi.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.phi.value |  | FLT_0D (uncertain) | rad | Value
summary.heating_current_drive.nbi[:].position.r |  | STRUCTURE | m | Major radius
summary.heating_current_drive.nbi[:].position.r.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.r.value |  | FLT_0D (uncertain) | m | Value
summary.heating_current_drive.nbi[:].position.z |  | STRUCTURE | m | Height
summary.heating_current_drive.nbi[:].position.z.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.z.value |  | FLT_0D (uncertain) | m | Value
summary.heating_current_drive.nbi[:].power |  | STRUCTURE | W | NBI power coupled to the plasma by this unit (i.e. without shine-through and fast ion losses)
summary.heating_current_drive.nbi[:].power.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].power.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.nbi[:].power_launched |  | STRUCTURE | W | NBI power launched into the vacuum vessel from this unit
summary.heating_current_drive.nbi[:].power_launched.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].power_launched.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.nbi[:].species |  | STRUCTURE |  | Injected species
summary.heating_current_drive.nbi[:].species.a |  | STRUCTURE | Atomic Mass Unit | Mass of atom
summary.heating_current_drive.nbi[:].species.a.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.a.value |  | FLT_0D (uncertain) | Atomic Mass Unit | Value
summary.heating_current_drive.nbi[:].species.label |  | STRUCTURE |  | String identifying the species (e.g. H, D, T, ...)
summary.heating_current_drive.nbi[:].species.label.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.label.value |  | STR_0D |  | Value
summary.heating_current_drive.nbi[:].species.z_n |  | STRUCTURE | Elementary Charge Unit | Nuclear charge
summary.heating_current_drive.nbi[:].species.z_n.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.z_n.value |  | FLT_0D (uncertain) | Elementary Charge Unit | Value
summary.heating_current_drive.nbi[:].tangency_radius |  | STRUCTURE | m | Tangency radius (major radius where the central line of a NBI unit is tangent to a circle around the torus)
summary.heating_current_drive.nbi[:].tangency_radius.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].tangency_radius.value |  | FLT_0D (uncertain) | m | Value
summary.heating_current_drive.power_additional |  | STRUCTURE | W | Total additional external power (NBI+EC+IC+LH, without ohmic) coupled to the plasma
summary.heating_current_drive.power_additional.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_additional.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_ec |  | STRUCTURE | W | Total EC power coupled to the plasma
summary.heating_current_drive.power_ec.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_ec.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_ic |  | STRUCTURE | W | Total IC power coupled to the plasma
summary.heating_current_drive.power_ic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_ic.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_launched_ec |  | STRUCTURE | W | Total EC power launched from EC antennas into the vacuum vessel
summary.heating_current_drive.power_launched_ec.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_launched_ec.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_launched_ic |  | STRUCTURE | W | Total IC power launched from IC antennas into the vacuum vessel
summary.heating_current_drive.power_launched_ic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_launched_ic.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_launched_lh |  | STRUCTURE | W | Total LH power launched from LH antennas into the vacuum vessel
summary.heating_current_drive.power_launched_lh.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_launched_lh.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_launched_nbi |  | STRUCTURE | W | Total NBI power launched from neutral beam injectors into the vacuum vessel
summary.heating_current_drive.power_launched_nbi.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_launched_nbi.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_launched_nbi_co_injected_ratio |  | STRUCTURE | - | Ratio of co-injected beam launched power to total NBI launched power. Is set to 1 for purely perpendicular injection
summary.heating_current_drive.power_launched_nbi_co_injected_ratio.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_launched_nbi_co_injected_ratio.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.power_lh |  | STRUCTURE | W | Total LH power coupled to the plasma
summary.heating_current_drive.power_lh.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_lh.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.power_nbi |  | STRUCTURE | W | Total NBI power coupled to the plasma
summary.heating_current_drive.power_nbi.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.power_nbi.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
summary.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
summary.ids_properties.creation_date |  | STR_0D |  | Date at which this data has been produced
summary.ids_properties.homogeneous_time |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
summary.ids_properties.occurrence |  | INT_0D |  |
summary.ids_properties.provider |  | STR_0D |  | Name of the person in charge of producing this data
summary.ids_properties.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.ids_properties.version_put |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
summary.ids_properties.version_put.access_layer |  | STR_0D |  | Version of Access Layer used to PUT this IDS
summary.ids_properties.version_put.access_layer_language |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
summary.ids_properties.version_put.data_dictionary |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
summary.kicks |  | STRUCTURE |  | Vertical kicks of the plasma position
summary.kicks.occurrence |  | STRUCTURE | Hz | Flag set to 1 if vecrtical kicks of the plasma position are used during the pulse, 0 otherwise
summary.kicks.occurrence.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.kicks.occurrence.value |  | INT_0D |  | Value
summary.limiter |  | STRUCTURE |  | Limiter characteristics
summary.limiter.material |  | STRUCTURE |  | Limiter material 0) unspecified : unspecified 1) C : Carbon 2) W : Tungsten 3) C_W_coating : Carbon with tungsten coating 4) SS : Stainless steel 5) SS_C_coating : Stainless steel with carbon coating 6) IN : Inconel 7) IN_C_coating : Inconel with carbon coating 8) B_C : Boron carbide 9) Ti_C_coating : Titanium with carbon coating 10) Be : Beryllium
summary.limiter.material.description |  | STR_0D |  | Verbose description
summary.limiter.material.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
summary.limiter.material.name |  | STR_0D |  | Short string identifier
summary.line_average |  | STRUCTURE |  | Line average plasma parameters
summary.line_average.dn_e_dt |  | STRUCTURE | m^-3.s-1 | Time derivative of the electron density
summary.line_average.dn_e_dt.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.dn_e_dt.value | [summary.time] | FLT_1D (uncertain) | m^-3.s-1 | Value
summary.line_average.isotope_fraction_hydrogen |  | STRUCTURE | - | Fraction of hydrogen density among the hydrogenic species (nH/(nH+nD+nT))
summary.line_average.isotope_fraction_hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.isotope_fraction_hydrogen.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.line_average.meff_hydrogenic |  | STRUCTURE | amu | Effective mass of the hydrogenic species (MH. nH+MD.nD+MT.nT)/(nH+nD+nT)
summary.line_average.meff_hydrogenic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.meff_hydrogenic.value | [summary.time] | FLT_1D (uncertain) | amu | Value
summary.line_average.n_e |  | STRUCTURE | m^-3 | Electron density
summary.line_average.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.line_average.n_i.argon |  | STRUCTURE |  | Argon
summary.line_average.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.line_average.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.carbon |  | STRUCTURE |  | Carbon
summary.line_average.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.line_average.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.line_average.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.line_average.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.line_average.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.lithium |  | STRUCTURE |  | Lithium
summary.line_average.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.neon |  | STRUCTURE |  | Neon
summary.line_average.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.line_average.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.line_average.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.tritium |  | STRUCTURE |  | Tritium
summary.line_average.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.line_average.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.xenon |  | STRUCTURE |  | Xenon
summary.line_average.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.line_average.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.t_e |  | STRUCTURE | eV | Electron temperature
summary.line_average.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.line_average.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.line_average.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.line_average.zeff |  | STRUCTURE | - | Effective charge
summary.line_average.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local |  | STRUCTURE |  | Plasma parameter values at different locations
summary.local.divertor_plate | [1...N] | STRUCT_ARRAY |  | Parameters at a divertor plate
summary.local.divertor_plate[:].flux_expansion |  | STRUCTURE | - | Flux expansion
summary.local.divertor_plate[:].flux_expansion.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].flux_expansion.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.divertor_plate[:].n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.divertor_plate[:].n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.divertor_plate[:].n_i.argon |  | STRUCTURE |  | Argon
summary.local.divertor_plate[:].n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.divertor_plate[:].n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.divertor_plate[:].n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.divertor_plate[:].n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.divertor_plate[:].n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.divertor_plate[:].n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.divertor_plate[:].n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.divertor_plate[:].n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.neon |  | STRUCTURE |  | Neon
summary.local.divertor_plate[:].n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.divertor_plate[:].n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.divertor_plate[:].n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.divertor_plate[:].n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.divertor_plate[:].n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.divertor_plate[:].n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.divertor_plate[:].n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].name |  | STRUCTURE |  | Name of the limiter or divertor plate
summary.local.divertor_plate[:].name.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].name.value |  | STR_0D |  | Value
summary.local.divertor_plate[:].t_e |  | STRUCTURE | eV | Electron temperature
summary.local.divertor_plate[:].t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.divertor_plate[:].t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.divertor_plate[:].t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.divertor_plate[:].zeff |  | STRUCTURE | - | Effective charge
summary.local.divertor_plate[:].zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb |  | STRUCTURE |  | Parameters at internal transport barrier
summary.local.itb.e_field_parallel |  | STRUCTURE | V.m^-1 | Component of electric field parallel to magnetic field
summary.local.itb.e_field_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.e_field_parallel.value | [summary.time] | FLT_1D (uncertain) | V.m^-1 | Value
summary.local.itb.magnetic_shear |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.itb.magnetic_shear.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.magnetic_shear.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb.momentum_tor |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.itb.momentum_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.momentum_tor.value | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.itb.n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.itb.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.itb.n_i.argon |  | STRUCTURE |  | Argon
summary.local.itb.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.itb.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.itb.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.itb.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.itb.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.itb.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.itb.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.itb.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.neon |  | STRUCTURE |  | Neon
summary.local.itb.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.itb.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.itb.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.itb.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.itb.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.itb.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.itb.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.position |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.itb.position.psi | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.itb.position.rho_tor | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.itb.position.rho_tor_norm | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.itb.q |  | STRUCTURE | - | Safety factor
summary.local.itb.q.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.q.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb.t_e |  | STRUCTURE | eV | Electron temperature
summary.local.itb.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.itb.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.itb.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.itb.velocity_tor |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.itb.velocity_tor.argon |  | STRUCTURE |  | Argon
summary.local.itb.velocity_tor.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.argon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.beryllium |  | STRUCTURE |  | Beryllium
summary.local.itb.velocity_tor.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.beryllium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.carbon |  | STRUCTURE |  | Carbon
summary.local.itb.velocity_tor.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.carbon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.deuterium |  | STRUCTURE |  | Deuterium
summary.local.itb.velocity_tor.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.deuterium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.itb.velocity_tor.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.helium_3.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.itb.velocity_tor.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.helium_4.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.itb.velocity_tor.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.lithium |  | STRUCTURE |  | Lithium
summary.local.itb.velocity_tor.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.lithium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.neon |  | STRUCTURE |  | Neon
summary.local.itb.velocity_tor.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.neon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.itb.velocity_tor.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.oxygen |  | STRUCTURE |  | Oxygen
summary.local.itb.velocity_tor.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.oxygen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.tritium |  | STRUCTURE |  | Tritium
summary.local.itb.velocity_tor.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.tritium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.tungsten |  | STRUCTURE |  | Tungsten
summary.local.itb.velocity_tor.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.tungsten.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.xenon |  | STRUCTURE |  | Xenon
summary.local.itb.velocity_tor.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.xenon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.zeff |  | STRUCTURE | - | Effective charge
summary.local.itb.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.limiter |  | STRUCTURE |  | Parameters at the limiter
summary.local.limiter.flux_expansion |  | STRUCTURE | - | Flux expansion
summary.local.limiter.flux_expansion.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.flux_expansion.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.limiter.n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.limiter.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.limiter.n_i.argon |  | STRUCTURE |  | Argon
summary.local.limiter.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.limiter.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.limiter.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.limiter.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.limiter.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.limiter.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.limiter.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.limiter.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.neon |  | STRUCTURE |  | Neon
summary.local.limiter.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.limiter.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.limiter.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.limiter.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.limiter.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.limiter.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.limiter.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.name |  | STRUCTURE |  | Name of the limiter or divertor plate
summary.local.limiter.name.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.name.value |  | STR_0D |  | Value
summary.local.limiter.t_e |  | STRUCTURE | eV | Electron temperature
summary.local.limiter.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.limiter.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.limiter.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.limiter.zeff |  | STRUCTURE | - | Effective charge
summary.local.limiter.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis |  | STRUCTURE |  | Parameters at magnetic axis
summary.local.magnetic_axis.b_field |  | STRUCTURE | T | Magnetic field
summary.local.magnetic_axis.b_field.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.b_field.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.local.magnetic_axis.e_field_parallel |  | STRUCTURE | V.m^-1 | Component of electric field parallel to magnetic field
summary.local.magnetic_axis.e_field_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.e_field_parallel.value | [summary.time] | FLT_1D (uncertain) | V.m^-1 | Value
summary.local.magnetic_axis.magnetic_shear |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.magnetic_axis.magnetic_shear.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.magnetic_shear.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis.momentum_tor |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.magnetic_axis.momentum_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.momentum_tor.value | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.magnetic_axis.n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.magnetic_axis.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.magnetic_axis.n_i.argon |  | STRUCTURE |  | Argon
summary.local.magnetic_axis.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.magnetic_axis.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.magnetic_axis.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.magnetic_axis.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.magnetic_axis.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.magnetic_axis.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.magnetic_axis.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.magnetic_axis.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.neon |  | STRUCTURE |  | Neon
summary.local.magnetic_axis.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.magnetic_axis.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.magnetic_axis.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.magnetic_axis.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.magnetic_axis.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.magnetic_axis.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.magnetic_axis.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.position |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.magnetic_axis.position.psi | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.magnetic_axis.position.r | [summary.time] | FLT_1D (uncertain) | m | Major radius
summary.local.magnetic_axis.position.rho_tor | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.magnetic_axis.position.rho_tor_norm | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.magnetic_axis.position.z | [summary.time] | FLT_1D (uncertain) | m | Height
summary.local.magnetic_axis.q |  | STRUCTURE | - | Safety factor (IMAS uses COCOS=11: only positive when toroidal current and magnetic field are in same direction)
summary.local.magnetic_axis.q.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.q.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis.t_e |  | STRUCTURE | eV | Electron temperature
summary.local.magnetic_axis.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.magnetic_axis.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.magnetic_axis.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.magnetic_axis.velocity_tor |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.magnetic_axis.velocity_tor.argon |  | STRUCTURE |  | Argon
summary.local.magnetic_axis.velocity_tor.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.argon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.beryllium |  | STRUCTURE |  | Beryllium
summary.local.magnetic_axis.velocity_tor.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.beryllium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.carbon |  | STRUCTURE |  | Carbon
summary.local.magnetic_axis.velocity_tor.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.carbon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.deuterium |  | STRUCTURE |  | Deuterium
summary.local.magnetic_axis.velocity_tor.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.deuterium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.magnetic_axis.velocity_tor.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.helium_3.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.magnetic_axis.velocity_tor.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.helium_4.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.magnetic_axis.velocity_tor.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.lithium |  | STRUCTURE |  | Lithium
summary.local.magnetic_axis.velocity_tor.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.lithium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.neon |  | STRUCTURE |  | Neon
summary.local.magnetic_axis.velocity_tor.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.neon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.magnetic_axis.velocity_tor.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.oxygen |  | STRUCTURE |  | Oxygen
summary.local.magnetic_axis.velocity_tor.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.oxygen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.tritium |  | STRUCTURE |  | Tritium
summary.local.magnetic_axis.velocity_tor.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.tritium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.tungsten |  | STRUCTURE |  | Tungsten
summary.local.magnetic_axis.velocity_tor.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.tungsten.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.xenon |  | STRUCTURE |  | Xenon
summary.local.magnetic_axis.velocity_tor.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.xenon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.zeff |  | STRUCTURE | - | Effective charge
summary.local.magnetic_axis.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal |  | STRUCTURE |  | Parameters at pedestal top
summary.local.pedestal.e_field_parallel |  | STRUCTURE | V.m^-1 | Component of electric field parallel to magnetic field
summary.local.pedestal.e_field_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.e_field_parallel.value | [summary.time] | FLT_1D (uncertain) | V.m^-1 | Value
summary.local.pedestal.magnetic_shear |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.pedestal.magnetic_shear.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.magnetic_shear.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal.momentum_tor |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.pedestal.momentum_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.momentum_tor.value | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.pedestal.n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.pedestal.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.pedestal.n_i.argon |  | STRUCTURE |  | Argon
summary.local.pedestal.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.pedestal.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.pedestal.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.pedestal.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.pedestal.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.pedestal.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.pedestal.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.pedestal.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.neon |  | STRUCTURE |  | Neon
summary.local.pedestal.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.pedestal.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.pedestal.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.pedestal.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.pedestal.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.pedestal.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.pedestal.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.position |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.pedestal.position.psi | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.pedestal.position.rho_tor | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.pedestal.position.rho_tor_norm | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.pedestal.q |  | STRUCTURE | - | Safety factor
summary.local.pedestal.q.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.q.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal.t_e |  | STRUCTURE | eV | Electron temperature
summary.local.pedestal.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.pedestal.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.pedestal.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.pedestal.velocity_tor |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.pedestal.velocity_tor.argon |  | STRUCTURE |  | Argon
summary.local.pedestal.velocity_tor.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.argon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.beryllium |  | STRUCTURE |  | Beryllium
summary.local.pedestal.velocity_tor.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.beryllium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.carbon |  | STRUCTURE |  | Carbon
summary.local.pedestal.velocity_tor.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.carbon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.deuterium |  | STRUCTURE |  | Deuterium
summary.local.pedestal.velocity_tor.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.deuterium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.pedestal.velocity_tor.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.helium_3.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.pedestal.velocity_tor.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.helium_4.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.pedestal.velocity_tor.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.lithium |  | STRUCTURE |  | Lithium
summary.local.pedestal.velocity_tor.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.lithium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.neon |  | STRUCTURE |  | Neon
summary.local.pedestal.velocity_tor.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.neon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.pedestal.velocity_tor.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.oxygen |  | STRUCTURE |  | Oxygen
summary.local.pedestal.velocity_tor.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.oxygen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.tritium |  | STRUCTURE |  | Tritium
summary.local.pedestal.velocity_tor.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.tritium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.tungsten |  | STRUCTURE |  | Tungsten
summary.local.pedestal.velocity_tor.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.tungsten.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.xenon |  | STRUCTURE |  | Xenon
summary.local.pedestal.velocity_tor.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.xenon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.zeff |  | STRUCTURE | - | Effective charge
summary.local.pedestal.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.r_eff_norm_2_3 |  | STRUCTURE |  | Parameters at r_eff_norm = 2/3, where r_eff_norm is the stellarator effective minor radius normalised to its value at the last closed flux surface
summary.local.r_eff_norm_2_3.effective_helical_ripple |  | STRUCTURE | - | Effective helical ripple for 1/nu neoclassical regime (see [Beidler, C. D., and W. N. G. Hitchon, 1994, Plasma Phys. Control. Fusion 35, 317])
summary.local.r_eff_norm_2_3.effective_helical_ripple.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.r_eff_norm_2_3.effective_helical_ripple.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.r_eff_norm_2_3.iota |  | STRUCTURE | - | Rotational transform (1/q)
summary.local.r_eff_norm_2_3.iota.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.r_eff_norm_2_3.iota.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.r_eff_norm_2_3.plateau_factor |  | STRUCTURE | - | Plateau factor, as defined in equation (25) of reference [Stroth U. et al 1998 Plasma Phys. Control. Fusion 40 1551]
summary.local.r_eff_norm_2_3.plateau_factor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.r_eff_norm_2_3.plateau_factor.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.separatrix |  | STRUCTURE |  | Parameters at separatrix
summary.local.separatrix.e_field_parallel |  | STRUCTURE | V.m^-1 | Component of electric field parallel to magnetic field
summary.local.separatrix.e_field_parallel.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.e_field_parallel.value | [summary.time] | FLT_1D (uncertain) | V.m^-1 | Value
summary.local.separatrix.magnetic_shear |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.separatrix.magnetic_shear.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.magnetic_shear.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.separatrix.momentum_tor |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.separatrix.momentum_tor.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.momentum_tor.value | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.separatrix.n_e |  | STRUCTURE | m^-3 | Electron density
summary.local.separatrix.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.local.separatrix.n_i.argon |  | STRUCTURE |  | Argon
summary.local.separatrix.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.local.separatrix.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.carbon |  | STRUCTURE |  | Carbon
summary.local.separatrix.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.local.separatrix.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.separatrix.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.separatrix.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.separatrix.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.lithium |  | STRUCTURE |  | Lithium
summary.local.separatrix.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.neon |  | STRUCTURE |  | Neon
summary.local.separatrix.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.separatrix.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.local.separatrix.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.tritium |  | STRUCTURE |  | Tritium
summary.local.separatrix.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.local.separatrix.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i.xenon |  | STRUCTURE |  | Xenon
summary.local.separatrix.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.separatrix.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.separatrix.position |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.separatrix.position.psi | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.separatrix.position.rho_tor | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.separatrix.position.rho_tor_norm | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.separatrix.q |  | STRUCTURE | - | Safety factor
summary.local.separatrix.q.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.q.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.separatrix.t_e |  | STRUCTURE | eV | Electron temperature
summary.local.separatrix.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.separatrix.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.separatrix.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.separatrix.velocity_tor |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.separatrix.velocity_tor.argon |  | STRUCTURE |  | Argon
summary.local.separatrix.velocity_tor.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.argon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.beryllium |  | STRUCTURE |  | Beryllium
summary.local.separatrix.velocity_tor.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.beryllium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.carbon |  | STRUCTURE |  | Carbon
summary.local.separatrix.velocity_tor.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.carbon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.deuterium |  | STRUCTURE |  | Deuterium
summary.local.separatrix.velocity_tor.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.deuterium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.separatrix.velocity_tor.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.helium_3.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.separatrix.velocity_tor.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.helium_4.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.hydrogen |  | STRUCTURE |  | Hydrogen
summary.local.separatrix.velocity_tor.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.lithium |  | STRUCTURE |  | Lithium
summary.local.separatrix.velocity_tor.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.lithium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.neon |  | STRUCTURE |  | Neon
summary.local.separatrix.velocity_tor.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.neon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.nitrogen |  | STRUCTURE |  | Nitrogen
summary.local.separatrix.velocity_tor.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.oxygen |  | STRUCTURE |  | Oxygen
summary.local.separatrix.velocity_tor.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.oxygen.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.tritium |  | STRUCTURE |  | Tritium
summary.local.separatrix.velocity_tor.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.tritium.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.tungsten |  | STRUCTURE |  | Tungsten
summary.local.separatrix.velocity_tor.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.tungsten.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.velocity_tor.xenon |  | STRUCTURE |  | Xenon
summary.local.separatrix.velocity_tor.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.velocity_tor.xenon.value | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.separatrix.zeff |  | STRUCTURE | - | Effective charge
summary.local.separatrix.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.separatrix.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.magnetic_shear_flag |  | STRUCTURE |  | Magnetic field shear indicator for stellarators: 0 for shearless stellarators (W7-A, W7-AS, W7-X); 1, otherwise. See [Stroth U. et al 1996 Nucl. Fusion 36 1063]
summary.magnetic_shear_flag.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.magnetic_shear_flag.value |  | INT_0D |  | Value
summary.pedestal_fits |  | STRUCTURE |  | Quantities derived from specific fits of pedestal profiles, typically used in the Pedestal Database.
summary.pedestal_fits.linear |  | STRUCTURE |  | Quantities related to linear fit
summary.pedestal_fits.linear.b_field_pedestal_top_hfs |  | STRUCTURE | T | Total magnetic field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.linear.b_field_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_pedestal_top_lfs |  | STRUCTURE | T | Total magnetic field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.linear.b_field_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_pol_pedestal_top_average |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) and averaged over the flux surface
summary.pedestal_fits.linear.b_field_pol_pedestal_top_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_pol_pedestal_top_average.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_pol_pedestal_top_hfs |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.linear.b_field_pol_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_pol_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_pol_pedestal_top_lfs |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.linear.b_field_pol_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_pol_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_tor_pedestal_top_hfs |  | STRUCTURE | T | Toroidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.linear.b_field_tor_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_tor_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.b_field_tor_pedestal_top_lfs |  | STRUCTURE | T | Toroidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.linear.b_field_tor_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.b_field_tor_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_average |  | STRUCTURE | - | Poloidal beta at pressure pedestal top for electrons using the flux surface average magnetic poloidal field
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_average.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_hfs |  | STRUCTURE | - | Poloidal beta at pressure pedestal top for electrons using the high field side magnetic poloidal field
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_hfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_lfs |  | STRUCTURE | - | Poloidal beta at pressure pedestal top for electrons using the low field side magnetic poloidal field
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.beta_pol_pedestal_top_electron_lfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.coulomb_factor_pedestal_top |  | STRUCTURE | - | Coulomb factor log(lambda) at the position of the pressure pedestal top (as determined by the fit)
summary.pedestal_fits.linear.coulomb_factor_pedestal_top.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.coulomb_factor_pedestal_top.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.energy_thermal_pedestal_electron |  | STRUCTURE | J | Pedestal stored thermal energy for electrons
summary.pedestal_fits.linear.energy_thermal_pedestal_electron.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.energy_thermal_pedestal_electron.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.pedestal_fits.linear.energy_thermal_pedestal_ion |  | STRUCTURE | J | Pedestal stored thermal energy for ions
summary.pedestal_fits.linear.energy_thermal_pedestal_ion.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.energy_thermal_pedestal_ion.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.pedestal_fits.linear.n_e |  | STRUCTURE | m^-3 | Electron density related quantities
summary.pedestal_fits.linear.n_e.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.linear.n_e.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.linear.n_e.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.linear.n_e.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.linear.n_e.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.linear.n_e.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.offset.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.linear.n_e.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.linear.n_e.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.linear.n_e.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.linear.n_e.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.n_e.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.linear.n_e.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.n_e.separatrix |  | STRUCTURE |  | Value at separatrix
summary.pedestal_fits.linear.n_e.separatrix.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.n_e.separatrix.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.linear.nustar_pedestal_top_electron |  | STRUCTURE | - | Normalised collisionality at pressure pedestal top for electrons
summary.pedestal_fits.linear.nustar_pedestal_top_electron.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.nustar_pedestal_top_electron.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.parameters | [1...5] | FLT_1D (uncertain) | mixed | Parameters of the fit
summary.pedestal_fits.linear.pressure_electron |  | STRUCTURE | Pa | Electron pressure related quantities
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max_position |  | STRUCTURE | - | Position (in terms of normalised poloidal flux) of the maximum gradient of the parent quantity in the pedestal
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.d_dpsi_norm_max_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.pressure_electron.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.linear.pressure_electron.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.offset.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.linear.pressure_electron.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.linear.pressure_electron.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.linear.pressure_electron.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.linear.pressure_electron.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.pressure_electron.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.linear.pressure_electron.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.pressure_electron.separatrix |  | STRUCTURE |  | Value at separatrix
summary.pedestal_fits.linear.pressure_electron.separatrix.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.pressure_electron.separatrix.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_hfs |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the high field side magnetic field (important for spherical tokamaks)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_hfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_lfs |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the low field side magnetic field (important for spherical tokamaks)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_lfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_magnetic_axis |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the magnetic field on the magnetic axis (definition used in most tokamak literature)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_magnetic_axis.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.rhostar_pedestal_top_electron_magnetic_axis.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.t_e |  | STRUCTURE | eV | Electron temperature related quantities
summary.pedestal_fits.linear.t_e.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.linear.t_e.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.linear.t_e.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.linear.t_e.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.linear.t_e.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.linear.t_e.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.offset.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.linear.t_e.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.linear.t_e.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.linear.t_e.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.linear.t_e.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.t_e.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.linear.t_e.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.t_e.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.linear.volume_inside_pedestal |  | STRUCTURE | m^-3 | Plasma volume enclosed between the magnetic axis and the top of the pedestal
summary.pedestal_fits.linear.volume_inside_pedestal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.linear.volume_inside_pedestal.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh |  | STRUCTURE |  | Quantities related to "mtanh" fit
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max |  | STRUCTURE | - | Maximum value in the pedestal of the alpha parameter for electron pressure (see [Miller PoP 5 (1998),973,Eq. 42])
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max_position |  | STRUCTURE | - | Position in normalised poloidal flux of the maximum value in the pedestal of the alpha parameter for electron pressure (see [Miller PoP 5 (1998),973,Eq. 42])
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.alpha_electron_pedestal_max_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.b_field_pedestal_top_hfs |  | STRUCTURE | T | Total magnetic field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.mtanh.b_field_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_pedestal_top_lfs |  | STRUCTURE | T | Total magnetic field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.mtanh.b_field_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_average |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) and averaged over the flux surface
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_average.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_hfs |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_lfs |  | STRUCTURE | T | Poloidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_pol_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_hfs |  | STRUCTURE | T | Toroidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the high field side
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_hfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_lfs |  | STRUCTURE | T | Toroidal field calculated at the position of the pressure pedestal top (as determined by the fit) on the low field side
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.b_field_tor_pedestal_top_lfs.value | [summary.time] | FLT_1D (uncertain) | T | Value
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_average |  | STRUCTURE | - | Poloidal beta at pressure pedestal top for electrons using the flux surface average magnetic poloidal field
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_average.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_hfs |  | STRUCTURE | - | Poloidal beta at pressure pedestal top for electrons using the high field side magnetic poloidal field
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_hfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_lfs |  | STRUCTURE | - | Poloidal beta at pedestal top for electrons using the low field side magnetic poloidal field
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.beta_pol_pedestal_top_electron_lfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.coulomb_factor_pedestal_top |  | STRUCTURE | - | Coulomb factor log(lambda) at the position of the pressure pedestal top (as determined by the fit)
summary.pedestal_fits.mtanh.coulomb_factor_pedestal_top.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.coulomb_factor_pedestal_top.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.energy_thermal_pedestal_electron |  | STRUCTURE | J | Pedestal stored thermal energy for electrons
summary.pedestal_fits.mtanh.energy_thermal_pedestal_electron.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.energy_thermal_pedestal_electron.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.pedestal_fits.mtanh.energy_thermal_pedestal_ion |  | STRUCTURE | J | Pedestal stored thermal energy for ions
summary.pedestal_fits.mtanh.energy_thermal_pedestal_ion.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.energy_thermal_pedestal_ion.value | [summary.time] | FLT_1D (uncertain) | J | Value
summary.pedestal_fits.mtanh.n_e |  | STRUCTURE | m^-3 | Electron density related quantities
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max_position |  | STRUCTURE | - | Position (in terms of normalised poloidal flux) of the maximum gradient of the parent quantity in the pedestal
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.d_dpsi_norm_max_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.n_e.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.mtanh.n_e.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.offset.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh.n_e.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.mtanh.n_e.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh.n_e.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.mtanh.n_e.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.n_e.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.mtanh.n_e.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.n_e.separatrix |  | STRUCTURE |  | Value at separatrix
summary.pedestal_fits.mtanh.n_e.separatrix.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.n_e.separatrix.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pedestal_fits.mtanh.nustar_pedestal_top_electron |  | STRUCTURE | - | Normalised collisionality at pressure pedestal top for electrons
summary.pedestal_fits.mtanh.nustar_pedestal_top_electron.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.nustar_pedestal_top_electron.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.parameters | [1...5] | FLT_1D (uncertain) | mixed | Parameters of the fit
summary.pedestal_fits.mtanh.pressure_electron |  | STRUCTURE | Pa | Electron pressure related quantities
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max_position |  | STRUCTURE | - | Position (in terms of normalised poloidal flux) of the maximum gradient of the parent quantity in the pedestal
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.d_dpsi_norm_max_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.pressure_electron.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.mtanh.pressure_electron.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.offset.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.mtanh.pressure_electron.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.mtanh.pressure_electron.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.mtanh.pressure_electron.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.mtanh.pressure_electron.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.pressure_electron.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.mtanh.pressure_electron.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.pressure_electron.separatrix |  | STRUCTURE |  | Value at separatrix
summary.pedestal_fits.mtanh.pressure_electron.separatrix.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.pressure_electron.separatrix.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_hfs |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the high field side magnetic field (important for spherical tokamaks)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_hfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_hfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_lfs |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the low field side magnetic field (important for spherical tokamaks)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_lfs.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_lfs.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_magnetic_axis |  | STRUCTURE | - | Normalised Larmor radius at pressure pedestal top for electrons using the magnetic field on the magnetic axis (definition used in most tokamak litterature)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_magnetic_axis.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.rhostar_pedestal_top_electron_magnetic_axis.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability |  | STRUCTURE |  | MHD stability analysis of the pedestal (for this fit of the profiles)
summary.pedestal_fits.mtanh.stability.alpha_experimental |  | STRUCTURE | - | Experimental normalized pressure gradient reconstructed by an MHD stability code (with assumptions on the ion pressure). See definition in [Miller PoP 5 (1998),973,Eq. 42]
summary.pedestal_fits.mtanh.stability.alpha_experimental.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.alpha_experimental.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager |  | STRUCTURE |  | MHD calculations of the critical alpha parameter using the Hager formula for the calculation of the bootstrap current, from Phys. Plasmas 23 (2016) 042503
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_critical |  | STRUCTURE | - | Critical normalized pressure gradient determined with self-consistent runs with an MHD stability code. Details of the method for scanning parameters in the series of runs must be described in the 'source' node
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_critical.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_critical.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_ratio |  | STRUCTURE | - | Ratio of alpha_critical over alpha_experimental
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_ratio.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.alpha_ratio.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.t_e_pedestal_top_critical |  | STRUCTURE | eV | Critical electron temperature at pedestal top determined with self-consistent runs with an MHD stability code. Details of the method for scanning parameters in the series of runs must be described in the 'source' node
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.t_e_pedestal_top_critical.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_hager.t_e_pedestal_top_critical.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter |  | STRUCTURE |  | MHD calculations of the critical alpha parameter using the Sauter formula for the calculation of the bootstrap current, from Phys. Plasmas 6 (1999) 2834
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_critical |  | STRUCTURE | - | Critical normalized pressure gradient determined with self-consistent runs with an MHD stability code. Details of the method for scanning parameters in the series of runs must be described in the 'source' node
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_critical.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_critical.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_ratio |  | STRUCTURE | - | Ratio of alpha_critical over alpha_experimental
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_ratio.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.alpha_ratio.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.t_e_pedestal_top_critical |  | STRUCTURE | eV | Critical electron temperature at pedestal top determined with self-consistent runs with an MHD stability code. Details of the method for scanning parameters in the series of runs must be described in the 'source' node
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.t_e_pedestal_top_critical.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.stability.bootstrap_current_sauter.t_e_pedestal_top_critical.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.t_e |  | STRUCTURE | eV | Electron temperature related quantities
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm |  | STRUCTURE |  | Core slope of the parent quantity
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max |  | STRUCTURE |  | Maximum gradient of the parent quantity (with respect to the normalised poloidal flux) in the pedestal
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max_position |  | STRUCTURE | - | Position (in terms of normalised poloidal flux) of the maximum gradient of the parent quantity in the pedestal
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.d_dpsi_norm_max_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.t_e.offset |  | STRUCTURE |  | Offset of the parent quantity in the SOL
summary.pedestal_fits.mtanh.t_e.offset.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.offset.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.t_e.pedestal_height |  | STRUCTURE |  | Pedestal height
summary.pedestal_fits.mtanh.t_e.pedestal_height.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.pedestal_height.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.pedestal_fits.mtanh.t_e.pedestal_position |  | STRUCTURE | - | Pedestal position in normalised poloidal flux
summary.pedestal_fits.mtanh.t_e.pedestal_position.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.pedestal_position.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.t_e.pedestal_width |  | STRUCTURE | - | Pedestal full width in normalised poloidal flux
summary.pedestal_fits.mtanh.t_e.pedestal_width.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.t_e.pedestal_width.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.pedestal_fits.mtanh.volume_inside_pedestal |  | STRUCTURE | m^-3 | Plasma volume enclosed between the magnetic axis and the top of the pedestal
summary.pedestal_fits.mtanh.volume_inside_pedestal.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pedestal_fits.mtanh.volume_inside_pedestal.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.pellets |  | STRUCTURE |  | Pellet related quantities
summary.pellets.occurrence |  | STRUCTURE | Hz | Flag set to 1 if there is any pellet injected during the pulse, 0 otherwise
summary.pellets.occurrence.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.pellets.occurrence.value |  | INT_0D |  | Value
summary.rmps |  | STRUCTURE |  | Resonant magnetic perturbations related quantities
summary.rmps.occurrence |  | STRUCTURE | Hz | Flag set to 1 if resonant magnetic perturbations are used during the pulse, 0 otherwise
summary.rmps.occurrence.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.rmps.occurrence.value |  | INT_0D |  | Value
summary.runaways |  | STRUCTURE |  | Runaway electrons
summary.runaways.current |  | STRUCTURE | A | Parallel current driven by the runaway electrons
summary.runaways.current.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.runaways.current.value | [summary.time] | FLT_1D (uncertain) | A | Value
summary.runaways.particles |  | STRUCTURE | - | Number of runaway electrons
summary.runaways.particles.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.runaways.particles.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.scrape_off_layer |  | STRUCTURE |  | Scrape-Off-Layer (SOL) characteristics
summary.scrape_off_layer.heat_flux_e_decay_length |  | STRUCTURE | m | Electron heat flux radial decay length inv(grad qe/qe)
summary.scrape_off_layer.heat_flux_e_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.heat_flux_e_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.heat_flux_i_decay_length |  | STRUCTURE | m | Ion heat flux radial decay length inv(grad qi/qi)
summary.scrape_off_layer.heat_flux_i_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.heat_flux_i_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.n_e_decay_length |  | STRUCTURE | m | Electron density radial decay length inv(grad ne/ne)
summary.scrape_off_layer.n_e_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.n_e_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.n_i_total_decay_length |  | STRUCTURE | m | Ion density radial decay length inv(grad ni/ni)
summary.scrape_off_layer.n_i_total_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.n_i_total_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.power_radiated |  | STRUCTURE | W | Power radiated from the SOL
summary.scrape_off_layer.power_radiated.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.power_radiated.value | [summary.time] | FLT_1D (uncertain) | W | Value
summary.scrape_off_layer.pressure_neutral |  | STRUCTURE | Pa | Neutral pressure in the SOL
summary.scrape_off_layer.pressure_neutral.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.pressure_neutral.value | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.scrape_off_layer.t_e_decay_length |  | STRUCTURE | m | Electron temperature radial decay length inv(grad Te/Te)
summary.scrape_off_layer.t_e_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.t_e_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.t_i_average_decay_length |  | STRUCTURE | m | Ion temperature (average over ion species) radial decay length inv(grad Ti/Ti)
summary.scrape_off_layer.t_i_average_decay_length.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.t_i_average_decay_length.value | [summary.time] | FLT_1D (uncertain) | m | Value
summary.stationary_phase_flag |  | STRUCTURE |  | This flag is set to one if the pulse is in a stationary phase from the point of the of the energy content (if the time derivative of the energy dW/dt can be neglected when calculating tau_E as W/(P_abs-dW/dt).)
summary.stationary_phase_flag.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.stationary_phase_flag.value | [summary.time] | INT_1D |  | Value
summary.tag |  | STRUCTURE |  | Tag qualifying this data entry (or a list of data entries)
summary.tag.comment |  | STR_0D |  | Any comment describing the content of the tagged list of entries
summary.tag.name |  | STR_0D |  | Name of the tag
summary.time | [1...N] | FLT_1D_TYPE | s | Generic time
summary.time_width | [summary.time] | FLT_1D (uncertain) | s | In case the time-dependent quantities of this IDS are averaged over a time interval, this node is the width of this time interval (empty otherwise). By convention, the time interval starts at time-time_width and ends at time.
summary.volume_average |  | STRUCTURE |  | Volume average plasma parameters
summary.volume_average.dn_e_dt |  | STRUCTURE | m^-3.s-1 | Time derivative of the electron density
summary.volume_average.dn_e_dt.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.dn_e_dt.value | [summary.time] | FLT_1D (uncertain) | m^-3.s-1 | Value
summary.volume_average.isotope_fraction_hydrogen |  | STRUCTURE | - | Fraction of hydrogen density among the hydrogenic species (nH/(nH+nD+nT))
summary.volume_average.isotope_fraction_hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.isotope_fraction_hydrogen.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.volume_average.meff_hydrogenic |  | STRUCTURE | amu | Effective mass of the hydrogenic species (MH. nH+MD.nD+MT.nT)/(nH+nD+nT)
summary.volume_average.meff_hydrogenic.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.meff_hydrogenic.value | [summary.time] | FLT_1D (uncertain) | amu | Value
summary.volume_average.n_e |  | STRUCTURE | m^-3 | Electron density
summary.volume_average.n_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_e.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i |  | STRUCTURE | m^-3 | Ion density per species
summary.volume_average.n_i.argon |  | STRUCTURE |  | Argon
summary.volume_average.n_i.argon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.argon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.beryllium |  | STRUCTURE |  | Beryllium
summary.volume_average.n_i.beryllium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.beryllium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.carbon |  | STRUCTURE |  | Carbon
summary.volume_average.n_i.carbon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.carbon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.deuterium |  | STRUCTURE |  | Deuterium
summary.volume_average.n_i.deuterium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.deuterium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.helium_3 |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.volume_average.n_i.helium_3.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.helium_3.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.helium_4 |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.volume_average.n_i.helium_4.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.helium_4.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.hydrogen |  | STRUCTURE |  | Hydrogen
summary.volume_average.n_i.hydrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.hydrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.lithium |  | STRUCTURE |  | Lithium
summary.volume_average.n_i.lithium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.lithium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.neon |  | STRUCTURE |  | Neon
summary.volume_average.n_i.neon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.neon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.nitrogen |  | STRUCTURE |  | Nitrogen
summary.volume_average.n_i.nitrogen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.nitrogen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.oxygen |  | STRUCTURE |  | Oxygen
summary.volume_average.n_i.oxygen.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.oxygen.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.tritium |  | STRUCTURE |  | Tritium
summary.volume_average.n_i.tritium.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.tritium.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.tungsten |  | STRUCTURE |  | Tungsten
summary.volume_average.n_i.tungsten.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.tungsten.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.xenon |  | STRUCTURE |  | Xenon
summary.volume_average.n_i.xenon.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.xenon.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i_total |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.volume_average.n_i_total.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i_total.value | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.t_e |  | STRUCTURE | eV | Electron temperature
summary.volume_average.t_e.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.t_e.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.volume_average.t_i_average |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.volume_average.t_i_average.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.t_i_average.value | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.volume_average.zeff |  | STRUCTURE | - | Effective charge
summary.volume_average.zeff.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.zeff.value | [summary.time] | FLT_1D (uncertain) | - | Value
summary.wall |  | STRUCTURE |  | Wall characteristics
summary.wall.evaporation |  | STRUCTURE |  | Chemical formula of the evaporated material or gas used to cover the vaccum vessel wall. NONE for no evaporation.
summary.wall.evaporation.source |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.wall.evaporation.value |  | STR_0D |  | Value
summary.wall.material |  | STRUCTURE |  | Wall material 0) unspecified : unspecified 1) C : Carbon 2) W : Tungsten 3) C_W_coating : Carbon with tungsten coating 4) SS : Stainless steel 5) SS_C_coating : Stainless steel with carbon coating 6) IN : Inconel 7) IN_C_coating : Inconel with carbon coating 8) B_C : Boron carbide 9) Ti_C_coating : Titanium with carbon coating 10) Be : Beryllium
summary.wall.material.description |  | STR_0D |  | Verbose description
summary.wall.material.index |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
summary.wall.material.name |  | STR_0D |  | Short string identifier

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
temporary (alpha) |  |  |  | Storage of undeclared data model components
temporary.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
temporary.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
temporary.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
temporary.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
temporary.code.library[:].name (alpha) |  | STR_0D |  | Name of software
temporary.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
temporary.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
temporary.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
temporary.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
temporary.code.output_flag (alpha) | [temporary.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
temporary.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
temporary.code.repository (alpha) |  | STR_0D |  | URL of software repository
temporary.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
temporary.constant_float0d (alpha) | [1...N] | STRUCT_ARRAY | mixed | Constant 0D float
temporary.constant_float0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float0d[:].value (alpha) |  | FLT_0D (uncertain) | - | Value
temporary.constant_float1d (alpha) | [1...N] | STRUCT_ARRAY | mixed | Constant 1D float
temporary.constant_float1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float1d[:].value (alpha) | [1...N] | FLT_1D (uncertain) | - | Value
temporary.constant_float2d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 2D float
temporary.constant_float2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float2d[:].value (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | Value
temporary.constant_float3d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 3D float
temporary.constant_float3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float3d[:].value (alpha) | [1...N, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Value
temporary.constant_float4d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 4D float
temporary.constant_float4d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float4d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float4d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float4d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float4d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N] | FLT_4D (uncertain) | mixed | Value
temporary.constant_float5d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 5D float
temporary.constant_float5d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float5d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float5d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float5d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float5d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N] | FLT_5D (uncertain) | mixed | Value
temporary.constant_float6d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 6D float
temporary.constant_float6d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float6d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float6d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_float6d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float6d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N, 1...N] | FLT_6D (uncertain) | mixed | Value
temporary.constant_integer0d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 0D integer
temporary.constant_integer0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_integer0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer0d[:].value (alpha) |  | INT_0D |  | Value
temporary.constant_integer1d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 1D integer
temporary.constant_integer1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_integer1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer1d[:].value (alpha) | [1...N] | INT_1D |  | Value
temporary.constant_integer2d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 2D integer
temporary.constant_integer2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_integer2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer2d[:].value (alpha) | [1...N, 1...N] | INT_2D |  | Value
temporary.constant_integer3d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 3D integer
temporary.constant_integer3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_integer3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer3d[:].value (alpha) | [1...N, 1...N, 1...N] | INT_3D |  | Value
temporary.constant_string0d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 0D string
temporary.constant_string0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_string0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_string0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_string0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_string0d[:].value (alpha) |  | STR_0D |  | Value
temporary.constant_string1d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 1D string
temporary.constant_string1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_string1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_string1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.constant_string1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_string1d[:].value (alpha) | [1...N] | STR_1D |  | Value
temporary.dynamic_float1d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 1D float
temporary.dynamic_float1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float1d[:].value (alpha) |  | STRUCTURE | mixed | Value
temporary.dynamic_float1d[:].value.data (alpha) | [temporary.dynamic_float1d[:].value.time] | FLT_1D (uncertain) | mixed | Data
temporary.dynamic_float1d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_float2d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 2D float
temporary.dynamic_float2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float2d[:].value (alpha) | [1...N, temporary.dynamic_float2d[:].value.time] | STRUCTURE | mixed | Value
temporary.dynamic_float2d[:].value.data (alpha) | [1...N, temporary.dynamic_float2d[:].value.time] | FLT_2D (uncertain) | mixed | Data
temporary.dynamic_float2d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_float3d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 3D float
temporary.dynamic_float3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float3d[:].value (alpha) | [1...N, 1...N, temporary.dynamic_float3d[:].value.time] | STRUCTURE | mixed | Value
temporary.dynamic_float3d[:].value.data (alpha) | [temporary.dynamic_float3d[:].value.data.as_parent, temporary.dynamic_float3d[:].value.data.as_parent, temporary.dynamic_float3d[:].value.time] | FLT_3D (uncertain) | mixed | Data
temporary.dynamic_float3d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_float4d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 4D float
temporary.dynamic_float4d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float4d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float4d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float4d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float4d[:].value (alpha) | [1...N, 1...N, 1...N, temporary.dynamic_float4d[:].value.time] | STRUCTURE | mixed | Value
temporary.dynamic_float4d[:].value.data (alpha) | [temporary.dynamic_float4d[:].value.data.as_parent, temporary.dynamic_float4d[:].value.data.as_parent, temporary.dynamic_float4d[:].value.data.as_parent, temporary.dynamic_float4d[:].value.time] | FLT_4D (uncertain) | mixed | Data
temporary.dynamic_float4d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_float5d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 5D float
temporary.dynamic_float5d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float5d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float5d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float5d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float5d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, temporary.dynamic_float5d[:].value.time] | STRUCTURE | mixed | Value
temporary.dynamic_float5d[:].value.data (alpha) | [temporary.dynamic_float5d[:].value.data.as_parent, temporary.dynamic_float5d[:].value.data.as_parent, temporary.dynamic_float5d[:].value.data.as_parent, temporary.dynamic_float5d[:].value.data.as_parent, temporary.dynamic_float5d[:].value.time] | FLT_5D (uncertain) | mixed | Data
temporary.dynamic_float5d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_float6d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 6D float
temporary.dynamic_float6d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float6d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float6d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_float6d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float6d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N, temporary.dynamic_float6d[:].value.time] | STRUCTURE | mixed | Value
temporary.dynamic_float6d[:].value.data (alpha) | [temporary.dynamic_float6d[:].value.data.as_parent, temporary.dynamic_float6d[:].value.data.as_parent, temporary.dynamic_float6d[:].value.data.as_parent, temporary.dynamic_float6d[:].value.data.as_parent, temporary.dynamic_float6d[:].value.data.as_parent, temporary.dynamic_float6d[:].value.time] | FLT_6D (uncertain) | mixed | Data
temporary.dynamic_float6d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_integer1d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 1D integer
temporary.dynamic_integer1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_integer1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer1d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_integer1d[:].value.data (alpha) | [temporary.dynamic_integer1d[:].value.time] | INT_1D |  | Data
temporary.dynamic_integer1d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_integer2d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 2D integer
temporary.dynamic_integer2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_integer2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer2d[:].value (alpha) | [1...N, temporary.dynamic_integer2d[:].value.time] | STRUCTURE |  | Value
temporary.dynamic_integer2d[:].value.data (alpha) | [temporary.dynamic_integer2d[:].value.data.as_parent, temporary.dynamic_integer2d[:].value.time] | INT_2D |  | Data
temporary.dynamic_integer2d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.dynamic_integer3d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 3D integer
temporary.dynamic_integer3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
temporary.dynamic_integer3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer3d[:].value (alpha) | [1...N, 1...N, temporary.dynamic_integer3d[:].value.time] | STRUCTURE |  | Value
temporary.dynamic_integer3d[:].value.data (alpha) | [temporary.dynamic_integer3d[:].value.data.as_parent, temporary.dynamic_integer3d[:].value.data.as_parent, temporary.dynamic_integer3d[:].value.time] | INT_3D |  | Data
temporary.dynamic_integer3d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
temporary.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
temporary.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
temporary.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
temporary.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
temporary.ids_properties.occurrence |  | INT_0D |  |
temporary.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
temporary.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
temporary.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
temporary.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
temporary.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
temporary.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
temporary.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
tf (alpha) |  |  |  | Toroidal field coils
tf.b_field_tor_vacuum_r (alpha) |  | STRUCTURE | T.m | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
tf.b_field_tor_vacuum_r.data (alpha) | [tf.b_field_tor_vacuum_r.time] | FLT_1D (uncertain) | T.m | Data
tf.b_field_tor_vacuum_r.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.coil (alpha) | [1...N] | STRUCT_ARRAY |  | Set of coils around the tokamak
tf.coil[:].conductor (alpha) | [1...N] | STRUCT_ARRAY |  | Set of conductors inside the coil. The structure can be used with size 1 for a simplified description as a single conductor. A conductor is composed of several elements, serially connected, i.e. transporting the same current.
tf.coil[:].conductor[:].cross_section (alpha) |  | STRUCTURE |  | The cross-section perpendicular to the TF conductor contour is described by a series of contour points, given by their relative position with respect to the start point of the first element. This cross-section is assumed constant for all elements.
tf.coil[:].conductor[:].cross_section.delta_phi (alpha) | [tf.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | rad | Toroidal angles (relative to a reference point)
tf.coil[:].conductor[:].cross_section.delta_r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii (relative to a reference point)
tf.coil[:].conductor[:].cross_section.delta_z (alpha) | [tf.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | m | Heights (relative to a reference point)
tf.coil[:].conductor[:].current (alpha) |  | STRUCTURE | A | Current in the conductor (positive when it flows from the first to the last element)
tf.coil[:].conductor[:].current.data (alpha) | [tf.coil[:].conductor[:].current.time] | FLT_1D (uncertain) | A | Data
tf.coil[:].conductor[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.coil[:].conductor[:].elements (alpha) |  | STRUCTURE |  | Set of geometrical elements (line segments and/or arcs of a circle) describing the contour of the TF conductor centre
tf.coil[:].conductor[:].elements.centres (alpha) |  | STRUCTURE |  | Position of the centre of the arc of a circle of every element (meaningful only if type/index = 2 or 3, fill with default/empty value otherwise)
tf.coil[:].conductor[:].elements.centres.phi (alpha) | [tf.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
tf.coil[:].conductor[:].elements.centres.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.centres.z (alpha) | [tf.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.end_points (alpha) |  | STRUCTURE |  | Position of the end point of every element. Meaningful only if type/index = 1 or 2, fill with default/empty value otherwise
tf.coil[:].conductor[:].elements.end_points.phi (alpha) | [tf.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
tf.coil[:].conductor[:].elements.end_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.end_points.z (alpha) | [tf.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.intermediate_points (alpha) |  | STRUCTURE |  | Position of an intermediate point along the arc of circle, for every element, providing the orientation of the element (must define with the corresponding start point an aperture angle strictly inferior to PI). Meaningful only if type/index = 2, fill with default/empty value otherwise
tf.coil[:].conductor[:].elements.intermediate_points.phi (alpha) | [tf.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
tf.coil[:].conductor[:].elements.intermediate_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.intermediate_points.z (alpha) | [tf.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.names (alpha) | [1...N] | STR_1D |  | Name or description of every element
tf.coil[:].conductor[:].elements.start_points (alpha) |  | STRUCTURE |  | Position of the start point of every element
tf.coil[:].conductor[:].elements.start_points.phi (alpha) | [tf.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
tf.coil[:].conductor[:].elements.start_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.start_points.z (alpha) | [tf.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.types (alpha) | [tf.coil[:].conductor[:].elements.names] | INT_1D |  | Type of every element: 1: line segment, its ends are given by the start and end points; index = 2: arc of a circle; index = 3: full circle
tf.coil[:].conductor[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | conductor resistance
tf.coil[:].conductor[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the conductor terminals
tf.coil[:].conductor[:].voltage.data (alpha) | [tf.coil[:].conductor[:].voltage.time] | FLT_1D (uncertain) | V | Data
tf.coil[:].conductor[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.coil[:].current (alpha) |  | STRUCTURE | A | Current in the coil
tf.coil[:].current.data (alpha) | [tf.coil[:].current.time] | FLT_1D (uncertain) | A | Data
tf.coil[:].current.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.coil[:].identifier (alpha) |  | STR_0D |  | Alphanumeric identifier of coil used for convenience
tf.coil[:].name (alpha) |  | STR_0D |  | Name of the coil
tf.coil[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Coil resistance
tf.coil[:].turns (alpha) |  | FLT_0D (uncertain) | - | Number of total turns in a toroidal field coil. May be a fraction when describing the coil connections.
tf.coil[:].voltage (alpha) |  | STRUCTURE | V | Voltage on the coil terminals
tf.coil[:].voltage.data (alpha) | [tf.coil[:].voltage.time] | FLT_1D (uncertain) | V | Data
tf.coil[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.coils_n (alpha) |  | INT_0D |  | Number of coils around the torus, in case is_periodic = 1
tf.delta_b_field_tor_vacuum_r (alpha) |  | STRUCTURE | T.m | Variation of (vacuum field times major radius in the toroidal field magnet) from the start of the plasma.
tf.delta_b_field_tor_vacuum_r.data (alpha) | [tf.delta_b_field_tor_vacuum_r.time] | FLT_1D (uncertain) | T.m | Data
tf.delta_b_field_tor_vacuum_r.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
tf.field_map (alpha) | [tf.field_map[:].time] | STRUCT_ARRAY |  | Map of the vacuum field at various time slices, represented using the generic grid description
tf.field_map[:].a_field_r (alpha) | [1...N] | STRUCT_ARRAY | T.m | R component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_r[:].coefficients (alpha) | [tf.field_map[:].a_field_r[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].a_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T.m | Toroidal component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_tor[:].coefficients (alpha) | [tf.field_map[:].a_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].a_field_z (alpha) | [1...N] | STRUCT_ARRAY | T.m | Z component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_z[:].coefficients (alpha) | [tf.field_map[:].a_field_z[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_r (alpha) | [1...N] | STRUCT_ARRAY | T | R component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_r[:].coefficients (alpha) | [tf.field_map[:].b_field_r[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T | Toroidal component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_tor[:].coefficients (alpha) | [tf.field_map[:].b_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_z (alpha) | [1...N] | STRUCT_ARRAY | T | Z component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_z[:].coefficients (alpha) | [tf.field_map[:].b_field_z[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].grid (alpha) |  | STRUCTURE |  | Grid description
tf.field_map[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
tf.field_map[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
tf.field_map[:].grid.grid_subset[:].base[:].jacobian (alpha) | [tf.field_map[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
tf.field_map[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
tf.field_map[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
tf.field_map[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
tf.field_map[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
tf.field_map[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
tf.field_map[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
tf.field_map[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
tf.field_map[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
tf.field_map[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
tf.field_map[:].grid.grid_subset[:].metric.jacobian (alpha) | [tf.field_map[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
tf.field_map[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
tf.field_map[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
tf.field_map[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
tf.field_map[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
tf.field_map[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
tf.field_map[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
tf.field_map[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
tf.field_map[:].grid.space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
tf.field_map[:].grid.space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
tf.field_map[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
tf.field_map[:].time (alpha) |  | FLT_0D | s | Time
tf.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
tf.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
tf.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
tf.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
tf.ids_properties.occurrence |  | INT_0D |  |
tf.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
tf.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
tf.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
tf.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
tf.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
tf.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
tf.is_periodic (alpha) |  | INT_0D |  | Flag indicating whether coils are described one by one in the coil() structure (flag=0) or whether the coil structure represents only coils having different characteristics (flag = 1, n_coils must be filled in that case). In the latter case, the coil() sequence is repeated periodically around the torus.
tf.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius of the device (from the official description of the device). This node is the placeholder for this official machine description quantity (typically the middle of the vessel at the equatorial midplane, although the exact definition may depend on the device)
tf.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
thomson_scattering (alpha) |  |  |  | Thomson scattering diagnostic
thomson_scattering.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
thomson_scattering.channel[:].delta_position (alpha) |  | STRUCTURE |  | Incremental variation of the position of the measurements, due to e.g. different lasers not intersecting the line of sight at the same position. The actual position is then the static position + delta_position
thomson_scattering.channel[:].delta_position.phi (alpha) | [thomson_scattering.channel[:].delta_position.time] | FLT_1D (uncertain) | rad | Toroidal angle
thomson_scattering.channel[:].delta_position.r (alpha) | [thomson_scattering.channel[:].delta_position.time] | FLT_1D (uncertain) | m | Major radius
thomson_scattering.channel[:].delta_position.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time for the R,Z,phi coordinates
thomson_scattering.channel[:].delta_position.z (alpha) | [thomson_scattering.channel[:].delta_position.time] | FLT_1D (uncertain) | m | Height
thomson_scattering.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
thomson_scattering.channel[:].n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
thomson_scattering.channel[:].n_e.data (alpha) | [thomson_scattering.channel[:].n_e.time] | FLT_1D (uncertain) | m^-3 | Data
thomson_scattering.channel[:].n_e.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
thomson_scattering.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
thomson_scattering.channel[:].position (alpha) |  | STRUCTURE |  | Average position of the measurements (intersection between laser beam and line of sight)
thomson_scattering.channel[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle (oriented counter-clockwise when viewing from above)
thomson_scattering.channel[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
thomson_scattering.channel[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
thomson_scattering.channel[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
thomson_scattering.channel[:].t_e.data (alpha) | [thomson_scattering.channel[:].t_e.time] | FLT_1D (uncertain) | eV | Data
thomson_scattering.channel[:].t_e.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
thomson_scattering.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
thomson_scattering.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
thomson_scattering.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
thomson_scattering.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
thomson_scattering.code.library[:].name (alpha) |  | STR_0D |  | Name of software
thomson_scattering.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
thomson_scattering.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
thomson_scattering.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
thomson_scattering.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
thomson_scattering.code.output_flag (alpha) | [thomson_scattering.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
thomson_scattering.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
thomson_scattering.code.repository (alpha) |  | STR_0D |  | URL of software repository
thomson_scattering.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
thomson_scattering.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
thomson_scattering.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
thomson_scattering.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
thomson_scattering.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
thomson_scattering.ids_properties.occurrence |  | INT_0D |  |
thomson_scattering.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
thomson_scattering.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
thomson_scattering.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
thomson_scattering.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
thomson_scattering.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
thomson_scattering.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
thomson_scattering.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
transport_solver_numerics (alpha) |  |  |  | Numerical quantities used by transport solvers and convergence details
transport_solver_numerics.boundary_conditions_1d (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].time] | STRUCT_ARRAY |  | Boundary conditions of the radial transport equations for various time slices. To be removed when the solver_1d structure is finalized.
transport_solver_numerics.boundary_conditions_1d[:].current (alpha) |  | STRUCTURE |  | Boundary condition for the current diffusion equation.
transport_solver_numerics.boundary_conditions_1d[:].current.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: poloidal flux; 2: ip; 3: loop voltage; 4: undefined; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].current.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].current.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy (alpha) |  | STRUCTURE | W.m^-3 | Boundary condition for the electron energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Boundary condition for the electron density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total (alpha) |  | STRUCTURE | W.m^-3 | Boundary condition for the ion total (sum over ion species) energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.boundary_conditions_1d[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy (alpha) |  | STRUCTURE | W.m^-3 | Boundary condition for the ion energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Boundary condition for the ion density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy (alpha) |  | STRUCTURE | W.m^-3 | Boundary condition for the charge state energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Boundary condition for the charge state density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor (alpha) |  | STRUCTURE | kg.m.s^-1 | Boundary condition for the total plasma toroidal momentum equation (summed over ion species and electrons) (momentum if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.boundary_conditions_ggd (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].time] | STRUCT_ARRAY |  | Boundary conditions of the transport equations, provided on the GGD, for various time slices
transport_solver_numerics.boundary_conditions_ggd[:].current (alpha) | [1...N] | STRUCT_ARRAY |  | Boundary condition for the current diffusion equation, on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].current[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].current[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].current[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the electron energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the electron density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
transport_solver_numerics.boundary_conditions_ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the ion energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the ion density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the charge state energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the charge state density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier (alpha) |  | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.boundary_conditions_ggd[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
transport_solver_numerics.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
transport_solver_numerics.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
transport_solver_numerics.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
transport_solver_numerics.code.library[:].name (alpha) |  | STR_0D |  | Name of software
transport_solver_numerics.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
transport_solver_numerics.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
transport_solver_numerics.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
transport_solver_numerics.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
transport_solver_numerics.code.output_flag (alpha) | [transport_solver_numerics.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
transport_solver_numerics.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
transport_solver_numerics.code.repository (alpha) |  | STR_0D |  | URL of software repository
transport_solver_numerics.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
transport_solver_numerics.convergence (alpha) |  | STRUCTURE |  | Convergence details To be removed when the solver_1d structure is finalized.
transport_solver_numerics.convergence.equations (alpha) | [transport_solver_numerics.convergence.equations[:].time] | STRUCT_ARRAY |  | Convergence details of the transport equations, for various time slices
transport_solver_numerics.convergence.equations[:].current (alpha) |  | STRUCTURE |  | Convergence details of the current diffusion equation
transport_solver_numerics.convergence.equations[:].current.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].current.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].current.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].current.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.convergence.equations[:].electrons.energy (alpha) |  | STRUCTURE | W.m^-3 | Convergence details of the electron energy equation
transport_solver_numerics.convergence.equations[:].electrons.energy.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].electrons.energy.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].electrons.energy.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].electrons.energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].electrons.particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Convergence details of the electron density equation
transport_solver_numerics.convergence.equations[:].electrons.particles.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].electrons.particles.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].electrons.particles.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].electrons.particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].energy_ion_total (alpha) |  | STRUCTURE | W.m^-3 | Convergence details of the ion total (sum over ion species) energy equation
transport_solver_numerics.convergence.equations[:].energy_ion_total.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].energy_ion_total.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].energy_ion_total.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].energy_ion_total.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.convergence.equations[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.convergence.equations[:].ion[:].energy (alpha) |  | STRUCTURE | W.m^-3 | Convergence details of the ion energy equation
transport_solver_numerics.convergence.equations[:].ion[:].energy.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].ion[:].energy.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].energy.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.convergence.equations[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.convergence.equations[:].ion[:].particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Convergence details of the ion density equation
transport_solver_numerics.convergence.equations[:].ion[:].particles.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].ion[:].particles.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].particles.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Convergence details of the related to the different states transport equations
transport_solver_numerics.convergence.equations[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy (alpha) |  | STRUCTURE | W.m^-3 | Convergence details of the charge state energy equation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles (alpha) |  | STRUCTURE | m^-3.s^-1 | Convergence details of the charge state density equation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.convergence.equations[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.convergence.equations[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.convergence.equations[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.convergence.equations[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.convergence.equations[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.convergence.time_step (alpha) |  | STRUCTURE | s | Internal time step used by the transport solver (assuming all transport equations are solved with the same time step)
transport_solver_numerics.convergence.time_step.data (alpha) | [transport_solver_numerics.convergence.time_step.time] | FLT_1D (uncertain) | s | Data
transport_solver_numerics.convergence.time_step.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
transport_solver_numerics.derivatives_1d (alpha) | [transport_solver_numerics.derivatives_1d[:].time] | STRUCT_ARRAY |  | Radial profiles derivatives for various time slices. To be removed when the solver_1d structure is finalized.
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives of total ion quantities with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d2psi_drho_tor2 (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb.m^-2 | Second derivative of the poloidal flux profile with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives of total ion quantities with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives of total ion quantities with respect to time
transport_solver_numerics.derivatives_1d[:].d_dt.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d_dt.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d_dvolume_drho_tor_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Partial derivative with respect to time of the derivative of the volume with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].dpsi_drho_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb.m^-1 | Derivative of the poloidal flux profile with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].dpsi_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time
transport_solver_numerics.derivatives_1d[:].dpsi_dt_cphi (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time, at constant toroidal flux
transport_solver_numerics.derivatives_1d[:].dpsi_dt_crho_tor_norm (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time, at constant normalised toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].drho_tor_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Partial derivative of the toroidal flux coordinate profile with respect to time
transport_solver_numerics.derivatives_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
transport_solver_numerics.derivatives_1d[:].grid.area (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
transport_solver_numerics.derivatives_1d[:].grid.psi (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
transport_solver_numerics.derivatives_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
transport_solver_numerics.derivatives_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
transport_solver_numerics.derivatives_1d[:].grid.rho_pol_norm (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
transport_solver_numerics.derivatives_1d[:].grid.rho_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
transport_solver_numerics.derivatives_1d[:].grid.surface (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
transport_solver_numerics.derivatives_1d[:].grid.volume (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
transport_solver_numerics.derivatives_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.derivatives_1d[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.derivatives_1d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.derivatives_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.derivatives_1d[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.derivatives_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
transport_solver_numerics.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
transport_solver_numerics.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
transport_solver_numerics.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
transport_solver_numerics.ids_properties.occurrence |  | INT_0D |  |
transport_solver_numerics.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
transport_solver_numerics.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
transport_solver_numerics.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
transport_solver_numerics.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
transport_solver_numerics.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
transport_solver_numerics.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
transport_solver_numerics.primary_coordinate (alpha) |  | STRUCTURE |  | Primary coordinate system with which the transport equations are solved. For a 1D transport solver: index = 1 means rho_tor_norm; 2 = rho_tor.
transport_solver_numerics.primary_coordinate.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.primary_coordinate.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.primary_coordinate.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.restart_files (alpha) | [transport_solver_numerics.restart_files[:].time] | STRUCT_ARRAY |  | Set of code-specific restart files for a given time slice. These files are managed by a physical application to ensure its restart during long simulations
transport_solver_numerics.restart_files[:].descriptions (alpha) | [transport_solver_numerics.restart_files[:].names] | STR_1D |  | Descriptions of the restart files
transport_solver_numerics.restart_files[:].names (alpha) | [1...N] | STR_1D |  | Names of the restart files
transport_solver_numerics.restart_files[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.solver (alpha) |  | STRUCTURE |  | Solver identifier
transport_solver_numerics.solver.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.solver.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.solver.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.solver_1d (alpha) | [transport_solver_numerics.solver_1d[:].time] | STRUCT_ARRAY |  | Numerics related to 1D radial solver, for various time slices.
transport_solver_numerics.solver_1d[:].control_parameters (alpha) |  | STRUCTURE |  | Solver-specific input or output quantities
transport_solver_numerics.solver_1d[:].control_parameters.integer0d (alpha) | [1...N] | STRUCT_ARRAY |  | Set of integer type scalar control parameters
transport_solver_numerics.solver_1d[:].control_parameters.integer0d[:].value (alpha) |  | INT_0D |  | Value of the control parameter
transport_solver_numerics.solver_1d[:].control_parameters.real0d (alpha) | [1...N] | STRUCT_ARRAY |  | Set of real type scalar control parameters
transport_solver_numerics.solver_1d[:].control_parameters.real0d[:].value (alpha) |  | FLT_0D (uncertain) | mixed | Value of the control parameter
transport_solver_numerics.solver_1d[:].d_dvolume_drho_tor_dt (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Partial derivative with respect to time of the derivative of the volume with respect to the toroidal flux coordinate
transport_solver_numerics.solver_1d[:].drho_tor_dt (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Partial derivative of the toroidal flux coordinate profile with respect to time
transport_solver_numerics.solver_1d[:].equation (alpha) | [1...N] | STRUCT_ARRAY |  | Set of transport equations
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition (alpha) | [1...N] | STRUCT_ARRAY |  | Set of boundary conditions of the transport equation
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].position (alpha) |  | FLT_0D (uncertain) | mixed | Position, in terms of the primary coordinate, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed (in case of a single boundary condition).
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].type (alpha) |  | STRUCTURE |  | Boundary condition type 0) not_solved : Equation is not solved 1) value : Boundary condition is the value of the equations primary quantity 2) derivative_or_ip : Boundary condition is the radial derivative of the equations primary quantity, or the plasma current for the current diffusion equation 3) e_folding_length_or_vloop : Boundary condition is the e-folding length of the equations primary quantity, or the loop voltage for the current diffusion equation 4) flux : Boundary condition is the flux of the equations primary quantity 5) combination : Boundary condition is a linear combination of radial derivative and value of the flux of the equations primary quantity, in the form a1.y-prime + a2.y = a3
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.solver_1d[:].equation[:].boundary_condition[:].value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For type/index = 1 to 3, only the first position in the vector is used. For type/index = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.solver_1d[:].equation[:].coefficient (alpha) | [1...N] | STRUCT_ARRAY |  | Set of numerical coefficients involved in the transport equation
transport_solver_numerics.solver_1d[:].equation[:].coefficient[:].profile (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Radial profile of the numerical coefficient
transport_solver_numerics.solver_1d[:].equation[:].computation_mode (alpha) |  | STRUCTURE |  | Computation mode for this equation 0) static : Equation is not solved, no profile evolution 1) interpretative : Equation is not solved, profile is evolved by interpolating from input objects 2) predictive : Equation is solved, profile evolves
transport_solver_numerics.solver_1d[:].equation[:].computation_mode.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.solver_1d[:].equation[:].computation_mode.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.solver_1d[:].equation[:].computation_mode.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.solver_1d[:].equation[:].convergence (alpha) |  | STRUCTURE |  | Convergence details
transport_solver_numerics.solver_1d[:].equation[:].convergence.delta_relative (alpha) |  | STRUCTURE |  | Relative deviation on the primary quantity of the transport equation between the present and the previous iteration of the solver
transport_solver_numerics.solver_1d[:].equation[:].convergence.delta_relative.expression (alpha) |  | STR_0D |  | Expression used by the solver to calculate the relative deviation
transport_solver_numerics.solver_1d[:].equation[:].convergence.delta_relative.value (alpha) |  | FLT_0D (uncertain) | - | Value of the relative deviation
transport_solver_numerics.solver_1d[:].equation[:].convergence.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity (alpha) |  | STRUCTURE |  | Profile and derivatives of the primary quantity of the transport equation
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.d2_dr2 (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second order radial derivative with respect to the primary coordinate
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.d_dr (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Radial derivative with respect to the primary coordinate
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.d_dt (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.d_dt_cphi (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to time, at constant toroidal flux (for current diffusion equation)
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.d_dt_cr (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to time, at constant primary coordinate coordinate (for current diffusion equation)
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.identifier (alpha) |  | STRUCTURE |  | Identifier of the primary quantity of the transport equation. The description node contains the path to the quantity in the physics IDS (example: core_profiles/profiles_1d/ion(1)/density)
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.ion_index (alpha) |  | INT_0D |  | If the primary quantity is related to a ion species, index of the corresponding species in the core_profiles/profiles_1d/ion array
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.neutral_index (alpha) |  | INT_0D |  | If the primary quantity is related to a neutral species, index of the corresponding species in the core_profiles/profiles_1d/neutral array
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.profile (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Profile of the primary quantity
transport_solver_numerics.solver_1d[:].equation[:].primary_quantity.state_index (alpha) |  | INT_0D |  | If the primary quantity is related to a particular state (of an ion or a neutral species), index of the corresponding state in the core_profiles/profiles_1d/ion (or neutral)/state array
transport_solver_numerics.solver_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
transport_solver_numerics.solver_1d[:].grid.area (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
transport_solver_numerics.solver_1d[:].grid.psi (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
transport_solver_numerics.solver_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
transport_solver_numerics.solver_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
transport_solver_numerics.solver_1d[:].grid.rho_pol_norm (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
transport_solver_numerics.solver_1d[:].grid.rho_tor (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
transport_solver_numerics.solver_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
transport_solver_numerics.solver_1d[:].grid.surface (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
transport_solver_numerics.solver_1d[:].grid.volume (alpha) | [transport_solver_numerics.solver_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
transport_solver_numerics.solver_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
transport_solver_numerics.time_step (alpha) |  | STRUCTURE | s | Internal time step used by the transport solver (assuming all transport equations are solved with the same time step)
transport_solver_numerics.time_step.data (alpha) | [transport_solver_numerics.time_step.time] | FLT_1D (uncertain) | s | Data
transport_solver_numerics.time_step.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
transport_solver_numerics.time_step_average (alpha) |  | STRUCTURE | s | Average internal time step used by the transport solver between the previous and the current time stored for this quantity (assuming all transport equations are solved with the same time step)
transport_solver_numerics.time_step_average.data (alpha) | [transport_solver_numerics.time_step_average.time] | FLT_1D (uncertain) | s | Data
transport_solver_numerics.time_step_average.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
transport_solver_numerics.time_step_min (alpha) |  | STRUCTURE | s | Minimum internal time step used by the transport solver between the previous and the current time stored for this quantity (assuming all transport equations are solved with the same time step)
transport_solver_numerics.time_step_min.data (alpha) | [transport_solver_numerics.time_step_min.time] | FLT_1D (uncertain) | s | Data
transport_solver_numerics.time_step_min.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
transport_solver_numerics.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
transport_solver_numerics.vacuum_toroidal_field.b0 (alpha) | [transport_solver_numerics.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
transport_solver_numerics.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
turbulence (alpha) |  |  |  | Description of plasma turbulence
turbulence.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
turbulence.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
turbulence.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
turbulence.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
turbulence.code.library[:].name (alpha) |  | STR_0D |  | Name of software
turbulence.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
turbulence.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
turbulence.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
turbulence.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
turbulence.code.output_flag (alpha) | [turbulence.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
turbulence.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
turbulence.code.repository (alpha) |  | STR_0D |  | URL of software repository
turbulence.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
turbulence.grid_2d (alpha) | [turbulence.grid_2d[:].time] | STRUCT_ARRAY |  | Values for the 2D grid, for various time slices. The timebase of this array of structure must be a subset of the profiles_2d timebase
turbulence.grid_2d[:].dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
turbulence.grid_2d[:].dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
turbulence.grid_2d[:].time (alpha) |  | FLT_0D | s | Time
turbulence.grid_2d_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types for grid_2d 1) rectangular : Cylindrical R,Z ala eqdsk (R=dim1, Z=dim2). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho=dim1, theta=dim2) with magnetic axis as centre of grid; theta and values following the COCOS=11 convention; the polar angle is theta=atan2(z-zaxis,r-raxis) 11) inverse_psi_straight_field_line : Flux surface type with psi as radial label (dim1) and the straight-field line poloidal angle (mod(index,10)=1) (dim2); could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 12) inverse_psi_equal_arc : Flux surface type with psi as radial label (dim1) and the equal arc poloidal angle (mod(index,10)=2) (dim2) 13) inverse_psi_polar : Flux surface type with psi as radial label (dim1) and the polar poloidal angle (mod(index,10)=3) (dim2); could be non-equidistant 14) inverse_psi_straight_field_line_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the straight-field line poloidal angle (mod(index,10)=4) (dim2), could be non-equidistant; magnetic axis as centre of grid; following the COCOS=11 convention 15) inverse_psi_equal_arc_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the equal arc poloidal angle (mod(index,10)=5) (dim2) 16) inverse_psi_polar_fourier : Flux surface type with psi as radial label (dim1) and Fourier modes in the polar poloidal angle (mod(index,10)=6) (dim2); could be non-equidistant 21) inverse_rhopolnorm_straight_field_line : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the straight-field line poloidal angle (dim2) 22) inverse_rhopolnorm_equal_arc : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the equal arc poloidal angle (dim2) 23) inverse_rhopolnorm_polar : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and the polar poloidal angle (dim2) 24) inverse_rhopolnorm_straight_field_line_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 25) inverse_rhopolnorm_equal_arc_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 26) inverse_rhopolnorm_polar_fourier : Flux surface type with radial label sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] (dim1) and Fourier modes in the polar poloidal angle (dim2) 31) inverse_rhotornorm_straight_field_line : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the straight-field line poloidal angle (dim2) 32) inverse_rhotornorm_equal_arc : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the equal arc poloidal angle (dim2) 33) inverse_rhotornorm_polar : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and the polar poloidal angle (dim2) 34) inverse_rhotornorm_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 35) inverse_rhotornorm_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 36) inverse_rhotornorm_polar_fourier : Flux surface type with radial label sqrt[Phi/Phi_edge] (dim1) and Fourier modes in the polar poloidal angle (dim2) 41) inverse_rhopol_straight_field_line : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the straight-field line poloidal angle (dim2) 42) inverse_rhopol_equal_arc : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the equal arc poloidal angle (dim2) 43) inverse_rhopol_polar : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and the polar poloidal angle (dim2) 44) inverse_rhopol_straight_field_line_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the straight-field line poloidal angle (dim2) 45) inverse_rhopol_equal_arc_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the equal arc poloidal angle (dim2) 46) inverse_rhopol_polar_fourier : Flux surface type with radial label sqrt[psi-psi_axis] (dim1) and Fourier modes in the polar poloidal angle (dim2) 51) inverse_rhotor_straight_field_line : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the straight-field line poloidal angle (dim2) 52) inverse_rhotor_equal_arc : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the equal arc poloidal angle (dim2) 53) inverse_rhotor_polar : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and the polar poloidal angle (dim2) 54) inverse_rhotor_straight_field_line_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the straight-field line poloidal angle (dim2) 55) inverse_rhotor_equal_arc_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the equal arc poloidal angle (dim2) 56) inverse_rhotor_polar_fourier : Flux surface type with radial label sqrt[Phi/pi/B0] (dim1), Phi being toroidal flux, and Fourier modes in the polar poloidal angle (dim2) 91) irregular_rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1)
turbulence.grid_2d_type.description (alpha) |  | STR_0D |  | Verbose description
turbulence.grid_2d_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
turbulence.grid_2d_type.name (alpha) |  | STR_0D |  | Short string identifier
turbulence.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
turbulence.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
turbulence.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
turbulence.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
turbulence.ids_properties.occurrence |  | INT_0D |  |
turbulence.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
turbulence.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
turbulence.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
turbulence.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
turbulence.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
turbulence.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
turbulence.profiles_2d (alpha) | [turbulence.profiles_2d[:].time] | STRUCT_ARRAY |  | Fluctuating physical quantities for various time slices
turbulence.profiles_2d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to electrons
turbulence.profiles_2d[:].electrons.density (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
turbulence.profiles_2d[:].electrons.density_thermal (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density of thermal particles
turbulence.profiles_2d[:].electrons.temperature (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | eV | Temperature
turbulence.profiles_2d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the various ion species
turbulence.profiles_2d[:].ion[:].density (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].ion[:].density_thermal (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
turbulence.profiles_2d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
turbulence.profiles_2d[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
turbulence.profiles_2d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
turbulence.profiles_2d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
turbulence.profiles_2d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
turbulence.profiles_2d[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
turbulence.profiles_2d[:].ion[:].temperature (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
turbulence.profiles_2d[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the various neutral species
turbulence.profiles_2d[:].neutral[:].density (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].neutral[:].density_thermal (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | m^-3 | Density (thermal) (sum over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
turbulence.profiles_2d[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
turbulence.profiles_2d[:].neutral[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
turbulence.profiles_2d[:].neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
turbulence.profiles_2d[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
turbulence.profiles_2d[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
turbulence.profiles_2d[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
turbulence.profiles_2d[:].neutral[:].temperature (alpha) | [turbulence.grid_2d[:].dim1, turbulence.grid_2d[:].dim2] | FLT_2D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
turbulence.profiles_2d[:].time (alpha) |  | FLT_0D | s | Time
turbulence.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
wall (alpha) |  |  |  | Description of the torus wall and its interaction with the plasma
wall.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
wall.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
wall.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
wall.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
wall.code.library[:].name (alpha) |  | STR_0D |  | Name of software
wall.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
wall.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
wall.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
wall.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
wall.code.output_flag (alpha) | [wall.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
wall.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
wall.code.repository (alpha) |  | STR_0D |  | URL of software repository
wall.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
wall.description_2d (alpha) | [1...N] | STRUCT_ARRAY |  | Set of 2D wall descriptions, for each type of possible physics or engineering configurations necessary (gas tight vs wall with ports and holes, coarse vs fine representation, single contour limiter, disjoint gapped plasma facing components, ...). A simplified description of the toroidal extension of the 2D contours is also provided by using the phi_extensions nodes.
wall.description_2d[:].limiter (alpha) |  | STRUCTURE |  | Description of the immobile limiting surface(s) or plasma facing components for defining the Last Closed Flux Surface.
wall.description_2d[:].limiter.type (alpha) |  | STRUCTURE |  | Type of the limiter description. index = 0 for the official single contour limiter and 1 for the official disjoint PFC structure like first wall. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on index =2
wall.description_2d[:].limiter.type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].limiter.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_2d[:].limiter.type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].limiter.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of limiter units
wall.description_2d[:].limiter.unit[:].closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].limiter.unit[:].name (alpha) |  | STR_0D |  | Name of the limiter unit
wall.description_2d[:].limiter.unit[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the limiting surface. Do NOT repeat the first point for closed contours
wall.description_2d[:].limiter.unit[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].limiter.unit[:].outline.z (alpha) | [wall.description_2d[:].limiter.unit[:].outline.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].limiter.unit[:].phi_extensions (alpha) | [1...2, 1...N] | FLT_2D (uncertain) | rad | Simplified description of toroidal angle extensions of the unit, by a list of zones defined by their centre and full width (in toroidal angle). In each of these zones, the unit outline remains the same. Leave this node empty for an axisymmetric unit. The first dimension gives the centre and full width toroidal angle values for the unit. The second dimension represents the toroidal occurrences of the unit countour (i.e. the number of toroidal zones).
wall.description_2d[:].limiter.unit[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the limiter unit
wall.description_2d[:].mobile (alpha) |  | STRUCTURE |  | In case of mobile plasma facing components, use the time-dependent description below this node to provide the full outline of the closest PFC surfaces to the plasma. Even in such a case, the 'limiter' structure is still used to provide the outermost limiting surface (can be used e.g. to define the boundary of the mesh of equilibrium reconstruction codes)
wall.description_2d[:].mobile.type (alpha) |  | STRUCTURE |  | Type of the description
wall.description_2d[:].mobile.type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].mobile.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_2d[:].mobile.type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].mobile.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of mobile units
wall.description_2d[:].mobile.unit[:].closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].mobile.unit[:].name (alpha) |  | STR_0D |  | Name of the mobile unit
wall.description_2d[:].mobile.unit[:].outline (alpha) | [wall.description_2d[:].mobile.unit[:].outline[:].time] | STRUCT_ARRAY |  | Irregular outline of the mobile unit, for a set of time slices. Do NOT repeat the first point for closed contours
wall.description_2d[:].mobile.unit[:].outline[:].r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].mobile.unit[:].outline[:].time (alpha) |  | FLT_0D | s | Time
wall.description_2d[:].mobile.unit[:].outline[:].z (alpha) | [wall.description_2d[:].mobile.unit[:].outline[:].r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].mobile.unit[:].phi_extensions (alpha) | [1...2, 1...N] | FLT_2D (uncertain) | rad | Simplified description of toroidal angle extensions of the unit, by a list of zones defined by their centre and full width (in toroidal angle). In each of these zones, the unit outline remains the same. Leave this node empty for an axisymmetric unit. The first dimension gives the centre and full width toroidal angle values for the unit. The second dimension represents the toroidal occurrences of the unit countour (i.e. the number of toroidal zones).
wall.description_2d[:].mobile.unit[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the mobile unit
wall.description_2d[:].type (alpha) |  | STRUCTURE |  | Type of the description. index = 0 for equilibrium codes (single closed limiter and vessel); 1 for gas-tight walls (disjoint PFCs with inner vessel as last limiter_unit; no vessel structure); 2 for free boundary codes (disjoint PFCs and vessel)
wall.description_2d[:].type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_2d[:].type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].vessel (alpha) |  | STRUCTURE |  | Mechanical structure of the vacuum vessel. The vessel is described as a set of nested layers with given physics properties; Two representations are admitted for each vessel unit : annular (two contours) or block elements.
wall.description_2d[:].vessel.type (alpha) |  | STRUCTURE |  | Type of the description. index = 0 for the official single/multiple annular representation and 1 for the official block element representation for each unit. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on index=2
wall.description_2d[:].vessel.type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].vessel.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_2d[:].vessel.type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].vessel.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of units
wall.description_2d[:].vessel.unit[:].annular (alpha) |  | STRUCTURE |  | Annular representation of a layer by two contours, inner and outer. Alternatively, the layer can be described by a centreline and thickness.
wall.description_2d[:].vessel.unit[:].annular.centreline (alpha) |  | STRUCTURE |  | Centreline, i.e. middle of the vessel layer as a series of point. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].annular.centreline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].vessel.unit[:].annular.centreline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].annular.centreline.z (alpha) | [wall.description_2d[:].vessel.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].annular.outline_inner (alpha) |  | STRUCTURE |  | Inner vessel outline. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].annular.outline_inner.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].vessel.unit[:].annular.outline_inner.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].annular.outline_inner.z (alpha) | [wall.description_2d[:].vessel.unit[:].annular.outline_inner.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].annular.outline_outer (alpha) |  | STRUCTURE |  | Outer vessel outline. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].annular.outline_outer.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].vessel.unit[:].annular.outline_outer.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].annular.outline_outer.z (alpha) | [wall.description_2d[:].vessel.unit[:].annular.outline_outer.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].annular.resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the vessel unit
wall.description_2d[:].vessel.unit[:].annular.thickness (alpha) | [wall.description_2d[:].vessel.unit[:].annular.centreline.r] | FLT_1D (uncertain) | m | Thickness of the vessel layer in the perpendicular direction to the centreline. Thickness(i) is the thickness of the layer between centreline/r(i),z(i) and centreline/r(i+1),z(i+1)
wall.description_2d[:].vessel.unit[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of block elements
wall.description_2d[:].vessel.unit[:].element[:].j_tor (alpha) |  | STRUCTURE | A | Toroidal current induced in this block element
wall.description_2d[:].vessel.unit[:].element[:].j_tor.data (alpha) | [wall.description_2d[:].vessel.unit[:].element[:].j_tor.time] | FLT_1D (uncertain) | A | Data
wall.description_2d[:].vessel.unit[:].element[:].j_tor.time (alpha) | [1...N] | FLT_1D_TYPE | s | Time
wall.description_2d[:].vessel.unit[:].element[:].name (alpha) |  | STR_0D |  | Name of the block element
wall.description_2d[:].vessel.unit[:].element[:].outline (alpha) |  | STRUCTURE |  | Outline of the block element. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].element[:].outline.closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].vessel.unit[:].element[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].element[:].outline.z (alpha) | [wall.description_2d[:].vessel.unit[:].element[:].outline.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].element[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Resistance of the block element
wall.description_2d[:].vessel.unit[:].element[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the block element
wall.description_2d[:].vessel.unit[:].identifier (alpha) |  | STR_0D |  | Identifier of the unit
wall.description_2d[:].vessel.unit[:].name (alpha) |  | STR_0D |  | Name of the unit
wall.description_ggd (alpha) | [1...N] | STRUCT_ARRAY |  | Set of 3D wall descriptions, described using the GGD, for each type of possible physics or engineering configurations necessary (gas tight vs wall with ports and holes, coarse vs fine representation, ...).
wall.description_ggd[:].ggd (alpha) | [wall.description_ggd[:].ggd[:].time] | STRUCT_ARRAY |  | Wall physics quantities represented using the general grid description, for various time slices.
wall.description_ggd[:].ggd[:].power_density (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Power density arriving on the wall surface, for various wall components (grid subsets)
wall.description_ggd[:].ggd[:].power_density[:].coefficients (alpha) | [wall.description_ggd[:].ggd[:].power_density[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
wall.description_ggd[:].ggd[:].power_density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
wall.description_ggd[:].ggd[:].power_density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
wall.description_ggd[:].ggd[:].power_density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
wall.description_ggd[:].ggd[:].temperature (alpha) | [1...N] | STRUCT_ARRAY | K | Temperature of the wall, for various wall components (grid subsets)
wall.description_ggd[:].ggd[:].temperature[:].coefficients (alpha) | [wall.description_ggd[:].ggd[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | K | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
wall.description_ggd[:].ggd[:].temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
wall.description_ggd[:].ggd[:].temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
wall.description_ggd[:].ggd[:].temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | K | One scalar value is provided per element in the grid subset.
wall.description_ggd[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
wall.description_ggd[:].grid_ggd (alpha) | [wall.description_ggd[:].grid_ggd[:].time] | STRUCT_ARRAY |  | Wall geometry described using the Generic Grid Description, for various time slices (in case of mobile wall elements). The timebase of this array of structure must be a subset of the timebase on which physical quantities are described (../ggd structure). Grid_subsets are used to describe various wall components in a modular way.
wall.description_ggd[:].grid_ggd[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
wall.description_ggd[:].grid_ggd[:].grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
wall.description_ggd[:].grid_ggd[:].grid_subset[:].base[:].jacobian (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
wall.description_ggd[:].grid_ggd[:].grid_subset[:].base[:].tensor_contravariant (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
wall.description_ggd[:].grid_ggd[:].grid_subset[:].base[:].tensor_covariant (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
wall.description_ggd[:].grid_ggd[:].grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
wall.description_ggd[:].grid_ggd[:].grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
wall.description_ggd[:].grid_ggd[:].grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
wall.description_ggd[:].grid_ggd[:].grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
wall.description_ggd[:].grid_ggd[:].grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
wall.description_ggd[:].grid_ggd[:].grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
wall.description_ggd[:].grid_ggd[:].grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
wall.description_ggd[:].grid_ggd[:].grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
wall.description_ggd[:].grid_ggd[:].grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_ggd[:].grid_ggd[:].grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_ggd[:].grid_ggd[:].grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
wall.description_ggd[:].grid_ggd[:].grid_subset[:].metric.jacobian (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
wall.description_ggd[:].grid_ggd[:].grid_subset[:].metric.tensor_contravariant (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
wall.description_ggd[:].grid_ggd[:].grid_subset[:].metric.tensor_covariant (alpha) | [wall.description_ggd[:].grid_ggd[:].grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
wall.description_ggd[:].grid_ggd[:].identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
wall.description_ggd[:].grid_ggd[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
wall.description_ggd[:].grid_ggd[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_ggd[:].grid_ggd[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_ggd[:].grid_ggd[:].space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
wall.description_ggd[:].grid_ggd[:].space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
wall.description_ggd[:].grid_ggd[:].space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
wall.description_ggd[:].grid_ggd[:].space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_ggd[:].grid_ggd[:].space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_ggd[:].grid_ggd[:].space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_ggd[:].grid_ggd[:].space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
wall.description_ggd[:].grid_ggd[:].space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
wall.description_ggd[:].grid_ggd[:].space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_ggd[:].grid_ggd[:].space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
wall.description_ggd[:].grid_ggd[:].space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
wall.description_ggd[:].grid_ggd[:].time (alpha) |  | FLT_0D | s | Time
wall.description_ggd[:].type (alpha) |  | STRUCTURE |  | Type of wall: index = 0 for gas tight and 1 for a wall with holes/open ports
wall.description_ggd[:].type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_ggd[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
wall.description_ggd[:].type.name (alpha) |  | STR_0D |  | Short string identifier
wall.global_quantities (alpha) |  | STRUCTURE |  | Simple 0D description of plasma-wall interaction
wall.global_quantities.current_tor (alpha) | [wall.time] | FLT_1D (uncertain) | A | Toroidal current flowing in the vacuum vessel
wall.global_quantities.electrons (alpha) |  | STRUCTURE |  | Quantities related to electrons
wall.global_quantities.electrons.gas_puff (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Gas puff rate (in equivalent electrons)
wall.global_quantities.electrons.particle_flux_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Particle flux from the plasma (in equivalent electrons)
wall.global_quantities.electrons.particle_flux_from_wall (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | s^-1 | Particle flux from the wall corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast), in equivalent electrons
wall.global_quantities.electrons.power_inner_target (alpha) | [wall.time] | FLT_1D (uncertain) | W | Electron power on the inner target
wall.global_quantities.electrons.power_outer_target (alpha) | [wall.time] | FLT_1D (uncertain) | W | Electron power on the inner target
wall.global_quantities.electrons.pumping_speed (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Pumped particle flux (in equivalent electrons)
wall.global_quantities.neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the various neutral species
wall.global_quantities.neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
wall.global_quantities.neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
wall.global_quantities.neutral[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
wall.global_quantities.neutral[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
wall.global_quantities.neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
wall.global_quantities.neutral[:].gas_puff (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Gas puff rate for that species
wall.global_quantities.neutral[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, CD4, ...)
wall.global_quantities.neutral[:].particle_flux_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Particle flux from the plasma for that species
wall.global_quantities.neutral[:].particle_flux_from_wall (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | s^-1 | Particle flux from the wall corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].pumping_speed (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Pumped particle flux for that species
wall.global_quantities.neutral[:].recycling_energy_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Energy recycling coefficient corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].recycling_particles_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Particle recycling coefficient corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].sputtering_chemical_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Effective coefficient of chemical sputtering for various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].sputtering_physical_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Effective coefficient of physical sputtering for various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].wall_inventory (alpha) | [wall.time] | FLT_1D (uncertain) | - | Wall inventory, i.e. cumulated exchange of neutral species between plasma and wall from t = 0, positive if a species has gone to the wall, for that species
wall.global_quantities.power_density_inner_target_max (alpha) | [wall.time] | FLT_1D (uncertain) | W | Maximum power density on the inner target
wall.global_quantities.power_density_outer_target_max (alpha) | [wall.time] | FLT_1D (uncertain) | W | Maximum power density on the outer target
wall.global_quantities.power_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | W | Power flowing from the plasma to the wall
wall.global_quantities.power_inner_target_ion_total (alpha) | [wall.time] | FLT_1D (uncertain) | W | Total ion (summed over ion species) power on the inner target
wall.global_quantities.power_to_cooling (alpha) | [wall.time] | FLT_1D (uncertain) | W | Power to cooling systems
wall.global_quantities.temperature (alpha) | [wall.time] | FLT_1D (uncertain) | K | Wall temperature
wall.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
wall.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
wall.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
wall.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
wall.ids_properties.occurrence |  | INT_0D |  |
wall.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
wall.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
wall.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
wall.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
wall.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
wall.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
wall.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
waves (alpha) |  |  |  | RF wave propagation and deposition. Note that current estimates in this IDS are a priori not taking into account synergies between multiple sources (a convergence loop with Fokker-Planck calculations is required to account for such synergies)
waves.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
waves.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
waves.code.library (alpha) | [1...N] | STRUCT_ARRAY |  | List of external libraries used by the code that has produced this IDS
waves.code.library[:].commit (alpha) |  | STR_0D |  | Unique commit reference of software
waves.code.library[:].name (alpha) |  | STR_0D |  | Name of software
waves.code.library[:].parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
waves.code.library[:].repository (alpha) |  | STR_0D |  | URL of software repository
waves.code.library[:].version (alpha) |  | STR_0D |  | Unique version (tag) of software
waves.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
waves.code.output_flag (alpha) | [waves.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
waves.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
waves.code.repository (alpha) |  | STR_0D |  | URL of software repository
waves.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
waves.coherent_wave (alpha) | [1...N] | STRUCT_ARRAY |  | Wave description for each frequency
waves.coherent_wave[:].beam_tracing (alpha) | [waves.coherent_wave[:].beam_tracing[:].time] | STRUCT_ARRAY |  | Beam tracing calculations, for various time slices
waves.coherent_wave[:].beam_tracing[:].beam (alpha) | [1...N] | STRUCT_ARRAY |  | Set of rays/beams describing the wave propagation
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field (alpha) |  | STRUCTURE |  | Electric field polarization of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel to magnetic field polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].beam_tracing[:].beam[:].electrons.power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].beam_tracing[:].beam[:].length (alpha) | [1...N] | FLT_1D (uncertain) | m | Ray/beam curvilinear length
waves.coherent_wave[:].beam_tracing[:].beam[:].position (alpha) |  | STRUCTURE |  | Position of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].position.phi (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | rad | Toroidal angle
waves.coherent_wave[:].beam_tracing[:].beam[:].position.psi (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | Wb | Poloidal flux
waves.coherent_wave[:].beam_tracing[:].beam[:].position.r (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m | Major radius
waves.coherent_wave[:].beam_tracing[:].beam[:].position.theta (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | rad | Poloidal angle
waves.coherent_wave[:].beam_tracing[:].beam[:].position.z (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m | Height
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm (alpha) |  | STRUCTURE |  | Normalised power flow
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm.parallel (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Normalized power flow in the direction parallel to the magnetic field
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm.perpendicular (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Normalized power flow in the direction perpendicular to the magnetic field
waves.coherent_wave[:].beam_tracing[:].beam[:].power_initial (alpha) |  | FLT_0D (uncertain) | W | Initial power in the ray/beam
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector (alpha) |  | STRUCTURE |  | Wave vector of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_r (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the major radius direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_tor (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the toroidal direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_z (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the vertical direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_parallel (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Parallel refractive index
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_perpendicular (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Perpendicular refractive index
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_tor (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | INT_1D |  | Toroidal wave number, contains a single value if varying_ntor = 1 to avoid useless repetition constant values
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.varying_n_tor (alpha) |  | INT_0D |  | Flag telling whether n_tor is constant along the ray path (0) or varying (1)
waves.coherent_wave[:].beam_tracing[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].full_wave (alpha) | [waves.coherent_wave[:].full_wave[:].time] | STRUCT_ARRAY |  | Solution by a full wave code, given on a generic grid description, for various time slices
waves.coherent_wave[:].full_wave[:].b_field (alpha) |  | STRUCTURE |  | Components of the wave magnetic field
waves.coherent_wave[:].full_wave[:].b_field.bi_normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of perpendicular (to the static magnetic field) wave magnetic field tangent to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].b_field.normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of wave magnetic field normal to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].b_field.parallel (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Parallel (to the static magnetic field) component of the wave magnetic field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.parallel[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field (alpha) |  | STRUCTURE |  | Components of the wave electric field
waves.coherent_wave[:].full_wave[:].e_field.bi_normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of perpendicular (to the static magnetic field) wave electric field tangent to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.minus (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Right hand circularly polarised component of the perpendicular (to the static magnetic field) electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.minus[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.minus[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.minus[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.minus[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.minus[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of wave electric field normal to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.parallel (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Parallel (to the static magnetic field) component of electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.parallel[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.plus (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Left hand circularly polarised component of the perpendicular (to the static magnetic field) electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.plus[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.plus[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.plus[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.plus[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.plus[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].grid (alpha) |  | STRUCTURE |  | Grid description
waves.coherent_wave[:].full_wave[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].jacobian (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier 0) unspecified : unspecified 1) nodes : All nodes (0D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure). In case of a structured grid represented with multiple 1D spaces, the order of the implicit elements in the grid_subset follows Fortran ordering, i.e. iterate always on nodes of the first space first, then move to the second node of the second space, ... : [((s1_1 to s1_end), s2_1, s3_1 ... sN_1), (((s1_1 to s1_end), s2_2, s3_1, ... sN_1)), ... ((s1_1 to s1_end), s2_end, s3_end ... sN_end)] 2) edges : All edges (1D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 3) x_aligned_edges : All x-aligned (poloidally) aligned edges belonging to the associated spaces 4) y_aligned_edges : All y-aligned (radially) aligned edges belonging to the associated spaces 5) cells : All cells (2D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 6) x_points : Nodes defining x-points 7) core_cut : y-aligned edges inside the separatrix connecting to the active x-point 8) PFR_cut : y-aligned edges in the private flux region connecting to the active x-point 9) outer_throat : y-aligned edges in the outer SOL connecting to the active x-point 10) inner_throat : y-aligned edges in the inner SOL connecting to the active x-point 11) outer_midplane : y-aligned edges connecting to the node closest to outer midplane on the separatrix 12) inner_midplane : y-aligned edges connecting to the node closest to inner midplane on the separatrix 13) outer_target : y-aligned edges defining the outer target 14) inner_target : y-aligned edges defining the inner target 15) core_boundary : Innermost x-aligned edges 16) separatrix : x-aligned edges defining the active separatrix 17) main_chamber_wall : x-aligned edges defining main chamber wall outside of the divertor regions 18) outer_baffle : x-aligned edges defining the chamber wall of the outer active divertor region 19) inner_baffle : x-aligned edges defining the chamber wall of the inner active divertor region 20) outer_PFR_wall : x-aligned edges defining the private flux region wall of the outer active divertor region 21) inner_PFR_wall : x-aligned edges defining the private flux region wall of the inner active divertor region 22) core : Cells inside the active separatrix 23) sol : Cells defining the main SOL outside of the divertor regions 24) outer_divertor : Cells defining the outer divertor region 25) inner_divertor : Cells defining the inner divertor region 26) core_sol : x-aligned edges defining part of active separatrix separating core and sol 27) full_main_chamber_wall : main_chamber_wall + outer_baffle(s) + inner_baffle(s) 28) full_PFR_wall : outer_PFR__wall(s) + inner_PFR_wall(s) 29) core_cut_X2 : y-aligned edges inside the separatrix connecting to the non-active x-point 30) PFR_cut_X2 : y-aligned edges in the private flux region connecting to the non-active x-point 31) outer_throat_X2 : y-aligned edges in the outer SOL connecting to the non-active x-point 32) inner_throat_X2 : y-aligned edges in the inner SOL connecting to the non-active x-point 33) separatrix_2 : x-aligned edges defining the non-active separatrix 34) outer_baffle_2 : x-aligned edges defining the chamber wall of the outer non-active divertor region 35) inner_baffle_2 : x-aligned edges defining the chamber wall of the inner non-active divertor region 36) outer_PFR_wall_2 : x-aligned edges defining the private flux region wall of the outer non-active divertor region 37) inner_PFR_wall_2 : x-aligned edges defining the private flux region wall of the inner non-active divertor region 38) intra_sep : Cells between the two separatrices 39) outer_divertor_2 : Cells defining the outer inactive divertor region 40) inner_divertor_2 : Cells defining the inner inactive divertor region 41) outer_target_2 : y-aligned edges defining the outer inactive target 42) inner_target_2 : y-aligned edges defining the inner inactive target 43) volumes : All volumes (3D) belonging to the associated spaces, implicit declaration (no need to replicate the grid elements in the grid_subset structure) 101) outer_mid_plane_separatrix : Point on active separatrix at outer mid-plane 102) inner_mid_plane_separatrix : Point on active separatrix at inner mid-plane 103) outer_target_separatrix : Point on active separatrix at outer active target 104) inner_target_separatrix : Point on active separatrix at inner active target 105) outer_target_separatrix_2 : Point on non-active separatrix at outer non-active target 106) inner_target_separatrix_2 : Point on non-active separatrix at inner non-active target
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.jacobian (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier 0) unspecified : unspecified 1) linear : Linear 2) cylinder : Cylindrical geometry (straight in axial direction) 3) limiter : Limiter 4) SN : Single null 5) CDN : Connected double null 6) DDN_bottom : Disconnected double null with inner X-point below the midplane 7) DDN_top : Disconnected double null with inner X-point above the midplane 8) annulus : Annular geometry (not necessarily with straight axis) 9) stellarator_island : Stellarator island geometry 10) structured_spaces : Structured grid represented with multiple spaces of dimension 1
waves.coherent_wave[:].full_wave[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].full_wave[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
waves.coherent_wave[:].full_wave[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therefore defines the dimension of the space. The meaning of these predefined integer constants can be found in the Data Dictionary under utilities/coordinate_identifier.xml
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.space[:].identifier (alpha) |  | STRUCTURE |  | Space identifier 0) unspecified : unspecified 1) primary_standard : Primary space defining the standard grid 2) primary_staggered : Primary space defining a grid staggered with respect to the primary standard space
waves.coherent_wave[:].full_wave[:].grid.space[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.space[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].full_wave[:].grid.space[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
waves.coherent_wave[:].full_wave[:].k_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Perpendicular wave vector, given on various grid subsets
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].k_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].global_quantities (alpha) | [waves.coherent_wave[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities for various time slices
waves.coherent_wave[:].global_quantities[:].current_tor (alpha) |  | FLT_0D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources)
waves.coherent_wave[:].global_quantities[:].current_tor_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources) per toroidal mode number
waves.coherent_wave[:].global_quantities[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].global_quantities[:].electrons.distribution_assumption (alpha) |  | INT_0D |  | Assumption on the distribution function used by the wave solver to calculate the power deposition on this species: 0 = Maxwellian (linear absorption); 1 = quasi-linear (F given by a distributions IDS).
waves.coherent_wave[:].global_quantities[:].electrons.power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].electrons.power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].electrons.power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].electrons.power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Wave frequency
waves.coherent_wave[:].global_quantities[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].global_quantities[:].ion[:].distribution_assumption (alpha) |  | INT_0D |  | Assumption on the distribution function used by the wave solver to calculate the power deposition on this species: 0 = Maxwellian (linear absorption); 1 = quasi-linear (F given by a distributions IDS).
waves.coherent_wave[:].global_quantities[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].global_quantities[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].global_quantities[:].ion[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].ion[:].power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].ion[:].power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].global_quantities[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].global_quantities[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].global_quantities[:].power (alpha) |  | FLT_0D (uncertain) | W | Total absorbed wave power
waves.coherent_wave[:].global_quantities[:].power_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Absorbed wave power per toroidal mode number
waves.coherent_wave[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the coherent wave, in terms of the type and name of the antenna driving the wave and an index separating waves driven by the same antenna.
waves.coherent_wave[:].identifier.antenna_name (alpha) |  | STR_0D |  | Name of the antenna that launches this wave. Corresponds to the name specified in antennas/ec(i)/name, or antennas/ic(i)/name or antennas/lh(i)/name (depends of antenna/wave type) in the ANTENNAS IDS.
waves.coherent_wave[:].identifier.index_in_antenna (alpha) |  | INT_0D |  | Index of the wave (starts at 1), separating different waves generated from a single antenna.
waves.coherent_wave[:].identifier.type (alpha) |  | STRUCTURE |  | Wave/antenna type. index=1 for name=EC; index=2 for name=IC; index=3 for name=LH 0) unspecified : unspecified 1) EC : Wave field for electron cyclotron heating and current drive 2) LH : Wave field for lower hybrid heating and current drive 3) IC : Wave field for ion cyclotron frequency heating and current drive
waves.coherent_wave[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].profiles_1d (alpha) | [waves.coherent_wave[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source radial profiles (flux surface averaged quantities) for various time slices
waves.coherent_wave[:].profiles_1d[:].current_parallel_density (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Flux surface averaged wave driven parallel current density = average(j.B) / B0, where B0 = vacuum_toroidal_field/b0.
waves.coherent_wave[:].profiles_1d[:].current_parallel_density_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | A.m^-2 | Flux surface averaged wave driven parallel current density, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].current_tor_inside (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Wave driven toroidal current, inside a flux surface
waves.coherent_wave[:].profiles_1d[:].current_tor_inside_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | A | Wave driven toroidal current, inside a flux surface, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].n_tor] | STRUCT_ARRAY |  | Components of the electric field per toroidal mode number, averaged over the flux surface, where the averaged is weighted with the power deposition density, such that e_field = ave(e_field.power_density) / ave(power_density)
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
waves.coherent_wave[:].profiles_1d[:].grid.area (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
waves.coherent_wave[:].profiles_1d[:].grid.psi (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
waves.coherent_wave[:].profiles_1d[:].grid.psi_boundary (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the plasma boundary (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
waves.coherent_wave[:].profiles_1d[:].grid.psi_magnetic_axis (alpha) |  | FLT_0D (uncertain) | Wb | Value of the poloidal magnetic flux at the magnetic axis (useful to normalize the psi array values when the radial grid doesn't go from the magnetic axis to the plasma boundary)
waves.coherent_wave[:].profiles_1d[:].grid.rho_pol_norm (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Normalised poloidal flux coordinate = sqrt((psi(rho)-psi(magnetic_axis)) / (psi(LCFS)-psi(magnetic_axis)))
waves.coherent_wave[:].profiles_1d[:].grid.rho_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
waves.coherent_wave[:].profiles_1d[:].grid.surface (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
waves.coherent_wave[:].profiles_1d[:].grid.volume (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
waves.coherent_wave[:].profiles_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].profiles_1d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].profiles_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].profiles_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].profiles_1d[:].k_perpendicular (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | V.m^-1 | Perpendicular wave vector, averaged over the flux surface, where the averaged is weighted with the power deposition density, such that k_perpendicular = ave(k_perpendicular.power_density) / ave(power_density), for every flux surface and every toroidal number
waves.coherent_wave[:].profiles_1d[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].profiles_1d[:].power_density (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged total absorbed wave power density (electrons + ion + fast populations)
waves.coherent_wave[:].profiles_1d[:].power_density_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].power_inside (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total absorbed wave power (electrons + ion + fast populations) inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].power_inside_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Total absorbed wave power (electrons + ion + fast populations) inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].profiles_2d (alpha) | [waves.coherent_wave[:].profiles_2d[:].time] | STRUCT_ARRAY |  | 2D profiles in poloidal cross-section, for various time slices
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor (alpha) | [waves.coherent_wave[:].profiles_2d[:].n_tor] | STRUCT_ARRAY |  | Components of the electric field per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].grid (alpha) |  | STRUCTURE |  | 2D grid in a poloidal cross-section
waves.coherent_wave[:].profiles_2d[:].grid.area (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m^2 | Cross-sectional area of the flux surface
waves.coherent_wave[:].profiles_2d[:].grid.psi (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | Wb | Poloidal magnetic flux
waves.coherent_wave[:].profiles_2d[:].grid.r (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Major radius
waves.coherent_wave[:].profiles_2d[:].grid.rho_tor (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
waves.coherent_wave[:].profiles_2d[:].grid.rho_tor_norm (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
waves.coherent_wave[:].profiles_2d[:].grid.theta_geometric (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | rad | Geometrical poloidal angle
waves.coherent_wave[:].profiles_2d[:].grid.theta_straight (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | rad | Straight field line poloidal angle
waves.coherent_wave[:].profiles_2d[:].grid.type (alpha) | [waves.coherent_wave[:].profiles_2d[:].grid.rho_tor_norm] | STRUCTURE | m^3 | Grid type: index=0: Rectangular grid in the (R,Z) coordinates; index=1: Rectangular grid in the (radial, theta_geometric) coordinates; index=2: Rectangular grid in the (radial, theta_straight) coordinates. index=3: unstructured grid.
waves.coherent_wave[:].profiles_2d[:].grid.type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].profiles_2d[:].grid.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].profiles_2d[:].grid.type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].profiles_2d[:].grid.volume (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
waves.coherent_wave[:].profiles_2d[:].grid.z (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Height
waves.coherent_wave[:].profiles_2d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].profiles_2d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].atoms_n (alpha) |  | INT_0D |  | Number of atoms of this element in the molecule
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].multiplicity (obsolescent) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].profiles_2d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].profiles_2d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].profiles_2d[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].profiles_2d[:].power_density (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Total absorbed wave power density (electrons + ion + fast populations)
waves.coherent_wave[:].profiles_2d[:].power_density_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].wave_solver_type (alpha) |  | STRUCTURE |  | Type of wave deposition solver used for this wave. Index = 1 for beam/ray tracing; index = 2 for full wave
waves.coherent_wave[:].wave_solver_type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].wave_solver_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list). Private identifier values must be indicated by a negative index.
waves.coherent_wave[:].wave_solver_type.name (alpha) |  | STR_0D |  | Short string identifier
waves.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
waves.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
waves.ids_properties.creation_date (alpha) |  | STR_0D |  | Date at which this data has been produced
waves.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | This node must be filled (with 0, 1, or 2) for the IDS to be valid. If 1, the time of this IDS is homogeneous, i.e. the time values for this IDS are stored in the time node just below the root of this IDS. If 0, the time values are stored in the various time fields at lower levels in the tree. In the case only constant or static nodes are filled within the IDS, homogeneous_time must be set to 2
waves.ids_properties.occurrence |  | INT_0D |  |
waves.ids_properties.provider (alpha) |  | STR_0D |  | Name of the person in charge of producing this data
waves.ids_properties.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
waves.ids_properties.version_put (alpha) |  | STRUCTURE |  | Version of the access layer package used to PUT this IDS
waves.ids_properties.version_put.access_layer (alpha) |  | STR_0D |  | Version of Access Layer used to PUT this IDS
waves.ids_properties.version_put.access_layer_language (alpha) |  | STR_0D |  | Programming language of the Access Layer high level API used to PUT this IDS
waves.ids_properties.version_put.data_dictionary (alpha) |  | STR_0D |  | Version of Data Dictionary used to PUT this IDS
waves.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
waves.magnetic_axis.r (alpha) | [waves.time] | FLT_1D (uncertain) | m | Major radius
waves.magnetic_axis.z (alpha) | [waves.time] | FLT_1D (uncertain) | m | Height
waves.time (alpha) | [1...N] | FLT_1D_TYPE | s | Generic time
waves.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
waves.vacuum_toroidal_field.b0 (alpha) | [waves.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewing from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
waves.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)